<?php
namespace Teknisa\OPL\Controllers;

use \Setforms2\Shared\ORM\DateTime;

class ContaPagar {

    protected $contaPagarService;
    
    public function __construct($contaPagarService) {
        $this->contaPagarService = $contaPagarService;
    }
    
    public function excluiNFContaPagar($cdfildest, $cdfillanc, $nrautoforn, $orcamentoFinanceiro, $empresa = '') {
        try {
            $this->contaPagarService->proceExcluiContaPagarPrevista($cdfildest, $cdfillanc, $nrautoforn);
            
            if($orcamentoFinanceiro) {
                $idgercontpgt = $this->contaPagarService->retornaGeraContaPagarFornecedor($cdfildest, $cdfillanc, $nrautoforn);
                
                if($idgercontpgt) {
                    $cdclassfina = self::verificaClassificacaoFinanceira($cdfildest, $cdfillanc, $nrautoforn);
                    
                    if(isset($cdclassfina)) {
                        $autoForne = $this->contaPagarService->retornaAutoforneContaPagar($cdfildest, $cdfillanc, $nrautoforn);
                        
                        $paramsProceCriaVencimento = array(
                            "CDFILDEST"     =>  $cdfildest,
                            "CDFILLANC"     =>  $cdfillanc,
                            "NRAUTOFORN"    =>  $nrautoforn
                        );
                        
                        $paramsProceOrcamentoOk = array(
                            'CDEMPRESA'     => $empresa ? $empresa : $autoForne[0]['CDEMPRESA'],
                            'CDCLASSFINA'   => $cdclassfina
                        );
                        
                        foreach($autoForne as $af) {
                            $paramsProceCriaVencimento['VRTOTAL_REST'] = $af['VRTOTAL_REST'];
                            $paramsProceCriaVencimento['DTPROGENTAF']  = substr($af["DTPROGENTAF"], 0, 10);
                            
                            $this->contaPagarService->proceCriaVencimento($paramsProceCriaVencimento);
                            /**
                             * 26/04/2019 - Foi definido que, para este processo, os parâmetros tem a seguinte equivalência:
                             * ---------------------------------
                             * | Tabela          |    AF       |
                             * ---------------------------------
                             * | CDFILIALVENC    =  CDFILDEST  |
                             * | NRLANCTONFVENC  =  NRAUTOFORN |
                             * ---------------------------------
                             */
                            $trabVencimento = $this->contaPagarService->retornaTrabVencimento($cdfildest, $nrautoforn);
                            
                            $orcamentoNaoEstaOk;
                            
                            foreach($trabVencimento as $trabVenc) {
                                $paramsProceOrcamentoOk['CDFILIAL']      = $trabVenc['CDFILIALVENC'];
                                $paramsProceOrcamentoOk['DTLANCAMENTO']  = $trabVenc['DTVENCIMENTO'];
                                $paramsProceOrcamentoOk['VRVALOR']       = $trabVenc['VRVENCIMENTO'];
                                
                                $retornoProceOrcamento = $this->contaPagarService->proceOrcamentoOk($paramsProceOrcamentoOk);
                                
                                $orcamentoNaoEstaOk = !self::isOrcamentoOk($retornoProceOrcamento);
                                
                                if ($orcamentoNaoEstaOk) {
                                 //   $paramsProceOrcamentoOk['VRVALOR'] = -$trabVenc['VRVENCIMENTO'];
                                 //   $this->contaPagarService->proceOrcamentoOk($paramsProceOrcamentoOk);
                                    break;
                                }
                            }
                            
                            $this->contaPagarService->deletaTrabVencimento($cdfildest, $nrautoforn);
                            
                            if ($orcamentoNaoEstaOk) {
                                return false;
                                break;
                            }
                        }
                        
                        /*if ($orcamentoNaoEstaOk) {
                            foreach($autoForne as $af) {
                                $paramsProceCriaVencimento['VRTOTAL_REST'] = $af['VRTOTAL_REST'];
                                $paramsProceCriaVencimento['DTPROGENTAF'] = substr($af["DTPROGENTAF"], 0, 10);
                                
                                $this->contaPagarService->proceCriaVencimento($paramsProceCriaVencimento);
                                
                                $trabVencimento = $this->contaPagarService->retornaTrabVencimento($cdfildest, $nrautoforn);
                                
                                foreach($trabVencimento as $trabVenc) {
                                    $paramsProceOrcamentoOk['CDFILIAL']      = $trabVenc['CDFILIALVENC'];
                                    $paramsProceOrcamentoOk['DTLANCAMENTO']  = $trabVenc['DTVENCIMENTO'];
                                    $paramsProceOrcamentoOk['VRVALOR']       = -$trabVenc['VRVENCIMENTO'];
                                    
                                    $this->contaPagarService->proceOrcamentoOk($paramsProceOrcamentoOk);
                                }
                            }
                            
                            return false;
                        }*/
                        
                    }
                }
            }
            return true;
        
        } catch(\Exception $e) {
            throw new \Exception($e->getMessage(), 10);
        }
    }
    
    public function verificaClassificacaoFinanceira($cdfildest, $cdfillanc, $nrautoforn) {
        
        $classificacaoFinanceira = $this->contaPagarService->retornaClassificacaoFinanceira($cdfildest, $cdfillanc, $nrautoforn);
        $cdclassfina = $classificacaoFinanceira ? $classificacaoFinanceira['CDCLASSFINA'] : false;
        
        if(!$cdclassfina) {
            
            $cdtipooper = $this->contaPagarService->retornaTipoOper($cdfildest);
            
            $classificacaoTipoOperador = $this->contaPagarService->retornaClassificacaoTipoOperador($cdtipooper);
            $cdclassfina = $classificacaoTipoOperador ? $classificacaoTipoOperador['CDCLASSFINA'] : false;
            
        }
        
        return $cdclassfina;
        
    }
    
    
    public function geraNFContaPagar($cdfildest, $cdfillanc, $nrautoforn) {
        $this->contaPagarService->proceGeraContaPagarPrevista($cdfildest, $cdfillanc, $nrautoforn);
    }
    
    /**
     * A procedure avalia essa condição e a retorna em forma de números.
     * 0 - Erro.
     * 1 - Ok.
     */
    public function isOrcamentoOk($retornoProceOrcamento) {
        return $retornoProceOrcamento['P_RESULTADO'] == 1;
    }
    
    private function dateToDateTime($date) {

        $explode = explode('/', $date);

        return new DateTime($explode[2].'-'.$explode[1].'-'.$explode[0]);
    }
    
    public function retornaVencimentos($cdfildest, $cdfillanc, $nrautoforn, $newEmpresa = null, $newClassFina = null)
    {
        $trabVencimento = array();
        $autoForne = $this->contaPagarService->retornaAutoforneContaPagar($cdfildest, $cdfillanc, $nrautoforn);
        
        $paramsProceCriaVencimento = array(
            "CDFILDEST"     =>  $cdfildest,
            "CDFILLANC"     =>  $cdfillanc,
            "NRAUTOFORN"    =>  $nrautoforn
        );
        
        foreach($autoForne as $af) {
            $paramsProceCriaVencimento['VRTOTAL_REST'] = $af['VRTOTAL_REST'];
            $paramsProceCriaVencimento['DTPROGENTAF']  = substr($af["DTPROGENTAF"], 0, 10);
            
            $this->contaPagarService->proceCriaVencimento($paramsProceCriaVencimento);
            
            $trabVencimento = array_merge($trabVencimento, $this->contaPagarService->retornaTrabVencimento($cdfildest, $nrautoforn));
            
            $this->contaPagarService->deletaTrabVencimento($cdfildest, $nrautoforn);
            
        }
        
        $params = array(
            'CDEMPRESA'     => ($newEmpresa && $newClassFina) ? $newEmpresa : $autoForne[0]['CDEMPRESA'],
            'CDCLASSFINA'   => ($newEmpresa && $newClassFina) ? $newClassFina : self::verificaClassificacaoFinanceira($cdfildest, $cdfillanc, $nrautoforn)
        );
        
        foreach($trabVencimento as &$row) {
            $dtVencimento = $this->dateToDateTime(substr($row['DTVENCIMENTO'], 0, 10));
            
            //First day of month
            $dtVencimento->modify('first day of this month');
            $firstday = $dtVencimento->format('d/m/Y');
            
            //Last day of month
            $dtVencimento->modify('last day of this month');
            $lastday = $dtVencimento->format('d/m/Y');
            
            $orcaFina = $this->contaPagarService->getOrcaFina($params, $cdfildest, $firstday, $lastday);
            
            $row['VRREALORCA']   = $orcaFina['VRREALORCA'];
            $row['VRORCAFINA']   = $orcaFina['VRORCAFINA'];
            $row['VREXTOLEORCA'] = $orcaFina['VREXTOLEORCA'];
            $row['DTORCAFINA']   = substr($orcaFina['DTORCAFINA'], 0, 10);
            $row['IDREMANEJA']   = 'N';
        }
        
        return $trabVencimento;
    }
}
   