/* Sistemas Integrados TECNISA
   Planejamento Alimentao Industrial

Nome: 7100_PLASTP_CONSUMO_PLANEJADO_PLA.SQL

Descrio:
Clculo do Consumo Planejado (Cardpio, Consumo por Servio Fixo ou
Percapita) e gravao na tabela CONSPLAN ou PREVRETI.

P_FILIAL       - Codigo da Filial
P_SERVICOS     - String contendo sequencia de Servios a serem calculados
P_DTINICIAL    - Data inicial
P_DTFINAL      - Data final
P_IDARQUIVO    - Identificador da tabela a ser gravada
                 "P" -> PREVRETI
                 "C" -> CONSPLAN
                 "A" -> AMBAS
P_IDPRODUTOS   - Identificador dos produtos a serem gravados.
                 Formato "XXX"
                 1 posio = "C" -> Cardpio
                 2 posio = "F" -> Consumo por Servio Fixo
                 3 posio = "P" -> Consumo por Servio Percapita
P_IDSEPPRATO   - Identificador de requisio analtica, ou seja, separada
                 por prato ou por setor, consumo fixo e consumo percapita.
                 Formato "S" (setor), "P" (prato) ou "N" (n/a).
P_PEACRESCIMO  - Percentual de acrscimo
P_IDARREDOND   - Identificador de utilizao do arredondamento
                 para requisio do Produto. Formato
                    S - ARREDONDAMENTO DE REQUISIO
                    N - NAO ARREDONDAR
                    C - ARREDONDAMENTO DE COMPRAS
P_NRCONSPLAN   - Nmero sequencial a ser utilizado para gravao dos dados
P_CDPRODUTOINI - Cdigo do Produto inicial
P_CDPRODUTOFIN - Cdigo do Produto final
P_CDOPERADOR   - Cdigo do Operador
P_STDTINICIAL  - Lista de data inicial em string por servio
P_STDTFINAL    - Lista de data final em string por servio

Observao: o formato das strings de data inicial e de data final deve ser
"_YYYYMMDD_YYYYMMDD_YYYYMMDD_"
"_YYYYMMDD_YYYYMMDD_YYYYMMDD_"

*/


IF EXISTS (SELECT * FROM SYSOBJECTS O, SYSUSERS U
                    WHERE
	        O.NAME = 'CONSUMO_PLANEJADO_PLA'  AND
	        TYPE = 'P' 		          AND
	        U.UID = O.UID                     AND
	        U.NAME = USER)
  DROP PROCEDURE CONSUMO_PLANEJADO_PLA
  GO

 
CREATE PROCEDURE CONSUMO_PLANEJADO_PLA
   @P_FILIAL       VARCHAR(4),
   @P_SERVICOS     VARCHAR(4000),
   @P_DTINICIAL    DATETIME,
   @P_DTFINAL      DATETIME,
   @P_IDARQUIVO    VARCHAR(1),
   @P_IDPRODUTOS   VARCHAR(3),
   @P_IDSEPPRATO   VARCHAR(1),
   @P_PEACRESCIMO  NUMERIC(15,6),
   @P_IDARREDOND   VARCHAR(1),
   @P_NRCONSPLAN   VARCHAR(10),
   @P_CDPRODUTOINI VARCHAR(10),
   @P_CDPRODUTOFIN VARCHAR(10),
   @P_CDOPERADOR   VARCHAR(12),	
   @P_STDTINICIAL  VARCHAR(2000) = NULL,
   @P_STDTFINAL    VARCHAR(2000) = NULL
AS

   DECLARE @V_CONSSERV       INT;

   DECLARE @V_DTINICIAL       DATETIME;
   DECLARE @V_DTFINAL         DATETIME;
   DECLARE @V_COUNTSERVICO    INT;
   DECLARE @V_ARRED           NUMERIC(15, 6);

   DECLARE @V_CDFILIAL        VARCHAR(4);
   DECLARE @V_CDSERVFILI      VARCHAR(4000);

   DECLARE @V_IDCARDAPIO      VARCHAR(1);
   DECLARE @V_IDCONSFIXO      VARCHAR(1);
   DECLARE @V_IDCONSPERC      VARCHAR(1);
   DECLARE @V_IDCONSPENT      VARCHAR(1); 
   DECLARE @V_IDTPCONSSERV    VARCHAR(1);
   DECLARE @V_DTLIMITE        DATETIME;
   DECLARE @V_HRLIMITE        VARCHAR(4);
   DECLARE @V_CDARVPROD       VARCHAR(20);
   DECLARE @V_TAM_MASCARA     NUMERIC;


   DECLARE @V_CDFAPRATCPLA    VARCHAR(4);
   DECLARE @V_CDPRATCONSPL    VARCHAR(10);
   DECLARE @V_CDSETOCONSPL    VARCHAR(2);
   DECLARE @V_CDTPPRATCPLA    VARCHAR(2);
   DECLARE @V_SGUNIDADE       VARCHAR(10);

   DECLARE @V_IDUTILFATCOR    VARCHAR(1);
   DECLARE @V_IDUTILFATCOC    VARCHAR(1);
   DECLARE @V_IDTIPCALCFAT    VARCHAR(1);

   DECLARE @V_CDSETCONFIXO    VARCHAR(2);
   DECLARE @V_CDSETCONPERC    VARCHAR(2);

   DECLARE @V_QTCOMESTICAR    DOUBLE PRECISION;
   DECLARE @V_QTESTITURNO1    NUMERIC(10,3);
   DECLARE @V_QTESTITURNO2    NUMERIC(10,3);
   DECLARE @V_QTESTITURNO3    NUMERIC(10,3);
   DECLARE @V_QTESTITURNO4    NUMERIC(10,3);

   DECLARE @V_QTDEAUX         NUMERIC(15,6);

   DECLARE @V_QTPRATO         NUMERIC(15,6);
   DECLARE @V_FERIADO         NUMERIC;
   DECLARE @V_CONTTURNO       NUMERIC;
   DECLARE @V_CONTTURNCARD    NUMERIC;

   DECLARE @V_QTPREV          NUMERIC(15,6);
   DECLARE @V_QTPREV1         NUMERIC(15,6);
   DECLARE @V_QTPREV2         NUMERIC(15,6);
   DECLARE @V_QTPREV3         NUMERIC(15,6);
   DECLARE @V_QTPREV4         NUMERIC(15,6);
   DECLARE @V_PEACRESCIMO     NUMERIC(15,6);
   DECLARE @V_PEACRESCIMO1    NUMERIC(15,6);
   DECLARE @V_PEACRESCIMO2    NUMERIC(15,6);
   DECLARE @V_PEACRESCIMO3    NUMERIC(15,6);
   DECLARE @V_PEACRESCIMO4    NUMERIC(15,6);


   /* ---------- VARIVEIS QUE CONTERO OS CURSORES E OS REGISTROS --------------- */
   /*CUR_CONSPLAN      UTIL_CONSPLAN.CONSPLAN_CURTYPE;
   REC_CONSPLAN      UTIL_CONSPLAN.CONSPLAN_RECTYPE; */

   DECLARE @V_REC_DTDATA       DATETIME;
   DECLARE @V_REC_CDSERVFILI   VARCHAR(5);
   DECLARE @V_REC_HRINICATEN   VARCHAR(4);
   DECLARE @V_REC_NRCARDAPIO   VARCHAR(10);
   DECLARE @V_REC_CDCLIENTE    VARCHAR(21);
   DECLARE @V_REC_CDDESTFILI   VARCHAR(3);
   DECLARE @V_REC_QTCOMESTICAR DOUBLE PRECISION;
   DECLARE @V_REC_QTESTITURNO1 DOUBLE PRECISION;
   DECLARE @V_REC_QTESTITURNO2 DOUBLE PRECISION;
   DECLARE @V_REC_QTESTITURNO3 DOUBLE PRECISION;
   DECLARE @V_REC_QTESTITURNO4 DOUBLE PRECISION;
   DECLARE @V_REC_QTBRUTAUNR   DOUBLE PRECISION; 
   /*CUR_COMPCARD      UTIL_CONSPLAN.COMPCARD_CURTYPE;
   REC_COMPCARD      UTIL_CONSPLAN.COMPCARD_RECTYPE;*/
   DECLARE @V_REC_CDFILAUXPRAT VARCHAR(4);
   DECLARE @V_REC_CDPRATO      VARCHAR(10);
   DECLARE @V_REC_VRPECONSCARD FLOAT;
   /*DECLARE @V_REC_NRSEQPRATCAR SMALLINT;*/
   DECLARE @V_REC_CDTIPOPRAT   VARCHAR(2);
   DECLARE @V_REC_CDSETORCOZ   VARCHAR(2);

   /*CUR_PRODPRAT      UTIL_CONSPLAN.PRODPRAT_CURTYPE;
   REC_PRODPRAT      UTIL_CONSPLAN.PRODPRAT_RECTYPE;*/
   DECLARE @V_REC_CDPRODUTO      VARCHAR(10);
   DECLARE @V_REC_QTPRODUTO      NUMERIC(15,6);
   DECLARE @V_REC_SGUNIDADE    VARCHAR(10);
   DECLARE @V_VRPEFATCOC         NUMERIC(10,4);
   DECLARE @V_VRPEFATCOR         NUMERIC(10,3);
   DECLARE @V_REC_HRTEMPPREP     VARCHAR(5);
   DECLARE @V_REC_CDAPRERECE     VARCHAR(3);
   DECLARE @V_REC_QTCOMPLPROD    NUMERIC(15,6);

   /*CUR_CONSSERV      UTIL_CONSPLAN.CONSSERV_CURTYPE;
   REC_CONSSERV      UTIL_CONSPLAN.CONSSERV_RECTYPE;*/
   DECLARE @V_REC_CONS_CDFILIAL       VARCHAR(4);
   DECLARE @V_REC_CONS_CDSERVFILI     VARCHAR(5);
   DECLARE @V_REC_CONS_DTCONSSERV     DATETIME;
   DECLARE @V_REC_CONS_CDPRODUTO      VARCHAR(10);
   DECLARE @V_REC_CONS_QTCONSSERV     NUMERIC(12,5);
   DECLARE @V_REC_CONS_IDQTDECONS     VARCHAR(1);
   
   /*CUR_ARREDOND      UTIL_CONSPLAN.ARREDOND_CURTYPE;
   REC_ARREDOND      UTIL_CONSPLAN.ARREDOND_RECTYPE;*/
   DECLARE @V_REC_ARR_NRREQUCONS   VARCHAR(10);
   DECLARE @V_REC_ARR_CDFILIAL     VARCHAR(4);
   DECLARE @V_REC_ARR_CDSERVFILI   VARCHAR(5);
   DECLARE @V_REC_ARR_DTDATA       DATETIME;
   DECLARE @V_REC_ARR_IDTIPOCONS   VARCHAR(01);
   DECLARE @V_REC_ARR_CDFILAUXPRAT VARCHAR(4);
   DECLARE @V_REC_ARR_CDPRATO      VARCHAR(10);
   DECLARE @V_REC_ARR_CDPRODUTO    VARCHAR(10);
   DECLARE @V_REC_ARR_DTLIMITE     DATETIME;
   DECLARE @V_REC_ARR_HRLIMITE     VARCHAR(05);
   DECLARE @V_REC_ARR_CDTIPOPRAT   VARCHAR(2);
   DECLARE @V_REC_ARR_CDCLIENTE    VARCHAR(21);
   DECLARE @V_REC_ARR_CDDESTFILI   VARCHAR(3);

   DECLARE @V_REC_ARR_VRARREDREQ   NUMERIC(10,3);
   DECLARE @V_REC_ARR_VRARREDCMP   NUMERIC(10,3);
   DECLARE @V_REC_ARR_QTCOMENS     NUMERIC(15,6);
   DECLARE @V_REC_ARR_QTCOMENST1   NUMERIC(15,6);
   DECLARE @V_REC_ARR_QTCOMENST2   NUMERIC(15,6);
   DECLARE @V_REC_ARR_QTCOMENST3   NUMERIC(15,6);
   DECLARE @V_REC_ARR_QTCOMENST4   NUMERIC(15,6);

   DECLARE @V_CUR_CONSPLANSE_CDSERVFILI   VARCHAR(5);
   DECLARE @V_CUR_CONSPLANSE_DTCARDAPIO   DATETIME;
   DECLARE @V_CUR_CONSPLANSE_CDFILAUXPRAT VARCHAR(4);
   DECLARE @V_CUR_CONSPLANSE_CDTIPOPRAT   VARCHAR(2);
   DECLARE @V_CUR_CONSPLANSE_CDPRATO      VARCHAR(10);
   DECLARE @V_CUR_CONSPLANSE_QTCOMESTDIE  NUMERIC(15,6);
   DECLARE @V_CUR_CONSPLANSE_QTCOMESTICAR NUMERIC(15,6);

   DECLARE  @C_PREVRETI_CDFILICPLA   VARCHAR(4);
   DECLARE  @C_PREVRETI_CDSERVCPLA   VARCHAR(5);
   DECLARE  @C_PREVRETI_DTCONSPLAN   DATETIME;
   DECLARE  @C_PREVRETI_NRREQUEXTR   VARCHAR(10);
   DECLARE  @C_PREVRETI_IDCONSPLAN   VARCHAR(1);
   DECLARE  @C_PREVRETI_CDPRODCPLA   VARCHAR(10);
   DECLARE  @C_PREVRETI_DTLIMITECPLA DATETIME;
   DECLARE  @C_PREVRETI_HRLIMITECPLA VARCHAR(4);
   DECLARE  @C_PREVRETI_QTCONSPLAN   NUMERIC(15,6);
   DECLARE  @C_PREVRETI_QTCONSPLANT1 NUMERIC(15,6);
   DECLARE  @C_PREVRETI_QTCONSPLANT2 NUMERIC(15,6);
   DECLARE  @C_PREVRETI_QTCONSPLANT3 NUMERIC(15,6);
   DECLARE  @C_PREVRETI_QTCONSPLANT4 NUMERIC(15,6);
   DECLARE  @C_PREVRETI_QTCONSPLANSA NUMERIC(15,6);
   DECLARE  @C_PREVRETI_QTCONPLAT1SA NUMERIC(15,6);
   DECLARE  @C_PREVRETI_QTCONPLAT2SA NUMERIC(15,6);
   DECLARE  @C_PREVRETI_QTCONPLAT3SA NUMERIC(15,6);
   DECLARE  @C_PREVRETI_QTCONPLAT4SA NUMERIC(15,6);
   DECLARE  @C_PREVRETI_CDTPPRATCPLA VARCHAR(2);
   DECLARE  @C_PREVRETI_CDFAPRATCPLA VARCHAR(4);
   DECLARE  @C_PREVRETI_CDPRATCONSPL VARCHAR(10);
   DECLARE  @C_PREVRETI_QTBRUTACONS  NUMERIC(15,6);
   DECLARE  @C_PREVRETI_SGUNIDADE    VARCHAR(10);

   DECLARE @V_IDUTRETIPRAT VARCHAR(1);
   DECLARE @V_NRPRPREVRETI VARCHAR(4);
   DECLARE @V_CDTPRCONSFIX VARCHAR(2);
   DECLARE @V_CDFILCONSFIX VARCHAR(4);
   DECLARE @V_CDPRACONSFIX VARCHAR(10);
   DECLARE @V_CDTPRCONSPER VARCHAR(2);
   DECLARE @V_CDFILCONSPER VARCHAR(4);
   DECLARE @V_CDPRACONSPER VARCHAR(10);
   /*DECLARE @V_CONT_CONSPLANSE SMALLINT;*/
   DECLARE @V_SERV_ATUAL VARCHAR(5);
   DECLARE @V_DIASEMANA INT;

BEGIN
   /* --------------------- IDENTIFICADORES DE CLCULO ---------------------- */
   SET @V_IDCARDAPIO = SUBSTRING(@P_IDPRODUTOS, 1, 1);         /* CARDPIO          */
   SET @V_IDCONSFIXO = SUBSTRING(@P_IDPRODUTOS, 2, 1);         /* CONSUMO FIXO      */
   SET @V_IDCONSPERC = SUBSTRING(@P_IDPRODUTOS, 3, 1);         /* CONSUMO PERCAPITA */
   SET @V_IDUTRETIPRAT = 'N';                         /* UTILIZA RETIRADA POR PRATO */

   SELECT @V_CDTPRCONSFIX = MAX(CDTPRCONSFIX),
          @V_CDFILCONSFIX = MAX(CDFILCONSFIX),
          @V_CDPRACONSFIX = MAX(CDPRACONSFIX),
          @V_CDTPRCONSPER = MAX(CDTPRCONSPER),
          @V_CDFILCONSPER = MAX(CDFILCONSPER),
          @V_CDPRACONSPER = MAX(CDPRACONSPER)
   FROM PARAMPLANEJA
   WHERE CDFILIAL = @P_FILIAL;

   SELECT @V_TAM_MASCARA = LEN(CDPICTPRAT) - (A.NIVEL - 1)
   FROM PARAMGERAL, (SELECT MAX(CDNVPRATO) AS NIVEL FROM PRATO) A;

    /* --------------- INICIALIZACAO DO ARQUIVO PREVRETI E CONSPLANSE --------------- */
   SET @V_COUNTSERVICO = 2;
   DECLARE CUR_SERVICO CURSOR FOR
      SELECT
          CDFILIAL,
          CDSERVFILI
       FROM
          SERVICO
       WHERE
          (CDFILIAL = @P_FILIAL) AND
          (CHARINDEX(CDSERVFILI,@P_SERVICOS) > 0 OR @P_SERVICOS = 'T')
       ORDER BY
           CDSERVFILI;

   OPEN CUR_SERVICO;

   FETCH NEXT FROM CUR_SERVICO INTO  @V_CDFILIAL, @V_CDSERVFILI;

   WHILE (@@FETCH_STATUS = 0)
   BEGIN

      IF @P_STDTINICIAL IS NULL
      BEGIN
        SET @V_DTINICIAL  = @P_DTINICIAL;
        SET @V_DTFINAL    = @P_DTFINAL;
      END
      ELSE
      BEGIN

         SET @V_DTINICIAL  = CONVERT(DATETIME, SUBSTRING(@P_STDTINICIAL, @V_COUNTSERVICO, 8), 103);
         SET @V_DTFINAL    = CONVERT(DATETIME, SUBSTRING(@P_STDTFINAL, @V_COUNTSERVICO, 8), 103);

         IF DATALENGTH(@P_STDTINICIAL) > 10
         BEGIN
            SET @V_COUNTSERVICO = @V_COUNTSERVICO + 9;
         END;
      END;
      /*
      SET @V_CONT_CONSPLANSE = 0;
      SELECT
         @V_CONT_CONSPLANSE = COUNT(*)
      FROM
         CONSPLANSE
      WHERE
         NRCONSPLANSE = @P_NRCONSPLAN AND
         CDFILICPLASE = @V_CDFILIAL   AND
         CDSERVCPLASE  = @V_CDSERVFILI;
      IF @V_CONT_CONSPLANSE = 0 BEGIN

         INSERT INTO CONSPLANSE
            (NRCONSPLANSE,
             CDFILICPLASE,
             CDSERVCPLASE,
             DTINICCPLASE,
             DTFINACPLASE)
         VALUES
            (@P_NRCONSPLAN,
             @V_CDFILIAL,
             @V_CDSERVFILI,
             @V_DTINICIAL,
             @V_DTFINAL);
      END
      ELSE BEGIN

         UPDATE CONSPLANSE
            SET DTINICCPLASE = @V_DTINICIAL,
                DTFINACPLASE = @V_DTFINAL
         WHERE
            NRCONSPLANSE = @P_NRCONSPLAN AND
            CDFILICPLASE = @V_CDFILIAL   AND
            CDSERVCPLASE = @V_CDSERVFILI;

      END;
      */
      IF (@P_IDARQUIVO IN ('P','A')) AND (@V_IDCARDAPIO = 'C')
      BEGIN
         DELETE FROM PREVRETI
         WHERE
            (CDFILIAL   = @V_CDFILIAL)         AND
            (CDSERVFILI = @V_CDSERVFILI) AND
            (DTPREVRETI BETWEEN @P_DTINICIAL AND @P_DTFINAL) AND
            (NRREQUEXTR = '0000000000')      AND
            (IDPREVRETI = 'C');
      END;
      FETCH NEXT FROM CUR_SERVICO INTO  @V_CDFILIAL, @V_CDSERVFILI;
   END;
   CLOSE CUR_SERVICO;
   DEALLOCATE CUR_SERVICO;

   /* ----------------- CALCULO DOS PRODUTOS DOS CARDAPIOS ------------------ */
   IF (@V_IDCARDAPIO = 'C')
   BEGIN
      SELECT
         @V_IDUTILFATCOR = MAX(IDUTILFATCOR),
         @V_IDUTILFATCOC = MAX(IDUTILFATCOC),
         @V_IDTIPCALCFAT = MAX(IDTIPCALCFAT)
      FROM
         PARAMPLANEJA
      WHERE
         CDFILIAL = @P_FILIAL;

      IF @V_IDUTILFATCOC IS NULL
      BEGIN
         SET @V_IDUTILFATCOC = 'S';
      END;
      IF @V_IDUTILFATCOR IS NULL
      BEGIN
         SET @V_IDUTILFATCOR = 'S';
      END;
      IF @V_IDTIPCALCFAT IS NULL
      BEGIN
         SET @V_IDTIPCALCFAT = 'T';
      END;

      /* - Consumo do 'CARDAPIO' -------------------------------------------- */
      DECLARE CUR_CONSPLAN CURSOR FOR
      SELECT
         CA.DTCARDAPIO,
         CA.CDSERVFILI,
         LEFT(CONVERT(VARCHAR, SE.HRINICATEN) + REPLICATE('0', 4), 4) AS HRINICATEN,
         CA.NRCARDAPIO,
         'XXX' CDCLIENTE,
         'XXX' CDDESTFILI,
         CA.QTCOMESTICAR,
         CA.QTESTITURNO1,
         CA.QTESTITURNO2,
         CA.QTESTITURNO3,
         CA.QTESTITURNO4
      FROM
         SERVICO SE,
         /*CONSPLANSE CO,*/
         CARDADIA CA
      WHERE/*
         (CO.CDFILICPLASE = @P_FILIAL)        AND
         (CO.NRCONSPLANSE = @P_NRCONSPLAN)    AND
         (SE.CDFILIAL     = @P_FILIAL)        AND
         (SE.CDSERVFILI   = CO.CDSERVCPLASE)  AND
         (CA.CDFILIAL     = @P_FILIAL)        AND
         (CA.CDSERVFILI   = CO.CDSERVCPLASE)  AND
         (CA.DTCARDAPIO BETWEEN CO.DTINICCPLASE AND CO.DTFINACPLASE) AND*/
         (SE.CDFILIAL   = @P_FILIAL)     AND
         (CHARINDEX(SE.CDSERVFILI, @P_SERVICOS) > 0 OR @P_SERVICOS = 'T') AND
         (CA.CDFILIAL   = SE.CDFILIAL)   AND
         (CA.CDSERVFILI = SE.CDSERVFILI) AND
         (CA.DTCARDAPIO BETWEEN @P_DTINICIAL AND @P_DTFINAL) AND
         NOT EXISTS (SELECT * FROM CARDACLI
                     WHERE CDFILIAL = CA.CDFILIAL AND
                     NRCARDAPIO = CA.NRCARDAPIO)

      UNION

      SELECT
         CA.DTCARDAPIO,
         CA.CDSERVFILI,
         LEFT(CONVERT(VARCHAR, SE.HRINICATEN) + REPLICATE('0', 4), 4) AS HRINICATEN,
         CA.NRCARDAPIO,
         CC.CDCLIENTE,
         CC.CDDESTFILI,
         CC.QTCOMESTICLI QTCOMESTICAR,
         0 QTESTITURNO1,
         0 QTESTITURNO2,
         0 QTESTITURNO3,
         0 QTESTITURNO4
      FROM
         CARDACLI   CC,
         CARDADIA   CA,
         SERVICO    SE/*,
         CONSPLANSE CO*/
      WHERE/*
         (CO.CDFILICPLASE = @P_FILIAL)         AND
         (CO.NRCONSPLANSE = @P_NRCONSPLAN)       AND
         (SE.CDFILIAL     = CO.CDFILICPLASE)    AND
         (SE.CDSERVFILI   = CO.CDSERVCPLASE)    AND
         (CA.CDFILIAL     = CO.CDFILICPLASE)    AND
         (CA.CDSERVFILI   = CO.CDSERVCPLASE)    AND
         (CA.DTCARDAPIO BETWEEN CO.DTINICCPLASE AND CO.DTFINACPLASE) AND*/
         (SE.CDFILIAL   = @P_FILIAL)     AND
         (CHARINDEX(SE.CDSERVFILI, @P_SERVICOS) > 0 OR @P_SERVICOS = 'T') AND
         (CA.CDFILIAL   = SE.CDFILIAL)   AND
         (CA.CDSERVFILI = SE.CDSERVFILI) AND
         (CA.DTCARDAPIO BETWEEN @P_DTINICIAL AND @P_DTFINAL) AND
         (CC.CDFILIAL   = CA.CDFILIAL )   AND
         (CC.NRCARDAPIO = CA.NRCARDAPIO)
      ORDER BY
         1, 2, 3, 4, 5, 6;

      OPEN CUR_CONSPLAN;

      FETCH NEXT FROM CUR_CONSPLAN INTO @V_REC_DTDATA, @V_REC_CDSERVFILI,
                                        @V_REC_HRINICATEN, @V_REC_NRCARDAPIO,
                                        @V_REC_CDCLIENTE, @V_REC_CDDESTFILI,
                                        @V_REC_QTCOMESTICAR, @V_REC_QTESTITURNO1,
                                        @V_REC_QTESTITURNO2, @V_REC_QTESTITURNO3,
                                        @V_REC_QTESTITURNO4;
      /*******FETCH CUR_CONSPLAN INTO REC_CONSPLAN;*******/

      /* ------------------- LOOP PARA CALCULO DOS CARDAPIOS ---------------- */
      WHILE (@@FETCH_STATUS = 0)
      BEGIN

         SELECT @V_IDUTRETIPRAT = ISNULL(IDUTRETIPRAT, 'N')
         FROM SERVICO
         WHERE (CDFILIAL   = @P_FILIAL) AND
               (CDSERVFILI = @V_REC_CDSERVFILI);

         /* ---------------- AJUSTE DOS TURNOS DOS CARDAPIOS ---------------- */
         IF (@V_REC_CDCLIENTE IS NULL) OR (@V_REC_CDCLIENTE = 'XXX') BEGIN

            SET @V_CONTTURNCARD = 0;

            IF NOT @V_REC_QTESTITURNO1 IS NULL BEGIN SET @V_CONTTURNCARD = @V_CONTTURNCARD + 1; END;
            IF NOT @V_REC_QTESTITURNO2 IS NULL BEGIN SET @V_CONTTURNCARD = @V_CONTTURNCARD + 1; END;
            IF NOT @V_REC_QTESTITURNO3 IS NULL BEGIN SET @V_CONTTURNCARD = @V_CONTTURNCARD + 1; END;
            IF NOT @V_REC_QTESTITURNO4 IS NULL BEGIN SET @V_CONTTURNCARD = @V_CONTTURNCARD + 1; END;

            SELECT
               @V_CONTTURNO = COUNT(*)
            FROM
               TURNOSERV
            WHERE
               (CDFILIAL   = @P_FILIAL) AND
               (CDSERVFILI = @V_REC_CDSERVFILI);

            IF @V_CONTTURNO = 0
            BEGIN

               SET @V_REC_QTESTITURNO1 = NULL;
               SET @V_REC_QTESTITURNO2 = NULL;
               SET @V_REC_QTESTITURNO3 = NULL;
               SET @V_REC_QTESTITURNO4 = NULL;

               UPDATE
                  CARDADIA
               SET
                  QTCOMESTICAR = @V_REC_QTCOMESTICAR,
                  QTESTITURNO1 = NULL,
                  QTESTITURNO2 = NULL,
                  QTESTITURNO3 = NULL,
                  QTESTITURNO4 = NULL
               WHERE
                  (CDFILIAL   = @P_FILIAL)         AND
                  (NRCARDAPIO = @V_REC_NRCARDAPIO);

            END
            ELSE BEGIN

               SELECT @V_FERIADO = COUNT(*)
               FROM FERIFILI
               WHERE
                  CDFILIAL   = @P_FILIAL AND
                  DTFERIFILI = @V_REC_DTDATA;

               IF @V_FERIADO = 0 BEGIN
                  SET @V_DIASEMANA = CONVERT(VARCHAR, DATEPART(DW, @V_REC_DTDATA));
               END ELSE BEGIN
                  SET @V_DIASEMANA = 8;
               END;
               SET @V_SERV_ATUAL = @V_REC_CDSERVFILI;

               SELECT
                  @V_QTESTITURNO1 = COUNT(*)
               FROM TURNOSERV
               WHERE
                  CDFILIAL   = @P_FILIAL     AND
                  CDSERVFILI = @V_SERV_ATUAL AND
                  CDTURNO    = '1';

               SELECT
                  @V_QTESTITURNO2 = COUNT(*)
               FROM TURNOSERV
               WHERE
                  CDFILIAL   = @P_FILIAL     AND
                  CDSERVFILI = @V_SERV_ATUAL AND
                  CDTURNO    = '2';

               SELECT
                  @V_QTESTITURNO3 = COUNT(*)
               FROM TURNOSERV
               WHERE
                  CDFILIAL   = @P_FILIAL     AND
                  CDSERVFILI = @V_SERV_ATUAL AND
                  CDTURNO    = '3';

               SELECT
                  @V_QTESTITURNO4 = COUNT(*)
               FROM TURNOSERV
               WHERE
                  CDFILIAL   = @P_FILIAL     AND
                  CDSERVFILI = @V_SERV_ATUAL AND
                  CDTURNO    = '4';


               IF (@V_QTESTITURNO1 IS NULL) BEGIN SET @V_REC_QTESTITURNO1 = NULL; END;
               IF (@V_QTESTITURNO2 IS NULL) BEGIN SET @V_REC_QTESTITURNO2 = NULL; END;
               IF (@V_QTESTITURNO3 IS NULL) BEGIN SET @V_REC_QTESTITURNO3 = NULL; END;
               IF (@V_QTESTITURNO4 IS NULL) BEGIN SET @V_REC_QTESTITURNO4 = NULL; END;

               UPDATE
                  CARDADIA
               SET
                  QTCOMESTICAR = @V_REC_QTCOMESTICAR,
                  QTESTITURNO1 = @V_REC_QTESTITURNO1,
                  QTESTITURNO2 = @V_REC_QTESTITURNO2,
                  QTESTITURNO3 = @V_REC_QTESTITURNO3,
                  QTESTITURNO4 = @V_REC_QTESTITURNO4
               WHERE
                  (CDFILIAL   = @P_FILIAL) AND
                  (NRCARDAPIO = @V_REC_NRCARDAPIO);

            END;

            IF @V_REC_QTESTITURNO1 IS NULL BEGIN SET @V_REC_QTESTITURNO1 = 0; END;
            IF @V_REC_QTESTITURNO2 IS NULL BEGIN SET @V_REC_QTESTITURNO2 = 0; END;
            IF @V_REC_QTESTITURNO3 IS NULL BEGIN SET @V_REC_QTESTITURNO3 = 0; END;
            IF @V_REC_QTESTITURNO4 IS NULL BEGIN SET @V_REC_QTESTITURNO4 = 0; END;
         END;
         /* EDERSON - NO CALCULA PRATOS PARA COMENSAIS IGUAL A ZERO */
         IF @V_REC_QTCOMESTICAR <> 0
         BEGIN
            /* ----------------- LOOP DA COMPOSIO DO CARDAPIO ---------------- */
            DECLARE CUR_COMPCARD CURSOR FOR
            SELECT
               CC.CDFILAUXPRAT,
               CC.CDPRATO,
               SUM(CC.VRPECONSCARD) AS VRPECONSCARD,
               /*CC.NRSEQPRATCAR,*/
               CC.CDTIPOPRAT,
               ST.CDSETORCOZ
            FROM
               COMPCARD CC LEFT JOIN SETOTIPOPRAT ST
                           ON ((CC.CDFILIAL   = ST.CDFILIAL)    AND
                               (CC.CDTIPOPRAT = ST.CDTIPOPRAT))
            WHERE
               (CC.CDFILIAL   = @P_FILIAL)            AND
               (CC.NRCARDAPIO = @V_REC_NRCARDAPIO)
            GROUP BY
               CC.CDFILAUXPRAT,
               CC.CDPRATO,
               /*CC.NRSEQPRATCAR,*/
               CC.CDTIPOPRAT,
               ST.CDSETORCOZ;

            OPEN CUR_COMPCARD;

            FETCH NEXT FROM CUR_COMPCARD INTO @V_REC_CDFILAUXPRAT, @V_REC_CDPRATO,
                                              @V_REC_VRPECONSCARD, /*@V_REC_NRSEQPRATCAR,*/
                                              @V_REC_CDTIPOPRAT,   @V_REC_CDSETORCOZ;


            WHILE (@@FETCH_STATUS = 0)
            BEGIN
               IF @V_REC_VRPECONSCARD <> 0
               BEGIN

                  SET @V_QTPRATO = (@V_REC_VRPECONSCARD * @V_REC_QTCOMESTICAR)/ 100 ;

                  /* ---------------- LOOP DA COMPOSIO DOS PRATOS --------------- */
                  DECLARE CUR_PRODPRAT CURSOR FOR
                  SELECT
                     RECESERV.CDPRODUTO,
                     RECESERV.QTBRUTASE AS QTPRODUTO,
                     RECESERV.SGUNIDADE,
                     RECESERV.VRPEFATCOCSE AS VRPEFATCOC,
                     RECESERV.VRPEFATCORSE AS VRPEFATCOR,
                     ISNULL(RECESERV.HRTEMPPREPSE, '00100') AS HRTEMPPREP,
                     RECESERV.CDAPRERECE,
                     RECESERV.QTBRUTASEUNR AS QTBRUTAUNR
                  FROM
                     PRODUTO, RECESERV
                  WHERE
                     (RECESERV.CDFILAUXPRAT = @V_REC_CDFILAUXPRAT) AND
                     (RECESERV.CDPRATO      = @V_REC_CDPRATO)      AND
                     (RECESERV.CDFILIAL     = @P_FILIAL)           AND
                     (RECESERV.CDSERVFILI   = @V_REC_CDSERVFILI)   AND
                     (RECESERV.CDPRODUTO    = PRODUTO.CDPRODUTO)   AND
                     (PRODUTO.CDARVPROD BETWEEN @P_CDPRODUTOINI AND @P_CDPRODUTOFIN)

                  UNION ALL

                  SELECT
                     RECEFILI.CDPRODUTO,
                     RECEFILI.QTBRUTALO AS QTPRODUTO,
                     RECEFILI.SGUNIDADE,
                     RECEFILI.VRPEFATCOCLO AS VRPEFATCOC,
                     RECEFILI.VRPEFATCORLO AS VRPEFATCOR,
                     ISNULL(RECEFILI.HRTEMPPREPLO, '00100') AS HRTEMPPREP,
                     RECEFILI.CDAPRERECE,
                     RECEFILI.QTBRUTALOUNR AS QTBRUTAUNR  
                  FROM
                     PRODUTO, RECEFILI
                  WHERE
                     (RECEFILI.CDFILAUXPRAT = @V_REC_CDFILAUXPRAT)                    AND
                     (RECEFILI.CDPRATO      = @V_REC_CDPRATO)                         AND
                     (RECEFILI.CDFILIAL     = @P_FILIAL)                              AND
                     (RECEFILI.CDPRODUTO    = PRODUTO.CDPRODUTO)                      AND
                     (PRODUTO.CDARVPROD BETWEEN @P_CDPRODUTOINI AND @P_CDPRODUTOFIN) AND
                      NOT EXISTS (SELECT
                                     CDPRATO
                                  FROM
                                     RECESERV
                                  WHERE
                                     (CDFILAUXPRAT = @V_REC_CDFILAUXPRAT)        AND
                                     (CDPRATO      = @V_REC_CDPRATO)        AND
                                     (CDFILIAL     = @P_FILIAL)             AND
                                     (CDSERVFILI   = @V_REC_CDSERVFILI)
                                  )
                  UNION ALL

                  SELECT
                     RECEPADR.CDPRODUTO,
                     RECEPADR.QTBRUTAPR AS QTPRODUTO,
                     RECEPADR.SGUNIDADE,
                     RECEPADR.VRPEFATCOCPR AS VRPEFATCOC,
                     RECEPADR.VRPEFATCORPR AS VRPEFATCOR,
                     ISNULL(RECEPADR.HRTEMPPREPPR, '00100') AS HRTEMPPREP,
                     RECEPADR.CDAPRERECE,
                     RECEPADR.QTBRUTAPRUNR AS QTBRUTAUNR
                  FROM
                     PRODUTO, RECEPADR
                  WHERE
                     (RECEPADR.CDFILAUXPRAT = @V_REC_CDFILAUXPRAT) AND
                     (RECEPADR.CDPRATO      = @V_REC_CDPRATO)      AND
                     (RECEPADR.CDPRODUTO    = PRODUTO.CDPRODUTO)   AND
                     (PRODUTO.CDARVPROD BETWEEN @P_CDPRODUTOINI AND @P_CDPRODUTOFIN) AND
                      NOT EXISTS (SELECT
                                     CDPRATO
                                  FROM
                                     RECEFILI
                                  WHERE
                                     (CDFILAUXPRAT = @V_REC_CDFILAUXPRAT)      AND
                                     (CDPRATO      = @V_REC_CDPRATO)       AND
                                     (CDFILIAL     = @P_FILIAL)
                                  ) AND
                      NOT EXISTS (SELECT
                                     CDPRATO
                                  FROM
                                     RECESERV
                                  WHERE
                                     (CDFILAUXPRAT = @V_REC_CDFILAUXPRAT) AND
                                     (CDPRATO      = @V_REC_CDPRATO)                        AND
                                     (CDFILIAL     = @P_FILIAL)                       AND
                                     (CDSERVFILI   = @V_REC_CDSERVFILI));


                  OPEN CUR_PRODPRAT;

                  FETCH NEXT FROM CUR_PRODPRAT INTO @V_REC_CDPRODUTO,
                                                    @V_REC_QTPRODUTO,
                                                    @V_REC_SGUNIDADE,
                                                    @V_VRPEFATCOC,
                                                    @V_VRPEFATCOR,
                                                    @V_REC_HRTEMPPREP,
                                                    @V_REC_CDAPRERECE,
                                                    @V_REC_QTBRUTAUNR;



                  WHILE (@@FETCH_STATUS = 0)
                  BEGIN

                     SET @V_REC_QTPRODUTO = @V_REC_QTPRODUTO * @V_QTPRATO;
                     SET @V_REC_QTBRUTAUNR = @V_REC_QTBRUTAUNR * @V_QTPRATO;
                     SET @V_DTLIMITE = CONVERT(DATETIME, CONVERT(VARCHAR,@V_REC_DTDATA, 103)+' '+SUBSTRING(@V_REC_HRINICATEN,1,2)+':'+SUBSTRING(@V_REC_HRINICATEN,3,2), 103);

                     EXEC SUBTHTOD_PLA @V_DTLIMITE, @V_REC_HRTEMPPREP, @P_DTATUAL = @V_DTLIMITE OUTPUT;

                     SET @V_HRLIMITE = SUBSTRING(CONVERT(VARCHAR, @V_DTLIMITE,8), 1,2) + SUBSTRING(CONVERT(VARCHAR, @V_DTLIMITE,8), 4,2);

                     /* ---------------- EVITA DIVISAO POR ZERO ------------------- */
                     SET @V_QTDEAUX = @V_REC_QTCOMESTICAR;

                     IF (@V_QTDEAUX = 0) OR (@V_QTDEAUX IS NULL) BEGIN
                        SET @V_QTDEAUX = 1;
                     END;

                     SELECT @V_IDUTRETIPRAT = ISNULL(IDUTRETIPRAT, 'N')
                     FROM SERVICO
                     WHERE (CDFILIAL   = @P_FILIAL) AND
                           (CDSERVFILI = @V_REC_CDSERVFILI);

                     /* --------------------- GRAVA NA PREVRETI ------------------- */
                     IF @P_IDARQUIVO = 'P'
                     BEGIN
                        SET @V_PEACRESCIMO  = @V_REC_QTPRODUTO * (1 + (@P_PEACRESCIMO / 100));
                        SET @V_PEACRESCIMO1 = (@V_REC_QTPRODUTO * @V_REC_QTESTITURNO1 / @V_QTDEAUX) * (1 + (@P_PEACRESCIMO / 100));
                        SET @V_PEACRESCIMO2 = (@V_REC_QTPRODUTO * @V_REC_QTESTITURNO2 / @V_QTDEAUX) * (1 + (@P_PEACRESCIMO / 100));
                        SET @V_PEACRESCIMO3 = (@V_REC_QTPRODUTO * @V_REC_QTESTITURNO3 / @V_QTDEAUX) * (1 + (@P_PEACRESCIMO / 100));
                        SET @V_PEACRESCIMO4 = (@V_REC_QTPRODUTO * @V_REC_QTESTITURNO4 / @V_QTDEAUX) * (1 + (@P_PEACRESCIMO / 100));
                        EXEC ATUALIZA_PREVRETI @P_FILIAL,
                                               @V_REC_DTDATA,
                                               @V_REC_CDSERVFILI,
                                               @V_REC_HRINICATEN,
                                               @V_REC_NRCARDAPIO,
                                               @V_REC_QTCOMESTICAR,
                                               @V_REC_QTESTITURNO1,
                                               @V_REC_QTESTITURNO2,
                                               @V_REC_QTESTITURNO3,
                                               @V_REC_QTESTITURNO4,
                                               'C',
                                               @V_REC_CDPRODUTO,
                                               @V_DTLIMITE,
                                               @V_HRLIMITE,
                                               @V_PEACRESCIMO,
                                               @V_PEACRESCIMO1,
                                               @V_PEACRESCIMO2,
                                               @V_PEACRESCIMO3,
                                               @V_PEACRESCIMO4,
                                               'S',
                                               @P_CDOPERADOR,
                                               @V_IDUTRETIPRAT,
                                               @V_REC_CDTIPOPRAT,
                                               @V_REC_CDFILAUXPRAT,
                                               @V_REC_CDPRATO,
					                           @V_VRPEFATCOR,
					                           @V_REC_QTBRUTAUNR,
					                           @V_REC_SGUNIDADE

                     /* --------------------- GRAVA NA CONSPLAN ------------------- */
                     END
                     ELSE BEGIN
                        SET @V_CDFAPRATCPLA = ' ';
                        SET @V_CDPRATCONSPL = '          ';
                        SET @V_CDSETOCONSPL = '  ';
                        SET @V_CDTPPRATCPLA = '  ';
                        SET @V_SGUNIDADE = NULL;  
                        
                        IF (@P_IDSEPPRATO = 'P')OR(@P_IDSEPPRATO = 'S')
                        BEGIN
                           /* Por Setor */
                           IF @P_IDSEPPRATO = 'S' BEGIN

                              SELECT
                                 @V_CDARVPROD = CDARVPROD
                              FROM
                                 PRODUTO
                              WHERE
                                 CDPRODUTO = @V_REC_CDPRODUTO;

                              SELECT
                                 @V_CDSETOCONSPL = MAX(CDSETORCOZ)
                              FROM
                                 SETOPRODCARD S,
                                 PRODUTO P
                              WHERE
                                 (S.CDFILIAL   = @P_FILIAL)                AND
                                 (S.CDTIPOPRAT = @V_REC_CDTIPOPRAT) AND
                                 (S.CDPRODUTO  = P.CDPRODUTO) AND
                                 (CHARINDEX(P.CDARVPROD, @V_CDARVPROD) = 1);

                              IF @V_CDSETOCONSPL IS NULL
                              BEGIN
                                 IF NOT @V_REC_CDSETORCOZ IS NULL
                                 BEGIN
                                    SET @V_CDSETOCONSPL = @V_REC_CDSETORCOZ;
                                 END
                                 ELSE
                                 BEGIN
                                    SET @V_CDSETOCONSPL = '  ';
                                 END;
                              END;
                           END; 

                           SET @V_CDFAPRATCPLA = @V_REC_CDFILAUXPRAT;
                           SET @V_CDPRATCONSPL = @V_REC_CDPRATO;
                           SET @V_CDTPPRATCPLA = @V_REC_CDTIPOPRAT;
                           SET @V_SGUNIDADE    = @V_REC_SGUNIDADE;
                        END;

                        SET @V_PEACRESCIMO  = (@V_REC_QTPRODUTO) * (1 + (@P_PEACRESCIMO / 100));
                        SET @V_PEACRESCIMO1 = (@V_REC_QTPRODUTO * @V_REC_QTESTITURNO1 / @V_QTDEAUX) * (1 + (@P_PEACRESCIMO / 100));
                        SET @V_PEACRESCIMO2 = (@V_REC_QTPRODUTO * @V_REC_QTESTITURNO2 / @V_QTDEAUX) * (1 + (@P_PEACRESCIMO / 100));
                        SET @V_PEACRESCIMO3 = (@V_REC_QTPRODUTO * @V_REC_QTESTITURNO3 / @V_QTDEAUX) * (1 + (@P_PEACRESCIMO / 100));
                        SET @V_PEACRESCIMO4 = (@V_REC_QTPRODUTO * @V_REC_QTESTITURNO4 / @V_QTDEAUX) * (1 + (@P_PEACRESCIMO / 100));


                        EXEC ATUALIZA_CONSPLAN @P_NRCONSPLAN,
                                               @P_FILIAL,
                                               @V_REC_DTDATA,
                                               @V_REC_CDSERVFILI,
                                               @V_REC_HRINICATEN,
                                               @V_REC_NRCARDAPIO,
                                               @V_REC_CDCLIENTE,
                                               @V_REC_CDDESTFILI,
                                               @V_REC_QTCOMESTICAR,
                                               @V_REC_QTESTITURNO1,
                                               @V_REC_QTESTITURNO2,
                                               @V_REC_QTESTITURNO3,
                                               @V_REC_QTESTITURNO4,
                                               'C',
                                               @V_CDFAPRATCPLA,
                                               @V_CDPRATCONSPL,
                                               @V_REC_CDAPRERECE,
                                               @V_CDSETOCONSPL,
                                               @V_REC_CDPRODUTO,
                                               @V_DTLIMITE,
                                               @V_HRLIMITE,
                                               @V_CDTPPRATCPLA,
                                               @V_PEACRESCIMO,
                                               @V_PEACRESCIMO1,
                                               @V_PEACRESCIMO2,
                                               @V_PEACRESCIMO3,
                                               @V_PEACRESCIMO4,
                                               @V_REC_VRPECONSCARD,
                                               @V_QTPRATO, /*@V_REC_QTCOMESTICAR,*/
                                               'S',
                                               @V_REC_QTCOMPLPROD,
					                           @V_VRPEFATCOR,
					                           @V_REC_QTBRUTAUNR,
					                           @V_SGUNIDADE;

                     END; /* GRAVACAO NA CONSPLAN OU PREVRETI */
                     FETCH NEXT FROM CUR_PRODPRAT INTO @V_REC_CDPRODUTO,
                                                       @V_REC_QTPRODUTO,
                                                       @V_REC_SGUNIDADE,
                                                       @V_VRPEFATCOC,
                                                       @V_VRPEFATCOR,
                                                       @V_REC_HRTEMPPREP,
                                                       @V_REC_CDAPRERECE,
                                                       @V_REC_QTBRUTAUNR;
                  END; /* LOOP DA COMPOSICAO DOS PRATOS */

                  CLOSE CUR_PRODPRAT;
                  DEALLOCATE CUR_PRODPRAT;
               END;

               FETCH NEXT FROM CUR_COMPCARD INTO @V_REC_CDFILAUXPRAT, @V_REC_CDPRATO,
                                                 @V_REC_VRPECONSCARD, /*@V_REC_NRSEQPRATCAR,*/
                                                 @V_REC_CDTIPOPRAT, @V_REC_CDSETORCOZ;
            END; /* LOOP DA COMPOSIO DO CARDAPIO */

            CLOSE CUR_COMPCARD;
            DEALLOCATE CUR_COMPCARD;
         END;
         FETCH NEXT FROM CUR_CONSPLAN INTO @V_REC_DTDATA, @V_REC_CDSERVFILI,
                                           @V_REC_HRINICATEN, @V_REC_NRCARDAPIO,
                                           @V_REC_CDCLIENTE, @V_REC_CDDESTFILI,
                                           @V_REC_QTCOMESTICAR, @V_REC_QTESTITURNO1,
                                           @V_REC_QTESTITURNO2, @V_REC_QTESTITURNO3,
                                           @V_REC_QTESTITURNO4;
      END; /* LOOP PARA CALCULO DOS CARDAPIOS */

      CLOSE CUR_CONSPLAN;
      DEALLOCATE CUR_CONSPLAN;

      /* GRAVA NUMERO DE COMENSAIS POR PRATO (DIETA) */
      IF @P_IDSEPPRATO = 'S'
      BEGIN
         DECLARE CUR_CONSPLANSE CURSOR FOR
         SELECT
            CA.CDFILIAL,
            CA.CDSERVFILI,
            CA.DTCARDAPIO,
            CC.CDFILAUXPRAT,
            CC.CDTIPOPRAT,
            CC.CDPRATO,
            SUM((CC.VRPECONSCARD*CA.QTCOMESTICAR)/100) QTCOMESTDIE,
            SUM(CA.QTCOMESTICAR) QTCOMESTICAR
         FROM
            COMPCARD CC,
            CARDADIA CA
         WHERE
            CA.CDFILIAL = @P_FILIAL     AND
            (CHARINDEX(CA.CDSERVFILI,@P_SERVICOS) > 0 OR @P_SERVICOS = 'T') AND
            (CA.DTCARDAPIO BETWEEN @P_DTINICIAL AND @P_DTFINAL) AND
            (NOT (CA.CDDIETPAD IS NULL))  AND
            CC.CDFILIAL     = CA.CDFILIAL AND
            CC.NRCARDAPIO   = CA.NRCARDAPIO
         GROUP BY
            CA.CDFILIAL,
            CA.CDSERVFILI,
            CA.DTCARDAPIO,
            CC.CDFILAUXPRAT,
            CC.CDTIPOPRAT,
            CC.CDPRATO;

         OPEN CUR_CONSPLANSE;

         FETCH NEXT FROM CUR_CONSPLANSE INTO @V_CDFILIAL,
                                             @V_CUR_CONSPLANSE_CDSERVFILI,
                                             @V_CUR_CONSPLANSE_DTCARDAPIO,
                                             @V_CUR_CONSPLANSE_CDFILAUXPRAT,
                                             @V_CUR_CONSPLANSE_CDTIPOPRAT,
                                             @V_CUR_CONSPLANSE_CDPRATO,
                                             @V_CUR_CONSPLANSE_QTCOMESTDIE,
                                             @V_CUR_CONSPLANSE_QTCOMESTICAR;

         WHILE (@@FETCH_STATUS = 0)
         BEGIN

            UPDATE
               CONSPLAN
            SET
               QTCOMESTCPLA = @V_CUR_CONSPLANSE_QTCOMESTICAR,
               QTCOMESTDIE  = @V_CUR_CONSPLANSE_QTCOMESTDIE
            WHERE
               CDFILICPLA   = @P_FILIAL AND
               NRCONSPLAN   = @P_NRCONSPLAN AND
               CDSERVCPLA   = @V_CUR_CONSPLANSE_CDSERVFILI AND
               DTCONSPLAN   = @V_CUR_CONSPLANSE_DTCARDAPIO AND
               CDFAPRATCPLA = @V_CUR_CONSPLANSE_CDFILAUXPRAT AND
               CDTPPRATCPLA = @V_CUR_CONSPLANSE_CDTIPOPRAT AND
               CDPRATCONSPL = @V_CUR_CONSPLANSE_CDPRATO AND
               IDCONSPLAN   = 'C';

            FETCH NEXT FROM CUR_CONSPLANSE INTO @V_CDFILIAL,
                                                @V_CUR_CONSPLANSE_CDSERVFILI,
                                                @V_CUR_CONSPLANSE_DTCARDAPIO,
                                                @V_CUR_CONSPLANSE_CDFILAUXPRAT,
                                                @V_CUR_CONSPLANSE_CDTIPOPRAT,
                                                @V_CUR_CONSPLANSE_CDPRATO,
                                                @V_CUR_CONSPLANSE_QTCOMESTDIE,
                                                @V_CUR_CONSPLANSE_QTCOMESTICAR;
         END;
         CLOSE CUR_CONSPLANSE;
      END ELSE BEGIN
         DECLARE CUR_CONSPLANSE CURSOR FOR
         SELECT
            CA.CDFILIAL,
            CA.CDSERVFILI,
            CA.DTCARDAPIO,
            CC.CDFILAUXPRAT,
            CC.CDPRATO,
            SUM((CC.VRPECONSCARD*CA.QTCOMESTICAR)/100) QTCOMESTDIE,
            SUM(CA.QTCOMESTICAR) QTCOMESTICAR
         FROM
            COMPCARD CC,
            CARDADIA CA
         WHERE
            CA.CDFILIAL = @P_FILIAL     AND
            (CHARINDEX(CA.CDSERVFILI,@P_SERVICOS) > 0 OR @P_SERVICOS = 'T') AND
            (CA.DTCARDAPIO BETWEEN @P_DTINICIAL AND @P_DTFINAL) AND
            (NOT (CA.CDDIETPAD IS NULL))  AND
            CC.CDFILIAL     = CA.CDFILIAL AND
            CC.NRCARDAPIO   = CA.NRCARDAPIO
         GROUP BY
            CA.CDFILIAL,
            CA.CDSERVFILI,
            CA.DTCARDAPIO,
            CC.CDFILAUXPRAT,
            CC.CDPRATO;

         OPEN CUR_CONSPLANSE;

         FETCH NEXT FROM CUR_CONSPLANSE INTO @V_CDFILIAL,
                                             @V_CUR_CONSPLANSE_CDSERVFILI,
                                             @V_CUR_CONSPLANSE_DTCARDAPIO,
                                             @V_CUR_CONSPLANSE_CDFILAUXPRAT,
                                             @V_CUR_CONSPLANSE_CDPRATO,
                                             @V_CUR_CONSPLANSE_QTCOMESTDIE,
                                             @V_CUR_CONSPLANSE_QTCOMESTICAR;

         WHILE (@@FETCH_STATUS = 0)
         BEGIN

            UPDATE
               CONSPLAN
            SET
               QTCOMESTCPLA = @V_CUR_CONSPLANSE_QTCOMESTICAR,
               QTCOMESTDIE  = @V_CUR_CONSPLANSE_QTCOMESTDIE
            WHERE
               CDFILICPLA   = @P_FILIAL AND
               NRCONSPLAN   = @P_NRCONSPLAN AND
               CDSERVCPLA   = @V_CUR_CONSPLANSE_CDSERVFILI AND
               DTCONSPLAN   = @V_CUR_CONSPLANSE_DTCARDAPIO AND
               CDFAPRATCPLA = @V_CUR_CONSPLANSE_CDFILAUXPRAT AND
               CDPRATCONSPL = @V_CUR_CONSPLANSE_CDPRATO AND
               IDCONSPLAN   = 'C';
 
            FETCH NEXT FROM CUR_CONSPLANSE INTO @V_CDFILIAL,
                                                @V_CUR_CONSPLANSE_CDSERVFILI,
                                                @V_CUR_CONSPLANSE_DTCARDAPIO,
                                                @V_CUR_CONSPLANSE_CDFILAUXPRAT,
                                                @V_CUR_CONSPLANSE_CDPRATO,
                                                @V_CUR_CONSPLANSE_QTCOMESTDIE,
                                                @V_CUR_CONSPLANSE_QTCOMESTICAR;
         END;
         CLOSE CUR_CONSPLANSE;
      END;
      DEALLOCATE CUR_CONSPLANSE;

   END; /* CALCULO DOS PRODUTOS DOS CARDAPIOS */

   /* ----------------------- UTILIZAO DA CONSSERV ------------------------ */

   IF (@V_IDCONSFIXO = 'F') OR (@V_IDCONSPERC = 'P')
   BEGIN
      SELECT
         @V_CDSETCONFIXO = MAX(CDSETCONFIXO),
         @V_CDSETCONPERC = MAX(CDSETCONPERC)
      FROM
         PARAMPLANEJA
      WHERE
         CDFILIAL = @P_FILIAL;
      /* ABERTURA DO CURSOR */


      IF (@V_IDCONSPERC = 'P')
      /* - Consumo por servio 'PERCAPITA' - proporcional aos comensais ----- */
      BEGIN

         DECLARE CUR_CONSPLAN CURSOR FOR
         SELECT
            DT.DTDATA,
            SE.CDSERVFILI,
            LEFT(CONVERT(VARCHAR, SE.HRINICATEN) + REPLICATE('0', 4), 4) AS HRINICATEN,
            'PPPPPPPPPP' NRCARDAPIO,
            'XXX' CDCLIENTE,
            'XXX' CDDESTFILI,
            SUM(CA.QTCOMESTICAR) QTCOMESTICAR,
            SUM(CA.QTESTITURNO1) QTESTITURNO1,
            SUM(CA.QTESTITURNO2) QTESTITURNO2,
            SUM(CA.QTESTITURNO3) QTESTITURNO3,
            SUM(CA.QTESTITURNO4) QTESTITURNO4
         FROM
            DATA DT, SERVICO SE, /*CONSPLANSE CO, */CARDADIA CA
         WHERE/*
            (CO.CDFILICPLASE = @P_FILIAL)      AND
            (CO.NRCONSPLANSE = @P_NRCONSPLAN)    AND
            (SE.CDFILIAL     = @P_FILIAL)      AND
            (SE.CDSERVFILI   = CO.CDSERVCPLASE)  AND*/
            (SE.CDFILIAL     = @P_FILIAL)     AND
            (CHARINDEX(SE.CDSERVFILI, @P_SERVICOS) > 0 OR @P_SERVICOS = 'T') AND
            (CA.CDFILIAL     = SE.CDFILIAL)   AND
            (CA.CDSERVFILI   = SE.CDSERVFILI) AND
            (CA.DTCARDAPIO BETWEEN @P_DTINICIAL AND @P_DTFINAL) AND
            (DT.DTDATA       = CA.DTCARDAPIO) AND/*
            (CA.CDFILIAL     = @P_FILIAL)      AND
            (CA.CDSERVFILI   = CO.CDSERVCPLASE)  AND
            (CA.DTCARDAPIO BETWEEN CO.DTINICCPLASE AND CO.DTFINACPLASE) AND*/
            NOT EXISTS
            (SELECT * FROM CARDACLI
             WHERE CDFILIAL   = CA.CDFILIAL    AND
                   NRCARDAPIO = CA.NRCARDAPIO)
         GROUP BY DT.DTDATA, SE.CDSERVFILI, LEFT(CONVERT(VARCHAR, SE.HRINICATEN) + REPLICATE('0', 4), 4)
         UNION ALL
         SELECT
            DT.DTDATA,
            SE.CDSERVFILI,
            LEFT(CONVERT(VARCHAR, SE.HRINICATEN) + REPLICATE('0', 4), 4) AS HRINICATEN,
            'PPPPPPPPPP' NRCARDAPIO,
            CC.CDCLIENTE,
            CC.CDDESTFILI,
            SUM(CC.QTCOMESTICLI) QTCOMESTICAR,
            SUM(0) QTESTITURNO1,
            SUM(0) QTESTITURNO2,
            SUM(0) QTESTITURNO3,
            SUM(0) QTESTITURNO4
         FROM
            CARDACLI CC,
            DATA DT,
            SERVICO SE,
            /*CONSPLANSE CO,*/
            CARDADIA CA
         WHERE/*
            (CO.CDFILICPLASE = @P_FILIAL)      AND
            (CO.NRCONSPLANSE = @P_NRCONSPLAN)    AND
            (SE.CDFILIAL     = @P_FILIAL)      AND
            (SE.CDSERVFILI   = CO.CDSERVCPLASE) AND
            (DT.DTDATA       = CA.DTCARDAPIO)   AND
            (CA.CDFILIAL     = @P_FILIAL)      AND
            (CA.CDSERVFILI   = CO.CDSERVCPLASE) AND
            (CA.DTCARDAPIO BETWEEN CO.DTINICCPLASE AND CO.DTFINACPLASE) AND
            (CC.CDFILIAL     = CA.CDFILIAL)     AND*/
            (SE.CDFILIAL     = @P_FILIAL)      AND
            (CHARINDEX(SE.CDSERVFILI, @P_SERVICOS) > 0 OR @P_SERVICOS = 'T') AND
            (CA.CDFILIAL     = SE.CDFILIAL)    AND
            (CA.CDSERVFILI   = SE.CDSERVFILI)  AND
            (CA.DTCARDAPIO BETWEEN @P_DTINICIAL AND @P_DTFINAL) AND
            (DT.DTDATA       = CA.DTCARDAPIO)  AND
            (CC.CDFILIAL     = CA.CDFILIAL)    AND
            (CC.NRCARDAPIO   = CA.NRCARDAPIO)
         GROUP BY
            DT.DTDATA, SE.CDSERVFILI, LEFT(CONVERT(VARCHAR, SE.HRINICATEN) + REPLICATE('0', 4), 4), CC.CDCLIENTE, CC.CDDESTFILI
         UNION ALL
         SELECT
            DT.DTDATA,
            SE.CDSERVFILI,
            LEFT(CONVERT(VARCHAR, SE.HRINICATEN) + REPLICATE('0', 4), 4) AS HRINICATEN,
            NULL NRCARDAPIO,
            'XXX' CDCLIENTE,
            'XXX' CDDESTFILI,
            0 QTCOMESTICAR,
            0 QTESTITURNO1,
            0 QTESTITURNO2,
            0 QTESTITURNO3,
            0 QTESTITURNO4
         FROM
            DATA DT, SERVICO SE/*, CONSPLANSE CO*/
         WHERE/*
            (CO.CDFILICPLASE = @P_FILIAL)      AND
            (CO.NRCONSPLANSE = @P_NRCONSPLAN)    AND
            (SE.CDFILIAL = @P_FILIAL)                              AND
            (SE.CDSERVFILI = CO.CDSERVCPLASE)                       AND
            (DT.DTDATA BETWEEN CO.DTINICCPLASE AND CO.DTFINACPLASE) AND*/
            (SE.CDFILIAL = @P_FILIAL) AND
            (CHARINDEX(SE.CDSERVFILI, @P_SERVICOS) > 0 OR @P_SERVICOS = 'T') AND
            (DT.DTDATA BETWEEN @P_DTINICIAL AND @P_DTFINAL) AND
            (NOT EXISTS (SELECT
                            CA.CDFILIAL
                         FROM
                            CARDADIA CA
                         WHERE
                            (CA.CDFILIAL   = SE.CDFILIAL)   AND
                            (CA.CDSERVFILI = SE.CDSERVFILI) AND
                            (CA.DTCARDAPIO = DT.DTDATA)))
         ORDER BY DT.DTDATA, SE.CDSERVFILI, LEFT(CONVERT(VARCHAR, SE.HRINICATEN) + REPLICATE('0', 4), 4), 4, 5, 6;
         OPEN CUR_CONSPLAN;

         /* -------------------- LOOP PARA CALCULO DA CONSSERV ----------------- */
         FETCH NEXT FROM CUR_CONSPLAN INTO @V_REC_DTDATA,       @V_REC_CDSERVFILI,
                                           @V_REC_HRINICATEN,   @V_REC_NRCARDAPIO,
                                           @V_REC_CDCLIENTE,    @V_REC_CDDESTFILI,
                                           @V_REC_QTCOMESTICAR, @V_REC_QTESTITURNO1,
                                           @V_REC_QTESTITURNO2, @V_REC_QTESTITURNO3,
                                           @V_REC_QTESTITURNO4;

         WHILE (@@FETCH_STATUS = 0)
         BEGIN
            IF @V_REC_QTESTITURNO1 IS NULL
            BEGIN
          	   SET @V_REC_QTESTITURNO1 = 0;
            END;
            IF @V_REC_QTESTITURNO2 IS NULL
            BEGIN
               SET @V_REC_QTESTITURNO2 = 0;
            END;
            IF @V_REC_QTESTITURNO3 IS NULL
            BEGIN
                SET @V_REC_QTESTITURNO3 = 0;
            END;
            IF @V_REC_QTESTITURNO4 IS NULL
            BEGIN
               SET @V_REC_QTESTITURNO4 = 0;
            END;

            SELECT @V_IDUTRETIPRAT = ISNULL(IDUTRETIPRAT, 'N')
            FROM SERVICO
            WHERE (CDFILIAL   = @P_FILIAL) AND
                  (CDSERVFILI = @V_REC_CDSERVFILI);

            /* VERIFICA SE  FERIADO */
            SELECT
               @V_FERIADO = COUNT(*)
            FROM
               FERIFILI
            WHERE
               (CDFILIAL   = @P_FILIAL) AND
               (DTFERIFILI = @V_REC_DTDATA);

            /* --------------- INICIALIZACAO DO ARQUIVO PREVRETI ---------------*/
            IF (@P_IDARQUIVO IN ('P','A'))
            BEGIN

               IF (@V_IDCONSPERC = 'P')
               BEGIN
                  DELETE FROM PREVRETI
                  WHERE
                     (CDFILIAL   = @P_FILIAL)         AND
                     (CDSERVFILI = @V_REC_CDSERVFILI) AND
                     (DTPREVRETI = @V_REC_DTDATA)     AND
                     (NRREQUEXTR = '0000000000')      AND
                     (IDPREVRETI = 'P');
               END;
            END;   


            /* ---------------- LOOP PARA COMPOSIO DA CONSSERV --------------- */

            DECLARE CUR_CONSSERV CURSOR FOR
            SELECT
               C.CDFILIAL,
               C.CDSERVFILI,
               C.DTCONSSERV,
               C.CDPRODUTO,
               C.QTCONSSERV,
               C.IDQTDECONS
            FROM
               CONSSERV C, PRODUTO P
            WHERE
               C.CDFILIAL   = @P_FILIAL         AND
               C.CDSERVFILI = @V_REC_CDSERVFILI AND
               C.DTCONSSERV = @V_REC_DTDATA     AND
               C.IDTIPOCONS = '9'               AND
               C.IDQTDECONS = 'F'               AND
               P.CDARVPROD BETWEEN @P_CDPRODUTOINI AND @P_CDPRODUTOFIN AND
               P.CDPRODUTO = C.CDPRODUTO AND
               NOT EXISTS (SELECT
                              CDFILIAL
                           FROM
                              DIASEMCONS
                           WHERE
                              CDFILIAL    = @P_FILIAL         AND
                              CDSERVFILI  = @V_REC_CDSERVFILI AND
                              DTSCONSSERV = @V_REC_DTDATA     AND
                              IDTCONSSERV IN ('F','A'))

            UNION ALL

            SELECT
               C.CDFILIAL,
               C.CDSERVFILI,
               C.DTCONSSERV,
               C.CDPRODUTO,
               C.QTCONSSERV,
               C.IDQTDECONS
            FROM
               CONSSERV C, PRODUTO P
            WHERE
               C.CDFILIAL   = @P_FILIAL         AND
               C.CDSERVFILI = @V_REC_CDSERVFILI AND
               C.DTCONSSERV = @V_REC_DTDATA     AND
               C.IDTIPOCONS = '9'               AND
               C.IDQTDECONS = 'P'               AND
               P.CDARVPROD BETWEEN @P_CDPRODUTOINI AND @P_CDPRODUTOFIN AND
               P.CDPRODUTO = C.CDPRODUTO AND
               NOT EXISTS (SELECT
                              CDFILIAL
                           FROM
                              DIASEMCONS
                           WHERE
                              CDFILIAL    = @P_FILIAL         AND
                              CDSERVFILI  = @V_REC_CDSERVFILI AND
                              DTSCONSSERV = @V_REC_DTDATA     AND
                              IDTCONSSERV IN ('P','A'))
  
            UNION ALL
  
            SELECT
               C.CDFILIAL,
               C.CDSERVFILI,
               C.DTCONSSERV,
               C.CDPRODUTO,
               C.QTCONSSERV,
               C.IDQTDECONS
            FROM
               CONSSERV C, PRODUTO P
            WHERE
               C.CDFILIAL   = @P_FILIAL     AND
               C.CDSERVFILI = @V_REC_CDSERVFILI AND
               P.CDARVPROD BETWEEN @P_CDPRODUTOINI AND @P_CDPRODUTOFIN AND
               P.CDPRODUTO = C.CDPRODUTO AND
               C.DTCONSSERV IN (SELECT
                                 MAX(DTCONSSERV)
                              FROM
                                 CONSSERV
                              WHERE
                                 CDFILIAL    = @P_FILIAL         AND
                                 CDSERVFILI  = @V_REC_CDSERVFILI AND
                                 DTCONSSERV <= @V_REC_DTDATA     AND
                                 IDTIPOCONS <> '9')              AND

               ((C.IDTIPOCONS = DATEPART(dw, @V_REC_DTDATA) AND @V_FERIADO = 0) OR
               (C.IDTIPOCONS = '8' AND @V_FERIADO <> 0)) AND
                C.IDQTDECONS = 'F'                         AND
                NOT EXISTS (SELECT
                              CDFILIAL
                           FROM
                              DIASEMCONS
                           WHERE
                              CDFILIAL    = @P_FILIAL         AND
                              CDSERVFILI  = @V_REC_CDSERVFILI AND
                              DTSCONSSERV = @V_REC_DTDATA     AND
                              IDTCONSSERV IN ('F','A'))       AND
                NOT EXISTS (SELECT
                             CDFILIAL
                          FROM
                             CONSSERV
                          WHERE
                             CDFILIAL   = @P_FILIAL         AND
                             CDSERVFILI = @V_REC_CDSERVFILI AND
                             DTCONSSERV = @V_REC_DTDATA     AND
                             IDTIPOCONS = '9'               AND
                             IDQTDECONS = 'F')
 
            UNION ALL

            SELECT 
               C.CDFILIAL,
               C.CDSERVFILI,
               C.DTCONSSERV,
               C.CDPRODUTO,
               C.QTCONSSERV,
               C.IDQTDECONS
            FROM
               CONSSERV C, PRODUTO P
            WHERE
               C.CDFILIAL   = @P_FILIAL     AND
               C.CDSERVFILI = @V_REC_CDSERVFILI AND
               P.CDARVPROD BETWEEN @P_CDPRODUTOINI AND @P_CDPRODUTOFIN AND
               P.CDPRODUTO = C.CDPRODUTO AND
               C.DTCONSSERV IN (SELECT MAX(DTCONSSERV)
                              FROM CONSSERV
                              WHERE
                                 CDFILIAL    = @P_FILIAL         AND
                                 CDSERVFILI  = @V_REC_CDSERVFILI AND
                                 DTCONSSERV <= @V_REC_DTDATA     AND
                                 IDTIPOCONS <> '9')              AND
               ((C.IDTIPOCONS = DATEPART(dw, @V_REC_DTDATA) AND @V_FERIADO = 0) OR
                (C.IDTIPOCONS = '8' AND @V_FERIADO <> 0)) AND
               C.IDQTDECONS = 'P'                        AND
               NOT EXISTS (SELECT
                              CDFILIAL
                           FROM
                              DIASEMCONS
                           WHERE
                              CDFILIAL    = @P_FILIAL         AND
                              CDSERVFILI  = @V_REC_CDSERVFILI AND
                              DTSCONSSERV = @V_REC_DTDATA     AND
                              IDTCONSSERV IN ('P','A'))       AND
              NOT EXISTS (SELECT
                             CDFILIAL
                           FROM
                             CONSSERV
                          WHERE
                             CDFILIAL   = @P_FILIAL         AND
                             CDSERVFILI = @V_REC_CDSERVFILI AND
                             DTCONSSERV = @V_REC_DTDATA     AND
                             IDTIPOCONS = '9'               AND
                             IDQTDECONS = 'P')
            ORDER BY C.IDQTDECONS, C.CDPRODUTO;

            OPEN CUR_CONSSERV;
            FETCH NEXT FROM CUR_CONSSERV INTO @V_REC_CONS_CDFILIAL,
                                              @V_REC_CONS_CDSERVFILI,
                                              @V_REC_CONS_DTCONSSERV,
                                              @V_REC_CONS_CDPRODUTO,
                                              @V_REC_CONS_QTCONSSERV,
                                              @V_REC_CONS_IDQTDECONS;
 
            WHILE (@@FETCH_STATUS = 0)
            BEGIN
               /* TESTE PARA IMPEDIR DE SE CADASTRAR CONSUMO PERCAPITA PARA DIAS */
               /* ----------------------- SEM CARDAPIO ------------------------- */
               IF ((@V_IDCONSPERC = 'P') AND (NOT @V_REC_NRCARDAPIO IS NULL))
               BEGIN

                  /* TESTE PARA CALCULO DAS QUANTIDADES POR TURNO */
                  SET @V_QTCOMESTICAR = (@V_REC_CONS_QTCONSSERV * @V_REC_QTCOMESTICAR) * (1 + (@P_PEACRESCIMO / 100));
                  SET @V_QTESTITURNO1 = (@V_REC_CONS_QTCONSSERV * @V_REC_QTESTITURNO1) * (1 + (@P_PEACRESCIMO / 100));
                  SET @V_QTESTITURNO2 = (@V_REC_CONS_QTCONSSERV * @V_REC_QTESTITURNO2) * (1 + (@P_PEACRESCIMO / 100));
                  SET @V_QTESTITURNO3 = (@V_REC_CONS_QTCONSSERV * @V_REC_QTESTITURNO3) * (1 + (@P_PEACRESCIMO / 100));
                  SET @V_QTESTITURNO4 = (@V_REC_CONS_QTCONSSERV * @V_REC_QTESTITURNO4) * (1 + (@P_PEACRESCIMO / 100));
 
                  /* ----------------------- GRAVA NA PREVRETI -------------------- */
                  IF ((@V_IDCONSPERC = 'P') AND (@V_REC_CONS_IDQTDECONS = 'P'))
                  BEGIN
                     IF @P_IDARQUIVO = 'P'
                     BEGIN
                        EXEC ATUALIZA_PREVRETI @P_FILIAL,
                                               @V_REC_DTDATA,
                                               @V_REC_CDSERVFILI,
                                               @V_REC_HRINICATEN,
                                               @V_REC_NRCARDAPIO,
                                               @V_REC_QTCOMESTICAR,
                                               @V_REC_QTESTITURNO1,
                                               @V_REC_QTESTITURNO2,
                                               @V_REC_QTESTITURNO3,
                                               @V_REC_QTESTITURNO4,
                                               @V_REC_CONS_IDQTDECONS,
                                               @V_REC_CONS_CDPRODUTO,
                                               @V_REC_DTDATA,
                                               @V_REC_HRINICATEN,
                                               @V_QTCOMESTICAR,
                                               @V_QTESTITURNO1,
                                               @V_QTESTITURNO2,
                                               @V_QTESTITURNO3,
                                               @V_QTESTITURNO4,
                                               'N',
                                               @P_CDOPERADOR,
                                               'N',
                                               NULL,
                                               NULL,
                                               NULL,
                                               0,
                                               0,
					                           NULL;

                     /* ----------------------- GRAVA NA CONSPLAN -------------------- */
                     END
                     ELSE
                     BEGIN
                        SET @V_CDFAPRATCPLA = ' ';
                        IF @V_IDUTRETIPRAT = 'S'
                        BEGIN
                           SET @V_CDTPPRATCPLA = @V_CDTPRCONSPER;
                        END
                        ELSE
                        BEGIN
                           SET @V_CDTPPRATCPLA = 'PP';
                        END;

                        SET @V_CDSETOCONSPL = ' ';
                        SET @V_CDPRATCONSPL = '          ';


                        IF (@P_IDSEPPRATO = 'S') OR (@P_IDSEPPRATO = 'P')
                        BEGIN
                           IF @P_IDSEPPRATO = 'S' BEGIN
                              SELECT
                                 @V_CDARVPROD = CDARVPROD
                              FROM
                                 PRODUTO
                              WHERE
                                 CDPRODUTO = @V_REC_CONS_CDPRODUTO;

                              SELECT
                                 @V_CDSETOCONSPL = MAX(S.CDSETORCOZ)
                              FROM
                                 SETOPRODCONS S,
                                 PRODUTO P
                              WHERE
                                 (S.CDFILIAL     = @P_FILIAL)              AND
                                 (S.IDQTPRODCONS = @V_REC_CONS_IDQTDECONS) AND
                                 (S.CDPRODUTO    = P.CDPRODUTO)            AND
                                 (CHARINDEX(P.CDARVPROD, @V_CDARVPROD) = 1);

                              IF @V_CDSETOCONSPL IS NULL
                              BEGIN
                                 SET @V_CDSETOCONSPL = @V_CDSETCONPERC;

                                 IF @V_CDSETOCONSPL IS NULL
                                 BEGIN
                                    SET @V_CDSETOCONSPL = '  ';
                                 END;
                              END;
                           END;
                           IF @V_IDUTRETIPRAT = 'S'
                           BEGIN
                              SET @V_CDPRATCONSPL = @V_CDPRACONSPER;
                              SET @V_CDFAPRATCPLA = @V_CDFILCONSPER;
                           END
                           ELSE
                           BEGIN
                              SET @V_CDPRATCONSPL = LEFT('P' + REPLICATE('P', @V_TAM_MASCARA), @V_TAM_MASCARA) /*'PPPPPPPPPP'*/;
                              SET @V_CDFAPRATCPLA = 'P';
                           END;
                        END;

                        EXEC ATUALIZA_CONSPLAN @P_NRCONSPLAN,
                                               @P_FILIAL,
                                               @V_REC_DTDATA,
                                               @V_REC_CDSERVFILI,
                                               @V_REC_HRINICATEN,
                                               @V_REC_NRCARDAPIO,
                                               @V_REC_CDCLIENTE,
                                               @V_REC_CDDESTFILI,
                                               @V_REC_QTCOMESTICAR,
                                               @V_REC_QTESTITURNO1,
                                               @V_REC_QTESTITURNO2,
                                               @V_REC_QTESTITURNO3,
                                               @V_REC_QTESTITURNO4,
                                               @V_REC_CONS_IDQTDECONS,
                                               @V_CDFAPRATCPLA,
                                               @V_CDPRATCONSPL,
                                               @V_REC_CDAPRERECE,
                                               @V_CDSETOCONSPL,
                                               @V_REC_CONS_CDPRODUTO,
                                               @V_REC_DTDATA,
                                               @V_REC_HRINICATEN,
                                               @V_CDTPPRATCPLA,
                                               @V_QTCOMESTICAR,
                                               @V_QTESTITURNO1,
                                               @V_QTESTITURNO2,
                                               @V_QTESTITURNO3,
                                               @V_QTESTITURNO4,
                                               100,
                                               @V_REC_QTCOMESTICAR,
                                               'N',
                                                0,
					                            0,
					                            0,
					                            NULL;

                     END; /* GRAVACAO NA CONSPLAN OU PREVRETI */
                  END;
               END; /* TESTE DE CONSUMO PERCAPITA PARA DIAS SEM CARDAPIO */
               FETCH NEXT FROM CUR_CONSSERV INTO @V_REC_CONS_CDFILIAL, @V_REC_CONS_CDSERVFILI,
                                        	     @V_REC_CONS_DTCONSSERV, @V_REC_CONS_CDPRODUTO,
                                                 @V_REC_CONS_QTCONSSERV, @V_REC_CONS_IDQTDECONS;
            END; /* LOOP DA COMPOSIO DA CONSSERV */

            CLOSE CUR_CONSSERV;
            DEALLOCATE CUR_CONSSERV;
            FETCH NEXT FROM CUR_CONSPLAN INTO @V_REC_DTDATA,       @V_REC_CDSERVFILI,
                                              @V_REC_HRINICATEN,   @V_REC_NRCARDAPIO,
                                              @V_REC_CDCLIENTE,    @V_REC_CDDESTFILI,
                                              @V_REC_QTCOMESTICAR, @V_REC_QTESTITURNO1,
                                              @V_REC_QTESTITURNO2, @V_REC_QTESTITURNO3,
                                              @V_REC_QTESTITURNO4;
         END; /* LOOP PARA CALCULO DA CONSERV */

         CLOSE CUR_CONSPLAN;
         DEALLOCATE CUR_CONSPLAN;
      END; /* UTILIZAO DA CONSSERV */

      IF (@V_IDCONSFIXO = 'F')  /* - Consumo por servio 'FIXO' - no considera os comensais ---------- */
      BEGIN
         DECLARE CUR_CONSPLAN CURSOR FOR
         SELECT
            DT.DTDATA,
            SE.CDSERVFILI,
            LEFT(CONVERT(VARCHAR, SE.HRINICATEN) + REPLICATE('0', 4), 4) AS HRINICATEN,
            NULL NRCARDAPIO,
            'XXX' CDCLIENTE,
            'XXX' CDDESTFILI,
            0 QTCOMESTICAR,
            0 QTESTITURNO1,
            0 QTESTITURNO2,
            0 QTESTITURNO3,
            0 QTESTITURNO4
         FROM
            DATA DT, SERVICO SE
         WHERE
            (SE.CDFILIAL = @P_FILIAL) AND
            (CHARINDEX(SE.CDSERVFILI, @P_SERVICOS) > 0 OR @P_SERVICOS = 'T') AND
            (DT.DTDATA BETWEEN @P_DTINICIAL AND @P_DTFINAL)
         ORDER BY DT.DTDATA, SE.CDSERVFILI, LEFT(CONVERT(VARCHAR, SE.HRINICATEN) + REPLICATE('0', 4), 4);

         OPEN CUR_CONSPLAN;

         /* -------------------- LOOP PARA CALCULO DA CONSSERV ----------------- */
         FETCH NEXT FROM CUR_CONSPLAN INTO @V_REC_DTDATA,       @V_REC_CDSERVFILI,
                                           @V_REC_HRINICATEN,   @V_REC_NRCARDAPIO,
                                           @V_REC_CDCLIENTE,    @V_REC_CDDESTFILI,
                                           @V_REC_QTCOMESTICAR, @V_REC_QTESTITURNO1,
                                           @V_REC_QTESTITURNO2, @V_REC_QTESTITURNO3,
                                           @V_REC_QTESTITURNO4;

         WHILE (@@FETCH_STATUS = 0)
         BEGIN

            IF @V_REC_QTESTITURNO1 IS NULL
            BEGIN
          	   SET @V_REC_QTESTITURNO1 = 0;
            END;
            IF @V_REC_QTESTITURNO2 IS NULL
            BEGIN
               SET @V_REC_QTESTITURNO2 = 0;
            END;
            IF @V_REC_QTESTITURNO3 IS NULL
            BEGIN
               SET @V_REC_QTESTITURNO3 = 0;
            END;
            IF @V_REC_QTESTITURNO4 IS NULL
            BEGIN
               SET @V_REC_QTESTITURNO4 = 0;
            END;

            SELECT @V_IDUTRETIPRAT = ISNULL(IDUTRETIPRAT, 'N')
            FROM SERVICO
            WHERE (CDFILIAL   = @P_FILIAL) AND
                  (CDSERVFILI = @V_REC_CDSERVFILI);

            /* VERIFICA SE  FERIADO */
            SELECT
               @V_FERIADO = COUNT(*)
            FROM
               FERIFILI
            WHERE
               (CDFILIAL   = @P_FILIAL) AND
               (DTFERIFILI = @V_REC_DTDATA);

            /* --------------- INICIALIZACAO DO ARQUIVO PREVRETI ---------------*/
            IF (@P_IDARQUIVO IN ('P','A'))
            BEGIN

               IF (@V_IDCONSFIXO = 'F')
               BEGIN
                  DELETE FROM PREVRETI
                  WHERE
                     (CDFILIAL   = @P_FILIAL)         AND
                     (CDSERVFILI = @V_REC_CDSERVFILI) AND
                     (DTPREVRETI = @V_REC_DTDATA)     AND
                     (NRREQUEXTR = '0000000000')      AND
                     (IDPREVRETI = 'F');
               END;
            END;   


            /* ---------------- LOOP PARA COMPOSIO DA CONSSERV --------------- */

            DECLARE CUR_CONSSERV CURSOR FOR
            SELECT C.CDFILIAL,
               C.CDSERVFILI,
               C.DTCONSSERV,
               C.CDPRODUTO,
               C.QTCONSSERV,
               C.IDQTDECONS
			   FROM(
			SELECT
               C.CDFILIAL,
               C.CDSERVFILI,
               C.DTCONSSERV,
               C.CDPRODUTO,
               C.QTCONSSERV,
               C.IDQTDECONS,
			   C.IDPRODCONSFPE
            FROM
               CONSSERV C, PRODUTO P
            WHERE
               C.CDFILIAL   = @P_FILIAL         AND
               C.CDSERVFILI = @V_REC_CDSERVFILI AND
               C.DTCONSSERV = @V_REC_DTDATA     AND
               C.IDTIPOCONS = '9'               AND
               C.IDQTDECONS = 'F'               AND
               P.CDARVPROD BETWEEN @P_CDPRODUTOINI AND @P_CDPRODUTOFIN AND
               P.CDPRODUTO = C.CDPRODUTO AND
               NOT EXISTS (SELECT
                              CDFILIAL
                           FROM
                              DIASEMCONS
                           WHERE
                              CDFILIAL    = @P_FILIAL         AND
                              CDSERVFILI  = @V_REC_CDSERVFILI AND
                              DTSCONSSERV = @V_REC_DTDATA     AND
                              IDTCONSSERV IN ('F','A'))

            UNION ALL

            SELECT
               C.CDFILIAL,
               C.CDSERVFILI,
               C.DTCONSSERV,
               C.CDPRODUTO,
               C.QTCONSSERV,
               C.IDQTDECONS,
			   C.IDPRODCONSFPE
            FROM
               CONSSERV C, PRODUTO P
            WHERE
               C.CDFILIAL   = @P_FILIAL     AND
               C.CDSERVFILI = @V_REC_CDSERVFILI AND
               P.CDARVPROD BETWEEN @P_CDPRODUTOINI AND @P_CDPRODUTOFIN AND
               P.CDPRODUTO = C.CDPRODUTO AND
               C.DTCONSSERV IN (SELECT
                                 MAX(DTCONSSERV)
                              FROM
                                 CONSSERV
                              WHERE
                                 CDFILIAL    = @P_FILIAL         AND
                                 CDSERVFILI  = @V_REC_CDSERVFILI AND
                                 DTCONSSERV <= @V_REC_DTDATA     AND
                                 IDTIPOCONS <> '9')              AND

               ((C.IDTIPOCONS = DATEPART(dw, @V_REC_DTDATA) AND @V_FERIADO = 0) OR
                (C.IDTIPOCONS = '8' AND @V_FERIADO <> 0)) AND
               C.IDQTDECONS = 'F'                         AND
               NOT EXISTS (SELECT
                              CDFILIAL
                           FROM
                              DIASEMCONS
                           WHERE
                              CDFILIAL    = @P_FILIAL         AND
                              CDSERVFILI  = @V_REC_CDSERVFILI AND
                              DTSCONSSERV = @V_REC_DTDATA     AND
                              IDTCONSSERV IN ('F','A'))       AND
              NOT EXISTS (SELECT
                             CDFILIAL
                          FROM
                             CONSSERV
                          WHERE
                             CDFILIAL   = @P_FILIAL         AND
                             CDSERVFILI = @V_REC_CDSERVFILI AND
                             DTCONSSERV = @V_REC_DTDATA     AND
                             IDTIPOCONS = '9'               AND
                             IDQTDECONS = 'F')

							 )C
			WHERE (IDPRODCONSFPE <> 'S')
            ORDER BY C.IDQTDECONS, C.CDPRODUTO;
  
            OPEN CUR_CONSSERV;
            FETCH NEXT FROM CUR_CONSSERV INTO @V_REC_CONS_CDFILIAL,
                                              @V_REC_CONS_CDSERVFILI,
                                              @V_REC_CONS_DTCONSSERV,
                                              @V_REC_CONS_CDPRODUTO,
                                              @V_REC_CONS_QTCONSSERV,
                                              @V_REC_CONS_IDQTDECONS;

            WHILE (@@FETCH_STATUS = 0)
            BEGIN
            
               IF ((@V_IDCONSFIXO = 'F') AND (@V_REC_CONS_IDQTDECONS = 'F')) 
               BEGIN
  
                  /* TESTE PARA CALCULO DAS QUANTIDADES POR TURNO */
                  SET @V_QTCOMESTICAR = (@V_REC_CONS_QTCONSSERV) * (1 + (@P_PEACRESCIMO / 100));
                  SET @V_QTESTITURNO1 = 0;
                  SET @V_QTESTITURNO2 = 0;
                  SET @V_QTESTITURNO3 = 0;
                  SET @V_QTESTITURNO4 = 0;

                  /* ----------------------- GRAVA NA PREVRETI -------------------- */
                  IF ((@V_IDCONSFIXO = 'F') AND (@V_REC_CONS_IDQTDECONS = 'F'))
                  BEGIN
                     IF @P_IDARQUIVO = 'P'
                     BEGIN
                        EXEC ATUALIZA_PREVRETI @P_FILIAL,
                                               @V_REC_DTDATA,
                                               @V_REC_CDSERVFILI,
                                               @V_REC_HRINICATEN,
                                               @V_REC_NRCARDAPIO,
                                               @V_REC_QTCOMESTICAR,
                                               @V_REC_QTESTITURNO1,
                                               @V_REC_QTESTITURNO2,
                                               @V_REC_QTESTITURNO3,
                                               @V_REC_QTESTITURNO4,
                                               @V_REC_CONS_IDQTDECONS,
                                               @V_REC_CONS_CDPRODUTO,
                                               @V_REC_DTDATA,
                                               @V_REC_HRINICATEN,
                                               @V_QTCOMESTICAR,
                                               @V_QTESTITURNO1,
                                               @V_QTESTITURNO2,
                                               @V_QTESTITURNO3,
                                               @V_QTESTITURNO4,
                                               'N',
                                               @P_CDOPERADOR,
                                               'N',
                                               NULL,
                                               NULL,
                                               NULL,
                                               0,
                                               0,
					                           NULL;

                     /* ----------------------- GRAVA NA CONSPLAN -------------------- */
                     END
                     ELSE
                     BEGIN
                        SET @V_CDFAPRATCPLA = ' ';
                        IF @V_IDUTRETIPRAT = 'S'
                        BEGIN
                           SET @V_CDTPPRATCPLA = @V_CDTPRCONSFIX;
                        END
                        ELSE
                        BEGIN
                           SET @V_CDTPPRATCPLA = 'FF';
                        END;

                        SET @V_CDSETOCONSPL = ' ';
                        SET @V_CDPRATCONSPL = '          ';


                        IF (@P_IDSEPPRATO = 'S') OR (@P_IDSEPPRATO = 'P')
                        BEGIN
                           IF @P_IDSEPPRATO = 'S' BEGIN
                              SELECT
                                 @V_CDARVPROD = CDARVPROD
                              FROM
                                 PRODUTO
                              WHERE
                                 CDPRODUTO = @V_REC_CONS_CDPRODUTO;

                              SELECT
                                 @V_CDSETOCONSPL = MAX(S.CDSETORCOZ)
                              FROM
                                 SETOPRODCONS S,
                                 PRODUTO P
                              WHERE
                                 (S.CDFILIAL     = @P_FILIAL)              AND
                                 (S.IDQTPRODCONS = @V_REC_CONS_IDQTDECONS) AND
                                 (S.CDPRODUTO    = P.CDPRODUTO)            AND
                                 (CHARINDEX(P.CDARVPROD, @V_CDARVPROD) = 1);

                              IF @V_CDSETOCONSPL IS NULL
                              BEGIN
                                 SET @V_CDSETOCONSPL = @V_CDSETCONFIXO;

                                 IF @V_CDSETOCONSPL IS NULL
                                 BEGIN
                                    SET @V_CDSETOCONSPL = '  ';
                                 END;
                              END;
                           END;
                           IF @V_IDUTRETIPRAT = 'S'
                           BEGIN
                              SET @V_CDPRATCONSPL = @V_CDPRACONSFIX;
                              SET @V_CDFAPRATCPLA = @V_CDFILCONSFIX;
                           END
                           ELSE 
                           BEGIN
                              SET @V_CDPRATCONSPL = LEFT('F' + REPLICATE('F', @V_TAM_MASCARA), @V_TAM_MASCARA) /*'FFFFFFFFFF'*/;
                              SET @V_CDFAPRATCPLA = 'P';
                           END;
                        END;

                        EXEC ATUALIZA_CONSPLAN @P_NRCONSPLAN,
                                               @P_FILIAL,
                                               @V_REC_DTDATA,
                                               @V_REC_CDSERVFILI,
                                               @V_REC_HRINICATEN,
                                               @V_REC_NRCARDAPIO,
                                               @V_REC_CDCLIENTE,
                                               @V_REC_CDDESTFILI,
                                               @V_REC_QTCOMESTICAR,
                                               @V_REC_QTESTITURNO1,
                                               @V_REC_QTESTITURNO2,
                                               @V_REC_QTESTITURNO3,
                                               @V_REC_QTESTITURNO4,
                                               @V_REC_CONS_IDQTDECONS,
                                               @V_CDFAPRATCPLA,
                                               @V_CDPRATCONSPL,
                                               @V_REC_CDAPRERECE,
                                               @V_CDSETOCONSPL,
                                               @V_REC_CONS_CDPRODUTO,
                                               @V_REC_DTDATA,
                                               @V_REC_HRINICATEN,
                                               @V_CDTPPRATCPLA,
                                               @V_QTCOMESTICAR,
                                               @V_QTESTITURNO1,
                                               @V_QTESTITURNO2,
                                               @V_QTESTITURNO3,
                                               @V_QTESTITURNO4,
                                               100,
                                               @V_REC_QTCOMESTICAR,
                                               'N',
                                                0,
					                            0,
					                            0,
					                            NULL;

                     END; /* GRAVACAO NA CONSPLAN OU PREVRETI */
                  END;
               END; /* TESTE DE CONSUMO PERCAPITA PARA DIAS SEM CARDAPIO */
               FETCH NEXT FROM CUR_CONSSERV INTO @V_REC_CONS_CDFILIAL, @V_REC_CONS_CDSERVFILI,
                                         	     @V_REC_CONS_DTCONSSERV, @V_REC_CONS_CDPRODUTO,
                                                 @V_REC_CONS_QTCONSSERV, @V_REC_CONS_IDQTDECONS;
            END; /* LOOP DA COMPOSIO DA CONSSERV */
            
            CLOSE CUR_CONSSERV;
            DEALLOCATE CUR_CONSSERV;
            FETCH NEXT FROM CUR_CONSPLAN INTO @V_REC_DTDATA,       @V_REC_CDSERVFILI,
                                              @V_REC_HRINICATEN,   @V_REC_NRCARDAPIO,
                                              @V_REC_CDCLIENTE,    @V_REC_CDDESTFILI,
                                              @V_REC_QTCOMESTICAR, @V_REC_QTESTITURNO1,
                                              @V_REC_QTESTITURNO2, @V_REC_QTESTITURNO3,
                                              @V_REC_QTESTITURNO4;
         END; /* LOOP PARA CALCULO DA CONSERV */
         CLOSE CUR_CONSPLAN;
         DEALLOCATE CUR_CONSPLAN;

         /* - Consumo por servio 'FIXO SOMENTE PARA OS PRODUTOS REPLICAREM POR PONTO DE ENTREGA' - proporcional aos comensais ----- */
        
        DECLARE CUR_CONSPLAN CURSOR FOR
         SELECT
            DT.DTDATA,
            SE.CDSERVFILI,
            LEFT(CONVERT(VARCHAR, SE.HRINICATEN) + REPLICATE('0', 4), 4) AS HRINICATEN,
            'FFFFFFFFFF' NRCARDAPIO,
            CC.CDCLIENTE,
            CC.CDDESTFILI,
            SUM(CC.QTCOMESTICLI) QTCOMESTICAR,
            SUM(0) QTESTITURNO1,
            SUM(0) QTESTITURNO2,
            SUM(0) QTESTITURNO3,
            SUM(0) QTESTITURNO4
         FROM
            CARDACLI CC,
            DATA DT,
            SERVICO SE,
            CARDADIA CA
         WHERE
            (SE.CDFILIAL     = @P_FILIAL)      AND
            (CHARINDEX(SE.CDSERVFILI, @P_SERVICOS) > 0 OR @P_SERVICOS = 'T') AND
            (CA.CDFILIAL     = SE.CDFILIAL)    AND
            (CA.CDSERVFILI   = SE.CDSERVFILI)  AND
            (CA.DTCARDAPIO BETWEEN @P_DTINICIAL AND @P_DTFINAL) AND
            (DT.DTDATA       = CA.DTCARDAPIO)  AND
            (CC.CDFILIAL     = CA.CDFILIAL)    AND
            (CC.NRCARDAPIO   = CA.NRCARDAPIO)
         GROUP BY
            DT.DTDATA, SE.CDSERVFILI, LEFT(CONVERT(VARCHAR, SE.HRINICATEN) + REPLICATE('0', 4), 4), CC.CDCLIENTE, CC.CDDESTFILI
        
        OPEN CUR_CONSPLAN;
        /* -------------------- LOOP PARA CALCULO DA CONSSERV ----------------- */
        FETCH NEXT FROM CUR_CONSPLAN INTO @V_REC_DTDATA,       @V_REC_CDSERVFILI,
                                           @V_REC_HRINICATEN,   @V_REC_NRCARDAPIO,
                                           @V_REC_CDCLIENTE,    @V_REC_CDDESTFILI,
                                           @V_REC_QTCOMESTICAR, @V_REC_QTESTITURNO1,
                                           @V_REC_QTESTITURNO2, @V_REC_QTESTITURNO3,
                                           @V_REC_QTESTITURNO4;

        WHILE (@@FETCH_STATUS = 0)
        BEGIN


            IF @V_REC_QTESTITURNO1 IS NULL
            BEGIN
          	   SET @V_REC_QTESTITURNO1 = 0;
            END;
            IF @V_REC_QTESTITURNO2 IS NULL
            BEGIN
               SET @V_REC_QTESTITURNO2 = 0;
            END;
            IF @V_REC_QTESTITURNO3 IS NULL
            BEGIN
               SET @V_REC_QTESTITURNO3 = 0;
            END;
            IF @V_REC_QTESTITURNO4 IS NULL
            BEGIN
               SET @V_REC_QTESTITURNO4 = 0;
            END;

            SELECT @V_IDUTRETIPRAT = ISNULL(IDUTRETIPRAT, 'N')
            FROM SERVICO
            WHERE (CDFILIAL   = @P_FILIAL) AND
                  (CDSERVFILI = @V_REC_CDSERVFILI);
             /* VERIFICA SE  FERIADO */
             SELECT
               @V_FERIADO = COUNT(*)
            FROM
               FERIFILI
            WHERE
               (CDFILIAL   = @P_FILIAL) AND
               (DTFERIFILI = @V_REC_DTDATA);
             /* --------------- INICIALIZACAO DO ARQUIVO PREVRETI --------------- 
             IF (P_IDARQUIVO IN ('P','A')) BEGIN
                DELETE FROM PREVRETI
                 WHERE(CDFILIAL   = P_FILIAL)                AND
                      (CDSERVFILI = REC_CONSPLAN.CDSERVFILI) AND
                      (DTPREVRETI = REC_CONSPLAN.DTDATA)     AND
                      (NRREQUEXTR = '0000000000')            AND
                      (IDPREVRETI = 'F');
             END IF;
 ---------------- LOOP PARA COMPOSIO DA CONSSERV --------------- */
     
            DECLARE CUR_CONSSERV CURSOR FOR
               SELECT
					C.CDFILIAL,
					C.CDSERVFILI,
					C.DTCONSSERV,
					C.CDPRODUTO,
					C.QTCONSSERV,
					C.IDQTDECONS
				FROM PRODUTO,
			    (SELECT
				   	C.CDFILIAL,
					C.CDSERVFILI,
					C.DTCONSSERV,
					C.CDPRODUTO,
					C.QTCONSSERV,
					C.IDQTDECONS,
					C.IDPRODCONSFPE
				FROM
					CONSSERV C, PRODUTO P
				WHERE
					C.CDFILIAL   = @P_FILIAL         AND
					C.CDSERVFILI = @V_REC_CDSERVFILI AND
					C.DTCONSSERV = @V_REC_DTDATA     AND
					C.IDTIPOCONS = '9'               AND
					C.IDQTDECONS = 'F'               AND
					P.CDARVPROD BETWEEN @P_CDPRODUTOINI AND @P_CDPRODUTOFIN AND
					P.CDPRODUTO = C.CDPRODUTO AND
					NOT EXISTS (SELECT
                              CDFILIAL
                           FROM
                              DIASEMCONS
                           WHERE
                              CDFILIAL    = @P_FILIAL         AND
                              CDSERVFILI  = @V_REC_CDSERVFILI AND
                              DTSCONSSERV = @V_REC_DTDATA     AND
                              IDTCONSSERV IN ('F','A'))

                UNION ALL

                
                SELECT
                    C.CDFILIAL,
                    C.CDSERVFILI,
                    C.DTCONSSERV,
                    C.CDPRODUTO,
                    C.QTCONSSERV,
                    C.IDQTDECONS,
                    C.IDPRODCONSFPE
                 FROM
                    CONSSERV C, PRODUTO P
                 WHERE
                    C.CDFILIAL   = @P_FILIAL     AND
                    C.CDSERVFILI = @V_REC_CDSERVFILI AND
                    P.CDARVPROD BETWEEN @P_CDPRODUTOINI AND @P_CDPRODUTOFIN AND
                    P.CDPRODUTO = C.CDPRODUTO AND
                    C.DTCONSSERV IN (SELECT
                                        MAX(DTCONSSERV)
                                     FROM
                                        CONSSERV
                                     WHERE
                                         CDFILIAL    = @P_FILIAL         AND
                                         CDSERVFILI  = @V_REC_CDSERVFILI AND
                                         DTCONSSERV <= @V_REC_DTDATA     AND
                                         IDTIPOCONS <> '9')              AND
                    ((C.IDTIPOCONS = DATEPART(dw, @V_REC_DTDATA) AND @V_FERIADO = 0) OR
                    (C.IDTIPOCONS = '8' AND @V_FERIADO <> 0)) AND
                    C.IDQTDECONS = 'F'                       AND
                    NOT EXISTS (SELECT
                                   CDFILIAL
                                FROM
                                    DIASEMCONS
                               WHERE
                                   CDFILIAL    = @P_FILIAL         AND
                                   CDSERVFILI  = @V_REC_CDSERVFILI AND
                                   DTSCONSSERV = @V_REC_DTDATA     AND
                                   IDTCONSSERV IN ('F','A'))       AND
                    NOT EXISTS (SELECT
                                   CDFILIAL
                                FROM
                                   CONSSERV
                                WHERE
                                   CDFILIAL   = @P_FILIAL         AND
                                   CDSERVFILI = @V_REC_CDSERVFILI AND
                                   DTCONSSERV = @V_REC_DTDATA     AND
                                   IDTIPOCONS = '9'               AND
                                   IDQTDECONS = 'F')
								   ) C
                    WHERE
                       C.CDPRODUTO = PRODUTO.CDPRODUTO AND
                       PRODUTO.CDARVPROD BETWEEN @P_CDPRODUTOINI AND @P_CDPRODUTOFIN AND
                       (IDPRODCONSFPE = 'S')
                    ORDER BY 6, 4;
            --END;
            OPEN CUR_CONSSERV;
            FETCH NEXT FROM CUR_CONSSERV INTO @V_REC_CONS_CDFILIAL,
                                              @V_REC_CONS_CDSERVFILI,
                                              @V_REC_CONS_DTCONSSERV,
                                              @V_REC_CONS_CDPRODUTO,
                                              @V_REC_CONS_QTCONSSERV,
                                              @V_REC_CONS_IDQTDECONS;
 
            WHILE (@@FETCH_STATUS = 0)
            BEGIN
               IF ((@V_IDCONSFIXO = 'F') AND (@V_REC_CONS_IDQTDECONS = 'F')) 
               BEGIN

                  /* TESTE PARA CALCULO DAS QUANTIDADES POR TURNO */

                  SET @V_QTCOMESTICAR = (@V_REC_CONS_QTCONSSERV) * (1 + (@P_PEACRESCIMO / 100));
                  SET @V_QTESTITURNO1 = 0;
                  SET @V_QTESTITURNO2 = 0;
                  SET @V_QTESTITURNO3 = 0;
                  SET @V_QTESTITURNO4 = 0;

                   /* ----------------------- GRAVA NA PREVRETI -------------------- */
                  IF ((@V_IDCONSFIXO = 'F') AND (@V_REC_CONS_IDQTDECONS = 'F'))
                  BEGIN
                     IF @P_IDARQUIVO = 'P'
                     BEGIN
                        EXEC ATUALIZA_PREVRETI @P_FILIAL,
                                               @V_REC_DTDATA,
                                               @V_REC_CDSERVFILI,
                                               @V_REC_HRINICATEN,
                                               @V_REC_NRCARDAPIO,
                                               @V_REC_QTCOMESTICAR,
                                               @V_REC_QTESTITURNO1,
                                               @V_REC_QTESTITURNO2,
                                               @V_REC_QTESTITURNO3,
                                               @V_REC_QTESTITURNO4,
                                               @V_REC_CONS_IDQTDECONS,
                                               @V_REC_CONS_CDPRODUTO,
                                               @V_REC_DTDATA,
                                               @V_REC_HRINICATEN,
                                               @V_QTCOMESTICAR,
                                               @V_QTESTITURNO1,
                                               @V_QTESTITURNO2,
                                               @V_QTESTITURNO3,
                                               @V_QTESTITURNO4,
                                               'N',
                                               @P_CDOPERADOR,
                                               'N',
                                               NULL,
                                               NULL,
                                               NULL,
                                               0,
                                               0,
					                           NULL;

                     /* ----------------------- GRAVA NA CONSPLAN -------------------- */
                     END
                     ELSE
                     BEGIN
                        SET @V_CDFAPRATCPLA = ' ';
                        IF @V_IDUTRETIPRAT = 'S'
                        BEGIN
                           SET @V_CDTPPRATCPLA = @V_CDTPRCONSFIX;
                        END
                        ELSE
                        BEGIN
                           SET @V_CDTPPRATCPLA = 'FF';
                        END;

                        SET @V_CDSETOCONSPL = ' ';
                        SET @V_CDPRATCONSPL = '          ';


                        IF (@P_IDSEPPRATO = 'S') OR (@P_IDSEPPRATO = 'P')
                        BEGIN
                           IF @P_IDSEPPRATO = 'S' BEGIN
                              SELECT
                                 @V_CDARVPROD = CDARVPROD
                              FROM
                                 PRODUTO
                              WHERE
                                 CDPRODUTO = @V_REC_CONS_CDPRODUTO;

                              SELECT
                                 @V_CDSETOCONSPL = MAX(S.CDSETORCOZ)
                              FROM
                                 SETOPRODCONS S,
                                 PRODUTO P
                              WHERE
                                 (S.CDFILIAL     = @P_FILIAL)              AND
                                 (S.IDQTPRODCONS = @V_REC_CONS_IDQTDECONS) AND
                                 (S.CDPRODUTO    = P.CDPRODUTO)            AND
                                 (CHARINDEX(P.CDARVPROD, @V_CDARVPROD) = 1);

                              IF @V_CDSETOCONSPL IS NULL
                              BEGIN
                                 SET @V_CDSETOCONSPL = @V_CDSETCONFIXO;

                                 IF @V_CDSETOCONSPL IS NULL
                                 BEGIN
                                    SET @V_CDSETOCONSPL = '  ';
                                 END;
                              END;
                           END;
                           IF @V_IDUTRETIPRAT = 'S'
                           BEGIN
                              SET @V_CDPRATCONSPL = @V_CDPRACONSFIX;
                              SET @V_CDFAPRATCPLA = @V_CDFILCONSFIX;
                           END
                           ELSE 
                           BEGIN
                              SET @V_CDPRATCONSPL = LEFT('F' + REPLICATE('F', @V_TAM_MASCARA), @V_TAM_MASCARA) /*'FFFFFFFFFF'*/;
                              SET @V_CDFAPRATCPLA = 'P';
                           END;
                        END;

                        EXEC ATUALIZA_CONSPLAN @P_NRCONSPLAN,
                                               @P_FILIAL,
                                               @V_REC_DTDATA,
                                               @V_REC_CDSERVFILI,
                                               @V_REC_HRINICATEN,
                                               @V_REC_NRCARDAPIO,
                                               @V_REC_CDCLIENTE,
                                               @V_REC_CDDESTFILI,
                                               @V_REC_QTCOMESTICAR,
                                               @V_REC_QTESTITURNO1,
                                               @V_REC_QTESTITURNO2,
                                               @V_REC_QTESTITURNO3,
                                               @V_REC_QTESTITURNO4,
                                               @V_REC_CONS_IDQTDECONS,
                                               @V_CDFAPRATCPLA,
                                               @V_CDPRATCONSPL,
                                               @V_REC_CDAPRERECE,
                                               @V_CDSETOCONSPL,
                                               @V_REC_CONS_CDPRODUTO,
                                               @V_REC_DTDATA,
                                               @V_REC_HRINICATEN,
                                               @V_CDTPPRATCPLA,
                                               @V_QTCOMESTICAR,
                                               @V_QTESTITURNO1,
                                               @V_QTESTITURNO2,
                                               @V_QTESTITURNO3,
                                               @V_QTESTITURNO4,
                                               100,
                                               @V_REC_QTCOMESTICAR,
                                               'N',
                                                0,
					                            0,
					                            0,
					                            NULL;

                     END; /* GRAVACAO NA CONSPLAN OU PREVRETI */
                  END; 
               END;
               FETCH NEXT FROM CUR_CONSSERV INTO @V_REC_CONS_CDFILIAL, @V_REC_CONS_CDSERVFILI,
                                        	     @V_REC_CONS_DTCONSSERV, @V_REC_CONS_CDPRODUTO,
                                                 @V_REC_CONS_QTCONSSERV, @V_REC_CONS_IDQTDECONS;
            END; /* LOOP DA COMPOSIO DA CONSSERV */
            CLOSE CUR_CONSSERV;
            DEALLOCATE CUR_CONSSERV;
            FETCH NEXT FROM CUR_CONSPLAN INTO @V_REC_DTDATA,       @V_REC_CDSERVFILI,
                                              @V_REC_HRINICATEN,   @V_REC_NRCARDAPIO,
                                              @V_REC_CDCLIENTE,    @V_REC_CDDESTFILI,
                                              @V_REC_QTCOMESTICAR, @V_REC_QTESTITURNO1,
                                              @V_REC_QTESTITURNO2, @V_REC_QTESTITURNO3,
                                              @V_REC_QTESTITURNO4;
             END; /* LOOP PARA CALCULO DA CONSERV */
 
       CLOSE CUR_CONSPLAN;
       DEALLOCATE CUR_CONSPLAN;
      END; /* UTILIZAO DA CONSSERV */
   END;
      /* ------------------- EFETUA ARREDONDAMENTO DE REQUISICAO --------------- */
   IF (@P_IDARREDOND = 'S') OR (@P_IDARREDOND = 'C')
   BEGIN

      IF @P_IDARQUIVO = 'P'
      BEGIN
         DECLARE CUR_ARREDOND CURSOR FOR
         SELECT
            PV.NRREQUEXTR,
            PV.CDFILIAL,
            PV.CDSERVFILI,
            PV.DTPREVRETI,
            PV.IDPREVRETI,
            NULL,
            NULL,
            PV.CDPRODUTO,
            PV.DTLIMITERETI,
            PV.HRLIMITERETI,
            NULL,
            'XXX' CDCLIENTE,
            'XXX' CDDESTFILI,
            PR.VRARREDREQ,
            PR.VRARREDCMP,
            PV.QTPREVRETI,
            PV.QTPRERETT1,
            PV.QTPRERETT2,
            PV.QTPRERETT3,
            PV.QTPRERETT4
         FROM
            /*CONSPLANSE CO,*/ CONSPLAN CO, PRODUTO PR, PREVRETI PV
         WHERE/*
            (CO.CDFILICPLASE = @P_FILIAL)      AND
            (CO.NRCONSPLANSE = @P_NRCONSPLAN)    AND
            (PV.CDFILIAL     = @P_FILIAL)      AND
            (PV.CDSERVFILI   = CO.CDSERVCPLASE) AND*/
            (CO.CDFILICPLA = @P_FILIAL)     AND
            (CO.NRCONSPLAN = @P_NRCONSPLAN) AND
            (PV.CDFILIAL   = CO.CDFILICPLA) AND
            (PV.CDSERVFILI = CO.CDSERVCPLA) AND
            (PV.NRREQUEXTR = '0000000000')  AND
            (PR.CDPRODUTO  = PV.CDPRODUTO)  AND
            /*(PV.DTPREVRETI BETWEEN CO.DTINICCPLASE AND CO.DTFINACPLASE);*/
            (PV.DTPREVRETI BETWEEN @P_DTINICIAL AND @P_DTFINAL);

      END
      ELSE
      BEGIN  /* - Consumo planejdo (CONSPLAN) para a data e servio ------------- */
         DECLARE CUR_ARREDOND CURSOR FOR
         SELECT
            CP.NRCONSPLAN,
            CP.CDFILICPLA,
            CP.CDSERVCPLA,
            CP.DTCONSPLAN,
            CP.IDCONSPLAN,
            CP.CDFAPRATCPLA,
            CP.CDPRATCONSPL,
            CP.CDPRODCPLA,
            CP.DTLIMITECPLA,
            CP.HRLIMITECPLA,
            CP.CDTPPRATCPLA,
            CP.CDCLIECPLA,
            CP.CDDESTFICPLA,
            PR.VRARREDREQ,
            PR.VRARREDCMP,
            SUM(CP.QTCONSPLAN) QTCONSPLAN,
            SUM(CP.QTCONSPLANT1) QTCONSPLANT1,
            SUM(CP.QTCONSPLANT2) QTCONSPLANT2,
            SUM(CP.QTCONSPLANT3) QTCONSPLANT3,
            SUM(CP.QTCONSPLANT4) QTCONSPLANT4
         FROM
            PRODUTO PR, CONSPLAN CP/*, CONSPLANSE CO*/
         WHERE/*
            (CO.CDFILICPLASE = @P_FILIAL)    AND
            (CO.NRCONSPLANSE = @P_NRCONSPLAN)  AND*/
            (CP.NRCONSPLAN = @P_NRCONSPLAN) AND
            (CP.CDFILICPLA = @P_FILIAL)     AND
            (CP.DTCONSPLAN BETWEEN @P_DTINICIAL AND @P_DTFINAL) AND
            /*(CP.CDSERVCPLA = CO.CDSERVCPLASE) AND*/
            (PR.CDPRODUTO  = CP.CDPRODCPLA)
            /*(CP.DTCONSPLAN BETWEEN CO.DTINICCPLASE AND CO.DTFINACPLASE)*/
         GROUP BY
            CP.NRCONSPLAN,
            CP.CDFILICPLA,
            CP.CDSERVCPLA,
            CP.DTCONSPLAN,
            CP.IDCONSPLAN,
            CP.CDCLIECPLA,
            CP.CDDESTFICPLA,
            CP.CDFAPRATCPLA,
            CP.CDPRATCONSPL,
            CP.CDPRODCPLA,
            CP.DTLIMITECPLA,
            CP.HRLIMITECPLA,
            CP.CDTPPRATCPLA,
            PR.VRARREDREQ,
            PR.VRARREDCMP;
      END;
      OPEN CUR_ARREDOND;

      FETCH NEXT FROM CUR_ARREDOND INTO @V_REC_ARR_NRREQUCONS, @V_REC_ARR_CDFILIAL,
                                        @V_REC_ARR_CDSERVFILI, @V_REC_ARR_DTDATA,
                                        @V_REC_ARR_IDTIPOCONS, @V_REC_ARR_CDFILAUXPRAT,
                                        @V_REC_ARR_CDPRATO,    @V_REC_ARR_CDPRODUTO,
                                        @V_REC_ARR_DTLIMITE,   @V_REC_ARR_HRLIMITE,
                                        @V_REC_ARR_CDTIPOPRAT, @V_REC_ARR_CDCLIENTE,
                                        @V_REC_ARR_CDDESTFILI,
                                        @V_REC_ARR_VRARREDREQ, @V_REC_ARR_VRARREDCMP,
                                        @V_REC_ARR_QTCOMENS,   @V_REC_ARR_QTCOMENST1,
                                        @V_REC_ARR_QTCOMENST2, @V_REC_ARR_QTCOMENST3,
                                        @V_REC_ARR_QTCOMENST4;


      WHILE (@@FETCH_STATUS = 0)
      BEGIN
         IF (@P_IDARREDOND = 'S')
         BEGIN
            SET @V_ARRED = @V_REC_ARR_VRARREDREQ;
         END
         ELSE
         BEGIN
            SET @V_ARRED = @V_REC_ARR_VRARREDCMP;
         END;

         IF NOT (@V_ARRED IS NULL) AND (@V_ARRED <> 0)
         BEGIN
            IF (@V_REC_ARR_QTCOMENST1 > 0) AND ((@V_REC_ARR_QTCOMENST1 - @V_ARRED*FLOOR(@V_REC_ARR_QTCOMENST1/@V_ARRED)) > 0)
            BEGIN
               SET @V_QTPREV1 = (FLOOR(@V_REC_ARR_QTCOMENST1/@V_ARRED) + 1) * @V_ARRED;
            END
            ELSE
            BEGIN
               SET @V_QTPREV1 = @V_REC_ARR_QTCOMENST1;
            END;

            IF (@V_REC_ARR_QTCOMENST2 > 0) AND ((@V_REC_ARR_QTCOMENST2 - @V_ARRED*FLOOR(@V_REC_ARR_QTCOMENST2/@V_ARRED)) > 0)
            BEGIN
               SET @V_QTPREV2 = (FLOOR(@V_REC_ARR_QTCOMENST2/@V_ARRED) + 1) * @V_ARRED;
            END
            ELSE
            BEGIN
               SET @V_QTPREV2 = @V_REC_ARR_QTCOMENST2;
            END;

            IF (@V_REC_ARR_QTCOMENST3 > 0) AND ((@V_REC_ARR_QTCOMENST3 - @V_ARRED*FLOOR(@V_REC_ARR_QTCOMENST3/@V_ARRED)) > 0)
            BEGIN
               SET @V_QTPREV3 = (FLOOR(@V_REC_ARR_QTCOMENST3/@V_ARRED) + 1) * @V_ARRED;
            END
            ELSE
            BEGIN
               SET @V_QTPREV3 = @V_REC_ARR_QTCOMENST3;
            END;

            IF (@V_REC_ARR_QTCOMENST4 > 0) AND ((@V_REC_ARR_QTCOMENST4 - @V_ARRED*FLOOR(@V_REC_ARR_QTCOMENST4/@V_ARRED)) > 0)
            BEGIN
               SET @V_QTPREV4 = (FLOOR(@V_REC_ARR_QTCOMENST4/@V_ARRED) + 1) * @V_ARRED;
            END
            ELSE
            BEGIN
               SET @V_QTPREV4 = @V_REC_ARR_QTCOMENST4;
            END;

            IF (@V_QTPREV1 = 0) AND (@V_QTPREV2 = 0) AND (@V_QTPREV3 = 0) AND (@V_QTPREV4 = 0)
            BEGIN
               IF (@V_REC_ARR_QTCOMENS > 0) AND ((@V_REC_ARR_QTCOMENS - @V_ARRED*FLOOR(@V_REC_ARR_QTCOMENS/@V_ARRED)) >= 0)
               BEGIN
                  SET @V_QTPREV = (FLOOR(@V_REC_ARR_QTCOMENS/@V_ARRED) + 1) * @V_ARRED;
               END
               ELSE
               BEGIN
                  SET @V_QTPREV = @V_REC_ARR_QTCOMENS;
               END;
            END
            ELSE
            BEGIN
               SET @V_QTPREV = @V_QTPREV1 + @V_QTPREV2 + @V_QTPREV3 + @V_QTPREV4;
            END;

            IF @P_IDARQUIVO = 'P'
            BEGIN
               UPDATE
                  PREVRETI
               SET
                  QTPREVRETI = @V_QTPREV,
                  QTPRERETT1 = @V_QTPREV1,
                  QTPRERETT2 = @V_QTPREV2,
                  QTPRERETT3 = @V_QTPREV3,
                  QTPRERETT4 = @V_QTPREV4,
                  QTPREVRETISA = @V_REC_ARR_QTCOMENS,
                  QTPRERETT1SA = @V_REC_ARR_QTCOMENST1,
                  QTPRERETT2SA = @V_REC_ARR_QTCOMENST2,
                  QTPRERETT3SA = @V_REC_ARR_QTCOMENST3,
                  QTPRERETT4SA = @V_REC_ARR_QTCOMENST4
               WHERE
                  (CDFILIAL     = @V_REC_ARR_CDFILIAL)     AND
                  (CDSERVFILI   = @V_REC_ARR_CDSERVFILI)   AND
                  (DTPREVRETI   = @V_REC_ARR_DTDATA)       AND
                  (NRREQUEXTR   = @V_REC_ARR_NRREQUCONS)   AND
                  (IDPREVRETI   = @V_REC_ARR_IDTIPOCONS)   AND
                  (CDPRODUTO    = @V_REC_ARR_CDPRODUTO)    AND
                  (DTLIMITERETI = @V_REC_ARR_DTLIMITE)     AND
                  (HRLIMITERETI = @V_REC_ARR_HRLIMITE)     AND
                  (CDTIPOPRAT   = @V_REC_ARR_CDTIPOPRAT)   AND
                  (CDFILAUXPRAT = @V_REC_ARR_CDFILAUXPRAT) AND
                  (CDPRATO      = @V_REC_ARR_CDPRATO);

            END
            ELSE
            BEGIN
               UPDATE
                  CONSPLAN
               SET
                  QTCONSPLAN   = @V_QTPREV,
                  QTCONSPLANT1 = @V_QTPREV1,
                  QTCONSPLANT2 = @V_QTPREV2,
                  QTCONSPLANT3 = @V_QTPREV3,
                  QTCONSPLANT4 = @V_QTPREV4,
                  QTCONSPLANSA = @V_REC_ARR_QTCOMENS,
                  QTCONPLAT1SA = @V_REC_ARR_QTCOMENST1,
                  QTCONPLAT2SA = @V_REC_ARR_QTCOMENST2,
                  QTCONPLAT3SA = @V_REC_ARR_QTCOMENST3,
                  QTCONPLAT4SA = @V_REC_ARR_QTCOMENST4
               WHERE
                  (CDFILICPLA   = @V_REC_ARR_CDFILIAL)     AND
                  (NRCONSPLAN   = @V_REC_ARR_NRREQUCONS)   AND
                  (CDSERVCPLA   = @V_REC_ARR_CDSERVFILI)   AND
                  (DTCONSPLAN   = @V_REC_ARR_DTDATA)       AND
                  (IDCONSPLAN   = @V_REC_ARR_IDTIPOCONS)   AND
                  (CDCLIECPLA   = @V_REC_ARR_CDCLIENTE)    AND
                  (CDDESTFICPLA = @V_REC_ARR_CDDESTFILI)   AND
                  (CDFAPRATCPLA = @V_REC_ARR_CDFILAUXPRAT) AND
                  (CDPRATCONSPL = @V_REC_ARR_CDPRATO)      AND
                  (CDPRODCPLA   = @V_REC_ARR_CDPRODUTO)    AND
                  (DTLIMITECPLA = @V_REC_ARR_DTLIMITE)     AND
                  (HRLIMITECPLA = @V_REC_ARR_HRLIMITE)     AND
                  (CDTPPRATCPLA = @V_REC_ARR_CDTIPOPRAT);
            END;
         END; /* SE HOUVER FATOR DE ARREDONDAMENTO DO PRODUTO*/
         FETCH NEXT FROM CUR_ARREDOND INTO @V_REC_ARR_NRREQUCONS, @V_REC_ARR_CDFILIAL,
                                           @V_REC_ARR_CDSERVFILI, @V_REC_ARR_DTDATA,
                                           @V_REC_ARR_IDTIPOCONS, @V_REC_ARR_CDFILAUXPRAT,
                                           @V_REC_ARR_CDPRATO,    @V_REC_ARR_CDPRODUTO,
                                           @V_REC_ARR_DTLIMITE,   @V_REC_ARR_HRLIMITE,
                                           @V_REC_ARR_CDTIPOPRAT, @V_REC_ARR_CDCLIENTE,
                                           @V_REC_ARR_CDDESTFILI,
                                           @V_REC_ARR_VRARREDREQ, @V_REC_ARR_VRARREDCMP,
                                           @V_REC_ARR_QTCOMENS,   @V_REC_ARR_QTCOMENST1,
                                           @V_REC_ARR_QTCOMENST2, @V_REC_ARR_QTCOMENST3,
                                           @V_REC_ARR_QTCOMENST4;
      END;
      CLOSE CUR_ARREDOND;
      DEALLOCATE CUR_ARREDOND;
   END; /* ARREDONDAMENTO DE REQUISICAO */

   /* GRAVACAO NA PREVRETI APOS GRAVACAO NA CONSPLAN */
   IF (@P_IDARQUIVO = 'A')
   BEGIN
      SET @V_SERV_ATUAL = ' ';

      DECLARE C_PREVRETI CURSOR FOR
         SELECT
             CDFILICPLA, CDSERVCPLA, DTCONSPLAN,
             '0000000000', IDCONSPLAN, CDPRODCPLA,
             DTLIMITECPLA, HRLIMITECPLA, SUM(QTCONSPLAN) AS QTCONSPLAN,
             SUM(QTCONSPLANT1) AS QTCONSPLANT1, SUM(QTCONSPLANT2) AS QTCONSPLANT2, SUM(QTCONSPLANT3) AS QTCONSPLANT3,
             SUM(QTCONSPLANT4) AS QTCONSPLANT4, SUM(QTCONSPLANSA) AS QTCONSPLANSA, SUM(QTCONPLAT1SA) AS QTCONPLAT1SA,
             SUM(QTCONPLAT2SA) AS QTCONPLAT2SA, SUM(QTCONPLAT3SA) AS QTCONPLAT3SA, SUM(QTCONPLAT4SA) AS QTCONPLAT4SA,
             CDTPPRATCPLA, CDFAPRATCPLA, CDPRATCONSPL, SUM(QTCONSBRUTAUNR) AS QTCONSBRUTAUNR, SGCONSUNIADIC
          FROM
             SERVICO S,
             CONSPLAN C
          WHERE
             (CDFILICPLA = @P_FILIAL)     AND
             (NRCONSPLAN = @P_NRCONSPLAN) AND
             (CHARINDEX(CDSERVCPLA, @P_SERVICOS) > 0 OR @P_SERVICOS = 'T') AND
             (C.IDCONSPLAN IN (@V_IDCARDAPIO,@V_IDCONSFIXO,@V_IDCONSPERC)) AND
             (S.CDFILIAL = C.CDFILICPLA) AND
             (S.CDSERVFILI = C.CDSERVCPLA) AND
             (S.IDUTRETIPRAT = 'S')
          GROUP BY
             CDFILICPLA, CDSERVCPLA, DTCONSPLAN, IDCONSPLAN, CDPRODCPLA,
             DTLIMITECPLA, HRLIMITECPLA, CDFAPRATCPLA, CDPRATCONSPL, CDTPPRATCPLA, SGCONSUNIADIC
          ORDER BY
             CDFILICPLA, CDSERVCPLA, DTCONSPLAN;

      OPEN C_PREVRETI;
      FETCH NEXT FROM C_PREVRETI INTO @C_PREVRETI_CDFILICPLA,   @C_PREVRETI_CDSERVCPLA,   @C_PREVRETI_DTCONSPLAN,
                                      @C_PREVRETI_NRREQUEXTR,   @C_PREVRETI_IDCONSPLAN,   @C_PREVRETI_CDPRODCPLA,
                                      @C_PREVRETI_DTLIMITECPLA, @C_PREVRETI_HRLIMITECPLA, @C_PREVRETI_QTCONSPLAN,
                                      @C_PREVRETI_QTCONSPLANT1, @C_PREVRETI_QTCONSPLANT2, @C_PREVRETI_QTCONSPLANT3,
                                      @C_PREVRETI_QTCONSPLANT4, @C_PREVRETI_QTCONSPLANSA, @C_PREVRETI_QTCONPLAT1SA,
                                      @C_PREVRETI_QTCONPLAT2SA, @C_PREVRETI_QTCONPLAT3SA, @C_PREVRETI_QTCONPLAT4SA,
                                      @C_PREVRETI_CDTPPRATCPLA, @C_PREVRETI_CDFAPRATCPLA, @C_PREVRETI_CDPRATCONSPL,
                                      @C_PREVRETI_QTBRUTACONS,  @C_PREVRETI_SGUNIDADE;

      WHILE (@@FETCH_STATUS = 0) BEGIN

         IF @V_SERV_ATUAL <> @C_PREVRETI_CDSERVCPLA BEGIN
            SET @V_SERV_ATUAL = @C_PREVRETI_CDSERVCPLA;
            SELECT
               @V_NRPRPREVRETI = ISNULL(MAX(PR.NRPRPREVRETI), 0)
            FROM
               PREVRETI PR
            WHERE
               (PR.CDFILIAL     = @C_PREVRETI_CDFILICPLA)   AND
               (PR.CDSERVFILI   = @C_PREVRETI_CDSERVCPLA)   AND
               (PR.DTPREVRETI   = @C_PREVRETI_DTCONSPLAN)   AND
               (PR.IDPREVRETI   = @C_PREVRETI_IDCONSPLAN)   AND
               (PR.NRREQUEXTR   = '0000000000');
         END;

         SET @V_NRPRPREVRETI = RIGHT('0000'+CONVERT(VARCHAR(4), CONVERT(DOUBLE PRECISION, @V_NRPRPREVRETI) + 1), 4);

         INSERT INTO PREVRETI
            (CDFILIAL,     CDSERVFILI,   DTPREVRETI,   NRREQUEXTR,
             IDPREVRETI,   CDPRODUTO,    DTLIMITERETI, HRLIMITERETI,
             QTPREVRETI,   QTPRERETT1,   QTPRERETT2,   QTPRERETT3,
             QTPRERETT4,   QTPREVRETISA, QTPRERETT1SA, QTPRERETT2SA,
             QTPRERETT3SA, QTPRERETT4SA, CDTIPOPRAT,   CDFILAUXPRAT,
             CDPRATO,      IDPREVTPPRAT, NRPRPREVRETI, CDOPERADOR, QTPREVBRUTAUNR, SGPREVUNIADIC)
         VALUES(
          @C_PREVRETI_CDFILICPLA, @C_PREVRETI_CDSERVCPLA, @C_PREVRETI_DTCONSPLAN,
          '0000000000', @C_PREVRETI_IDCONSPLAN, @C_PREVRETI_CDPRODCPLA,
          CONVERT(DATETIME, CONVERT(VARCHAR, @C_PREVRETI_DTLIMITECPLA, 103), 103),
          @C_PREVRETI_HRLIMITECPLA, @C_PREVRETI_QTCONSPLAN,
          @C_PREVRETI_QTCONSPLANT1, @C_PREVRETI_QTCONSPLANT2, @C_PREVRETI_QTCONSPLANT3,
          @C_PREVRETI_QTCONSPLANT4, @C_PREVRETI_QTCONSPLANSA, @C_PREVRETI_QTCONPLAT1SA,
          @C_PREVRETI_QTCONPLAT2SA, @C_PREVRETI_QTCONPLAT3SA, @C_PREVRETI_QTCONPLAT4SA,
          @C_PREVRETI_CDTPPRATCPLA, @C_PREVRETI_CDFAPRATCPLA, @C_PREVRETI_CDPRATCONSPL,
          'S', @V_NRPRPREVRETI, @P_CDOPERADOR, @C_PREVRETI_QTBRUTACONS, @C_PREVRETI_SGUNIDADE);

         FETCH NEXT FROM C_PREVRETI INTO @C_PREVRETI_CDFILICPLA,   @C_PREVRETI_CDSERVCPLA,   @C_PREVRETI_DTCONSPLAN,
                                         @C_PREVRETI_NRREQUEXTR,   @C_PREVRETI_IDCONSPLAN,   @C_PREVRETI_CDPRODCPLA,
                                         @C_PREVRETI_DTLIMITECPLA, @C_PREVRETI_HRLIMITECPLA, @C_PREVRETI_QTCONSPLAN,
                                         @C_PREVRETI_QTCONSPLANT1, @C_PREVRETI_QTCONSPLANT2, @C_PREVRETI_QTCONSPLANT3,
                                         @C_PREVRETI_QTCONSPLANT4, @C_PREVRETI_QTCONSPLANSA, @C_PREVRETI_QTCONPLAT1SA,
                                         @C_PREVRETI_QTCONPLAT2SA, @C_PREVRETI_QTCONPLAT3SA, @C_PREVRETI_QTCONPLAT4SA,
                                         @C_PREVRETI_CDTPPRATCPLA, @C_PREVRETI_CDFAPRATCPLA, @C_PREVRETI_CDPRATCONSPL,
                                         @C_PREVRETI_QTBRUTACONS,  @C_PREVRETI_SGUNIDADE ;


      END;
      CLOSE C_PREVRETI;
      DEALLOCATE C_PREVRETI;
 
      INSERT INTO PREVRETI
         (CDFILIAL,     CDSERVFILI,   DTPREVRETI,   NRREQUEXTR,
          IDPREVRETI,   CDPRODUTO,    DTLIMITERETI, HRLIMITERETI,
          QTPREVRETI,   QTPRERETT1,   QTPRERETT2,   QTPRERETT3,
          QTPRERETT4,   QTPREVRETISA, QTPRERETT1SA, QTPRERETT2SA,
          QTPRERETT3SA, QTPRERETT4SA, IDPREVTPPRAT, CDOPERADOR)
      (SELECT
          CDFILICPLA, CDSERVCPLA, DTCONSPLAN,
          '0000000000', IDCONSPLAN, CDPRODCPLA,
          CONVERT(DATETIME, CONVERT(VARCHAR, DTLIMITECPLA, 103), 103), HRLIMITECPLA,
          CASE ISNULL(P.VRARRED, 0)
             WHEN 0.0 THEN SUM(QTCONSPLANSA)
             ELSE CASE SUM(QTCONSPLANSA) - FLOOR(SUM(QTCONSPLANSA))
                     WHEN 0.0 THEN SUM(QTCONSPLANSA)
                     ELSE (FLOOR(SUM(QTCONSPLANSA) / P.VRARRED) + 1) * P.VRARRED
                  END
          END AS QTCONSPLAN, /*SUM(QTCONSPLAN),*/
          SUM(QTCONSPLANT1), SUM(QTCONSPLANT2), SUM(QTCONSPLANT3),
          SUM(QTCONSPLANT4), SUM(QTCONSPLANSA), SUM(QTCONPLAT1SA),
          SUM(QTCONPLAT2SA), SUM(QTCONPLAT3SA), SUM(QTCONPLAT4SA),
          'N', @P_CDOPERADOR
       FROM
          SERVICO S,
          CONSPLAN C,
          (SELECT
              CDPRODUTO,
              CASE @P_IDARREDOND
                 WHEN 'S' THEN VRARREDREQ
                 WHEN 'C' THEN VRARREDCMP
                 ELSE 0
              END AS VRARRED
           FROM PRODUTO) P
       WHERE
          (CDFILICPLA = @P_FILIAL)     AND
          (NRCONSPLAN = @P_NRCONSPLAN) AND
          (CHARINDEX(CDSERVCPLA, @P_SERVICOS) > 0 OR @P_SERVICOS = 'T') AND
          (C.IDCONSPLAN IN (@V_IDCARDAPIO,@V_IDCONSFIXO,@V_IDCONSPERC)) AND
          (S.CDFILIAL = C.CDFILICPLA)   AND
          (S.CDSERVFILI = C.CDSERVCPLA) AND
          (S.IDUTRETIPRAT <> 'S') AND
          (C.CDPRODCPLA = P.CDPRODUTO)
       GROUP BY
          CDFILICPLA, CDSERVCPLA, DTCONSPLAN, IDCONSPLAN, CDPRODCPLA,
          DTLIMITECPLA, HRLIMITECPLA, P.VRARRED );

   END;
   
     
/*   DELETE FROM CONSPLANSE
   WHERE
      (CDFILICPLASE = @P_FILIAL) AND
      (NRCONSPLANSE = @P_NRCONSPLAN);*/
END;
GO


-- VERSAO --
EXEC ATUVEROBJ 'CONSUMO_PLANEJADO_PLA','5.65.000';
GO







