// FILE: ./assets/js/utilities/Utilities.js
function Utilities(ScreenService, General, ZhPreferences, Query, validateEngine, ZhFilterPreferences, templateManager, LibUtilities, MessageService, localStorageEngine) {

/*global Util, Configuration, $*/

    this.changeTagRichText = function(fieldValue) {
        if (typeof(fieldValue) === 'string') {
            var newFieldValue;

            if (fieldValue.substr(0, 3) == '<p>') {
                newFieldValue = fieldValue.replace(/<p>/g, '').replace(/<\/p>/g, '<br>');
            }
            else if (fieldValue.substr(0, 3) == '<p ') {
                newFieldValue = fieldValue.replace(/<p/g, '<span').replace(/<\/p>/g, '</span><br>');
            }
            else {
                newFieldValue = fieldValue;
            }

            if (fieldValue.substr(-4) == '</p>') {
                newFieldValue = newFieldValue.slice('', -4);
            }

            return newFieldValue;
        }
        else {
            return fieldValue;
        }
    };

    this.startFilter = function(widget, currentRow) {
        return ZhPreferences.getDefaultWidgetPreferences(widget.id).then(function(result) {
            if (result && result.DEFAULT_FILTER) {
                ZhPreferences.getPreferences('filter', Query.build().where('WIDGET_ID').equals(widget.id)).then(function(filters) {
                    var defaultFilter = filters.filter(function(filter) {
                        return filter.ID == result.DEFAULT_FILTER;
                    })[0];
                    var filter = {
                        ID: defaultFilter.LABEL_TO_PREFERENCE || 'EDITED',
                        FILTER_ROW: JSON.parse(defaultFilter.FILTER_ROW)
                    };

                    currentRow = filter.FILTER_ROW;

                    ZhFilterPreferences.applyFilter(widget, filter).then(function() {
                        widget.appliedFilter = widget.appliedFilter || filter;
                        widget.appliedFilter.ID = result.DEFAULT_FILTER;
                        if (defaultFilter.LABEL_TO_PREFERENCE) {
                            widget._filterInfo[0].value = defaultFilter.LABEL_TO_PREFERENCE;
                        }
                    });
                });
            }
            else {
                if (Util.isUndefinedOrNull(currentRow) || Util.isEmptyObject(currentRow)) {
                    currentRow = buildFilterCurrentRow(widget);
                }
            }
            ZhFilterPreferences.openFilterWidget(widget, currentRow);
        });
    };

    var buildFilterCurrentRow = function(widget) {
        return getFilterRowWithDefaultValues(widget.fields);
    };

    var getFilterRowWithDefaultValues = function(filterFields) {
        let filterRow = {};
        filterFields.forEach(field => {
            let defaultValue = Util.getNestedProperty(field, ["filterProperties", "defaultValue"]) || field.defaultValue;
            if (!Util.isUndefinedOrNull(defaultValue)) {
                filterRow[field.name] = Util.evaluate(defaultValue);
            }
        });
        return filterRow;
    };
    
    function formatStringToFloat(word, simbolThousands, simbolDecimals){
        word = word.split(simbolThousands).join('');
        word = word.replace(simbolDecimals, '.');    
        return word;
    }


    function verifyRange(value, validationAttrs) {
        const maxValue = validationAttrs.max || '9999999.99';
        const minValue = validationAttrs.min || 0;
        const simbolThousands = validationAttrs.thousands || '.';
        const simbolDecimals = validationAttrs.decimals || ',';
        let valid = true;
        let msg = ScreenService.i18n(validationAttrs.message) || ScreenService.i18n("Não está dentro do intervalo de " + minValue + " a " + maxValue);
        
        if (typeof(value) == 'string') {
            value = formatStringToFloat(value, simbolThousands, simbolDecimals);
        }

        if (value && (parseFloat(value) > parseFloat(maxValue) || parseFloat(value) < parseFloat(minValue))) {
            valid = false;
        }
        
        return  {"valid": valid, "message": msg};
    }
    
    function validaProduto(value, validationAttrs) {

        var filtro = templateManager.container.getActiveWidget();
        var retorno = {
            "valid": true
        };
        let field = validationAttrs.field;
        let fieldProduto;
        const final = filtro.currentRow.CDPRODFIN;
        const inicial = filtro.currentRow.CDPRODINI;

        if (value) {
            fieldProduto = field == "NMPRODFIN" ? inicial : final;
            if (fieldProduto) {
                if (inicial > final) {
                    return {
                        "valid": false,
                        "message": ScreenService.i18n(validationAttrs.message) || ScreenService.i18n('Produto inicial deve ser menor ou igual ao produto final')
                    };
                }
            }
        }
        else if (field == "NMPRODFIN" && filtro.currentRow.CDPRODINI || field == "NMPRODINI" && filtro.currentRow.CDPRODFIN) {
            let msg = field == "NMPRODFIN" ? 'Produto final obrigatório' : 'Produto inicial obrigatório';
            return {
                "valid": false,
                "message": ScreenService.i18n(validationAttrs.message) || ScreenService.i18n(msg)
            };
        }

        return retorno;
    }
    
    var registeredValidations = validateEngine.getMappedValidations();
    
    if (!registeredValidations.hasOwnProperty('verifyRange')) {
        validateEngine.registerValidation('verifyRange', verifyRange);
    }
    
    
    if (!registeredValidations.hasOwnProperty('validaProduto')) {
        validateEngine.registerValidation('validaProduto', validaProduto);
    }
    
    this.saveCollectedDataGeneric = function (widget, description = undefined, ids = undefined, fromFilter = false) {
    	let collectionIds;
    	let valuesWidget = widget;
    	
    	if(fromFilter) {
            valuesWidget = templateManager.container.factoredWidgets.filter((widget) => {
                return widget._filteredWidgetId == valuesWidget.id;
            })[0];
        }
        
        if(valuesWidget) {
        	if(valuesWidget.currentRow) {
        		if(valuesWidget.currentRow.CDFILIALOL)
        			collectionIds = valuesWidget.currentRow.CDFILIALOL;
        		else if(valuesWidget.currentRow.CDFILIAL)
        			collectionIds = valuesWidget.currentRow.CDFILIAL;
        		else if(valuesWidget.currentRow.CDFILIALUN)
        	        collectionIds = valuesWidget.currentRow.CDFILIALUN;
        	    else
        	        return null;
        	} else
        	    return null;
        } else
            return null;
        
        //widget instanceof Container
    	let operationId = '';
    	
    	MessageService.getMessageByCode("UTLTELA").then(fraseComParametro => {
    	    operationId = ScreenService.i18n(fraseComParametro, { NMTELA: description });
        	/*
        	* Lista de descriptions utilizadas para tentar padronizar chamadas:
        	* ContainerAfterinit
        	*/
        	/*
    	    * @param $collectionIds  => ID ou ARRAY da(s) coleta(s) (Cod Filial, Cod Operador, Cod da Loja, ...)
    	    * @param $operationId    => ID da operação (Retirada, Cardápio, Login, ...)
    	    * @param $productId      => Código do Produto (opcional).
    	    * @param $operatorCode   => Código do Operador (opcional).
    	    * @param $operatorName   => Nome do Operador (opcional).
    	    * @param $organizationId => Código do organização (opcional).
    	    */
        	LibUtilities.saveCollectedData(collectionIds, operationId);
    	});
    };
    
    this.getLocalVar = function(key) {
        return localStorageEngine.getLocalVar(key);
    };
    
    this.nextContainerAfterInit = function(container, route) {
        try{
    		if(typeof memoryStorage !== 'undefined') {
	            localStorageEngine.getLocalVar = memoryStorage.getLocalVar;
	            localStorageEngine.setLocalVar = memoryStorage.setLocalVar;
	            setLocalVar = memoryStorage.setLocalVar;
	            getLocalVar = memoryStorage.getLocalVar;
	        }
	        
    		getLocalVar('loginPromise').then(() => {
		        var token = localStorage.getItem('LOGIN_TOKEN');
		        var hash = localStorage.getItem('LOGIN_HASH') || '0';
		        var user      = localStorage.getItem('NEXTSESSION_ENCRYPTED');
		        var languange = localStorage.getItem('LOGIN_LANGUAGE');
		        var productId = window.projectId;
		
		        var url = window.nextUrl + 'modules/opl-next/' + route + "?header=0&menu=0" +
		                                                     "&token=" + token +
		                                                     "&hash=" + hash +
		                                                     "&user=" + user +
		                                                     "&languange=" + languange +
		                                                     "&productId=" + productId +
		                                                     "&isZhAngular=1";
		
		        // Clear OM session timeout to use only OM Next session timeout.
		        //clearTimeout(LibUtilities.expiredSessionMethod);
		        
		        console.log(url);
		
		        container.widgets[0].sourceUrl = url;
    		});
    	} catch(error) {
    	    console.log(error);
    		return null;
    	}
    };
}

Configuration(function(ContextRegister) {
    ContextRegister.register('Utilities', Utilities);
});

// FILE: ./assets/js/services/Constants.js

if (typeof Constants === "undefined") {
	var Constants = {
		successNotification: {
			type: "success"
		}, 

		successMessage: {
			type: "success",
			icon: "checked"
		},

		errorNotification: {
			type: "error"
		},

		errorMessage: {
			type: "error",
			icon: "error"
		},

		alertMessage: {
			type: "alert",
			icon: "exclamation"
		},

		infoMessage: {
			type: "information",
			icon: "information"
		},

		confirmationMessage: {
			type: "question",
			icon: "question"
		}
	};
}

// FILE: ./assets/modules/relatorios/assets/js/services/emissao_de_pedidos_Service.js
function emissao_de_pedidos_Service(restEngine) {
    this.empresasPorUnidade = function(currentRow) {
        const dadosPost = {
            "requestType": "FilterData",
            "filter": [
                {
                    "name": "CDFILIAL",
                    "value": currentRow.CDFILDEST,
                    "operator": "="
                },
                {
                    "name": "NRORG",
                    "value": getLocalVar("NRORG"),
                    "operator": "="
                }
            ]
        };
        
        return restEngine.post("opl_relatorios#/crud/sup07200_empresas_por_unidade", dadosPost);
    };
    
    this.empresaClientePrincipal = function(currentRow) {
        const dadosPost = {
            "requestType": "FilterData",
            "filter": [
                {
                    "name": "IDCLIENPRIN",
                    "value": "S",
                    "operator": "="
                },
                {
                    "name": "CDFILIAL",
                    "value": currentRow.CDFILDEST,
                    "operator": "="
                },
                {
                    "name": "NRORG",
                    "value": getLocalVar("NRORG"),
                    "operator": "="
                }
            ]
        };
        
        return restEngine.post("opl_relatorios#/crud/sup07200_empresa_cliente_principal", dadosPost);
    };
    
    this.enviaEmailEmissaoPedidoOL = function(row) {
        return restEngine.post("opl_relatorios#/enviaEmailEmissaoPedidoOL", {
            "requestType": "Row",
            "row": row
        });
    };
    
    this.retornaCookieEmail = function() {
        return restEngine.post("opl_relatorios#/retornaCookieEmail", {
            "requestType": "Row",
            "row": {}
        });
    };
}

Configuration(function (ContextRegister) {
    ContextRegister.register("emissao_de_pedidos_Service", emissao_de_pedidos_Service);
});

// FILE: ./assets/modules/documentosFiscais/assets/js/services/Dfs72000_EntradaDevolucoesOperadorLogistico_Service.js
function Dfs72000_EntradaDevolucoesOperadorLogistico_Service (General){
      
    this.buildFilter = function(fieldsName, currentRow) { 
        let filter = [];
        fieldsName.forEach((fieldName) => {
            filter.push({
                "name": "P_".concat(fieldName),
                "operator": "=",
                "value": (currentRow[fieldName]) ? currentRow[fieldName] : 'T'
            }); 
        });
        return filter;
    };
    
    this.getParamGeral = function() {
        return General.callRestEngine("opl#/crud/paramgeral", "FilterData", []);
    };
    
    this.getDtProcessa = function(){
        var filter = [
            {
                "name": "CDFILIAL",
                "operator": "=",
                "value": "0008"
            }
        ];
        return General.callRestEngine("opl#/crud/paramestoque_processamento", "FilterData", filter);
    };
    
    this.getFilial = function(){
        var filter = [
            {
                "name": "CDFILIAL",
                "operator": "=",
                "value": "0008"
            }
        ];
        return General.callRestEngine("opl#/crud/filial", "FilterData", filter);
    };
    
    
    this.dataAtualFormatada = function(){
        var data = new Date();
        var dia = data.getDate() + 1;
        if (dia.toString().length == 1)
          dia = "0"+dia;
        var mes = data.getMonth()+1;
        if (mes.toString().length == 1)
          mes = "0"+mes;
        var ano = data.getFullYear();  
        return dia+"/"+mes+"/"+ano;
    };
}
Configuration(function (ContextRegister){
    ContextRegister.register('Dfs72000_EntradaDevolucoesOperadorLogistico_Service', Dfs72000_EntradaDevolucoesOperadorLogistico_Service);
});


// FILE: ./assets/modules/autorizacaoFornecimento/assets/js/services/Cmp03900_LancamentoAutorizacaoDeFornecimento_Service.js
function Cmp03900_LancamentoAutorizacaoDeFornecimento_Service(restEngine){
    
    this.retornaComprador = function() {
        return restEngine.post('opl#/crud/comprador_operador', {
            "requestType": "FilterData",
            "filter": [
                {
                    "name": "CDOPERADOR",
                    "operator": "=",
                    "value": getLocalVar('CDOPERADOR') ? getLocalVar("CDOPERADOR") : "OPERADOR_LOGADO"
                }
            ]
        });
    };
    
}

Configuration(function (ContextRegister) {
    ContextRegister.register('Cmp03900_LancamentoAutorizacaoDeFornecimento_Service', Cmp03900_LancamentoAutorizacaoDeFornecimento_Service);
});

// FILE: ./assets/modules/autorizacaoFornecimento/assets/js/services/sup05100_analise_AF_Service.js
function sup05100_analise_AF_Service(restEngine){
    
    this.retornaCentralCompras = function(cdfilial) {
        return restEngine.post('opl#/crud/central_compras', {
            "requestType": "FilterData",
            "filter": [{
                "name": "CDFILIAL",
                "operator": "=",
                "value": cdfilial
            }]
        });
    };
    
    this.retornaParaSupriCentralCompras = function(cdfilial) {
        return restEngine.post('opl#/crud/parasupri_central_compras', {
            "requestType": "FilterData",
            "filter": [{
                "name": "CDFILIAL",
                "operator": "=",
                "value": cdfilial
            }]
        });
    };
    
    this.retornaCountAF = function(cdfildest, cdfillanc, nrseqapuraf) {
        return restEngine.post('opl_autorizacaoFornecimento#/crud/sup05100_afs_count', {
            "requestType": "FilterData",
            "filter": [
                { "name": "CDFILDEST", "operator": "=", "value": cdfildest },
                { "name": "CDFILLANC", "operator": "=", "value": cdfillanc },
                { "name": "NRSEQAPURAF", "operator": "=", "value": nrseqapuraf }]
        });
        
    };
    
    this.remanejarItensAF = function(prodSelecionados, afDestino, currentRowRemanejo, idSituacaoApuPrec) {
        return restEngine.post('opl_autorizacaoFornecimento#/sup05100_remanejarItensAF', {
            "requestType": "Row",
            "row": {
                "AF_ORIGEM": prodSelecionados,
                "AF_DESTINO": afDestino,
                "REMANEJO": currentRowRemanejo,
                "IDSITAPUPREC": idSituacaoApuPrec
            }
        });
    };
    
    this.remanejarAF = function(afsSelecionadas, afDestino, currentRowRemanejo, idSituacaoApuPrec) {
        return restEngine.post('opl_autorizacaoFornecimento#/sup05100_remanejarAF', {
            "requestType": "Row",
            "row": {
                "AF_ORIGEM": afsSelecionadas,
                "AF_DESTINO": afDestino,
                "REMANEJO": currentRowRemanejo,
                "IDSITAPUPREC": idSituacaoApuPrec
            }
        });
    };
    
    this.remanejarAFTrocaProd = function(afDestino, prodDestino, afOrigem, idSituacaoApuPrec) {
        return restEngine.post('opl_autorizacaoFornecimento#/sup05100_remanejarTrocarProduto', {
            "requestType": "Row",
            "row": {
                "AF_ORIGEM": afOrigem,
                "AF_DESTINO": afDestino,
                "ITEM_DESTINO": prodDestino,
                "IDSITAPUPREC": idSituacaoApuPrec
            }
        });
    };
    
    this.concluirAF = function(row) {
        return restEngine.post('opl_autorizacaoFornecimento#/sup05100_concluirAF', {
            "requestType": "Row",
            "row": row
        });
    };
    
    this.salvaEdicaoProduto = function(currentRow) {
        return restEngine.post('opl_autorizacaoFornecimento#/sup05100_salvaEdicaoProduto', {
            "requestType": "Row",
            "row": {
                "NRAPURPREC": currentRow.NRAPURPREC,
                "CDFILCENTCMP": currentRow.CDFILCENTCMP,
                "CDFILDEST": currentRow.CDFILDEST,
                "CDFILLANC": currentRow.CDFILLANC,
                "CDPRODUTO": currentRow.CDPRODUTO,
                "VRFATOCONV": currentRow.VRFATOCONV,
                "DTPROGENTAF": currentRow.DTPROGENTAF,
                "CDFORNECED": currentRow.CDFORNECED,
                "QTPROGENTAF": currentRow.QTPROGENTAF,
                "NRAUTOFORN": currentRow.NRAUTOFORN,
                "CDMARCA": currentRow.CDMARCA,
                "DTPROGENTAF_OLD": currentRow.DTPROGENTAF_OLD,
                "QTPROGENTAF_OLD": currentRow.QTPROGENTAF_OLD,
                "IDGERAFDTENT": currentRow.IDGERAFDTENT,
                "ATUSOLICITACMP": currentRow.ATUSOLICITACMP,
                "ALTERADTENTREGA": currentRow.ALTERADTENTREGA,
                "IDSITAPUPREC": currentRow.IDSITAPUPREC,
                "IDFUNCAOFILI": currentRow.IDFUNCAOFILI,
                "IDCONSOLAPUEFET": currentRow.IDCONSOLAPUEFET
            }
        });
    };
    
    this.verificaOperadorRelacionado = function(apuracao) {
        return restEngine.post('opl_autorizacaoFornecimento#/sup05100_verificaOperadorRelacionado', {
            "requestType": "Row",
            "row": apuracao
        });
    };
    
    this.validarBeforeLiberarAF = function(currentRow) {
        return restEngine.post('opl_autorizacaoFornecimento#/sup05100_validar_before_liberar_af', {
            "requestType": "Row",
            "row": currentRow
        });
    };
    
    this.liberarAFInconsistente = function(row) {
        return restEngine.post('opl_autorizacaoFornecimento#/sup05100_liberar_af_inconsistente', {
            "requestType": "Row",
            "row": row
        });
    };
    
    this.verificarGerenteComprador = function(currentRow) {
        return restEngine.post('opl_autorizacaoFornecimento#/sup05100_verificar_gerente_comprador', {
            "requestType": "Row",
            "row": {
                "CDCOMPRADOR": currentRow.CDCOMPRADOR
            }
        });
    };
    
    this.validarSenhaGerente = function(currentRow) {
        return restEngine.post('opl_autorizacaoFornecimento#/sup05100_validar_senha_gerente', {
            "requestType": "Row",
            "row": currentRow
        });
    };
    
    this.excluirAF = function(row) {
        return restEngine.post('opl_autorizacaoFornecimento#/sup05100_excluir_af', {
            "requestType": "Row",
            "row": row
        });
    };
    
    this.defineCookieEmail = function(row) {
        return restEngine.post('opl_autorizacaoFornecimento#/sup05100_define_cookie_email', {
            "requestType": "Row",
            "row": row
        });
    };
    
    this.retornaCookieEmail = function(row) {
        return restEngine.post('opl_autorizacaoFornecimento#/sup05100_retorna_cookie_email', {
            "requestType": "Row",
            "row": row
        });
    };
    
    this.resendEmail = function(row) {
        return restEngine.post('opl_autorizacaoFornecimento#/resendEmailandSaveFile', {
            "requestType": "Row",
            "row": row
        });
    };
    
    this.concluiRemanejamentoApuracao = function(row) {
        return restEngine.post('opl_autorizacaoFornecimento#/concluiRemanejamentoApuracao', {
            "requestType": "Row",
            "row": row
        });
    };
    
    this.openRemanejoEmpresa = function(dataset) {
        return restEngine.post('opl_autorizacaoFornecimento#/sup05100_remaneja_empresa', {
            "requestType": "DataSet",
            "dataset": dataset
        });
    };
    
    this.saveRemanejoEmpresa = function(row) {
        return restEngine.post('opl_autorizacaoFornecimento#/saveRemanejoEmpresa', {
            "requestType": "Row",
            "row": row
        });
    };
}

Configuration(function (ContextRegister) {
    ContextRegister.register('sup05100_analise_AF_Service', sup05100_analise_AF_Service);
});

// FILE: ./assets/modules/consolidacao/assets/modules/solicitacao/assets/js/services/Sup07200_lancamento_de_pedidos_Service.js
function Sup07200_lancamento_de_pedidos_Service(restEngine) {
    this.empresasPorUnidade = function(currentRow) {
        const dadosPost = {
            "requestType": "FilterData",
            "filter": [
                {
                    "name": "CDFILIAL",
                    "value": currentRow.CDFILDEST,
                    "operator": "="
                },
                {
                    "name": "NRORG",
                    "value": getLocalVar("NRORG"),
                    "operator": "="
                }
            ]
        };
        
        return restEngine.post("opl_solicitacao#/crud/sup07200_empresas_por_unidade", dadosPost);
    };
    
    this.empresaClientePrincipal = function(currentRow) {
        const dadosPost = {
            "requestType": "FilterData",
            "filter": [
                {
                    "name": "IDCLIENPRIN",
                    "value": "S",
                    "operator": "="
                },
                {
                    "name": "CDFILIAL",
                    "value": currentRow.CDFILDEST,
                    "operator": "="
                },
                {
                    "name": "NRORG",
                    "value": getLocalVar("NRORG"),
                    "operator": "="
                }
            ]
        };
        
        return restEngine.post("opl_solicitacao#/crud/sup07200_empresa_cliente_principal", dadosPost);
    };
    
    this.enviaEmailEmissao = function(row) {
        return restEngine.post("opl_solicitacao#/enviaEmailEmissao", {
            "requestType": "Row",
            "row": row
        });
    };
    
    this.retornaCookieEmail = function() {
        return restEngine.post("opl_solicitacao#/retornaCookieEmail", {
            "requestType": "Row",
            "row": {}
        });
    };
}

Configuration(function (ContextRegister) {
    ContextRegister.register("Sup07200_lancamento_de_pedidos_Service", Sup07200_lancamento_de_pedidos_Service);
});

// FILE: ./assets/js/controllers/zhFavorites.js
var ZeedhiFields = angular.module("ZeedhiFields");

ZeedhiFields.directive('zhNavbarDefaultHeader', function(templateManager, ScreenService, eventAggregator, $compile, ApplicationContext) {
	return {
		restrict: 'C',
		link: function($scope, element) {
		    $scope.favoritesList = [];
		    $scope.lastDeletedItem = undefined;
		    
		    
		    var favoritesText = 'Favoritos';
		    var favoritesAddText = 'Adicionar aos Favoritos';
		    var favoritesRemoveText = 'Remover dos Favoritos';
		    var favoritesUndoText = 'DESFAZER';

			// TRANSLATE - Adicionar essas variaveis a lista da aplicação (words.jon)
		    // var favoritesText = ScreenService.i18n('FAVORITES');
		    // var favoritesAddText = ScreenService.i18n('ADD_TO_FAVORITES');
		    // var favoritesRemoveText = ScreenService.i18n('REMOVE_FROM_FAVORITES');
		    // var favoritesUndoText = ScreenService.i18n('UNDO');
		    
		    var favoritesContainer;
		    
		    var startHollowCode = '<svg version="1.1" id="Layer_1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" x="0px" y="0px" viewBox="0 0 30 30" style="enable-background:new 0 0 30 30;" xml:space="preserve">'+
				'	<style type="text/css">'+
				'		.st0{fill:#FFFFFF;}'+
				'	</style>'+
				'	<g>'+
				'		<path class="st0" d="M15,4.21l3.51,7.1l7.84,1.14l-5.67,5.53l1.34,7.81L15,22.1l-7.01,3.69l1.34-7.81l-5.67-5.53l7.84-1.14L15,4.21'+
				'			 M15,2.21c-0.76,0-1.46,0.43-1.79,1.11l-3.04,6.16l-6.8,0.99c-0.75,0.11-1.38,0.64-1.61,1.36c-0.24,0.72-0.04,1.52,0.51,2.05'+
				'			l4.92,4.8l-1.16,6.77c-0.13,0.75,0.18,1.51,0.8,1.96c0.35,0.25,0.76,0.38,1.18,0.38c0.32,0,0.64-0.08,0.93-0.23l6.08-3.2l6.08,3.2'+
				'			c0.29,0.15,0.61,0.23,0.93,0.23c0.41,0,0.83-0.13,1.18-0.38c0.62-0.45,0.92-1.21,0.8-1.96l-1.16-6.77l4.92-4.8'+
				'			c0.55-0.53,0.74-1.33,0.51-2.05c-0.24-0.72-0.86-1.25-1.61-1.36l-6.8-0.99l-3.04-6.16C16.46,2.64,15.76,2.21,15,2.21L15,2.21z"/>'+
				'	</g>'+
				'</svg>';
		    var startFilledCode = '<svg version="1.1" id="Layer_1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" x="0px" y="0px" viewBox="0 0 30 30" style="enable-background:new 0 0 30 30;" xml:space="preserve">'+
				'	<style type="text/css">'+
				'		.st0{fill:#FFFFFF;}'+
				'	</style>'+
				'	<g>'+
				'		<path class="st0" d="M28.25,11.83c-0.24-0.72-0.86-1.25-1.61-1.36l-6.8-0.99l-3.04-6.16C16.46,2.64,15.76,2.21,15,2.21'+
				'			s-1.46,0.43-1.79,1.11l-3.04,6.16l-6.8,0.99c-0.75,0.11-1.38,0.64-1.61,1.36c-0.24,0.72-0.04,1.52,0.51,2.05l4.92,4.8l-1.16,6.77'+
				'			c-0.13,0.75,0.18,1.51,0.8,1.96c0.35,0.25,0.76,0.38,1.18,0.38c0.32,0,0.64-0.08,0.93-0.23l6.08-3.2l6.08,3.2'+
				'			c0.29,0.15,0.61,0.23,0.93,0.23c0.41,0,0.83-0.13,1.18-0.38c0.62-0.45,0.92-1.21,0.8-1.96l-1.16-6.77l4.92-4.8'+
				'			C28.29,13.35,28.48,12.56,28.25,11.83z"/>'+
				'	</g>'+
				'</svg>';
		    
		    function createVisualElements() {
    			var headerContainer = $(element).children()[0];
    			headerContainer.style.width = 'calc(100% - 50px)';
    			
    			favoritesContainer = $('<div class="zh-favorites"></div>').appendTo(element);
    			
    			var favoritesButtonElement = $compile(
    				'<div class="zh-favorites-button" ng-click="toggleList()">'+
    				'  <div class="zh-favorites-button-star" ng-if="!isFavorited">'+
    				'    '+startHollowCode+
    				'  </div>'+
    				'  <div class="zh-favorites-button-star" ng-if="isFavorited">'+
    				'    '+startFilledCode+
    				'  </div>'+
    				'  <div class="zh-favorites-button-text">'+favoritesText+'</div>'+
    				'</div>'
    			)($scope);
    			var favoritesButton = $(favoritesButtonElement).appendTo(favoritesContainer);
    			
    			var favoritesListElement = $compile(
    				'<div class="zh-favorites-list" ng-class="{\'opened\': opened}">'+
    				'  <div class="zh-favorites-list-button" ng-if="!isFavorited" ng-click="addToFavorites()">'+favoritesAddText+'</div>'+
    				'  <div class="zh-favorites-list-button" ng-if="isFavorited" ng-click="removeFromFavorites()">'+favoritesRemoveText+'</div>'+
    				'  <div class="zh-favorites-list-undo" ng-show="lastDeletedItem" ng-click="undo()">'+favoritesUndoText+'</div>'+
    				'  <div class="zh-favorites-list-items" ng-show="favoritesList.length > 0">'+
    				'	 <div class="zh-favorites-list-item" ng-repeat="item in favoritesList track by item.id" ng-click="openItem(item)">'+
    				'      {{ item.label }}'+
    				'      <span class="zh-favorites-list-item-delete" data-zh-icon="trash icon-white no-border" ng-click="deleteItem(item, $index, $event)"></span>'+
    				'    </div>'+
    				'  </div>'+
    				'</div>'
    			)($scope);
    			var favoritesList = $(favoritesListElement).appendTo(favoritesContainer);
		    }
		    
		    function checkIsFavorited(containerId) {
		    	var oldIsFavorited = $scope.isFavorited;
			    $scope.isFavorited = $scope.favoritesList.findIndex((item) => item.id === containerId) !== -1;
			    if (oldIsFavorited !== $scope.isFavorited) {
			    	templateManager.updateTemplate();
			    }
		    }
		    
		    $scope.addToFavorites = function() {
		    	var item = {
		    		id: templateManager.container.id,
		    		name: templateManager.container.fileName.split('.json')[0],
		    		label: templateManager.container.label,
		    	};
		    	$scope.favoritesList.push(item);
		    	$scope.isFavorited = true;
		    	eventAggregator.publish('ZhFavoritesOnChange', { fullList: $scope.favoritesList, changed: { item, status: 'add' }});
		    };
		    
		    $scope.removeFromFavorites = function() {
		    	var index = $scope.favoritesList.findIndex((item) => item.id === templateManager.container.id);
		    	if (index > -1) {
			    	var item = $scope.favoritesList.splice(index, 1);
			    	$scope.isFavorited = false;
			    	eventAggregator.publish('ZhFavoritesOnChange', { fullList: $scope.favoritesList, changed: { item, status: 'delete' }});
		    	}
		    };
		    
		    $scope.openItem = function(item) {
		    	ApplicationContext.LibUtilities.openWindow(item.name);
	    		$scope.opened = false;
		    };
		    
		    var undoTimeout;
		    
		    $scope.deleteItem = function(item, index, event) {
		    	$scope.favoritesList.splice(index, 1);
		    	$scope.lastDeletedItem = { item, index };

		    	clearTimeout(undoTimeout);
		    	undoTimeout = setTimeout(() => {
		    		$scope.lastDeletedItem = undefined;
		    		templateManager.updateTemplate();
		    	}, 10000);

			    eventAggregator.publish('ZhFavoritesOnChange', { fullList: $scope.favoritesList, changed: { item, status: 'delete' }});

		    	if (item.id === templateManager.container.id) {
		    		$scope.isFavorited = false;
		    	}

		    	event.stopImmediatePropagation();
		    };
		    
		    $scope.undo = function() {
		    	if ($scope.lastDeletedItem) {
		    		$scope.favoritesList.splice($scope.lastDeletedItem.index, 0, $scope.lastDeletedItem.item);
		    	}
		    	$scope.lastDeletedItem = undefined;
		    };

		    $scope.toggleList = function() {
		    	$scope.opened = !$scope.opened;
		    };
		    
		    document.addEventListener('mousedown', (evt) => {
		    	if ($(favoritesContainer).find(evt.target).length === 0 && $scope.opened) {
		    		$scope.opened = false;
			    	templateManager.updateTemplate();
		    	}	
		    });
		    
		    eventAggregator.subscribe(eventAggregator.ON_CONTAINER_OPEN, (args) => {
		    	checkIsFavorited(args.container.id);
		    });
		    
		    eventAggregator.subscribe('ZhFavoritesOnLoad', (favorites) => {
		    	
		    	$scope.favoritesList = favorites;
			    if (templateManager.container) {
			    	checkIsFavorited(templateManager.container.id);
			    }
		    });

		    createVisualElements();
		}
	};
});

// FILE: ./assets/modules/parametros/assets/js/controllers/sup03500_parametrizacao_de_produtos_para_suprimentosController.js
function sup03500_parametrizacao_de_produtos_para_suprimentosController(General, Utilities, RestEngine, ScreenService, MessageService, templateManager){
    
    this.productRangeValidations = function (field) {
        const widgetRow = field.widget.currentRow;
        
        if (!validaProduto(widgetRow.CDPRODINI, widgetRow.CDPRODFIN)) 
        {
            field.clearValue();
        }
    };
    
    function validaProduto(prodInicial, prodFinal) {
        
        if (prodInicial && prodFinal) {
            if (!General.comparaPratoProduto(prodInicial, prodFinal, getLocalVar('CDPICTPROD'))) {
                MessageService.showMessageByCode("PRODUTO_INICIAL_MENOR_IGUAL_FINAL");
                return false;
            }
        }

        return true;
    }
    
    this.subGrupoFilterReadOnly = function(widget){
        
        if(!Util.isEmptyOrBlank(widget.getField('OL').value())){
            widget.getField('SUBGRUPO').readOnly = false;
            
            widget.getField('SUBGRUPO').dataSourceFilter = [
                {
                    name: 'P_CDFILIOPELOG',
                    operator: '=',
                    value: concatArrayForParams(widget.currentRow.CDFILIAL),
                }
            ];
            
            if(!Util.isEmptyOrBlank(widget.getField('REGIAO').value())){
                this.unidadeFilterReadOnly(widget);
            }
        }else{
            widget.getField('SUBGRUPO').readOnly = true;
            
            widget.getField('UNIDADE').setValue(null);
            widget.getField('UNIDADE').readOnly = true;
        }
        
        widget.getField('SUBGRUPO').setValue(null);
        
    };
    
    this.unidadeFilterReadOnly = function(widget){
        if(!Util.isEmptyOrBlank(widget.getField('OL').value()) && !Util.isEmptyOrBlank(widget.getField('REGIAO').value())){
            const fieldUnidade = widget.getField('UNIDADE');
        
            fieldUnidade.readOnly = false;
            
            fieldUnidade.dataSourceFilter = [
                {
                    name: 'P_CDREGIAO',
                    operator: '=',
                    value: concatArrayForParams(widget.currentRow.CDREGIAO),
                },
                {
                    name: 'P_CDFILIOPELOG',
                    operator: '=',
                    value: concatArrayForParams(widget.currentRow.CDFILIAL),
                }
            ];
        }else{
            widget.getField('UNIDADE').readOnly = true;
            widget.getField('UNIDADE').setValue(null);
            MessageService.showMessageByCode("PREENCHER_CAMPOS_ANTERIORES");
        }
        
    };
    
    this.openExclusaoAutomaticaWidget = function(widget) {
        const exclusao = widget.container.getWidget('exclusaoAutomaticaWidget');
        
        ScreenService.openPopup(exclusao);
    };
    
    this.backPopup = function(widget) {
        widget.getField('UNIDADE').readOnly = true;
        widget.getField('SUBGRUPO').readOnly = true;
        widget.currentRow = {};
        ScreenService.closePopup();
    };
    
    this.openInclusaoAutomaticaWidget = function(widget) {
        const inclusao = widget.container.getWidget('inclusaoAutomaticaWidget');
        
        ScreenService.openPopup(inclusao);
    };
    
    this.subGrupoExcIncAuto = function(widget,action){
        if(widget.getField('OL').value()){
            widget.getField('SUBGRUPO').readOnly = false;
            if(!Util.isEmptyOrBlank(widget.getField('REGIAO').value())){
                this.unidadeExcInc(action);
            }
        }else{
            widget.getField('SUBGRUPO').readOnly = true;
            widget.getField('UNIDADE').readOnly = true;
        }
    };
    
    function procedureExcInc(widget, row){
        General.callRestEngine('opl_parametros#/sup03500ParametrizacaoProdutosSuprimentosController/procedureExcInc','Row', row).then(function(res){
        	MessageService.showMessageByCode("OPERACAO_SUCESSO");
        	ScreenService.closePopup();
            widget.container.getWidget('parametrizacao_de_produtos_para_suprimentos_widget').reload();
        }, function(error) {
            var errorMessage = "Timeout";
            let textContentError = '';
            if (error.data){
                errorMessage = "ERR_GENERICO";
                textContentError = error.data.error;
            }
            MessageService.showMessageByCode(errorMessage, {"PARAM":textContentError});
        });
    }
    
    this.excQuestion = function(widget){
        let row;
        MessageService.confirmMessageByCode("CONFIRMA_EXCLUCAO_ITENS").then(function (success) {
            
            row = {
                CDFILIOPELOG: widget.currentRow.CDFILIAL,
                CDFILIAL: concatArrayForParams(widget.currentRow.CDFILIALUN),
                CDREGIAO: concatArrayForParams(widget.currentRow.CDREGIAO),
                CDSUBGRPROD: concatArrayForParams(widget.currentRow.CDSUBGRPROD),
                CDPRODINI: widget.currentRow.CDPRODINI,
                CDPRODFIN: widget.currentRow.CDPRODFIN ? formataProdFinal(widget.currentRow.CDPRODFIN) : "",
                OPERACAO: '4',
                CDFILISUBGR: 'P',
                IDOPERLOG: 'N'
            };
            
            procedureExcInc(widget,row);
        });
    };
    
    this.incQuestion = function(widget){
        let row;
        MessageService.confirmMessageByCode("CONFIRMA_INCLUSAO_ITENS").then(function (success) {
            
            row = {
                CDFILIOPELOG: widget.currentRow.CDFILIAL,
                CDFILIAL: concatArrayForParams(widget.currentRow.CDFILIALUN),
                CDREGIAO: concatArrayForParams(widget.currentRow.CDREGIAO),
                CDSUBGRPROD: concatArrayForParams(widget.currentRow.CDSUBGRPROD),
                CDPRODINI: widget.currentRow.CDPRODINI,
                CDPRODFIN: widget.currentRow.CDPRODFIN ? formataProdFinal(widget.currentRow.CDPRODFIN) : "",
                OPERACAO: '4',
                CDFILISUBGR: 'P',
                IDOPERLOG: 'S'
            };
            
            procedureExcInc(widget,row);
        });
        
    };
    
    this.checkInc = function(args){
        const widget = args.owner;
        
        if (widget.inEditMode()) {
            return args.e.preventDefault();
        }
        
        const filterRow = widget.appliedFilter.FILTER_ROW;
        const selectedRow = widget.selectedRow;
        let row;
        row = {
                CDFILIOPELOG: filterRow.CDFILIAL,
                CDFILIAL: selectedRow.CDFILIAL,
                CDREGIAO: selectedRow.CDREGIAO,
                CDSUBGRPROD: selectedRow.CDSUBGRPROD,
                CDPRODINI: selectedRow.CDARVPROD,
                CDPRODFIN: selectedRow.CDARVPROD,
                OPERACAO: '4',
                CDFILISUBGR: 'P',
                IDOPERLOG: 'S'
            };
            
        procedureExcInc(widget,row);
    };
    
    this.checkExc = function(args){
        const widget = args.owner;
        
        if (widget.inEditMode()) {
            return args.e.preventDefault();
        }
        
        const filterRow = widget.appliedFilter.FILTER_ROW;
        const selectedRow = widget.selectedRow;
        let row;
        row = {
                CDFILIOPELOG: filterRow.CDFILIAL,
                CDFILIAL: selectedRow.CDFILIAL,
                CDREGIAO: selectedRow.CDREGIAO,
                CDSUBGRPROD: selectedRow.CDSUBGRPROD,
                CDPRODINI: selectedRow.CDARVPROD,
                CDPRODFIN: selectedRow.CDARVPROD,
                OPERACAO: '4',
                CDFILISUBGR: 'P',
                IDOPERLOG: 'N'
            };
            
        procedureExcInc(widget,row);
    };
    
    this.toggleModeInclusionExclusionAll = function(widget) {
        if (!widget.inEditMode()) {
            widget.edit(false);
        }
    };
    
    function concatArrayForParams(value, defaultValue = 'T'){
        if (!Util.isEmptyOrBlank(value)) {
            return Array.isArray(value) ? value.join('_') : value;
        }
    
        return defaultValue;
    }
    
    this.unidadeExcInc = function(action){
        let widget;
        if(action == "E"){
            widget = templateManager.container.getWidget('exclusaoAutomaticaWidget');
        }else{
            widget = templateManager.container.getWidget('inclusaoAutomaticaWidget');
        }
        
        if(widget.getField('OL').value() && !Util.isEmptyOrBlank(widget.getField('REGIAO').value())){
            const fieldUnidade = widget.getField('UNIDADE');
        
            fieldUnidade.readOnly = false;
            
            fieldUnidade.dataSourceFilter = [
                {
                    name: 'P_CDREGIAO',
                    operator: '=',
                    value: concatArrayForParams(widget.currentRow.CDREGIAO),
                },
                {
                    name: 'P_CDFILIOPELOG',
                    operator: '=',
                    value: concatArrayForParams(widget.currentRow.CDFILIAL),
                }
            ];
        }else{
            widget.getField('UNIDADE').readOnly = true;
            widget.getField('UNIDADE').setValue(null);
            MessageService.showMessageByCode("PREENCHER_CAMPOS_ANTERIORES");
        }
        
    };
    
    this.subGrupoExcInc = function(action){
        let widget;
        if(action == "E"){
            widget = templateManager.container.getWidget('exclusaoAutomaticaWidget');
        }else{
            widget = templateManager.container.getWidget('inclusaoAutomaticaWidget');
        }
        
        if(widget.getField('OL').value()){
            const fieldSubGrupo = widget.getField('SUBGRUPO');
        
            fieldSubGrupo.readOnly = false;
            
            fieldSubGrupo.dataSourceFilter = [
                {
                    name: 'P_CDFILIOPELOG',
                    operator: '=',
                    value: concatArrayForParams(widget.currentRow.CDFILIAL),
                }
            ];
        }
        
    };
    
    this.initiateFilter = function (widget) {
    	    
    	Utilities.startFilter(widget);
    };
    
    function formataProdFinal(prodFin){
        var pad = 'ZZZZZZZZZZZZZZZZZZZZ';
        return prodFin + pad.substr(0, pad.length - prodFin.length);
    }
    
    this.beforeApplyFilter = function (args) {
        args.e.preference.CUSTOM_FILTER_ROW = {};
        const widget = templateManager.container.getWidget('parametrizacao_de_produtos_para_suprimentos_widget');
        const filterRow = args.e.preference.FILTER_ROW;
        const parametrizado = filterRow.PARAMETRIZADO;
        let paramOperator;
        let value;
        
        if (parametrizado == "S") {
            paramOperator = ">";
            value = 0;
        } else if(parametrizado == "N"){
            paramOperator = "=";
            value = 0;
        } else {
            paramOperator = "<>";
            value = -1;
        }
        
        widget.dataSourceFilter = [
            {
                name: 'P_CDREGIAO',
                operator: '=',
                value: concatArrayForParams(filterRow.CDREGIAO)
            },
            {
                name: 'P_CDFILIOPELOG',
                operator: '=',
                value: filterRow.CDFILIAL
            },
            {
                name: 'P_CDSUBGRPROD',
                operator: '=',
                value: concatArrayForParams(filterRow.CDSUBGRPROD)
            },
            {
                name: 'P_CDPRODINI',
                operator: '=',
                value: filterRow.CDPRODINI
            },
            {
                name: 'P_CDPRODFIN',
                operator: '=',
                value: filterRow.CDPRODFIN ? formataProdFinal(filterRow.CDPRODFIN) : ""
            },
            {
                name: 'P_CDFILIAL',
                operator: '=',
                value: concatArrayForParams(filterRow.CDFILIALUN)
            },
            {
                name: 'CONTADOR',
                operator: paramOperator,
                value: value
            }
        ];
        
    };
    
    this.cancelGridOperations = function (args) {
        const widget = args.owner.widget;
        
        General.backOrCancel(args);
        widget.list();
        widget.reload();
    };
    
    
    /**
     * TODO:
     * - [] Colocar as funções do CANCELAR em uma única função no controller
     * - [] Verificar se o .list() resolve em vez do backOrCancel
     * - [] Verificar o impacto do reload do floatingControl quando está com o editMode
     */
    this.afterLoadDataSource = function (widget){
        if (widget.inEditMode()) return;
        
        if (widget.dataSource.data.length) {
            widget.dataSource.data.forEach(function(row){
                row.__isSelected = (row.CONTADOR > 0);
            });
        }
        
    };
}

Configuration(function(ContextRegister){
    ContextRegister.register('sup03500_parametrizacao_de_produtos_para_suprimentosController',sup03500_parametrizacao_de_produtos_para_suprimentosController);
});

// FILE: ./assets/modules/relatorios/assets/js/controllers/EmissaoPedidosOLController.js
function EmissaoPedidosOLController(ScreenService, templateManager, ZhFilterPreferences, MessageService, maskEngine, ZhUtil, General, emissao_de_pedidos_Service) { 
    var parametrosParaSupri;
    var parametrosGerais;
    var parametrosParCmpsup;
    var ServiceEmissaoPedidoOL = emissao_de_pedidos_Service;
    var self = this;
    var opEmissao;
    var CDFILIOPELOGPROD;
    var permissoesGeraisOperador;
    var permissoesFinaisOperador;
    
    this.onEnterOnceWidgetPedidos = function(args) {
        const widget = args.owner;
        const rowsToSet = {};
        const widgetDadosPedido = templateManager.container.getWidget("dadosPedido");
        const widgetDetalhesPedido = templateManager.container.getWidget("detalhesPedido");
        var resp;
        
        widgetDadosPedido.enabled = false;
        widgetDetalhesPedido.enabled = false;
        
        ScreenService.showLoader();
        
        rowsToSet.defaultFilter = widget.dataSourceFilter;
        rowsToSet.TCDLOTENVITOL = 'N';
        rowsToSet.IDBAIXAAF = [ '0', '1', '2', '3', '4', '5' ];
        rowsToSet.PEDOLEXTR = [ 'S', 'N' ];
        rowsToSet.TRESERVA = [ 'S', 'N' ];
        
        General.callRestEngine("opl#/crud/parcmpsup", "FilterData", [
            {
        		"name": "CDFILIAL",
        		"operator": "=",
        		"value": "FILIAL_LOGADA"
        	}
        ]).then(function(response) {
            parametrosParCmpsup = response.dataset.parcmpsup[0];
        }).catch(function(error) {
            MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
        });
        
        General.callRestEngine("opl_relatorios#/permissoesGrupoOperador", "Row", {}).then(function(response) {
            permissoesGeraisOperador = response.dataset.permissoesGeraisOperador.map(function(row) {
                return row.IDAUTGRUPOP;
            }).join("_");
            permissoesFinaisOperador = Util.isEmptyOrBlank(response.dataset.permissoesFinaisOperador) ? "" : response.dataset.permissoesFinaisOperador.map(function(row) {
                return row.IDAUTGRUPOP;
            }).join("_");
        }).catch(function(error) {
            MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
        });
        
        General.callRestEngine("opl_relatorios#/getCentralCompras", "Row", {}).then(function(response) {
            resp = response.dataset.data;
                
            if(resp) {
                if(resp.CDFILIAL == resp.CDFILCENTCMP) {
                    rowsToSet.NMFILIAL = [ resp.CDFILCENTCMP ];
                    
                    widget.currentRow.NMFILIAL = [ resp.CDFILCENTCMP ];
                } else {
                    rowsToSet.NMFILIAL = [ resp.CDFILIAL ];
                    
                    widget.currentRow.NMFILIAL = [ resp.CDFILIAL ];
                }
            }
            
            widget.getField("NMFILIAL").reload().then(function(resposta) {
                ZhFilterPreferences.openFilterWidget(widget, rowsToSet).then(opened => {
                    const filterWidget = templateManager.container.getActiveWidget();
                    const excluirReserva = widget.getAction("excluirReserva");
                    const incluirReserva = widget.getAction("incluirReserva");
                    const bloquearItemPedido = widget.getAction("bloquearItemPedido");
                    const desbloquearItemPedido = widget.getAction("desbloquearItemPedido");
                    const filter = [
                        {
        					"name": "CDFILIAL",
        					"operator": "=",
        					"value": resp.CDFILIAL
        				},
        				{
        					"name": "NRORG",
        					"operator": "=",
        					"value": resp.NRORG
        				}
        			];
        			
        			if(resp) {
        			    if(resp.CDFILIAL == resp.CDFILCENTCMP)
                            filterWidget.getField("NMFILIAL").readOnly = false;
                        else
                            filterWidget.getField("NMFILIAL").readOnly = true;
        			}
        			
        			bloquearItemPedido.isVisible = true;
        			desbloquearItemPedido.isVisible = true;
        			
                    filterWidget.getField("NMFILIAL").reload();
                    
                    filterWidget.activate();
        			
                    ScreenService.hideLoader();
                    
                    General.callRestEngine("opl#/crud/paramgeral", "FilterData", []).then(function(response) {
                        parametrosGerais = response.dataset.paramgeral[0];
                        
                        General.callRestEngine("opl#/crud/parasupri", "FilterData", filter).then(function(response) {
                            parametrosParaSupri = response.dataset.parasupri[0];
                            
                            if(parametrosParaSupri && parametrosParaSupri.IDUTRESPEDEXOL === 'S') {
                                excluirReserva.isVisible = true;
                                incluirReserva.isVisible = true;
                            } else {
                                excluirReserva.isVisible = false;
                                incluirReserva.isVisible = false;
                            }
                            
                            if(parametrosParaSupri && parametrosParaSupri.IDENVIOITMPEDOL == 'S') {
                                widget.getField("DSINCONITMOLEXP").isVisible = true;
                            } else {
                                widget.getField("DSINCONITMOLEXP").isVisible = false;
                            }
                            var boHabilita;
                            boHabilita = false;
                            if(permissoesGeraisOperador.indexOf("BLOL") == -1) {
                                boHabilita =  false;
                            } else {
                                if(permissoesFinaisOperador.indexOf("BLOL") != -1) {
                                    boHabilita = true;    
                                } else {
                                    boHabilita = false;
                                }
                            }
                            bloquearItemPedido.isVisible   = boHabilita;
                            desbloquearItemPedido.isVisible = boHabilita;    
                        }).catch(function(error) {
                            excluirReserva.isVisible = false;
                            incluirReserva.isVisible = false;
                            
                            MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
                        });
                    }).catch(function(error) {
                        MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
                    });
                    
                }).catch(error => {
                    ScreenService.hideLoader();
                });
            });
        }).catch(function(error) {
            if(error.data.error == "CDFILCENTCMP_NOT_REGISTERED") {
                MessageService.showMessageByCode(error.data.error);
            } else {
                MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
            }
        });
    };
    
    this.changeFieldsRegiaoRotaUnidade = function(widget) {
        const fieldRegiao = widget.getField("CDREGIAO");
        const fieldRota = widget.getField("CDROTATRANS");
        const fieldUnidade = widget.getField("NMFILIAL");
        
        widget.currentRow.CDREGIAO = null;
        widget.currentRow.CDROTATRANS = null;
        widget.currentRow.CDFILIAL = null;
        widget.currentRow.NMFILIAL = null;
        
        fieldRegiao.clearValue();
        fieldRegiao.reload();
        
        fieldRota.clearValue();
        fieldRota.reload();
        
        fieldUnidade.clearValue();
        fieldUnidade.reload();
        fieldUnidade.dataSourceFilter = [
            {
                "name": "P_CDOPERADOR",
                "operator": "=",
                "value": "@getLocalVar('CDOPERADOR')@"
            },
            {
                "name": "P_TCDREGIAO",
                "operator": "=",
                "value": "T"
            },
            {
                "name": "P_CDREGIAO",
                "operator": "=",
                "value": ""
            },
            {
                "name": "P_CDGRUPFILI",
                "operator": "=",
                "value": widget.currentRow.CDGRUPFILI ? widget.currentRow.CDGRUPFILI : 'T'
            },
            {
                "name": "P_CDROTA",
                "operator": "=",
                "value": "T"
            }
        ];
        fieldUnidade.reload();
        
        widget.activate();
    };
    
    this.changeFieldsRotaUnidade = function(widget) {
        const fieldRota = widget.getField("CDROTATRANS");
        const fieldUnidade = widget.getField("NMFILIAL");
        
        widget.currentRow.CDROTATRANS = null;
        widget.currentRow.CDFILIAL = null;
        widget.currentRow.NMFILIAL = null;
        
        fieldRota.clearValue();
        fieldRota.reload();
        
        fieldUnidade.clearValue();
        fieldUnidade.reload();
        fieldUnidade.dataSourceFilter = [
            {
                "name": "P_CDOPERADOR",
                "operator": "=",
                "value": "@getLocalVar('CDOPERADOR')@"
            },
            {
                "name": "P_TCDREGIAO",
                "operator": "=",
                "value": widget.currentRow.CDREGIAO ? (widget.currentRow.CDREGIAO.length > 0) ? "" : 'T' : 'T'
            },
            {
                "name": "P_CDREGIAO",
                "operator": "=",
                "value": widget.currentRow.CDREGIAO ? (widget.currentRow.CDREGIAO.length > 0) ? widget.currentRow.CDREGIAO.join('_') : "" : ""
            },
            {
                "name": "P_CDGRUPFILI",
                "operator": "=",
                "value": widget.currentRow.CDGRUPFILI ? widget.currentRow.CDGRUPFILI : 'T'
            },
            {
                "name": "P_CDROTA",
                "operator": "=",
                "value": "T"
            }
        ];
        fieldUnidade.reload();
        
        widget.activate();
    };
    
    this.changeFieldsUnidade = function(widget) {
        const fieldUnidade = widget.getField("NMFILIAL");
        
        widget.currentRow.CDFILIAL = null;
        widget.currentRow.NMFILIAL = null;
        
        fieldUnidade.clearValue();
        fieldUnidade.reload();
        fieldUnidade.dataSourceFilter = [
            {
                "name": "P_CDOPERADOR",
                "operator": "=",
                "value": "@getLocalVar('CDOPERADOR')@"
            },
            {
                "name": "P_TCDREGIAO",
                "operator": "=",
                "value": widget.currentRow.CDREGIAO ? (widget.currentRow.CDREGIAO.length > 0) ? "" : 'T' : 'T'
            },
            {
                "name": "P_CDREGIAO",
                "operator": "=",
                "value": widget.currentRow.CDREGIAO ? (widget.currentRow.CDREGIAO.length > 0) ? widget.currentRow.CDREGIAO.join('_') : "" : ""
            },
            {
                "name": "P_CDGRUPFILI",
                "operator": "=",
                "value": widget.currentRow.CDGRUPFILI ? widget.currentRow.CDGRUPFILI : 'T'
            },
            {
                "name": "P_CDROTA",
                "operator": "=",
                "value": widget.currentRow.CDROTATRANS ? (widget.currentRow.CDROTATRANS.length > 0) ? widget.currentRow.CDROTATRANS.join('_') : 'T' : 'T'
            }
        ];
        fieldUnidade.reload();
        
        widget.activate();
    };
    
    this.changeFieldLote = function(widget) {
        const fieldlote = widget.getField("CDLOTE");
        
        if(widget.currentRow.TCDLOTENVITOL === 'L') {
            fieldlote.readOnly = false;
            fieldlote.validations = {
                "required": true
            };
            fieldlote.reload();
            fieldlote.setValue(null);
            widget.redraw();
        } else {
            fieldlote.readOnly = true;
            fieldlote.reload();
            fieldlote.setValue(null);
            delete fieldlote.validations;
            widget.redraw();
        }
        
        widget.activate();
        widget.sync();
    };
    
    this.changeFieldSubgrupo = function(widget) {
        const fieldSubgrupo = widget.getField("CDSUBGRPROD");
        
        if(widget.currentRow.NCONSIDERASUBGRUPO === 'N') {
            fieldSubgrupo.readOnly = false;
            fieldSubgrupo.reload();
            fieldSubgrupo.setValue(null);
        } else {
            fieldSubgrupo.readOnly = true;
            fieldSubgrupo.reload();
            fieldSubgrupo.setValue(null);
        }
        
        widget.activate();
    };
    
    this.filterProdIni = function(args) {
		var widget = args.owner.field.widget;
		var row = widget.currentRow;
		var prodIniIsSet = row.CDPRODINI ? true : false;
		
		if(!prodIniIsSet) {
			widget.currentRow.NMPRODFIN = '';
			widget.currentRow.CDPRODFIN = '';
		}
        this.checkProductRange(args.owner.field);
	};
	
	this.filterProdFin = function(args) {
		var widget = args.owner.field.widget;
		var row = widget.currentRow;
		var prodFinIsSet = row.CDPRODFIN ? true : false;
		var prodIniIsSet = row.CDPRODINI ? true : false;
		
		if (prodFinIsSet) {
			if (row.CDPRODINI > row.CDPRODFIN) {
                MessageService.showMessageByCode("PRODUTO_INICIAL_MENOR_IGUAL_FINAL");
			}
		} else if(!prodIniIsSet) {
            widget.currentRow.NMPRODFIN = null;
            widget.currentRow.CDPRODFIN = null;
		}
		
		this.checkProductRange(args.owner.field);
	};
	
	this.checkProductRange = function(field) {
	   var currentRow = field.widget.currentRow;

		if (currentRow.CDPRODINI && currentRow.CDPRODFIN) {
			var compproduto = (currentRow.CDPRODFIN) ? currentRow.CDPRODFIN.replace(/[\.\-]/g, '') : null;

			if (!this.comparaPratoProduto(currentRow.CDPRODINI, compproduto, getLocalVar('CDPICTPROD'))) {
				currentRow[field.outData[field.descriptionField]] = null;
				currentRow[field.outData[field.valueField]] = null;

                field.widget.getField('NMPRODINI').clearValue();
                field.widget.getField('NMPRODFIN').clearValue();
                MessageService.showMessageByCode("PRODUTO_INICIAL_MENOR_IGUAL_FINAL");
			}
		}
	};
	
	this.comparaPratoProduto = function(pinicial, pfinal, mascara) {
        var mask = {
          type: "fix",
          params: {
              mask: mascara
          }
        };
        pinicial = Util.applyMask(pinicial, mask, maskEngine, ZhUtil).split('.');
        pfinal = Util.applyMask(pfinal, mask, maskEngine, ZhUtil).split('.');
        var nvinicial = pinicial.length;
        var nvfinal = pfinal.length;
        var resultado = true;
        if(nvinicial != nvfinal) {
            if(nvinicial > nvfinal) {
                resultado = false;
            }
        } else {
            var i = 0;
            do {
                if(pinicial[i] > pfinal[i]) {
                    resultado = false;
                }
                i++;
            }
            while (i<pinicial.length && resultado);
        }
        return resultado;
    };
    
    this.changeFieldBlock = function(widget) {
        const fieldBlock = widget.getField("DTBLOQ");
        
        if(widget.currentRow.TDTBLOQ === 'S') {
            fieldBlock.readOnly = false;
            fieldBlock.clearValue();
        } else {
            fieldBlock.readOnly = true;
            fieldBlock.clearValue();
        }
        
        widget.currentRow.DTBLOQ = {
            "start": "",
            "end": "",
            "formattedStart": "__/__/____",
            "formattedEnd": "__/__/____"
        };
        
        widget.activate();
    };
    
    this.changeFieldUnblock = function(widget) {
        const fieldUnblock = widget.getField("DTNBLOQ");
        
        if(widget.currentRow.TDTNBLOQ === 'S') {
            fieldUnblock.readOnly = false;
            fieldUnblock.clearValue();
        } else {
            fieldUnblock.readOnly = true;
            fieldUnblock.clearValue();
        }
        
        widget.currentRow.DTNBLOQ = {
            "start": "",
            "end": "",
            "formattedStart": "__/__/____",
            "formattedEnd": "__/__/____"
        };
        
        widget.activate();
    };
    
    this.setDataSourceFilter = function(args) {
        const filterRow = args.e.preference.FILTER_ROW;
        const widget = args.owner;
        const parametrosFinais = {
            "P_CDGRUPFILI": filterRow.CDGRUPFILI ? filterRow.CDGRUPFILI : null,
            "P_CDREGIAO": (!filterRow.CDREGIAO || filterRow.CDREGIAO.length == 0) ? null : '_' + filterRow.CDREGIAO.join('_') + '_',
            "P_TCDREGIAO": (!filterRow.CDREGIAO || filterRow.CDREGIAO.length == 0) ? 'T' : null,
            "P_CDFILIOPELOG": (!filterRow.NMFILIALOL || filterRow.NMFILIALOL.length == 0) ? null : '_' + filterRow.NMFILIALOL.join('_') + '_',
            "P_TCDFILIOPELOG": (!filterRow.NMFILIALOL || filterRow.NMFILIALOL.length == 0) ? 'T' : null,
            "P_CDFILIAL": (!filterRow.NMFILIAL || filterRow.NMFILIAL.length == 0) ? null : '_' + filterRow.NMFILIAL.join('_') + '_',
            "P_TCDFILIAL": (!filterRow.NMFILIAL || filterRow.NMFILIAL.length == 0) ? 'T' : null,
            "P_DTPEDINI": filterRow.DTPEDEXOL.start ? filterRow.DTPEDEXOL.start : null,
            "P_DTPEDFIN": filterRow.DTPEDEXOL.end ? filterRow.DTPEDEXOL.end : null,
            "P_DTEMBINI": filterRow.DTPROGEMBARQ.start ? filterRow.DTPROGEMBARQ.start : null,
            "P_DTEMBFIN": filterRow.DTPROGEMBARQ.end ? filterRow.DTPROGEMBARQ.end : null,
            "P_DTENTINI": filterRow.DTPROGENPEOL.start ? filterRow.DTPROGENPEOL.start : null,
            "P_DTENTFIN": filterRow.DTPROGENPEOL.end ? filterRow.DTPROGENPEOL.end : null,
            "P_CDPRODINI": filterRow.CDPRODINI ? filterRow.CDPRODINI : null,
            "P_CDPRODFIN": filterRow.CDPRODFIN ? (filterRow.CDPRODFIN + "ZZZZZZZZZZZZZZZZZZZZ").substr(0, 20) : null,
            "P_CDOPERADOR": getLocalVar('CDOPERADOR'),
            "P_DTBLOQINI": filterRow.TDTBLOQ === 'S' ? filterRow.DTBLOQ.start ? filterRow.DTBLOQ.start : null : null,
            "P_DTBLOQFIN": filterRow.TDTBLOQ === 'S' ? filterRow.DTBLOQ.end ? filterRow.DTBLOQ.end : null : null,
            "P_TBLOQ": (filterRow.TDTBLOQ === 'S' && !Util.isEmptyOrBlank(filterRow.DTBLOQ.start) && !Util.isEmptyOrBlank(filterRow.DTBLOQ.end)) ? null : filterRow.TDTBLOQ === 'S' ? 'T' : null,
            "P_BLOQ": filterRow.TDTBLOQ === 'S' ? 'S' : 'N',
            "P_DTNBLOQINI": filterRow.TDTNBLOQ === 'S' ? filterRow.DTNBLOQ.start ? filterRow.DTNBLOQ.start : null : null,
            "P_DTNBLOQFIN": filterRow.TDTNBLOQ === 'S' ? filterRow.DTNBLOQ.end ? filterRow.DTNBLOQ.end : null : null,
            "P_TNBLOQ": (filterRow.TDTNBLOQ === 'S' && !Util.isEmptyOrBlank(filterRow.DTNBLOQ.start) && !Util.isEmptyOrBlank(filterRow.DTNBLOQ.end)) ? null : filterRow.TDTNBLOQ === 'S' ? 'T' : null,
            "P_NBLOQ": filterRow.TDTNBLOQ === 'S' ? 'N' : 'S',
            "P_PEDOLEXTR": filterRow.PEDOLEXTR.length == 2 ? 'T' : filterRow.PEDOLEXTR[0] === 'S' ? 'S' : 'N',
            "P_CDLOTENVIOL": filterRow.TCDLOTENVITOL === 'N' ? 'T' : filterRow.TCDLOTENVITOL == 'S' ? 'S' : (!filterRow.CDLOTE || filterRow.CDLOTE.length == 0) ? 'T' : '_' + filterRow.CDLOTE.join('_') + '_',
            "P_TRESERVA": filterRow.TRESERVA.length == 2 ? '1' : filterRow.TRESERVA[0] === 'S' ? '2' : '3',
            "P_SUBGRUPO": filterRow.NCONSIDERASUBGRUPO === 'S' ? 'N' : (!filterRow.CDSUBGRPROD || filterRow.CDSUBGRPROD.length == 0) ? 'N' : '_' + filterRow.CDSUBGRPROD.join('_') + '_',
            "P_CDGRUPPROD": filterRow.NCONSIDERASUBGRUPO === 'S' ? null : (!filterRow.CDGRUPPROD || filterRow.CDGRUPPROD.length == 0) ? null : filterRow.CDGRUPPROD[0],
            "P_CDROTA": (!filterRow.CDROTATRANS || filterRow.CDROTATRANS.length == 0) ? 'T' : '_' + filterRow.CDROTATRANS.join('_') + '_',
            "P_IDBAIXAAF": (!filterRow.IDBAIXAAF || filterRow.IDBAIXAAF.length == 0) ? null : filterRow.IDBAIXAAF.length == 1 ? filterRow.IDBAIXAAF[0] :  '_' + filterRow.IDBAIXAAF.join('_') + '_'
        };
        const adicionaItemPedidoAction = widget.getAction("adicionaItemPedido");
        const adicionaNovoPedidoAction = widget.getAction("adicionaNovoPedido");
        
        if(parametrosFinais.P_TRESERVA == 3) {
            widget.getField("QTRESERVESTOL").isVisible = false;
        } else {
            widget.getField("QTRESERVESTOL").isVisible = true;
        }
        
        CDFILIOPELOGPROD = parametrosFinais.P_CDFILIOPELOG.substr(1, 4);
        
        widget.dataSourceFilter = [
		    {
		        "name": "P_CDGRUPFILI",
		        "operator": "=",
		        "value": parametrosFinais.P_CDGRUPFILI
		    },
		    {
		        "name": "P_CDREGIAO",
		        "operator": "=",
		        "value": parametrosFinais.P_CDREGIAO
		    },
		    {
		        "name": "P_TCDREGIAO",
		        "operator": "=",
		        "value": parametrosFinais.P_TCDREGIAO
		    },
		    {
		        "name": "P_CDFILIOPELOG",
		        "operator": "=",
		        "value": parametrosFinais.P_CDFILIOPELOG
		    },
		    {
		        "name": "P_TCDFILIOPELOG",
		        "operator": "=",
		        "value": parametrosFinais.P_TCDFILIOPELOG
		    },
		    {
		        "name": "P_CDFILIAL",
		        "operator": "=",
		        "value": parametrosFinais.P_CDFILIAL
		    },
		    {
		        "name": "P_TCDFILIAL",
		        "operator": "=",
		        "value": parametrosFinais.P_TCDFILIAL
		    },
		    {
		        "name": "P_DTPEDINI",
		        "operator": "=",
		        "value": parametrosFinais.P_DTPEDINI
		    },
		    {
		        "name": "P_DTPEDFIN",
		        "operator": "=",
		        "value": parametrosFinais.P_DTPEDFIN
		    },
		    {
		        "name": "P_DTEMBINI",
		        "operator": "=",
		        "value": parametrosFinais.P_DTEMBINI
		    },
		    {
		        "name": "P_DTEMBFIN",
		        "operator": "=",
		        "value": parametrosFinais.P_DTEMBFIN
		    },
		    {
		        "name": "P_DTENTINI",
		        "operator": "=",
		        "value": parametrosFinais.P_DTENTINI
		    },
		    {
		        "name": "P_DTENTFIN",
		        "operator": "=",
		        "value": parametrosFinais.P_DTENTFIN
		    },
		    {
		        "name": "P_CDPRODINI",
		        "operator": "=",
		        "value": parametrosFinais.P_CDPRODINI
		    },
		    {
		        "name": "P_CDPRODFIN",
		        "operator": "=",
		        "value": parametrosFinais.P_CDPRODFIN
		    },
		    {
		        "name": "P_CDOPERADOR",
		        "operator": "=",
		        "value": parametrosFinais.P_CDOPERADOR
		    },
		    {
		        "name": "P_DTBLOQINI",
		        "operator": "=",
		        "value": parametrosFinais.P_DTBLOQINI
		    },
		    {
		        "name": "P_DTBLOQFIN",
		        "operator": "=",
		        "value": parametrosFinais.P_DTBLOQFIN
		    },
		    {
		        "name": "P_TBLOQ",
		        "operator": "=",
		        "value": parametrosFinais.P_TBLOQ
		    },
		    {
		        "name": "P_BLOQ",
		        "operator": "=",
		        "value": parametrosFinais.P_BLOQ
		    },
		    {
		        "name": "P_DTNBLOQINI",
		        "operator": "=",
		        "value": parametrosFinais.P_DTNBLOQINI
		    },
		    {
		        "name": "P_DTNBLOQFIN",
		        "operator": "=",
		        "value": parametrosFinais.P_DTNBLOQFIN
		    },
		    {
		        "name": "P_TNBLOQ",
		        "operator": "=",
		        "value": parametrosFinais.P_TNBLOQ
		    },
		    {
		        "name": "P_NBLOQ",
		        "operator": "=",
		        "value": parametrosFinais.P_NBLOQ
		    },
		    {
		        "name": "P_PEDOLEXTR",
		        "operator": "=",
		        "value": parametrosFinais.P_PEDOLEXTR
		    },
		    {
		        "name": "P_CDLOTENVIOL",
		        "operator": "=",
		        "value": parametrosFinais.P_CDLOTENVIOL
		    },
		    {
		        "name": "P_TRESERVA",
		        "operator": "=",
		        "value": parametrosFinais.P_TRESERVA
		    },
		    {
		        "name": "P_SUBGRUPO",
		        "operator": "=",
		        "value": parametrosFinais.P_SUBGRUPO
		    },
		    {
		        "name": "P_CDGRUPPROD",
		        "operator": "=",
		        "value": parametrosFinais.P_CDGRUPPROD
		    },
		    {
		        "name": "P_CDROTA",
		        "operator": "=",
		        "value": parametrosFinais.P_CDROTA
		    },
		    {
		        "name": "P_IDBAIXAAF",
		        "operator": "=",
		        "value": parametrosFinais.P_IDBAIXAAF
		    }
		];
		
		widget.reload().then(function(callback) {
            widget.activate();
            
            if(callback.dataset.sup07200_lancamento_de_pedidos_grid.length == 0) {
                adicionaItemPedidoAction.isVisible = false;
                adicionaNovoPedidoAction.isVisible = true;
            } else {
                adicionaItemPedidoAction.isVisible = true;
                adicionaNovoPedidoAction.isVisible = false;
            }
		});
    };
    
    this.widgetAfterMoveRow = function(args) {
        const widgetItensPedido = args.owner;
        const widgetDadosPedido = templateManager.container.getWidget("dadosPedido");
        const widgetDetalhesPedido = templateManager.container.getWidget("detalhesPedido");
        const widgetStripe = templateManager.container.getWidget("stripeWidget");
        
        ScreenService.showLoader();
        
        if(widgetItensPedido.currentRow.NRPEDEXOL) {
            if(widgetItensPedido.mode === "inline_edit") {
                widgetDadosPedido.enabled = false;
                widgetDetalhesPedido.enabled = false;
            } else {
                widgetDadosPedido.enabled = true;
                widgetDetalhesPedido.enabled = true;
            }
            
            widgetDetalhesPedido.dataSourceFilter = [
                {
                    "name": "P_CDPRODUTO",
                    "operator": "=",
                    "value": widgetItensPedido.currentRow.CDARVPROD
                },
                {
                    "name": "P_CDMARCA",
                    "operator": "=",
                    "value": widgetItensPedido.currentRow.CDMARCA
                },
                {
    		        "name": "P_CDFILLANC",
    		        "operator": "=",
    		        "value": widgetItensPedido.currentRow.CDFILLANC
    		    },
    		    {
    		        "name": "P_DTPROGENPEOL",
    		        "operator": "=",
    		        "value": moment(widgetItensPedido.currentRow.DTPROGENPEOL, 'L').format('L')
    		    },
    		    {
    		        "name": "P_CDFILDEST",
    		        "operator": "=",
    		        "value": widgetItensPedido.currentRow.CDFILDEST.split(" - ")[0]
    		    },
    		    {
    		        "name": "P_NRPEDEXOL",
    		        "operator": "=",
    		        "value": widgetItensPedido.currentRow.NRPEDEXOL
    		    }
            ];
            
            widgetDetalhesPedido.reload();
            
            widgetStripe.currentRow.NRPEDEXOL = widgetItensPedido.currentRow.NRPEDEXOL;
            widgetStripe.currentRow.CDFILLANC = widgetItensPedido.currentRow.CDFILLANC;
            widgetStripe.currentRow.IDBAIXENPEOL = widgetStripe.getField("IDBAIXENPEOL").options[widgetItensPedido.currentRow.IDBAIXENPEOL];
            widgetStripe.currentRow.IDBAIXEXSAI = widgetStripe.getField("IDBAIXEXSAI").options[widgetItensPedido.currentRow.IDBAIXEXSAI];
            widgetStripe.currentRow.QTEFETENPEOL = widgetItensPedido.currentRow.QTEFETENPEOL == null ? '0,000' : widgetItensPedido.currentRow.QTEFETENPEOL + ',000';
            widgetStripe.currentRow.IDBAIXEXOL = widgetStripe.getField("IDBAIXEXOL").options[widgetItensPedido.currentRow.IDBAIXEXOL];
            widgetStripe.currentRow.DTPEDEXOL = moment(widgetItensPedido.currentRow.DTPEDEXOL, 'L').format('L');
            widgetStripe.currentRow.IDTIPOEXOL = widgetStripe.getField("IDTIPOEXOL").options[widgetItensPedido.currentRow.IDTIPOEXOL];
            widgetStripe.currentRow.IDITMPEDOLBLOQ = widgetStripe.getField("IDITMPEDOLBLOQ").options[widgetItensPedido.currentRow.IDITMPEDOLBLOQ];
            widgetStripe.currentRow.IDBAIXAOLSAI = widgetStripe.getField("IDBAIXAOLSAI").options[widgetItensPedido.currentRow.IDBAIXAOLSAI];
            
            General.callRestEngine("opl_relatorios#/carregaDadosPedido", "Row", widgetItensPedido.currentRow).then(function(response) {
                const result = response.dataset.opl07200_dados_pedido;
                
                if(result) {
                    widgetDadosPedido.currentRow.NMFILLANC = result.NMFILLANC;
                    widgetDadosPedido.currentRow.CDFILLANC = result.CDFILLANC;
                    widgetDadosPedido.currentRow.NMFILDEST = result.NMFILDEST;
                    widgetDadosPedido.currentRow.CDFILDEST = result.CDFILDEST;
                    widgetDadosPedido.currentRow.NMFILIOPELOG = result.NMFILIOPELOG;
                    widgetDadosPedido.currentRow.CDFILIOPELOG = result.CDFILIOPELOG;
                    widgetDadosPedido.currentRow.DTPEDEXOL = result.DTPEDEXOL;
                    widgetDadosPedido.currentRow.IDPEDEXOLEXTR = result.IDPEDEXOLEXTR;
                    widgetDadosPedido.currentRow.CDEMPRESA = result.CDEMPRESA;
                    widgetDadosPedido.currentRow.IDTIPOEMITAF = result.IDEMITEXOL;
                    widgetDadosPedido.currentRow.NMTIPOEMITAF = result.IDEMITEXOL == '1' ? "Empresa da Unidade" : result.IDEMITEXOL == '2' ? "Empresa Informada" : "Cliente Principal";
                    widgetDadosPedido.currentRow.CDLOTENVITOL = widgetItensPedido.currentRow.CDLOTENVITOL ? widgetItensPedido.currentRow.CDLOTENVITOL : "";
                    widgetDadosPedido.currentRow.CDTIPCOB = result.CDTIPCOB;
                    widgetDadosPedido.currentRow.NMTIPOCOBR = result.NMTIPOCOBR;
                    widgetDadosPedido.currentRow.IDTIPOFRETAF = result.IDTPFRETEXOL;
                    widgetDadosPedido.currentRow.CDTPCTPAGAR = result.CDTPCTPAGAR;
                    widgetDadosPedido.currentRow.DSTPCTPAGAR = result.DSTPCTPAGAR;
                    widgetDadosPedido.currentRow.NRINSJURTRAN = result.NRINSJTREXOL;
                    widgetDadosPedido.currentRow.NMRAZSOCTRAN = result.NMRAZSOCTRAN;
                    widgetDadosPedido.currentRow.IDTPIJURTRAN = result.IDTPJTREXOL;
                    widgetDadosPedido.currentRow.IDBAIXEXOL = result.IDBAIXEXOL;
                    widgetDadosPedido.currentRow.IDBAIXEXSAI = result.IDBAIXEXSAI;
                    widgetDadosPedido.currentRow.NRPEDEXOL = result.NRPEDEXOL;
                    
                    widgetDadosPedido.getField("NMEMPRESA").dataSourceFilter[0].value = result.CDFILDEST;
                    widgetDadosPedido.getField("NMEMPRESA").dataSourceFilter[1].value = result.CDEMPRESA;
                    
                    widgetDadosPedido.getField("NMRAZSOCTRAN").dataSourceFilter[0].value = result.CDFILDEST;
                    widgetDadosPedido.getField("NMRAZSOCTRAN").dataSourceFilter[1].value = "";
                    widgetDadosPedido.getField("NMRAZSOCTRAN").dataSourceFilter[2].value = "";
                    
                    widgetDadosPedido.getField("NMLOTENVITOL").reload().then(data => {
                        let resultLote = data.dataset.lotes_all.filter(function(row) {
                            return row.CDLOTENVITOL == widgetItensPedido.currentRow.CDLOTENVITOL;
                        });
                        widgetDadosPedido.currentRow.NMLOTENVITOL = resultLote.length > 0 ? resultLote[0].NMLOTENVITOL : "";
                        widgetDadosPedido.currentRow.CDLOTENVITOL = resultLote.length > 0 ? resultLote[0].CDLOTENVITOL : "";
                    });
                    
                    self.destinatarioNF(widgetDadosPedido);
                    
                    if(result.IDBAIXEXOL == null || result.IDBAIXEXOL == '0' || result.IDBAIXEXOL == '1') {
                        widgetDadosPedido.getAction("editaDadosPedido").isVisible = true;
                        widgetDadosPedido.getAction("baixaManualPedido").isVisible = true;
                        widgetDadosPedido.getAction("cancelarPedido").isVisible = true;
                        widgetDadosPedido.getAction("encerrarPedido").isVisible = true;
                    } else {
                        widgetDadosPedido.getAction("editaDadosPedido").isVisible = false;
                        widgetDadosPedido.getAction("baixaManualPedido").isVisible = false;
                        widgetDadosPedido.getAction("cancelarPedido").isVisible = false;
                        widgetDadosPedido.getAction("encerrarPedido").isVisible = false;
                    }
                    
                    if(result.IDBAIXEXOL == '3' || result.IDBAIXEXOL == '4' || result.IDBAIXEXOL == '5') {
                        widgetDadosPedido.getAction("emAbertoPedido").isVisible = true;
                    } else {
                        widgetDadosPedido.getAction("emAbertoPedido").isVisible = false;
                    }
                    
                    if(result.IDBAIXEXOL == null || result.IDBAIXEXOL == '0') {
                        widgetDadosPedido.getAction("excluiPedido").isVisible = true;
                    } else {
                        widgetDadosPedido.getAction("excluiPedido").isVisible = false;
                    }
                    
                    if((parametrosParaSupri && parametrosParaSupri.IDENVIOITMPEDOL == 'S') && (result.IDBAIXEXOL == null || result.IDBAIXEXOL == '0')) {
                        widgetDadosPedido.getAction("exportarPedido").isVisible = true;
                    } else {
                        widgetDadosPedido.getAction("exportarPedido").isVisible = false;
                    }
                    
                    ScreenService.hideLoader();
                } else {
                    ScreenService.hideLoader();
                    
                    MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": "Não foi possível carregar os dados do pedido." });
                }
            }).catch(function(error) {
                ScreenService.hideLoader();
                
                MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
            });
        } else {
            widgetDadosPedido.enabled = false;
            widgetDetalhesPedido.enabled = false;
            
            ScreenService.hideLoader();
        }
    };
    
    this.adicionaItemPedido = function(widget) {
        const widgetAdicionaItemPedido = templateManager.container.getWidget("adicionaItemPedido");
        var fieldProduto = widgetAdicionaItemPedido.getField('NMPRODUTO');
        fieldProduto.dataSourceFilter.forEach(function(filtro) {
            if(filtro.name == "P_PRODCMP")
                filtro.value = parametrosParaSupri.IDUTLPROCMP;
            if(filtro.name == "P_CDFILSOLI")
                filtro.value = "FILIAL_LOGADA";
        });
        
        if(widget.currentRow.NRPEDEXOL) {
            widgetAdicionaItemPedido.currentRow.NRPEDEXOL = widget.currentRow.NRPEDEXOL;
            widgetAdicionaItemPedido.currentRow.DTPROGENPEOL = moment(widget.currentRow.DTPROGENPEOL, 'L').format('L');
            widgetAdicionaItemPedido.currentRow.CDMARCA = widget.currentRow.CDMARCA;
            widgetAdicionaItemPedido.currentRow.NMMARCA = widget.currentRow.NMMARCA;
            widgetAdicionaItemPedido.currentRow.CDFILLANC = getLocalVar("CDFILIAL");
            widgetAdicionaItemPedido.currentRow.NMFILLANC = getLocalVar("NMFILIAL");
            widgetAdicionaItemPedido.currentRow.CDFILDEST = widget.currentRow.CDFILDEST.split(' - ')[0];
            widgetAdicionaItemPedido.currentRow.NMFILDEST = widget.currentRow.CDFILDEST.split(' - ')[1];
            widgetAdicionaItemPedido.currentRow.QTPROGENPEOL = widget.currentRow.QTPROGENPEOL;
            widgetAdicionaItemPedido.currentRow.CDFILIOPELOG = widget.currentRow.CDFILIOPELOG;
            
            widgetAdicionaItemPedido.getField("NMFILIOPELOG").reload().then(data => {
                let result = data.dataset.filial_ol.filter(function(row) {
                    return row.CDFILIAL == widget.currentRow.CDFILIOPELOG;
                });
                widgetAdicionaItemPedido.currentRow.NMFILIOPELOG = result[0].NMFILIAL;
            });
            
            widgetAdicionaItemPedido.getField("NRPEDEXOL").readOnly = true;
        } else {
            if(widget.dataSource.data.length > 0) {
                widgetAdicionaItemPedido.currentRow.NRPEDEXOL = widget.dataSource.data[0].NRPEDEXOL;
                widgetAdicionaItemPedido.currentRow.DTPROGENPEOL = moment(widget.dataSource.data[0].DTPROGENPEOL, 'L').format('L');
                widgetAdicionaItemPedido.currentRow.CDMARCA = widget.dataSource.data[0].CDMARCA;
                widgetAdicionaItemPedido.currentRow.NMMARCA = widget.dataSource.data[0].NMMARCA;
                widgetAdicionaItemPedido.currentRow.CDFILLANC = getLocalVar("CDFILIAL");
                widgetAdicionaItemPedido.currentRow.NMFILLANC = getLocalVar("NMFILIAL");
                widgetAdicionaItemPedido.currentRow.CDFILDEST = widget.dataSource.data[0].CDFILDEST.split(' - ')[0];
                widgetAdicionaItemPedido.currentRow.NMFILDEST = widget.dataSource.data[0].CDFILDEST.split(' - ')[1];
                widgetAdicionaItemPedido.currentRow.QTPROGENPEOL = widget.dataSource.data[0].QTPROGENPEOL;
                widgetAdicionaItemPedido.currentRow.CDFILIOPELOG = widget.dataSource.data[0].CDFILIOPELOG;
                
                widgetAdicionaItemPedido.getField("NMFILIOPELOG").reload().then(data => {
                    let result = data.dataset.filial_ol.filter(function(row) {
                        return row.CDFILIAL == widget.dataSource.data[0].CDFILIOPELOG;
                    });
                    widgetAdicionaItemPedido.currentRow.NMFILIOPELOG = result[0].NMFILIAL;
                });
                
                widgetAdicionaItemPedido.getField("NRPEDEXOL").readOnly = true;
            } else {
                widgetAdicionaItemPedido.currentRow.CDFILLANC = getLocalVar("CDFILIAL");
                widgetAdicionaItemPedido.currentRow.NMFILLANC = getLocalVar("NMFILIAL");
                widgetAdicionaItemPedido.currentRow.DTPROGENPEOL = moment().format('L');
                
                widgetAdicionaItemPedido.getField("NRPEDEXOL").readOnly = false;
            }
        }
        
        if(parametrosParaSupri.IDUTILCONSSOLIOLEXT === 'S') {
            widgetAdicionaItemPedido.getField("CDLOTENVITOL").readOnly = true;
            widgetAdicionaItemPedido.getField("CDLOTENVITOL").isVisible = true;
        } else {
            widgetAdicionaItemPedido.getField("CDLOTENVITOL").readOnly = true;
            widgetAdicionaItemPedido.getField("CDLOTENVITOL").isVisible = false;
        }
        
        ScreenService.openSwipe(widgetAdicionaItemPedido);
    };
    
    this.salvaAdicaoItemPedido = function(widget) {
        const dataProc = moment(getLocalVar("DTPROCESSA"), "DD/MM/YYYY").format("MM-DD-YYYY");
        const dataEscd = moment(widget.currentRow.DTPROGENPEOL, "DD/MM/YYYY").format("MM-DD-YYYY");
        
        widget.currentRow.FINAL = permissoesFinaisOperador;
        widget.currentRow.GERAL = permissoesGeraisOperador;
        
        if(widget.isValid()) {
            if(moment(dataEscd).isSameOrAfter(dataProc)) {
                General.callRestEngine("opl_relatorios#/adqRelacProdOL", "Row", widget.currentRow).then(function(resp) {
                    
                    if(Util.isEmptyOrBlank(resp.dataset.data)) {
                        if(parametrosParaSupri.IDBLQLANITSEMRELACOL == 'S') {
                            MessageService.showMessageByCode("PRODUTO_ITEM_SEM_RELACAO_PRODOL");
                            MessageService.showMessageByCode("PARAM_IDBLQLANITSEMRELACOL");
                        } else {
                            MessageService.showMessageByCode("PRODUTO_ITEM_SEM_RELACAO_PRODOL");
                            
                            General.callRestEngine("opl_relatorios#/checkIgualdadeItemPedidoOL", "Row", widget.currentRow).then(function(callback) {
                                General.callRestEngine("opl_relatorios#/insereItemPedidoOL", "Row", widget.currentRow).then(function(response) {
                                    widget.currentRow = {};
                                    
                                    MessageService.showMessageByCode("OPERACAO_SUCESSO");
                                    
                                    ScreenService.closeSwipe();
                                    
                                    const widgetItensPedido = widget.getParent();
                                    
                                    widgetItensPedido.activate();
                                    widgetItensPedido.reload();
                                }).catch(function(error) {
                                    if(error.data.error == "QTPROGENPEOL_EQUALS_ZERO")
                                        MessageService.showMessageByCode(error.data.error);
                                    else
                                        MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
                                });
                            }).catch(function(error) {
                                if(error.data.error == "ITEM_ALREADY_EXISTS_PEDIDO" || error.data.error == "ERRO_QUERY") {
                                    MessageService.showMessageByCode(error.data.error);
                                } else {
                                    MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
                                }
                            });
                        }
                    } else {
                        General.callRestEngine("opl_relatorios#/checkIgualdadeItemPedidoOL", "Row", widget.currentRow).then(function(callback) {
                            General.callRestEngine("opl_relatorios#/insereItemPedidoOL", "Row", widget.currentRow).then(function(response) {
                                widget.currentRow = {};
                                
                                MessageService.showMessageByCode("OPERACAO_SUCESSO");
                                
                                ScreenService.closeSwipe();
                                
                                const widgetItensPedido = widget.getParent();
                                
                                widgetItensPedido.activate();
                                widgetItensPedido.reload();
                            }).catch(function(error) {
                                if(error.data.error == "QTPROGENPEOL_EQUALS_ZERO")
                                    MessageService.showMessageByCode(error.data.error);
                                else
                                    MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
                            });
                        }).catch(function(error) {
                            if(error.data.error == "ITEM_ALREADY_EXISTS_PEDIDO" || error.data.error == "ERRO_QUERY") {
                                MessageService.showMessageByCode(error.data.error);
                            } else {
                                MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
                            }
                        });
                    }
                }).catch(function(error) {
                    MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
                });
            } else {
                MessageService.showMessageByCode("DATA_MAIOR_IGUAL_PROCESSAMENTO");
            }
        } else {
            MessageService.showMessageByCode("OBRIGATORY_FIELDS");
        }
    };
    
    this.excluiItemPedido = function(widget) {
        const rowsSelecionadas = widget.getCheckedRows();
        const rowsEmAberto = rowsSelecionadas.filter(function(row) {
            return ((row.IDBAIXENPEOL == null || row.IDBAIXENPEOL == 0) && (row.IDBAIXEXOL == null || row.IDBAIXEXOL == 0));
        });
        var rowsBloqueadas = [];
        
        rowsSelecionadas.forEach(row => {
           row.DTPROGENPEOL = moment(row.DTPROGENPEOL, "DD/MM/YYYY").format("DD/MM/YYYY");
           
           if(!verificaPermissaoItem(widget, row)) {
               rowsBloqueadas.push(row);
           }
        });
        
        if(rowsEmAberto.length == rowsSelecionadas.length) {
            if(rowsBloqueadas.length >= 1) {
                var rowsToMessage = [];
                var stringItem = "";
                
                rowsBloqueadas.forEach(row => {
					var prod = "Pedido: " + row.NRPEDEXOL + ", Produto: " + row.NMPRODUTO + ", Marca: " + row.NMMARCA + ", Entrega: " + row.DTPROGENPEOL;
										
					rowsToMessage.push(prod);
			    });
			    
			    stringItem = rowsToMessage.join("<br><br>");
			    
			    MessageService.showMessageByCode("OPER_BLOCK_ITEM_GRUPOOPER", { ITEM: stringItem });
            } else {
                MessageService.confirmMessageByCode("CONFIRMA_EXCLUSAO_ITENS").then(function(confirmed) {
                    General.callRestEngine("opl_relatorios#/excluiItemPedidoOL", "Row", rowsSelecionadas).then(function(response) {
                        widget.activate();
                        widget.reload();
                        
                        MessageService.showMessageByCode("EXCLUSAO_REALIZADA");
                    }).catch(function(error) {
                        MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
                    });
                });
            }
        } else {
            MessageService.showMessageByCode("ONLY_EM_ABERTO_ITENS_PEDIDO_DELETE");
        }
    };
    
    this.openWidgetAlteracaoDataEntregaItemPedido = function(widget) {
        const popUpWidget = templateManager.container.getWidget("alteracaoDataEntregaItemPedidoWidget");
        const rowsSelecionadas = widget.getCheckedRows();
        const rowsEmAberto = rowsSelecionadas.filter(function(row) {
            return ((row.IDBAIXENPEOL == null || row.IDBAIXENPEOL == 0) && (row.IDBAIXEXOL == null || row.IDBAIXEXOL == 0));
        });
        var rowsBloqueadas = [];
        
        rowsSelecionadas.forEach(row => {
           if(!verificaPermissaoItem(widget, row)) {
               rowsBloqueadas.push(row);
           }
        });
        
        popUpWidget.currentRow = {};
        
        if(rowsEmAberto.length == rowsSelecionadas.length) {
            if(rowsBloqueadas.length >= 1) {
                var rowsToMessage = [];
                var stringItem = "";
                
                rowsBloqueadas.forEach(row => {
					var prod = "Pedido: " + row.NRPEDEXOL + ", Produto: " + row.NMPRODUTO + ", Marca: " + row.NMMARCA + ", Entrega: " + row.DTPROGENPEOL;
										
					rowsToMessage.push(prod);
			    });
			    
			    stringItem = rowsToMessage.join("<br><br>");
			    
			    MessageService.showMessageByCode("OPER_BLOCK_ITEM_GRUPOOPER", { ITEM: stringItem });
            } else {
                ScreenService.openPopup(popUpWidget);
            }
        } else {
            MessageService.showMessageByCode("ONLY_EM_ABERTO_ITENS_PEDIDO_EDIT");
        }
    };
    
    this.salvaAlteracaoDataEntregaItemPedido = function(widget) {
        const dataProc = moment(getLocalVar("DTPROCESSA"), "DD/MM/YYYY").format("MM-DD-YYYY");
        const dataEscd = moment(widget.currentRow.NOVADTENTREGA, "DD/MM/YYYY").format("MM-DD-YYYY");
        const widgetItensPedido = widget.getParent();
        const rowsSelecionadas = widgetItensPedido.getCheckedRows();
        
        rowsSelecionadas.forEach(row => {
           row.NEW_DTPROGENPEOL = moment(widget.currentRow.NOVADTENTREGA, "DD/MM/YYYY").format("DD/MM/YYYY");
           row.DTPROGENPEOL = moment(row.DTPROGENPEOL, "DD/MM/YYYY").format("DD/MM/YYYY");
        });
        
        if(widget.isValid()) {
            if(moment(dataEscd).isSameOrAfter(dataProc)) {
                General.callRestEngine("opl_relatorios#/alteraDataEntregaItemPedidoOL", "Row", rowsSelecionadas).then(function(response) {
                    ScreenService.closePopup();
                    ScreenService.closePopup();
                    
                    widgetItensPedido.reload();
                    
                    MessageService.showMessageByCode("DTPROGENPEOL_EDIT_SUCCESS");
                }).catch(function(error) {
                    if(error.data.error == "DTPROGENPEOL_ALREADY_EXISTS_PEDIDO" || error.data.error == "ERRO_QUERY") {
                        MessageService.showMessageByCode(error.data.error);
                    } else {
                        MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
                    }
                    ScreenService.closePopup();
                    ScreenService.closePopup();
                    
                    widgetItensPedido.reload();
                });
            } else {
                MessageService.showMessageByCode("DATA_MAIOR_IGUAL_PROCESSAMENTO");
            }
        } else {
            MessageService.showMessageByCode("OBRIGATORY_FIELDS");
        }
    };
    
    this.openWidgetAlteracaoMarcaItemPedido = function(widget) {
        const popUpWidget = templateManager.container.getWidget("alteracaoMarcaItemPedidoWidget");
        const rowsSelecionadas = widget.getCheckedRows();
        const rowsEmAberto = rowsSelecionadas.filter(function(row) {
            return ((row.IDBAIXENPEOL == null || row.IDBAIXENPEOL == 0) && (row.IDBAIXEXOL == null || row.IDBAIXEXOL == 0));
        });
        var rowsBloqueadas = [];
        
        rowsSelecionadas.forEach(row => {
           if(!verificaPermissaoItem(widget, row)) {
               rowsBloqueadas.push(row);
           }
        });
        
        popUpWidget.currentRow = {};
        
        if(rowsEmAberto.length == rowsSelecionadas.length) {
            if(rowsBloqueadas.length >= 1) {
                var rowsToMessage = [];
                var stringItem = "";
                
                rowsBloqueadas.forEach(row => {
					var prod = "Pedido: " + row.NRPEDEXOL + ", Produto: " + row.NMPRODUTO + ", Marca: " + row.NMMARCA + ", Entrega: " + row.DTPROGENPEOL;
										
					rowsToMessage.push(prod);
			    });
			    
			    stringItem = rowsToMessage.join("<br><br>");
			    
			    MessageService.showMessageByCode("OPER_BLOCK_ITEM_GRUPOOPER", { ITEM: stringItem });
            } else {
                ScreenService.openPopup(popUpWidget);
            }
        } else {
            MessageService.showMessageByCode("ONLY_EM_ABERTO_ITENS_PEDIDO_EDIT");
        }
    };
    
    this.salvaAlteracaoMarcaItemPedido = function(widget) {
        const widgetItensPedido = widget.getParent();
        const rowsSelecionadas = widgetItensPedido.getCheckedRows();
        
        rowsSelecionadas.forEach(row => {
           row.NEW_CDMARCA = widget.currentRow.CDMARCA;
           row.OLD_CDMARCA = row.CDMARCA;
           row.DTPROGENPEOL = moment(row.DTPROGENPEOL, "DD/MM/YYYY").format("DD/MM/YYYY");
        });
        
        if(widget.isValid()) {
            General.callRestEngine("opl_relatorios#/alteraMarcaItemPedidoOL", "Row", rowsSelecionadas).then(function(response) {
                ScreenService.closePopup();
                ScreenService.closePopup();
                    
                widgetItensPedido.reload();
                    
                MessageService.showMessageByCode("CDMARCA_EDIT_SUCCESS");
            }).catch(function(error) {
                if(error.data.error == "CDMARCA_ALREADY_EXISTS_PEDIDO" || error.data.error == "ERRO_QUERY") {
                    MessageService.showMessageByCode(error.data.error);
                } else {
                    MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
                }
                ScreenService.closePopup();
                ScreenService.closePopup();
                
                widgetItensPedido.reload();
            });
        } else {
            MessageService.showMessageByCode("OBRIGATORY_FIELDS");
        }
    };
    
    this.openWidgetAlteracaoProdutoItemPedido = function(widget) {
        const popUpWidget = templateManager.container.getWidget("alteracaoProdutoItemPedidoWidget");
        const rowsSelecionadas = widget.getCheckedRows();
        const rowBase = rowsSelecionadas[0];
        const rowsEmAberto = rowsSelecionadas.filter(function(row) {
            return ((row.IDBAIXENPEOL == null || row.IDBAIXENPEOL == 0) && (row.IDBAIXEXOL == null || row.IDBAIXEXOL == 0));
        });
        var permiteOperacao = true;
        var rowsBloqueadas = [];
        
        rowsSelecionadas.forEach(row => {
           if(!verificaPermissaoItem(widget, row)) {
               rowsBloqueadas.push(row);
           }
        });
        
        for(let i = 0; i < rowsSelecionadas.length; i++) {
            if(rowsSelecionadas[i].CDARVPROD !== rowBase.CDARVPROD) {
                permiteOperacao = false;
                break;
            }
        }
        
        var mascaraProduto = getLocalVar('CDPICTPROD');
        var fieldProduto = popUpWidget.getField('NMPRODUTO');
        
        mascaraProduto = mascaraProduto.split('.');
        
        var nivelProduto = mascaraProduto.length;
        
        /*fieldProduto.dataSourceFilter.forEach(function(filtro) {
            if(filtro.name == 'CDNVPRODUTO')
                filtro.value = nivelProduto;
        });*/
        
        fieldProduto.dataSourceFilter.forEach(function(row) {
            if(row.name == "P_CDFILIOPELOG") {
                row.value = CDFILIOPELOGPROD;
            }
        });
        
        popUpWidget.currentRow = {};
        
        popUpWidget.currentRow.AJUSTE_UNIDADE = '0';
		popUpWidget.currentRow.AJUSTE_QUANTIDADE = '0';
        
        if(rowsEmAberto.length == rowsSelecionadas.length && permiteOperacao) {
            if(rowsBloqueadas.length >= 1) {
                var rowsToMessage = [];
                var stringItem = "";
                
                rowsBloqueadas.forEach(row => {
					var prod = "Pedido: " + row.NRPEDEXOL + ", Produto: " + row.NMPRODUTO + ", Marca: " + row.NMMARCA + ", Entrega: " + row.DTPROGENPEOL;
										
					rowsToMessage.push(prod);
			    });
			    
			    stringItem = rowsToMessage.join("<br><br>");
			    
			    MessageService.showMessageByCode("OPER_BLOCK_ITEM_GRUPOOPER", { ITEM: stringItem });
            } else {
                ScreenService.openPopup(popUpWidget);
            }
        } else if(!permiteOperacao) {
            MessageService.showMessageByCode("OPR_BLOCK_DIFF_PRODUCTS");
        } else {
            MessageService.showMessageByCode("ONLY_EM_ABERTO_ITENS_PEDIDO_EDIT");
        }
    };
    
    this.onChangeAjuste = function(field) {
        var value = angular.copy(field.value()),
        	minValue = '-99.99';
        
        if(typeof(value) == 'string') {
            value = value.split('.').join('');
            value = value.replace(',', '.');
        }
        
        if(value && parseFloat(value) < parseFloat(minValue)) {
            field.setValue('0');
            MessageService.showMessageByCode("VLR_MENOR_MENOS_99");
        }
        
        if (Util.isEmptyOrBlank(field.value())) {
    		field.setValue('0');
    	}
    };
    
    this.salvaAlteracaoProdutoItemPedido = function(widget) {
        const widgetItensPedido = widget.getParent();
        const rowsSelecionadas = widgetItensPedido.getCheckedRows();
        
        rowsSelecionadas.forEach(row => {
           row.NEW_CDPRODUTO = widget.currentRow.CDPRODUTO;
           row.NEW_CDPRODESTO = widget.currentRow.CDPRODESTO;
           row.NEW_CDARVPROD = widget.currentRow.CDARVPROD;
           row.NEW_VRFATOCONV = widget.currentRow.VRFATOCONV;
           row.OLD_CDPRODUTO = row.CDPRODUTO;
           row.OLD_CDPRODESTO = row.CDPRODESTO;
           row.OLD_CDARVPROD = row.CDARVPROD;
           row.OLD_VRFATOCONV = row.VRFATOCONV;
           row.AJUSTE_UNIDADE = widget.currentRow.AJUSTE_UNIDADE;
           row.AJUSTE_QUANTIDADE = widget.currentRow.AJUSTE_QUANTIDADE;
           row.CDFILDEST = row.CDFILDEST.substr(0, 4);
           row.DTPROGENPEOL = moment(row.DTPROGENPEOL, "DD/MM/YYYY").format("DD/MM/YYYY");
           row.CONSIDERASOL = widget.currentRow.CONSIDERASOL;
        });
        
        if(widget.isValid()) {
            General.callRestEngine("opl_relatorios#/alteraProdutoItemPedidoOL", "Row", rowsSelecionadas).then(function(response) {
                ScreenService.closePopup();
                ScreenService.closePopup();
                    
                widgetItensPedido.reload();
                
                if(response.messages.length > 0) {
                    response.messages.forEach(m => {
                        if(m.message == "ALL_ROWS_UPDATED") {
                            MessageService.showMessageByCode("CDPRODUTO_EDIT_SUCCESS");
                        }
                        if(m.message == "SOME_ROWS_UPDATED") {
                            MessageService.showMessageByCode("CDPRODUTO_SOME_EDIT_SUCCESS");
                        }
                        if(m.message == "NO_ROWS_UPDATED") {
                            MessageService.showMessageByCode("CDPRODUTO_NONE_EDIT_SUCCESS");
                        }
                    });
                }
            }).catch(function(error) {
                if(error.data.error == "CDPRODUTO_ALREADY_EXISTS_PEDIDO" || error.data.error == "ERRO_QUERY") {
                    MessageService.showMessageByCode(error.data.error);
                } else {
                    MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
                }
                ScreenService.closePopup();
                ScreenService.closePopup();
                
                widgetItensPedido.reload();
            });
        } else {
            MessageService.showMessageByCode("OBRIGATORY_FIELDS");
        }
    };
    
    this.openWidgetAlteracaoQuantidadeItemPedido = function(widget) {
        const popUpWidget = templateManager.container.getWidget("alteracaoQuantidadeItemPedidoWidget");
        const rowsSelecionadas = widget.getCheckedRows();
        const rowsEmAbertoParcial = rowsSelecionadas.filter(function(row) {
            return ((row.IDBAIXENPEOL == null || row.IDBAIXENPEOL == 0 || row.IDBAIXENPEOL == 1) && (row.IDBAIXEXOL == null || row.IDBAIXEXOL == 0 || row.IDBAIXEXOL == 1));
        });
        var rowsBloqueadas = [];
        
        rowsSelecionadas.forEach(row => {
           if(!verificaPermissaoItem(widget, row)) {
               rowsBloqueadas.push(row);
           }
        });
        
        popUpWidget.currentRow = {};
        
        if(rowsEmAbertoParcial.length == rowsSelecionadas.length) {
            if(rowsBloqueadas.length >= 1) {
                var rowsToMessage = [];
                var stringItem = "";
                
                rowsBloqueadas.forEach(row => {
					var prod = "Pedido: " + row.NRPEDEXOL + ", Produto: " + row.NMPRODUTO + ", Marca: " + row.NMMARCA + ", Entrega: " + row.DTPROGENPEOL;
										
					rowsToMessage.push(prod);
			    });
			    
			    stringItem = rowsToMessage.join("<br><br>");
			    
			    MessageService.showMessageByCode("OPER_BLOCK_ITEM_GRUPOOPER", { ITEM: stringItem });
            } else {
                ScreenService.openPopup(popUpWidget);
            }
        } else {
            MessageService.showMessageByCode("ONLY_EMABERTO_PARCIAL_ITENS_PEDIDO_EDIT");
        }
    };
    
    this.salvaAlteracaoQuantidadeItemPedido = function(widget) {
        const widgetItensPedido = widget.getParent();
        const rowsSelecionadas = widgetItensPedido.getCheckedRows();
        
        rowsSelecionadas.forEach(row => {
           row.NEW_QTPROGENPEOL = widget.currentRow.QTPROGENPEOL;
           row.OLD_QTPROGENPEOL = row.QTPROGENPEOL;
           row.CDFILDEST = row.CDFILDEST.substr(0, 4);
           row.DTPROGENPEOL = moment(row.DTPROGENPEOL, "DD/MM/YYYY").format("DD/MM/YYYY");
        });
        
        if(widget.isValid()) {
            if(widget.currentRow.QTPROGENPEOL === "0,000" || widget.currentRow.QTPROGENPEOL === 0) {
                MessageService.confirmMessageByCode("CONFIRMA_EXCLUSAO_ITENS").then(function(confirmed) {
                    General.callRestEngine("opl_relatorios#/excluiItemPedidoOL", "Row", rowsSelecionadas).then(function(response) {
                        ScreenService.closePopup();
                        ScreenService.closePopup();
                        
                        widgetItensPedido.reload();
                        
                        MessageService.showMessageByCode("EXCLUSAO_REALIZADA");
                    }).catch(function(error) {
                        ScreenService.closePopup();
                        ScreenService.closePopup();
                        
                        widgetItensPedido.reload();
                        
                        MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
                    });
                }).catch(function(error) {});
            } else {
                General.callRestEngine("opl_relatorios#/alteraQuantidadeItemPedidoOL", "Row", rowsSelecionadas).then(function(response) {
                    ScreenService.closePopup();
                    ScreenService.closePopup();
                        
                    widgetItensPedido.reload();
                        
                    MessageService.showMessageByCode("QTPROGENPEOL_EDIT_SUCCESS");
                }).catch(function(error) {
                    ScreenService.closePopup();
                    ScreenService.closePopup();
                    
                    widgetItensPedido.reload();
                    
                    MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
                });
            }
        } else {
            MessageService.showMessageByCode("OBRIGATORY_FIELDS");
        }
    };
    
    this.incluirLote = function(widget) {
        const popUpWidget = templateManager.container.getWidget("inclusaoDeLoteItemPedidoWidget");
        const rowsSelecionadas = widget.getCheckedRows();
        const rowsEmAberto = rowsSelecionadas.filter(function(row) {
            return ((row.IDBAIXENPEOL == null || row.IDBAIXENPEOL == 0) && (row.IDBAIXEXOL == null || row.IDBAIXEXOL == 0));
        });
        var rowsBloqueadas = [];
        
        rowsSelecionadas.forEach(row => {
           if(!verificaPermissaoItem(widget, row)) {
               rowsBloqueadas.push(row);
           }
        });
        
        popUpWidget.currentRow = {};
        
        if(rowsEmAberto.length == rowsSelecionadas.length) {
            if(rowsBloqueadas.length >= 1) {
                var rowsToMessage = [];
                var stringItem = "";
                
                rowsBloqueadas.forEach(row => {
					var prod = "Pedido: " + row.NRPEDEXOL + ", Produto: " + row.NMPRODUTO + ", Marca: " + row.NMMARCA + ", Entrega: " + row.DTPROGENPEOL;
										
					rowsToMessage.push(prod);
			    });
			    
			    stringItem = rowsToMessage.join("<br><br>");
			    
			    MessageService.showMessageByCode("OPER_BLOCK_ITEM_GRUPOOPER", { ITEM: stringItem });
            } else {
                ScreenService.openPopup(popUpWidget);
            }
        } else {
            MessageService.showMessageByCode("ONLY_EM_ABERTO_ITENS_PEDIDO_EDIT");
        }
    };
    
    this.salvaInclusaoDeLoteItemPedido = function(widget) {
        const widgetItensPedido = widget.getParent();
        const rowsSelecionadas = widgetItensPedido.getCheckedRows();
        const rowPai = rowsSelecionadas[0];
        
        rowPai.CDFILDEST1 = rowPai.CDFILDEST.split(" - ")[0];
        
        var inclusaoDeLote = false;
        
        rowsSelecionadas.forEach(row => {
            row.CDFILDEST1 = row.CDFILDEST.split(" - ")[0];
            row.NEW_CDLOTENVITOL = widget.currentRow.CDLOTENVITOL;
            row.OLD_CDLOTENVITOL = row.CDLOTENVITOL;
            row.DTPROGENPEOL = moment(row.DTPROGENPEOL, "DD/MM/YYYY").format("DD/MM/YYYY");
            
            if(row.CDFILIOPELOG == rowPai.CDFILIOPELOG && row.CDFILLANC == rowPai.CDFILLANC && row.CDFILDEST1 == rowPai.CDFILDEST1 && row.NRPEDEXOL == rowPai.NRPEDEXOL) {
                
            } else {
                inclusaoDeLote = true;
            }
        });
        
        if(inclusaoDeLote) {
            if(widget.isValid()) {
                General.callRestEngine("opl_relatorios#/incluiItemPedidoLoteDiversos", "Row", rowsSelecionadas).then(function(response) {
                   ScreenService.closePopup();
                   ScreenService.closePopup();
                   
                   widgetItensPedido.reload();
                   
                   MessageService.showMessageByCode("CDLOTENVITOL_NEW_SUCCESS");
                }).catch(function(error) {
                    ScreenService.closePopup();
                    ScreenService.closePopup();
                    
                    widgetItensPedido.reload();
                    
                    MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
                });
            } else {
                MessageService.showMessageByCode("OBRIGATORY_FIELDS");
            }
        } else {
           if(widget.isValid()) {
               General.callRestEngine("opl_relatorios#/incluiItemPedidoLote", "Row", rowsSelecionadas).then(function(response) {
                   ScreenService.closePopup();
                   ScreenService.closePopup();
                   
                   widgetItensPedido.reload();
                   
                   MessageService.showMessageByCode("CDLOTENVITOL_NEW_SUCCESS");
                }).catch(function(error) {
                    ScreenService.closePopup();
                    ScreenService.closePopup();
                    
                    widgetItensPedido.reload();
                    
                    MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
                });
            } else {
                MessageService.showMessageByCode("OBRIGATORY_FIELDS");
            } 
        }
    };
    
    this.incluirReserva = function(widget) {
        const rowsSelecionadas = widget.getCheckedRows();
        const rowsEmAberto = rowsSelecionadas.filter(function(row) {
            return ((row.IDBAIXENPEOL == null || row.IDBAIXENPEOL == 0) && (row.IDBAIXEXOL == null || row.IDBAIXEXOL == 0));
        });
        var rowsBloqueadas = [];
        
        rowsSelecionadas.forEach(row => {
           if(!verificaPermissaoItem(widget, row)) {
               rowsBloqueadas.push(row);
           }
        });
        
        if(rowsEmAberto.length == rowsSelecionadas.length) {
            if(rowsBloqueadas.length >= 1) {
                var rowsToMessage = [];
                var stringItem = "";
                
                rowsBloqueadas.forEach(row => {
					var prod = "Pedido: " + row.NRPEDEXOL + ", Produto: " + row.NMPRODUTO + ", Marca: " + row.NMMARCA + ", Entrega: " + row.DTPROGENPEOL;
										
					rowsToMessage.push(prod);
			    });
			    
			    stringItem = rowsToMessage.join("<br><br>");
			    
			    MessageService.showMessageByCode("OPER_BLOCK_ITEM_GRUPOOPER", { ITEM: stringItem });
            } else {
                MessageService.confirmMessageByCode("RESERVA_QUESTION_INSERT").then(function(confirmed) {
                    General.callRestEngine("opl_relatorios#/inclusaoReservaItemPedido", "Row", rowsSelecionadas).then(function(response) {
                        ScreenService.closePopup();
                        
                        widget.reload();
                        
                        MessageService.showMessageByCode("RESEVA_NEW_SUCCESS");
                    }).catch(function(error) {
                        ScreenService.closePopup();
                        
                        widget.reload();
                        
                        if(error.data.error == "QTD_INDISPONIVEL_RESERVA") {
                            MessageService.showMessageByCode(error.data.error);
                        } else {
                            MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
                        }
                    });
                });
            }
        } else {
            MessageService.showMessageByCode("ONLY_EM_ABERTO_ITENS_PEDIDO_EDIT");
        }
    };
    
    this.excluirReserva = function(widget) {
        const rowsSelecionadas = widget.getCheckedRows();
        const rowsEmAberto = rowsSelecionadas.filter(function(row) {
            return ((row.IDBAIXENPEOL == null || row.IDBAIXENPEOL == 0) && (row.IDBAIXEXOL == null || row.IDBAIXEXOL == 0));
        });
        var rowsBloqueadas = [];
        
        rowsSelecionadas.forEach(row => {
           if(!verificaPermissaoItem(widget, row)) {
               rowsBloqueadas.push(row);
           }
        });
        
        if(rowsEmAberto.length == rowsSelecionadas.length) {
            if(rowsBloqueadas.length >= 1) {
                var rowsToMessage = [];
                var stringItem = "";
                
                rowsBloqueadas.forEach(row => {
					var prod = "Pedido: " + row.NRPEDEXOL + ", Produto: " + row.NMPRODUTO + ", Marca: " + row.NMMARCA + ", Entrega: " + row.DTPROGENPEOL;
										
					rowsToMessage.push(prod);
			    });
			    
			    stringItem = rowsToMessage.join("<br><br>");
			    
			    MessageService.showMessageByCode("OPER_BLOCK_ITEM_GRUPOOPER", { ITEM: stringItem });
            } else {
                MessageService.confirmMessageByCode("RESERVA_QUESTION_DELETE").then(function(confirmed) {
                    General.callRestEngine("opl_relatorios#/exclusaoReservaItemPedido", "Row", rowsSelecionadas).then(function(response) {
                        ScreenService.closePopup();
                        
                        widget.reload();
                        
                        MessageService.showMessageByCode("RESEVA_DELETE_SUCCESS");
                    }).catch(function(error) {
                        ScreenService.closePopup();
                        
                        widget.reload();
                        
                        MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
                    });
                });
            }
        } else {
            MessageService.showMessageByCode("ONLY_EM_ABERTO_ITENS_PEDIDO_EDIT");
        }
    };
    
    this.baixaManualItemPedido = function(widget) {
        const rowsSelecionadas = widget.getCheckedRows();
        const rowsEmAbertoParcial = rowsSelecionadas.filter(function(row) {
            return ((row.IDBAIXENPEOL == null || row.IDBAIXENPEOL == 0 || row.IDBAIXENPEOL == 1) && (row.IDBAIXEXOL == null || row.IDBAIXEXOL == 0 || row.IDBAIXEXOL == 1));
        });
        var rowsBloqueadas = [];
        
        rowsSelecionadas.forEach(row => {
           row.NEW_IDBAIXAOLSAI = '3';
           row.NEW_CDOPERBAIXA = getLocalVar("CDOPERADOR");
           row.NEW_DTBAIXTMPEOL = moment().format("DD/MM/YYYY");
           row.DTPROGENPEOL = moment(row.DTPROGENPEOL, "DD/MM/YYYY").format("DD/MM/YYYY");
           
           if(!verificaPermissaoItem(widget, row)) {
               rowsBloqueadas.push(row);
           }
        });
        
        if(rowsEmAbertoParcial.length == rowsSelecionadas.length) {
            if(rowsBloqueadas.length >= 1) {
                var rowsToMessage = [];
                var stringItem = "";
                
                rowsBloqueadas.forEach(row => {
					var prod = "Pedido: " + row.NRPEDEXOL + ", Produto: " + row.NMPRODUTO + ", Marca: " + row.NMMARCA + ", Entrega: " + row.DTPROGENPEOL;
										
					rowsToMessage.push(prod);
			    });
			    
			    stringItem = rowsToMessage.join("<br><br>");
			    
			    MessageService.showMessageByCode("OPER_BLOCK_ITEM_GRUPOOPER", { ITEM: stringItem });
            } else {
                MessageService.confirmMessageByCode("CONFIRMA_BAIXA_MANUAL").then(function(confirmed) {
                    General.callRestEngine("opl_relatorios#/baixaManualItemPedidoOL", "Row", rowsSelecionadas).then(function(response) {
                        ScreenService.closePopup();
                        
                        widget.reload();
                        
                        MessageService.showMessageByCode("BAIXA_MANUAL_SUCCESS");
                    }).catch(function(error) {
                        ScreenService.closePopup();
                        
                        widget.reload();
                        
                        MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
                    });
                });
            }
        } else {
            MessageService.showMessageByCode("ONLY_EMABERTO_PARCIAL_ITENS_PEDIDO_EDIT");
        }
    };
    
    this.desbloquearItemPedido = function(widget) {
        const rowsSelecionadas = widget.getCheckedRows();
        const rowsEmAberto = rowsSelecionadas.filter(function(row) {
            return ((row.IDBAIXENPEOL == null || row.IDBAIXENPEOL == 0) && (row.IDBAIXEXOL == null || row.IDBAIXEXOL == 0));
        });
        const rowsDesbloqueadas = rowsSelecionadas.filter(function(row) {
            return (row.IDITMPEDOLBLOQ === 'N');
        });
        const rowsBloqueadas = rowsSelecionadas.filter(function(row) {
            return (row.IDITMPEDOLBLOQ === 'S' && ((row.IDBAIXENPEOL == null || row.IDBAIXENPEOL == 0) && (row.IDBAIXEXOL == null || row.IDBAIXEXOL == 0)));
        });
        var rowBlockOper = [];
        
        rowsBloqueadas.forEach(row => {
           row.NEW_CDOPERADOR = getLocalVar("CDOPERADOR");
           row.NEW_IDITMPEDOLBLOQ = 'N';
           row.NEW_DTBLOQITMPEDOL = moment().format("DD/MM/YYYY");
           row.DTPROGENPEOL = moment(row.DTPROGENPEOL, "DD/MM/YYYY").format("DD/MM/YYYY");
           
           if(!verificaPermissaoItem(widget, row)) {
               rowBlockOper.push(row);
           }
        });
        
        if(rowsDesbloqueadas.length == rowsSelecionadas.length) {
            MessageService.showMessageByCode("ITEM_ALREADY_DESBLOQUEADO");
        } else {
            if(rowsEmAberto.length == rowsSelecionadas.length) {
                if(rowBlockOper.length >= 1) {
                    var rowsToMessage = [];
                    var stringItem = "";
                    
                    rowBlockOper.forEach(row => {
    					var prod = "Pedido: " + row.NRPEDEXOL + ", Produto: " + row.NMPRODUTO + ", Marca: " + row.NMMARCA + ", Entrega: " + row.DTPROGENPEOL;
    										
    					rowsToMessage.push(prod);
    			    });
    			    
    			    stringItem = rowsToMessage.join("<br><br>");
    			    
    			    MessageService.showMessageByCode("OPER_BLOCK_ITEM_GRUPOOPER", { ITEM: stringItem });
                } else {
                    MessageService.confirmMessageByCode("CONFIRMA_DESBLOQUEIO_ITEM").then(function(confirmed) {
                        General.callRestEngine("opl_relatorios#/desbloqueioBloqueioItemPedidoOL", "Row", rowsBloqueadas).then(function(response) {
                            widget.reload();
                            
                            MessageService.showMessageByCode("DESBLOQUEIO_SUCCESS");
                        }).catch(function(error) {
                            widget.reload();
                            
                            MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
                        });
                    });
                }
            } else {
                MessageService.showMessageByCode("ONLY_EM_ABERTO_ITENS_PEDIDO_EDIT");
            }
        }
    };
    
    this.bloquearItemPedido = function(widget) {
        const rowsSelecionadas = widget.getCheckedRows();
        const rowsEmAberto = rowsSelecionadas.filter(function(row) {
            return ((row.IDBAIXENPEOL == null || row.IDBAIXENPEOL == 0) && (row.IDBAIXEXOL == null || row.IDBAIXEXOL == 0));
        });
        const rowsDesbloqueadas = rowsSelecionadas.filter(function(row) {
            return (row.IDITMPEDOLBLOQ === 'N' && ((row.IDBAIXENPEOL == null || row.IDBAIXENPEOL == 0) && (row.IDBAIXEXOL == null || row.IDBAIXEXOL == 0)));
        });
        const rowsBloqueadas = rowsSelecionadas.filter(function(row) {
            return (row.IDITMPEDOLBLOQ === 'S');
        });
        var rowBlockOper = [];
        
        rowsDesbloqueadas.forEach(row => {
           row.NEW_CDOPERADOR = getLocalVar("CDOPERADOR");
           row.NEW_IDITMPEDOLBLOQ = 'S';
           row.NEW_DTBLOQITMPEDOL = moment().format("DD/MM/YYYY");
           row.DTPROGENPEOL = moment(row.DTPROGENPEOL, "DD/MM/YYYY").format("DD/MM/YYYY");
           
           if(!verificaPermissaoItem(widget, row)) {
               rowBlockOper.push(row);
           }
        });
        
        if(rowsBloqueadas.length == rowsSelecionadas.length) {
            MessageService.showMessageByCode("ITEM_ALREADY_BLOQUEADO");
        } else {
            if(rowsEmAberto.length == rowsSelecionadas.length) {
                if(rowBlockOper.length >= 1) {
                    var rowsToMessage = [];
                    var stringItem = "";
                    
                    rowBlockOper.forEach(row => {
                        var prod = "Pedido: " + row.NRPEDEXOL + ", Produto: " + row.NMPRODUTO + ", Marca: " + row.NMMARCA + ", Entrega: " + row.DTPROGENPEOL;
                        
                        rowsToMessage.push(prod);
    			    });
    			    
    			    stringItem = rowsToMessage.join("<br><br>");
    			    
    			    MessageService.showMessageByCode("OPER_BLOCK_ITEM_GRUPOOPER", { ITEM: stringItem });
                } else {
                    MessageService.confirmMessageByCode("CONFIRMA_BLOQUEIO_ITEM").then(function(confirmed) {
                        General.callRestEngine("opl_relatorios#/desbloqueioBloqueioItemPedidoOL", "Row", rowsDesbloqueadas).then(function(response) {
                            widget.reload();
                            
                            MessageService.showMessageByCode("BLOQUEIO_SUCCESS");
                        }).catch(function(error) {
                            widget.reload();
                            
                            MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
                        });
                    });
                }
            } else {
                MessageService.showMessageByCode("ONLY_EM_ABERTO_ITENS_PEDIDO_EDIT");
            }
        }
    };
    
    this.entregaDiretaItemPedido = function(widget) {
        const popUpWidget = templateManager.container.getWidget("entregaDiretaItemPedidoWidget");
        const rowsSelecionadas = widget.getCheckedRows();
        const rowsEmAberto = rowsSelecionadas.filter(function(row) {
            return ((row.IDBAIXENPEOL == null || row.IDBAIXENPEOL == 0) && (row.IDBAIXEXOL == null || row.IDBAIXEXOL == 0));
        });
        var rowsBloqueadas = [];
        
        rowsSelecionadas.forEach(row => {
           if(!verificaPermissaoItem(widget, row)) {
               rowsBloqueadas.push(row);
           }
        });
        
        popUpWidget.currentRow = {};
        
        if(rowsEmAberto.length == rowsSelecionadas.length) {
            if(rowsBloqueadas.length >= 1) {
                var rowsToMessage = [];
                var stringItem = "";
                
                rowsBloqueadas.forEach(row => {
					var prod = "Pedido: " + row.NRPEDEXOL + ", Produto: " + row.NMPRODUTO + ", Marca: " + row.NMMARCA + ", Entrega: " + row.DTPROGENPEOL;
										
					rowsToMessage.push(prod);
                });
                
                stringItem = rowsToMessage.join("<br><br>");
                
                MessageService.showMessageByCode("OPER_BLOCK_ITEM_GRUPOOPER", { ITEM: stringItem });
            } else {
                ScreenService.openPopup(popUpWidget);
            }
        } else {
            MessageService.showMessageByCode("ONLY_EM_ABERTO_ITENS_PEDIDO_EDIT");
        }
    };
    
    this.validaFieldOperador = function(widget) {
        widget.getField("SENHA").clearValue();
        widget.currentRow.SENHA = "";
        
        if(widget.currentRow.CDOPERADOR == getLocalVar("CDOPERADOR")) {
            delete  widget.getField("SENHA").validations;
            widget.getField("SENHA").readOnly = true;
        } else {
            widget.getField("SENHA").validations = {
                "required": true
            };
            widget.getField("SENHA").readOnly = false;
        }
        widget.activate();
    };
    
    this.validacoesLoginED = function(widget) {
        const widgetItensPedido = widget.getParent();
        const rowsSelecionadas = widgetItensPedido.getCheckedRows();
        
        rowsSelecionadas.forEach(row => {
            row.DTPROGENPEOL = moment(row.DTPROGENPEOL, "DD/MM/YYYY").format("DD/MM/YYYY");
            row.CDOPERADOR = widget.currentRow.CDOPERADOR;
        });
        
        if(widget.isValid()) {
            if(widget.currentRow.CDOPERADOR == getLocalVar("CDOPERADOR")) {
                General.callRestEngine("opl_relatorios#/processoEntregaDiretaItemPedidoOL", "Row", rowsSelecionadas).then(function(response) {
                    ScreenService.closePopup();
                    ScreenService.closePopup();
                        
                    widgetItensPedido.reload();
                        
                    MessageService.showMessageByCode("ENTREGA_DIRETA_ITEM_SUCCESS");
                }).catch(function(error) {
                    MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
                });
            } else {
                General.callRestEngine("opl_relatorios#/validacaoSenhaED", "Row", widget.currentRow).then(function(response) {
                    General.callRestEngine("opl_relatorios#/processoEntregaDiretaItemPedidoOL", "Row", rowsSelecionadas).then(function(response) {
                        ScreenService.closePopup();
                        ScreenService.closePopup();
                            
                        widgetItensPedido.reload();
                            
                        MessageService.showMessageByCode("ENTREGA_DIRETA_ITEM_SUCCESS");
                    }).catch(function(error) {
                        MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
                    }); 
                }).catch(function(error) {
                    if(error.data.error == "INVALID_PASSWORD") {
                        MessageService.showMessageByCode(error.data.error);
                    } else {
                        MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
                    }
                });
            }
        } else {
            MessageService.showMessageByCode("OBRIGATORY_FIELDS");
        }
    };
    
    this.destinatarioNF = function(widget) {
        if(widget.currentRow.IDTIPOEMITAF == '1') {
            widget.getField("NMEMPRESA").validations = { required: true };
            
            ServiceEmissaoPedidoOL.empresasPorUnidade(widget.currentRow).then(function(callback) {
                widget.currentRow.CDEMPRESA = callback.dataset.sup07200_empresas_por_unidade[0].CDEMPRESA;
				widget.currentRow.NMEMPRESA = callback.dataset.sup07200_empresas_por_unidade[0].NMEMPRESA;
				
				widget.getField("NMEMPRESA").readOnly = true;
            }).catch(function(error) {
                MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
            });
        } else if(widget.currentRow.IDTIPOEMITAF == '2') {
            widget.getField("NMEMPRESA").validations = { required: true };
			widget.getField("NMEMPRESA").dataSourceFilter[0].value = widget.currentRow.CDFILDEST;
			widget.getField("NMEMPRESA").readOnly = false;
			widget.getField("NMEMPRESA").reload();
			
			widget.currentRow.NMEMPRESA = '';
			widget.currentRow.CDEMPRESA = '';
        } else if(widget.currentRow.IDTIPOEMITAF == '3') {
            ServiceEmissaoPedidoOL.empresaClientePrincipal(widget.currentRow).then(function(callback) {
                if (callback.dataset.sup07200_empresa_cliente_principal.length) {
                    widget.currentRow.NMEMPRESA = callback.dataset.sup07200_empresa_cliente_principal[0].NMEMPRESA;
    			    widget.currentRow.CDEMPRESA = callback.dataset.sup07200_empresa_cliente_principal[0].CDEMPRESA;
                } else {
                    widget.currentRow.NMEMPRESA = '';
    			    widget.currentRow.CDEMPRESA = '';    
                }
                
                if (callback.dataset.sup07200_empresa_cliente_principal.length === 0) {
                    MessageService.showMessageByCode("SEM_CLIENTE_PRINCIPAL_FILIAL");
                    widget.currentRow.IDTIPOEMITAF = '2';
                    widget.currentRow.NMTIPOEMITAF = "Empresa Informada";
                    
                    widget.getField("NMEMPRESA").readOnly = false;
                    widget.getField("NMEMPRESA").validations = { required: true };
                    return false;
                } else {
                    widget.getField("NMEMPRESA").readOnly = true;
                    widget.getField("NMEMPRESA").validations = {};
                }
            }).catch(function(error) {
                MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
            });
        } else {
            widget.getField("NMEMPRESA").readOnly = true;
            widget.getField("NMEMPRESA").validations = {};
            
            widget.currentRow.NMEMPRESA = '';
			widget.currentRow.CDEMPRESA = '';
        }
    };
    
    this.editaDadosPedido = function(widget) {
        const oldRow = angular.copy(widget.currentRow);
        const itensPedidosWidget = templateManager.container.getWidget("itensPedidosWidget");
        const detalhesPedido = templateManager.container.getWidget("detalhesPedido");
        
        widget.oldRow = oldRow;
        widget.template = "widget/form.html";
        widget.edit();
        
        itensPedidosWidget.enabled = false;
        detalhesPedido.enabled = false;
    };
    
    this.cancelaEditaDadosPedido = function(args) {
        const activeWidget = templateManager.container.getActiveWidget();
        const itensPedidosWidget = templateManager.container.getWidget("itensPedidosWidget");
        const detalhesPedido = templateManager.container.getWidget("detalhesPedido");
        
        activeWidget.template = "widget/form-view.html";
        activeWidget.reload();
        
        General.backOrCancel(args);
        
        activeWidget.list();
        activeWidget.reload();
        
        activeWidget.currentRow = activeWidget.oldRow;
        
        itensPedidosWidget.enabled = true;
        detalhesPedido.enabled = true;
    };
    
    this.salvaDadosPedido = function(widget) {
        const row = angular.copy(widget.currentRow);
        const itensPedidosWidget = templateManager.container.getWidget("itensPedidosWidget");
        const detalhesPedido = templateManager.container.getWidget("detalhesPedido");
        
        delete row.__rightActions;
        delete row.__leftActions;
        
        row.__isNew = false;
        
        row.DTPEDEXOL = moment(row.DTPEDEXOL, "DD/MM/YYYY").format("DD/MM/YYYY");
        
        if(widget.isValid()) {
            General.callRestEngine("opl_relatorios#/salvaDadosPedido", "Row", row).then(function(response) {
                widget.template = "widget/form-view.html";
                widget.list();
                widget.reload();
                
                itensPedidosWidget.enabled = true;
                detalhesPedido.enabled = true;
                
                MessageService.showMessageByCode("PEDIDO_EDIT_SUCCESS");
            }).catch(function(error) {
                MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
            });
        }
    };
    
    this.adicionaNovoPedido = function(widget) {
        const widgetAdicionaNovoPedido = templateManager.container.getWidget("adicionaNovoPedido");
        const widgetTabbedNovoPedido = templateManager.container.getWidget("tabbedNovoPedidoWidget");
        const prodsNovoPedidoWidget = templateManager.container.getWidget("prodsNovoPedidoWidget");
        const itensPedidosWidget = templateManager.container.getWidget("itensPedidosWidget");
        const detalhesPedidoWidget = templateManager.container.getWidget("detalhesPedido");
        
        widgetAdicionaNovoPedido.currentRow = widget.name === "dadosPedido" ? angular.copy(widget.currentRow) : {};
        
        if(Util.isEmptyOrBlank(widgetAdicionaNovoPedido.currentRow.CDFILDEST)) {
            widgetAdicionaNovoPedido.currentRow.CDFILDEST = getLocalVar("CDFILIAL");
            widgetAdicionaNovoPedido.currentRow.NMFILDEST = getLocalVar("NMFILIAL");
        }
        
        if(Util.isEmptyOrBlank(widgetAdicionaNovoPedido.currentRow.IDTIPOEMITAF)) {
            if(!Util.isEmptyOrBlank(parametrosParCmpsup.IDTIPEMITGER)) {
                if(parametrosParCmpsup.IDTIPEMITGER == '1') {
                    widgetAdicionaNovoPedido.currentRow.IDTIPOEMITAF = '1';
                    widgetAdicionaNovoPedido.currentRow.NMTIPOEMITAF = "Empresa da Unidade";
                } else if(parametrosParCmpsup.IDTIPEMITGER == '2') {
                    widgetAdicionaNovoPedido.currentRow.IDTIPOEMITAF = '2';
                    widgetAdicionaNovoPedido.currentRow.NMTIPOEMITAF = "Empresa Informada";
                } else {
                    widgetAdicionaNovoPedido.currentRow.IDTIPOEMITAF = '3';
                    widgetAdicionaNovoPedido.currentRow.NMTIPOEMITAF = "Cliente Principal";
                }
            }
        }
        
        self.destinatarioNF(widgetAdicionaNovoPedido);
        
        prodsNovoPedidoWidget.enabled = false;
        
        prodsNovoPedidoWidget.dataSource.data = [];
        
        delete widgetAdicionaNovoPedido.currentRow.NRPEDEXOL;
        
        widgetAdicionaNovoPedido.currentRow.DTPEDEXOL = moment().format("L");
        widgetAdicionaNovoPedido.currentRow.CDFILLANC = getLocalVar("CDFILIAL");
        widgetAdicionaNovoPedido.currentRow.NMFILLANC = getLocalVar("NMFILIAL");
        widgetAdicionaNovoPedido.currentRow.IDPEDEXOLEXTR = 'N';
        
        if(parametrosParaSupri.IDUTILCONSSOLIOLEXT === 'S') {
            widgetAdicionaNovoPedido.getField("IDPEDEXOLEXTR").readOnly = false;
            widgetAdicionaNovoPedido.getField("NMLOTENVITOL").readOnly = false;
        } else {
            widgetAdicionaNovoPedido.getField("IDPEDEXOLEXTR").readOnly = true;
            widgetAdicionaNovoPedido.getField("NMLOTENVITOL").readOnly = true;
        }
        
        itensPedidosWidget.enabled = false;
        
        detalhesPedidoWidget.enabled = false;
        
        self.destinatarioNF(widgetAdicionaNovoPedido);
        
        ScreenService.openSwipe(widgetTabbedNovoPedido);
    };
    
    this.baixaManualPedido = function(widget) {
        const itensPedidosWidget = templateManager.container.getWidget("itensPedidosWidget");
        
        widget.currentRow.NEW_IDBAIXEXOL = 3;
        widget.currentRow.NEW_DTBAIXTMPEOL = moment().format('L');
        
        MessageService.confirmMessageByCode("BAIXA_MANUAL_PEDIDO_ASK").then(function(confirmed) {
            General.callRestEngine("opl_relatorios#/baixaManualPedido", "Row", widget.currentRow).then(function(response) {
                delete widget.currentRow.NEW_IDBAIXEXOL;
                widget.currentRow.IDBAIXEXOL = 3;
                
                itensPedidosWidget.reload();
                
                widget.getAction("editaDadosPedido").isVisible = false;
                widget.getAction("baixaManualPedido").isVisible = false;
                widget.getAction("cancelarPedido").isVisible = false;
                widget.getAction("encerrarPedido").isVisible = false;
                widget.getAction("exportarPedido").isVisible = false;
                widget.getAction("excluiPedido").isVisible = false;
                widget.getAction("emAbertoPedido").isVisible = true;
                
                ScreenService.closePopup();
                
                MessageService.showMessageByCode("BAIXA_MANUAL_SUCCESS");
            }).catch(function(error) {
                MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
            });
        });
    };
    
    this.cancelarEncerrarPedido = function(widget, op) {
        const itensPedidosWidget = templateManager.container.getWidget("itensPedidosWidget");
        var message1, message2;
        
        widget.currentRow.NEW_IDBAIXEXOL = op;
        
        if(op == 5) {
            message1 = "CANCELA_PEDIDO_ASK";
            message2 = "CANCELA_PEDIDO_SUCCESS";
        } else {
            message1 = "ENCERRA_PEDIDO_ASK";
            message2 = "ENCERRA_PEDIDO_SUCCESS";
        }
        
        MessageService.confirmMessageByCode(message1).then(function(confirmed) {
            General.callRestEngine("opl_relatorios#/cancelaEncerraPedido", "Row", widget.currentRow).then(function(response) {
                delete widget.currentRow.NEW_IDBAIXEXOL;
                widget.currentRow.IDBAIXEXOL = op;
                
                itensPedidosWidget.reload();
                
                widget.getAction("editaDadosPedido").isVisible = false;
                widget.getAction("baixaManualPedido").isVisible = false;
                widget.getAction("cancelarPedido").isVisible = false;
                widget.getAction("encerrarPedido").isVisible = false;
                widget.getAction("exportarPedido").isVisible = false;
                widget.getAction("excluiPedido").isVisible = false;
                widget.getAction("emAbertoPedido").isVisible = true;
                
                ScreenService.closePopup();
                
                MessageService.showMessageByCode(message2);
            }).catch(function(error) {
                MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
            });
        });
    };
    
    this.emAbertoPedido = function(widget) {
        const itensPedidosWidget = templateManager.container.getWidget("itensPedidosWidget");
        
        widget.currentRow.NEW_IDBAIXEXOL = 0;
        
        MessageService.confirmMessageByCode("EMABERTO_PEDIDO_ASK").then(function(confirmed) {
            General.callRestEngine("opl_relatorios#/emAbertoPedido", "Row", widget.currentRow).then(function(response) {
                delete widget.currentRow.NEW_IDBAIXEXOL;
                widget.currentRow.IDBAIXEXOL = null;
                
                itensPedidosWidget.reload();
                
                widget.getAction("editaDadosPedido").isVisible = true;
                widget.getAction("baixaManualPedido").isVisible = true;
                widget.getAction("cancelarPedido").isVisible = true;
                widget.getAction("encerrarPedido").isVisible = true;
                widget.getAction("excluiPedido").isVisible = true;
                widget.getAction("emAbertoPedido").isVisible = false;
                
                if(parametrosParaSupri && parametrosParaSupri.IDENVIOITMPEDOL == 'S') {
                    widget.getAction("exportarPedido").isVisible = true;
                } else {
                    widget.getAction("exportarPedido").isVisible = false;
                }
                
                ScreenService.closePopup();
                
                MessageService.showMessageByCode("EMABERTO_SUCCESS");
            }).catch(function(error) {
                MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
            });
        });
    };
    
    this.excluiPedido = function(widget) {
        const itensPedidosWidget = templateManager.container.getWidget("itensPedidosWidget");
        const stripeWidget = templateManager.container.getWidget("stripeWidget");
        const detalhesPedidoWidget = templateManager.container.getWidget("detalhesPedido");
        
        MessageService.confirmMessageByCode("EXCLUIR_PEDIDO_ASK").then(function(confirmed) {
            General.callRestEngine("opl_relatorios#/exclusaoPedido", "Row", widget.currentRow).then(function(response) {
                widget.currentRow = {};
                widget.enabled = false;
                
                itensPedidosWidget.currentRow = {};
                itensPedidosWidget.activate();
                itensPedidosWidget.reload();
                
                stripeWidget.currentRow = {};
                
                detalhesPedidoWidget.enabled = false;
                
                MessageService.showMessageByCode("EXCLUSAO_REALIZADA");
            }).catch(function(error) {
                MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
            });
        });
    };
    
    this.cancelarNovoPedido = function(widget) {
        const widgetDadosPedido = templateManager.container.getWidget("dadosPedido");
        const itensPedidosWidget = templateManager.container.getWidget("itensPedidosWidget");
        const detalhesPedidoWidget = templateManager.container.getWidget("detalhesPedido");
        
        MessageService.confirmMessageByCode("CANCEL_NOVO_PEDIDO").then(function(confirmed) {
            itensPedidosWidget.enabled = true;
        
            detalhesPedidoWidget.enabled = true;
            
            ScreenService.closeSwipe();
            ScreenService.closeSwipe();
            
            widgetDadosPedido.activate();
        });
    };
    
    this.abrirAbaProdutos = function(widget) {
        const prodsNovoPedidoWidget = templateManager.container.getWidget("prodsNovoPedidoWidget");
        
        prodsNovoPedidoWidget.enabled = true;
        
        widget.enabled = false;
        
        prodsNovoPedidoWidget.activate();
    };
    
    this.adicionaNovoProdutoPedido = function(widget) {
        const inclusaoProdutoNovoPedidoWidget = templateManager.container.getWidget("inclusaoProdutoNovoPedidoWidget");
        const adicionaNovoPedidoWidget = templateManager.container.getWidget("adicionaNovoPedido");
        var fieldProduto = inclusaoProdutoNovoPedidoWidget.getField('NMPRODUTO');
        
        fieldProduto.dataSourceFilter.forEach(function(filtro) {
            if(filtro.name == "P_PRODCMP")
                filtro.value = parametrosParaSupri.IDUTLPROCMP;
            if(filtro.name == "P_CDFILSOLI")
                filtro.value = "FILIAL_LOGADA";
            if(filtro.name == "CDFILIAL")
                filtro.value = adicionaNovoPedidoWidget.currentRow.CDFILDEST || null;
        });
        
        inclusaoProdutoNovoPedidoWidget.currentRow.DTPROGENPEOL = moment().format('L');
        
        ScreenService.openPopup(inclusaoProdutoNovoPedidoWidget);
    };
    
    this.salvaInclusaoProdutoNvoPedido = function(widget) {
        const dataProc = moment(getLocalVar("DTPROCESSA"), "DD/MM/YYYY").format("MM-DD-YYYY");
        const dataEscd = moment(widget.currentRow.DTPROGENPEOL, "DD/MM/YYYY").format("MM-DD-YYYY");
        const prodsNovoPedidoWidget = widget.getParent();
        const adicionaNovoPedidoWidget = templateManager.container.getWidget("adicionaNovoPedido");
        
        widget.currentRow.CDFILDEST = adicionaNovoPedidoWidget.currentRow.CDFILDEST;
        
        widget.currentRow.FINAL = permissoesFinaisOperador;
        widget.currentRow.GERAL = permissoesGeraisOperador;
        
        if(widget.isValid()) {
            if(moment(dataEscd).isSameOrAfter(dataProc)) {
                if(prodsNovoPedidoWidget.dataSource.data.length == 0) {
                    General.callRestEngine("opl_relatorios#/adqProcedureCarregaPerifili", "Row", widget.currentRow).then(function(response) {
                        var message = response.messages[0].message != undefined ? response.messages[0].message : null;
                        
                        if(message == "successful") {
                            prodsNovoPedidoWidget.dataSource.data.push(angular.copy(widget.currentRow));
                    
                            widget.currentRow = {};
                            
                            ScreenService.closePopup();
                            
                            MessageService.showMessageByCode("PRODUCT_INSERT_LIST_SUCCESS");
                        }
                    }).catch(function(error) {
                        MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
                    });
                    
                } else {
                    var podeInserir = true;
                    
                    prodsNovoPedidoWidget.dataSource.data.forEach(row => {
                        if(row.DTPROGENPEOL == widget.currentRow.DTPROGENPEOL && row.CDMARCA == widget.currentRow.CDMARCA && row.CDPRODESTO == widget.currentRow.CDPRODESTO) {
                            podeInserir = false;
                        }
                    });
                    
                    if(podeInserir) {
                        General.callRestEngine("opl_relatorios#/adqProcedureCarregaPerifili", "Row", widget.currentRow).then(function(response) {
                            var message = response.messages[0].message != undefined ? response.messages[0].message : null;
                        
                            if(message == "successful") {
                                prodsNovoPedidoWidget.dataSource.data.push(angular.copy(widget.currentRow));
                        
                                widget.currentRow = {};
                                
                                ScreenService.closePopup();
                                
                                MessageService.showMessageByCode("PRODUCT_INSERT_LIST_SUCCESS");
                            }
                        }).catch(function(error) {
                            MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
                        });
                    } else {
                        MessageService.showMessageByCode("ITEM_ALREADY_EXISTS_PEDIDO");
                    }
                }
            } else {
                MessageService.showMessageByCode("DATA_MAIOR_IGUAL_PROCESSAMENTO");
            }
        }
    };
    
    this.excluiNovoProdutoPedido = function(widget) {
        const checkedRows = widget.getCheckedRows();
        const allRows = widget.dataSource.data;
        const returnRows = allRows.filter(function(rowA) {
            return !checkedRows.find(function(rowB) {
                return rowA.DTPROGENPEOL == rowB.DTPROGENPEOL && rowA.CDMARCA == rowB.CDMARCA && rowA.CDPRODESTO == rowB.CDPRODESTO;
            });
        });
        
        MessageService.confirmMessageByCode("CONFIRM_PRODUCT_DELETE_LIST").then(function(confirmed) {
            widget.dataSource.data = returnRows;
        });
    };
    
    this.finalizaNovoPedido = function(widget) {
        const adicionaNovoPedidoWidget = templateManager.container.getWidget("adicionaNovoPedido");
        const widgetDadosPedido = templateManager.container.getWidget("dadosPedido");
        const itensPedidosWidget = templateManager.container.getWidget("itensPedidosWidget");
        const widgetStripe = templateManager.container.getWidget("stripeWidget");
        const widgetDetalhesPedido = templateManager.container.getWidget("detalhesPedido");
        
        const rowFinal = {
            "DADOS": angular.copy(adicionaNovoPedidoWidget.currentRow),
            "PRODUTOS": angular.copy(widget.dataSource.data),
            "PARAMETROS": {
                "GERAL": permissoesGeraisOperador,
                "FINAL": permissoesFinaisOperador
            }
        };
        
        if(widget.dataSource.data.length > 0) {
            if(adicionaNovoPedidoWidget.isValid()) {
                MessageService.confirmMessageByCode("CONFIRMA_NOVO_PEDIDO").then(function(confirmed) {
                    General.callRestEngine("opl_relatorios#/inclusaoPedido", "Row", rowFinal).then(function(response) {
                        widgetDadosPedido.currentRow = adicionaNovoPedidoWidget.currentRow;
                        widgetDadosPedido.getAction("editaDadosPedido").isVisible = true;
                        widgetDadosPedido.getAction("baixaManualPedido").isVisible = true;
                        widgetDadosPedido.getAction("cancelarPedido").isVisible = true;
                        widgetDadosPedido.getAction("encerrarPedido").isVisible = true;
                        widgetDadosPedido.getAction("excluiPedido").isVisible = true;
                        widgetDadosPedido.getAction("emAbertoPedido").isVisible = false;
                        
                        if(parametrosParaSupri && parametrosParaSupri.IDENVIOITMPEDOL == 'S') {
                            widgetDadosPedido.getAction("exportarPedido").isVisible = true;
                        } else {
                            widgetDadosPedido.getAction("exportarPedido").isVisible = false;
                        }
                        
                        adicionaNovoPedidoWidget.currentRow = {};
                        
                        itensPedidosWidget.currentRow = {};
                        itensPedidosWidget.reload();
                        itensPedidosWidget.enabled = true;
                        
                        widgetStripe.currentRow = {};
                        
                        widget.dataSource.data = [];
                        
                        widgetDetalhesPedido.enabled = true;
                        
                        ScreenService.closeSwipe();
                        ScreenService.closeSwipe();
                        
                        MessageService.showMessageByCode("NEW_PEDIDO_SUCCESS");
                    }).catch(function(error) {
                        MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
                    });
                }).catch(function(declined) {
                    adicionaNovoPedidoWidget.activate();
                });
            } else {
                adicionaNovoPedidoWidget.activate();
                
                MessageService.showMessageByCode("OBRIGATORY_FIELDS");
            }
        } else {
            MessageService.showMessageByCode("ONE_PRODUCT_NEC_INSERT");
        }
    };
    
    this.exportarPedido = function(widget) {
        const widgetFatPrec = templateManager.container.getWidget("exportarPedidoOLWidget");
        
        widget.currentRow.IDENVIOITMPEDOL = parametrosParaSupri.IDENVIOITMPEDOL;
        
        MessageService.confirmMessageByCode("CONFIRM_EXPORT_PEDIDO").then(function(confirmed) {
            if(parametrosParaSupri && parametrosParaSupri.IDENVIOITMPEDOL == 'S') {
                ScreenService.openPopup(widgetFatPrec);
            } else {
                General.callRestEngine("opl_relatorios#/exportarPedidoOL", "Row", widget.currentRow).then(function(response) {
                    ScreenService.closePopup();
                    
                    MessageService.showMessageByCode("PEDIDO_EXPORTADO_SUCESSO");
                }).catch(function(error) {
                    MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
                });
            }
        });
    };
    
    this.salvaExportaPedido = function(widget) {
        const widgetPedido = widget.getParent();
        
        var currentRow = angular.copy(widgetPedido.currentRow);
        
        currentRow.CDFATPRECO = widget.currentRow.CDFATPRECO;
        
        if(widget.isValid()) {
            General.callRestEngine("opl_relatorios#/exportarPedidoOL", "Row", currentRow).then(function(response) {
                ScreenService.closePopup();
                    
                MessageService.showMessageByCode("PEDIDO_EXPORTADO_SUCESSO");
            }).catch(function(error) {
                MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
            });
        }
    };
    
    this.importacaoSolicitacaoOL = function(widget) {
        const importacaoSolicitacaoComprasOLWidget = templateManager.container.getWidget("importacaoSolicitacaoComprasOLWidget");
        
        importacaoSolicitacaoComprasOLWidget.currentRow = {};
        
        if(parametrosParaSupri.IDUTILCONSSOLIOLEXT === 'S') {
            importacaoSolicitacaoComprasOLWidget.getField("NMFATPRECO").isVisible = true;
            importacaoSolicitacaoComprasOLWidget.getField("EXTRA").isVisible = true;
            importacaoSolicitacaoComprasOLWidget.getField("NMLOTENVITOL").isVisible = true;
            importacaoSolicitacaoComprasOLWidget.getField("EXTRA").readOnly = false;
            importacaoSolicitacaoComprasOLWidget.getField("NMLOTENVITOL").readOnly = false;
        } else {
            importacaoSolicitacaoComprasOLWidget.getField("NMFATPRECO").isVisible = false;
            importacaoSolicitacaoComprasOLWidget.getField("EXTRA").isVisible = false;
            importacaoSolicitacaoComprasOLWidget.getField("NMLOTENVITOL").isVisible = false;
            importacaoSolicitacaoComprasOLWidget.getField("EXTRA").readOnly = true;
            importacaoSolicitacaoComprasOLWidget.getField("NMLOTENVITOL").readOnly = true;
        }
        
        if(parametrosParaSupri.IDENVIOITMPEDOL == 'S') {
            importacaoSolicitacaoComprasOLWidget.getField("NMFATPRECO").isVisible = true;
        } else {
            importacaoSolicitacaoComprasOLWidget.getField("NMFATPRECO").isVisible = false;
        }
        
        ScreenService.openPopup(importacaoSolicitacaoComprasOLWidget);
    };
    
    this.readOnlyImportSolFields = function(widget) {
        const fieldNaoConsid = widget.getField("NCONSIDERASUBGRUPO");
        const fieldSubgrupo = widget.getField("CDSUBGRPROD");
        const fieldProdIni = widget.getField("NMPRODINI");
        const fieldProdFin = widget.getField("NMPRODFIN");
        
        fieldNaoConsid.readOnly = widget.currentRow.TODOSPRODUTOS == 'S' ? true : false;
        
        fieldSubgrupo.readOnly = widget.currentRow.TODOSPRODUTOS == 'S' ? true : widget.currentRow.NCONSIDERASUBGRUPO == 'S' ? true : false;
        
        fieldProdIni.readOnly = widget.currentRow.TODOSPRODUTOS == 'S' ? true : false;
        
        fieldProdFin.readOnly = widget.currentRow.TODOSPRODUTOS == 'S' ? true : false;
        
        if(widget.currentRow.TODOSPRODUTOS == 'S') {
            widget.currentRow.CDSUBGRPROD = null;
            widget.currentRow.NCONSIDERASUBGRUPO = 'S';
            widget.currentRow.NMPRODINI = null;
            widget.currentRow.CDPRODINI = null;
            widget.currentRow.NMPRODFIN = null;
            widget.currentRow.CDPRODFIN = null;
            
            delete fieldProdIni.validations;
            delete fieldProdFin.validations;
        } else {
            fieldProdIni.validations = {
                "required": true
            };
            fieldProdFin.validations = {
                "required": true
            };
        }
        
        widget.activate();
    };
    
    this.confirmaImportSolOL = function(widget) {
        const itensPedidosWidget = templateManager.container.getWidget("itensPedidosWidget");
        const widgetDetalhesPedido = templateManager.container.getWidget("detalhesPedido");
        
        widget.currentRow.CDFILLANC = getLocalVar("CDFILIAL");
        widget.currentRow.CDPRODINI = widget.currentRow.CDPRODINI ? widget.currentRow.CDPRODINI : null;
        widget.currentRow.CDPRODFIN = widget.currentRow.CDPRODFIN ? (widget.currentRow.CDPRODFIN + "ZZZZZZZZZZZZZZZZZZZZ").substr(0, 20) : null;
        widget.currentRow.CDREGIAOBKP = (!widget.currentRow.CDREGIAO || widget.currentRow.CDREGIAO.length == 0) ? null : '_' + widget.currentRow.CDREGIAO.join('_') + '_';
        widget.currentRow.CDSUBGRPRODBKP = (!widget.currentRow.CDSUBGRPROD || widget.currentRow.CDSUBGRPROD.length == 0) ? null : '_' + widget.currentRow.CDSUBGRPROD.join('_') + '_';
        widget.currentRow.CDGRUPPRODBKP = (!widget.currentRow.CDGRUPPROD || widget.currentRow.CDGRUPPROD.length == 0) ? null : widget.currentRow.CDGRUPPROD[0];
        widget.currentRow.CDGRUPFILIBKP = (!widget.currentRow.CDGRUPFILI || widget.currentRow.CDGRUPFILI.length == 0) ? null : '_' + widget.currentRow.CDGRUPFILI.join('_') + '_';
        
        if(widget.isValid()) {
            MessageService.confirmMessageByCode("CONFIRM_IMPORT_SOL_OL").then(function(confirmed) {
                General.callRestEngine("opl_relatorios#/adqValidacoes", "Row", widget.currentRow).then(function(response) {
                    const produtos = response.dataset.adqValidacoes;
                    const inconsistWidget = templateManager.container.getWidget("inconsistenciaProdutosImportWidget");
                    
                    if(!Util.isEmptyOrBlank(produtos) && produtos.length >= 1) {
                        MessageService.confirmMessageByCode("INCONS_PROCESSO_IMPORTACAO").then(function(confirmed) {
                            inconsistWidget.dataSource.data = produtos;
                            
                            ScreenService.openPopup(inconsistWidget);
                            
                            inconsistWidget.reload();
                            inconsistWidget.activate();
                        }).catch(function(declined) {
                            General.callRestEngine("opl_relatorios#/importacaoSolicitacaoOL", "Row", widget.currentRow).then(function(response) {
                                ScreenService.closePopup();
                                
                                itensPedidosWidget.reload();
                                
                                widgetDetalhesPedido.reload();
                                
                                MessageService.showMessageByCode("IMPORT_SUCCESS");
                            }).catch(function(error) {
                                if(error.data.error == "ERROR_APUR" || error.data.error == "APUR_NOT_RESULTS") {
                                    MessageService.showMessageByCode(error.data.error);
                                } else {
                                    MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
                                }
                            });
                        });
                    } else {
                       General.callRestEngine("opl_relatorios#/importacaoSolicitacaoOL", "Row", widget.currentRow).then(function(response) {
                            ScreenService.closePopup();
                            
                            itensPedidosWidget.reload();
                            
                            widgetDetalhesPedido.reload();
                            
                            MessageService.showMessageByCode("IMPORT_SUCCESS");
                        }).catch(function(error) {
                            if(error.data.error == "ERROR_APUR" || error.data.error == "APUR_NOT_RESULTS") {
                                MessageService.showMessageByCode(error.data.error);
                            } else {
                                MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
                            }
                        });
                    }
                }).catch(function(error) {
                    MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
                });
            });
        } else {
            MessageService.showMessageByCode("OBRIGATORY_FIELDS");
        }
    };
    
    this.finalizaImportSolIncons = function(widgetIncons) {
        const itensPedidosWidget = templateManager.container.getWidget("itensPedidosWidget");
        const widgetDetalhesPedido = templateManager.container.getWidget("detalhesPedido");
        const widget = widgetIncons.getParent();
        
        General.callRestEngine("opl_relatorios#/importacaoSolicitacaoOL", "Row", widget.currentRow).then(function(response) {
            ScreenService.closePopup();
            ScreenService.closePopup();
                                
            itensPedidosWidget.reload();
                                
            widgetDetalhesPedido.reload();
                                
            MessageService.showMessageByCode("IMPORT_SUCCESS");
        }).catch(function(error) {
            if(error.data.error == "ERROR_APUR" || error.data.error == "APUR_NOT_RESULTS") {
                MessageService.showMessageByCode(error.data.error);
            } else {
                MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
            }
        });
    };
    
    this.emissaoPedidosOL = function(widget) {
        const emissaoPedidosOLWidget = templateManager.container.getWidget("emissaoPedidosOLWidget");
        const widgetItensPedido = templateManager.container.getWidget("itensPedidosWidget");

        emissaoPedidosOLWidget.currentRow = {};
        emissaoPedidosOLWidget.currentRow.TCDLOTENVITOL = 'N';
        emissaoPedidosOLWidget.currentRow.IDBAIXAAFSAI = [ '0', '1', '2', '3' ];
        emissaoPedidosOLWidget.currentRow.IDBAIXAAFENT = [ '0', '1', '2', '3', '4', '5' ];
        emissaoPedidosOLWidget.currentRow.PEDOLEXTR = [ 'S', 'N' ];
        emissaoPedidosOLWidget.currentRow.CDFILIOPELOG = widgetItensPedido.appliedFilter.FILTER_ROW.NMFILIALOL;
        emissaoPedidosOLWidget.currentRow.CDFILDEST = widgetItensPedido.appliedFilter.FILTER_ROW.NMFILIAL;
        emissaoPedidosOLWidget.currentRow.NCONSIDERASUBGRUPO = widgetItensPedido.appliedFilter.FILTER_ROW.NCONSIDERASUBGRUPO;
        if(emissaoPedidosOLWidget.currentRow.NCONSIDERASUBGRUPO == 'N') {
            emissaoPedidosOLWidget.currentRow.CDGRUPPROD = widgetItensPedido.appliedFilter.FILTER_ROW.CDGRUPPROD;
            emissaoPedidosOLWidget.currentRow.CDSUBGRPROD = widgetItensPedido.appliedFilter.FILTER_ROW.CDSUBGRPROD;
            emissaoPedidosOLWidget.currentRow.NMSUBGRPROD = widgetItensPedido.appliedFilter.FILTER_ROW.NMSUBGRPROD;
            
            emissaoPedidosOLWidget.getField("CDSUBGRPROD").readOnly = false;
        } else {
            emissaoPedidosOLWidget.getField("CDSUBGRPROD").readOnly = true;
        }
        emissaoPedidosOLWidget.currentRow.CDROTATRANS = widgetItensPedido.appliedFilter.FILTER_ROW.CDROTATRANS;
        emissaoPedidosOLWidget.currentRow.DTPROGENPEOL = widgetItensPedido.appliedFilter.FILTER_ROW.DTPROGENPEOL;
        emissaoPedidosOLWidget.currentRow.DTPROGEMBARQ = widgetItensPedido.appliedFilter.FILTER_ROW.DTPROGEMBARQ;
        emissaoPedidosOLWidget.currentRow.NMPRODINI = widgetItensPedido.appliedFilter.FILTER_ROW.NMPRODINI;
        emissaoPedidosOLWidget.currentRow.NMPRODFIN = widgetItensPedido.appliedFilter.FILTER_ROW.NMPRODFIN;
        emissaoPedidosOLWidget.currentRow.PEDOLEXTR = widgetItensPedido.appliedFilter.FILTER_ROW.PEDOLEXTR;
        emissaoPedidosOLWidget.currentRow.TCDLOTENVITOL = widgetItensPedido.appliedFilter.FILTER_ROW.TCDLOTENVITOL;
        if(emissaoPedidosOLWidget.currentRow.TCDLOTENVITOL == 'L') {
            emissaoPedidosOLWidget.currentRow.CDLOTE = widgetItensPedido.appliedFilter.FILTER_ROW.CDLOTE;
            emissaoPedidosOLWidget.currentRow.CDLOTENVITOL = widgetItensPedido.appliedFilter.FILTER_ROW.CDLOTENVITOL;
            emissaoPedidosOLWidget.currentRow.NMLOTENVITOL = widgetItensPedido.appliedFilter.FILTER_ROW.NMLOTENVITOL;
            
            emissaoPedidosOLWidget.getField("CDLOTE").readOnly = false;
            emissaoPedidosOLWidget.getField("CDLOTE").validations = {
                "required": true
            };
        } else {
            emissaoPedidosOLWidget.getField("CDLOTE").readOnly = true;
            delete emissaoPedidosOLWidget.getField("CDLOTE").validations;
        }
        
        emissaoPedidosOLWidget.getField("CDFILIOPELOG").reload();
        emissaoPedidosOLWidget.getField("CDFILDEST").reload();
        emissaoPedidosOLWidget.getField("CDSUBGRPROD").reload();
        emissaoPedidosOLWidget.getField("CDROTATRANS").reload();
        emissaoPedidosOLWidget.getField("NMPRODINI").reload();
        emissaoPedidosOLWidget.getField("NMPRODFIN").reload();
        emissaoPedidosOLWidget.getField("CDLOTE").reload();
        
        ScreenService.openPopup(emissaoPedidosOLWidget);
    };
    
    this.changeFieldRota = function(widget) {
        const fieldRota = widget.getField("CDROTATRANS");
        
        if(widget.currentRow.NCONSIDERAROTA === 'N') {
            fieldRota.readOnly = false;
            fieldRota.reload();
            fieldRota.setValue(null);
        } else {
            fieldRota.readOnly = true;
            fieldRota.reload();
            fieldRota.setValue(null);
        }
        
        widget.activate();
    };
    
    //Valida o tipo de inconsitencia de cada produto
    function validaProdsIncons(produtos) {
        //Para cada produto, faz-se as modificaçãoes
        produtos.forEach(produto => {
            //Altera o formato da data a ser exibida
            if(!Util.isEmptyOrBlank(produto.DTPROGENTAF) && produto.DTPROGENTAF !== ''){
               produto.DTPROGENTAF = produto.DTPROGENTAF.substr(0, 10); 
            }
            //Armazena o value
            var CDERRO = produto.CDERRO;
            //Se a string.length for maior que 6
            if(CDERRO.length >= 6) {
                //Separa os values
                CDERRO = produto.CDERRO.split("_");
                //Se a posição 0 for vazia, remove-a
                if(CDERRO[0] === ""){
                    CDERRO.shift();
                }
                //Se tiver 2 itens
                if(CDERRO.length == 2){
                    produto.CDERRO = CDERRO[0] + " - " + CDERRO[1];
                //Se tiver 3 ou mais itens
                }else if(CDERRO.length >= 3) {
                    //Guarda o primeiro e o ultimo item da array
                    let firstItem = CDERRO.shift() + " ";
                    let lastItem = " - " + CDERRO.pop();
                    let itens = [];
                    //Passa por cada item restante(que está entre o primeiro e ultimo item)
                    CDERRO.forEach(item => {
                        if(item !== firstItem && item !== lastItem){
                            item = " - " + item;
                            itens.push(item);
                        }
                    });
                    //Transforma a array em string
                    itens = itens.toString();
                    //Remove as virgulas (,)
                    itens = itens.replace(/,/g, "").replace(/\./g, "");
                    //Concatena os itens
                    itens = firstItem + itens + lastItem;
                    //Tranforma em string novamente
                    itens = itens.toString();
                    //Retorna uma string montada com todos os itens modificados
                    produto.CDERRO = itens;
                }
            //Se a string.length fir igual a 3
            }else if(CDERRO.length == 3){
                //Separa os values
                CDERRO = produto.CDERRO.split("_");
                //Se a posição 0 for vazia, remove-a
                if(CDERRO[0] === ""){
                    CDERRO.shift();
                }
                //Retorna uma string montada com todos os itens modificados
                produto.CDERRO = CDERRO[0];
            }
        });
        //Retorna a array completa
        return produtos;
    }
    
    //Confirmação da emissao dos pedidos
    this.confirmaEmissaoPedidosOL = function(widget, opcao) {
        //Armazena os dados 
        const row = angular.copy(widget.currentRow);
        const widgetGeraRelatorioEmissao = templateManager.container.getWidget("geraRelatorioEmissaoWidget");
        const widgetEmail = templateManager.container.getWidget("enviaEmailEmissaoWidget");
        var reportRow = {};
        opEmissao = opcao;
        //Verifica se o form está válido
        if(widget.isValid()) {
            //Armazena os dados para geração de relatório
            reportRow.P_CDCLIENTE = '';
            reportRow.P_TCDCLIENTE = 'T';
            reportRow.P_CDOPERADOR = getLocalVar('CDOPERADOR');
            reportRow.P_CDFILIOL = Util.isEmptyOrBlank(row.CDFILIOPELOG) ? '' : '_' + row.CDFILIOPELOG.join('_') + '_';
            reportRow.P_TCDFILIOL = Util.isEmptyOrBlank(row.CDFILIOPELOG) ? 'T' : '';
            reportRow.L_ROTA = Util.isEmptyOrBlank(row.CDROTATRANS) ? 'T' : '_' + row.CDROTATRANS.join('_') + '_';
            reportRow.L_ROTA1 = Util.isEmptyOrBlank(row.CDROTATRANS) ? 'T' : '_' + row.CDROTATRANS.join('_') + '_';
            reportRow.P_ROTA = Util.isEmptyOrBlank(row.CDROTATRANS) ? 'T' : '_' + row.CDROTATRANS.join('_') + '_';
            reportRow.P_CDFILIAL = Util.isEmptyOrBlank(row.CDFILDEST) ? '' : '_' + row.CDFILDEST.join('_') + '_';
            reportRow.P_TCDFILIAL = Util.isEmptyOrBlank(row.CDFILDEST) ? 'T' : '';
            reportRow.P_DTENTRINI = (Util.isEmptyOrBlank(row.DTPROGENPEOL.start) && Util.isEmptyOrBlank(row.DTPROGENPEOL.end)) ? '' : moment(row.DTPROGENPEOL.start, "DD/MM/YYYY").format('L');
            reportRow.P_DTENTRFIN = (Util.isEmptyOrBlank(row.DTPROGENPEOL.start) && Util.isEmptyOrBlank(row.DTPROGENPEOL.end)) ? '' : moment(row.DTPROGENPEOL.end, "DD/MM/YYYY").format('L');
            reportRow.P_TDTENTR = (Util.isEmptyOrBlank(row.DTPROGENPEOL.start) && Util.isEmptyOrBlank(row.DTPROGENPEOL.end)) ? 'T' : '';
            reportRow.P_DTEMBINI = (Util.isEmptyOrBlank(row.DTPROGEMBARQ.start) && Util.isEmptyOrBlank(row.DTPROGEMBARQ.end)) ? '' : moment(row.DTPROGEMBARQ.start, "DD/MM/YYYY").format('L');
            reportRow.P_DTEMBFIN = (Util.isEmptyOrBlank(row.DTPROGEMBARQ.start) && Util.isEmptyOrBlank(row.DTPROGEMBARQ.end)) ? '' : moment(row.DTPROGEMBARQ.end, "DD/MM/YYYY").format('L');
            reportRow.P_TDTEMB = (Util.isEmptyOrBlank(row.DTPROGEMBARQ.start) && Util.isEmptyOrBlank(row.DTPROGEMBARQ.end)) ? 'T' : '';
            reportRow.P_SUBGRUPO = row.NCONSIDERASUBGRUPO === 'S' ? 'N' : Util.isEmptyOrBlank(row.CDSUBGRPROD) ? 'T' : '_' + row.CDSUBGRPROD.join('_') + '_';
            reportRow.P_CDGRUPPROD = row.NCONSIDERASUBGRUPO === 'S' ? '' : parametrosParaSupri.CDGRUPPROD;
            reportRow.P_CDPRODINI = (Util.isEmptyOrBlank(row.CDPRODINI) && Util.isEmptyOrBlank(row.CDPRODFIN)) ? '' : row.CDPRODINI;
            reportRow.P_CDPRODFIN = (Util.isEmptyOrBlank(row.CDPRODINI) && Util.isEmptyOrBlank(row.CDPRODFIN)) ? "" : (row.CDPRODFIN + "ZZZZZZZZZZZZZZZZZZZZ").substr(0, 20);
            reportRow.P_TPRODUTO = (Util.isEmptyOrBlank(row.CDPRODINI) && Util.isEmptyOrBlank(row.CDPRODFIN)) ? 'T' : null;
            reportRow.P_CDPRODFINTEXT = (Util.isEmptyOrBlank(row.CDPRODINI) && Util.isEmptyOrBlank(row.CDPRODFIN)) ? '' : row.CDPRODFIN;
            reportRow.L_PRODUTO = (Util.isEmptyOrBlank(row.CDPRODINI) && Util.isEmptyOrBlank(row.CDPRODFIN)) ? 'T' : 'X';
            reportRow.P_PRODUTO = (Util.isEmptyOrBlank(row.CDPRODINI) && Util.isEmptyOrBlank(row.CDPRODFIN)) ? 'T' : 'X';
            reportRow.L_OPERADOR = getLocalVar("CDOPERADOR");
            reportRow.L_OPERADOR1 = getLocalVar("CDOPERADOR");
            reportRow.P_OPERADOR = getLocalVar("CDOPERADOR");
            reportRow.P_NMPRODINI = Util.isEmptyOrBlank(row.NMPRODINI) ? '' : row.NMPRODINI;
            reportRow.P_NMPRODFIN = Util.isEmptyOrBlank(row.NMPRODFIN) ? '' : row.NMPRODFIN;
            reportRow.P_IDSITUACAO = 'P';
            reportRow.P_IDBAIXEXOL = '_' + row.IDBAIXAAFENT.join('_') + '_';
            reportRow.P_IDBAIXEXSAI = '_' + row.IDBAIXAAFSAI.join('_') + '_';
            reportRow.P_PEDEXOLEXTR = row.PEDOLEXTR.length == 2 ? 'T' : row.PEDOLEXTR[0] === 'S' ? 'S' : 'N';
            reportRow.P_CDLOTENVITOL = row.TCDLOTENVITOL === 'S' ? 'S' : row.TCDLOTENVITOL === 'N' ? 'T' : row.TCDLOTENVITOL === 'L' ? Util.isEmptyOrBlank(row.CDLOTENVITOL) ? 'T' : '_' + row.CDLOTENVITOL.join('_') + '_' : 'T';
            reportRow.P_NRSEQRUPTURAOL = '';
            reportRow.P_TNRSEQRUPTURAOL = 'T';
            reportRow.P_TROTA = (Util.isEmptyOrBlank(row.P_ROTA)) ? 'T' : null;
            reportRow.P_IDPEDEXTRA = row.PEDOLEXTR.length == 2 ? 'T' : row.PEDOLEXTR[0] === 'S' ? 'S' : 'N';
            reportRow.STRATEGY = widget.currentRow.RELATORIO.split('.')[1];
            reportRow.__report_name = widget.currentRow.RELATORIO.split('.')[0];
            reportRow.reportLabel = widget.currentRow.RELATORIO.split('.')[0];
            reportRow.QR2TYPE = widget.currentRow.QR2TYPE;
            //ALtera o valor do checkbox do widget "Enviar E-Mail"
            widgetEmail.getField("SENDOPERATOR").label = "Enviar Cópia para " + getLocalVar("NMOPERADOR");
            //Armazena os dados dos itens para geração do relatório
            widget.reportRow = reportRow;
            //Retorna cookies
            ServiceEmissaoPedidoOL.retornaCookieEmail().then(function(messages) {
                //Armazena os cookies
                var cookies = messages.messages[0].message;
                //Determina os cookies para cada campo
                widgetEmail.currentRow.NOME_ARQUIVO = cookies.shift();
                widgetEmail.currentRow.MENSAGEM = cookies.shift();
                widgetEmail.currentRow.ASSUNTO = cookies.shift();
                widgetEmail.currentRow.SENDOPERATOR = cookies.shift();
                widgetEmail.currentRow.EMAILS = cookies.shift();
                //Mensagens de erro
                const promises = [
                    MessageService.getMessageByCode("SUCCESS_MESSAGE"),
                    MessageService.getMessageByCode("ERROR_MESSAGE"),
                    MessageService.getMessageByCode("EMAIL_N_REGISTERED"),
                    MessageService.getMessageByCode("EMAIL_SEND_SUCCESS"),
                    MessageService.getMessageByCode("EMAIL_SEND_FAILED")
                ];
                //Promisse retornada
                Promise.all(promises).then((response) => {
                   const msgArray = {
                        'SUCCESS_MESSAGE': response.shift(),
                        'ERROR_MESSAGE': response.shift(),
                        'EMAIL_N_REGISTERED': response.shift(),
                        'EMAIL_SEND_SUCCESS': response.shift(),
                        'EMAIL_SEND_FAILED': response.shift()
                    };
                    widgetEmail.currentRow.MSGARRAY = msgArray;
                });
                //Altera os valores dos seguintes campos do widget de Email
                if(!widgetEmail.currentRow.NOME_ARQUIVO) {
                    widgetEmail.currentRow.NOME_ARQUIVO = "";
                }
                if(!widgetEmail.currentRow.EMAILS) {
                    widgetEmail.currentRow.EMAILS = "";
                }
                if(!widgetEmail.currentRow.MENSAGEM) {
                    widgetEmail.currentRow.MENSAGEM = "Envio de E-Mail Emissão de Pedidos OL";
                }
                if(!widgetEmail.currentRow.ASSUNTO) {
                    widgetEmail.currentRow.ASSUNTO = "Envio de E-Mail Emissão de Pedidos OL";
                }
                //Gera/Envia relatorio
                if(widget.isValid() && reportRow.STRATEGY) {
                    if(opcao == 1) {
                        //Abre o popup de gerar relatório
                        ScreenService.openPopup(widgetGeraRelatorioEmissao);
                    } else {
                        //Abre o popup de enviar relatório por email
                        ScreenService.openPopup(widgetEmail);
                    }
                }    
            }).catch(function(error) {
                MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
            });
        } else {
            MessageService.showMessageByCode("OBRIGATORY_FIELDS");
            ScreenService.closePopup();
        }
    };
    
    //Seta a label do popup Inconsistências de Produtos da Emissão
    this.setLabelPopupInconsistenciaProdutoEmissao = function(){
        var widgetInconsistencia = templateManager.container.getWidget('inconsistenciaProdutosEmissaoWidget');
        setTimeout(() => {
            ScreenService.showLoader();
	        MessageService.getMessageByCode('LABEL_POPUP_INSCONSISTENCIA_PRODUTO_EMISSAO').then(function(response){
                var label = response;
                widgetInconsistencia.label = label;
                widgetInconsistencia.redraw();
                ScreenService.hideLoader();
            });
        }, 600);
    };
    
    //Finaliza a emissao de insonsistencia
    this.finalizaEmissaoIncons = function(widget) {
        //Armazena os dados
        const widgetcmp04900 = templateManager.container.getWidget("cmp04900");
        const widgetEmissao = widget.getParent();
        const reportRow = widgetEmissao.reportRow;
        const widgetEmail = templateManager.container.getWidget("enviaEmailEmissaoWidget");
        const row = {
            "DADOS_EMAIL": widgetEmail.currentRow,
            "CURRENT_ROW": reportRow
        };
        //Fecha o popup
        ScreenService.closePopup();
        //Valida o formulário
        if(widgetEmissao.isValid()) {
            //Se "opEmissao" !== 1 continua a geração de relatorio txt e envio de email  .. Senao continua a execução de gerar relatorio txt.
            if(opEmissao !== 1) {
                if(reportRow.P_GERARESERVA == 'S') {
                    if(Util.isEmptyOrBlank(permissoesFinaisOperador)) {
                        if(Util.isEmptyOrBlank(permissoesGeraisOperador)) {
                            MessageService.confirmMessageByCode("BLOQUEAR_PEDIDOS").then(function(confirmed) {
                                General.callRestEngine("opl_relatorios#/bloqueiaPedidoOL").then(function(response) {
                                    if(widgetEmail.isValid()) {
                                        ServiceEmissaoPedidoOL.enviaEmailEmissaoPedidoOL(row).then(function(success) {
                                            exibeLogEmail(widgetEmail, success.messages, false);
                                        }).catch(function(error) {
                                            MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
                                        });
                                    }
                                }).catch(function(error) {
                                    MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
                                });
                            }).catch(function(declined) {
                                if(widgetEmail.isValid()) {
                                    ServiceEmissaoPedidoOL.enviaEmailEmissaoPedidoOL(row).then(function(success) {
                                        exibeLogEmail(widgetEmail, success.messages, false);
                                    }).catch(function(error) {
                                        MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
                                    });
                                }
                            });
                        } else {
                            if(permissoesGeraisOperador.indexOf("SVOL") == -1) {
                                MessageService.confirmMessageByCode("BLOQUEAR_PEDIDOS").then(function(confirmed) {
                                    General.callRestEngine("opl_relatorios#/bloqueiaPedidoOL").then(function(response) {
                                        if(widgetEmail.isValid()) {
                                            ServiceEmissaoPedidoOL.enviaEmailEmissaoPedidoOL(row).then(function(success) {
                                                exibeLogEmail(widgetEmail, success.messages, false);
                                            }).catch(function(error) {
                                                MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
                                            });
                                        }
                                    }).catch(function(error) {
                                        MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
                                    });
                                }).catch(function(declined) {
                                    if(widgetEmail.isValid()) {
                                        ServiceEmissaoPedidoOL.enviaEmailEmissaoPedidoOL(row).then(function(success) {
                                            exibeLogEmail(widgetEmail, success.messages, false);
                                        }).catch(function(error) {
                                            MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
                                        });
                                    }
                                });
                            } else {
                                MessageService.showMessageByCode("OPER_BLOCK");
                            }
                        }
                    } else {
                        if(permissoesGeraisOperador.indexOf("SVOL") != -1 && permissoesFinaisOperador.indexOf("SVOL") != -1) {
                            MessageService.confirmMessageByCode("BLOQUEAR_PEDIDOS").then(function(confirmed) {
                                General.callRestEngine("opl_relatorios#/bloqueiaPedidoOL").then(function(response) {
                                    if(widgetEmail.isValid()) {
                                        ServiceEmissaoPedidoOL.enviaEmailEmissaoPedidoOL(row).then(function(success) {
                                            exibeLogEmail(widgetEmail, success.messages, false);
                                        }).catch(function(error) {
                                            MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
                                        });
                                    }
                                }).catch(function(error) {
                                    MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
                                });
                            }).catch(function(declined) {
                                if(widgetEmail.isValid()) {
                                    ServiceEmissaoPedidoOL.enviaEmailEmissaoPedidoOL(row).then(function(success) {
                                        exibeLogEmail(widgetEmail, success.messages, false);
                                    }).catch(function(error) {
                                        MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
                                    });
                                }
                            });
                        } else {
                            MessageService.showMessageByCode("OPER_BLOCK");
                        }
                    }
                } else {
                    if(widgetEmail.isValid()) {
                        ServiceEmissaoPedidoOL.enviaEmailEmissaoPedidoOL(row).then(function(success) {
                            exibeLogEmail(widgetEmail, success.messages, false);
                        }).catch(function(error) {
                            MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
                        });
                    }
                }
            } else {
                General.openReport("opl_relatorios#/emissao_pedidos_ol_relatorio", reportRow.reportLabel, reportRow).then(success => {}).catch(error => {
                    MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
                });
            }
        }
    };
    
    //Gera relatório
    this.openReport = function(widget, row, reportName) {
        row.QR2TYPE = widget.currentRow.QR2TYPE;
        row.STRATEGY = widget.currentRow.RELATORIO.split('.')[1];
        General.openReport("opl_relatorios#/emissao_pedidos_ol_relatorio", reportName, row).then(success => {}).catch(error => {
            MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
        });
    };
    
    //Gera relatório de emissao de pedidos ol
    this.openPopupGeraRelatorioEmissao = function(widget, row, reportName) {
        var widgetcmp04900 = templateManager.container.getWidget("cmp04900");
        var widgetGerRelatorioEmissao = templateManager.container.getWidget("geraRelatorioEmissaoWidget");
        const reportRow = widget.getParent().reportRow;
        row = reportRow;
        row.QR2TYPE = widgetGerRelatorioEmissao.currentRow.EXTENSAO;
        row.STRATEGY = widgetcmp04900.currentRow.RELATORIO.split('.')[1];
        //Se a extensão for TXT
        if(widget.currentRow.EXTENSAO == "TXT") {
            General.callRestEngine("opl_relatorios#/procedureVALIDA_ITEMAUTF_OL", "Row", reportRow).then(function(response) {
                //Se for retornado P_ERROS === "N" || "T", não há inconsistencias
                if(response.dataset.data.P_ERROS && response.dataset.data.P_ERROS == "N" || response.dataset.data.P_ERROS == "T"){
                   General.openReport("opl_relatorios#/emissao_pedidos_ol_relatorio", row.reportLabel, row).then(success => {}).catch(error => {
                        MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
                    });
                } else {
                    //Armazena o resultado da procedure
                    const arrayResult = response.dataset.data;
                    //Se fir retornado dados
                    if(arrayResult.length > 0){
                        //Function que valida o tipo de inconsistencia
                        var prodsIncons = validaProdsIncons(arrayResult);
                        //Abre um popup do type "question"
                        MessageService.confirmMessageByCode("INCONS_PROCESSO_EMISSAO").then(function(confirmed) {
                            //Armazena o widget de insconsistencia
                            const inconsistWidget = templateManager.container.getWidget("inconsistenciaProdutosEmissaoWidget");
                            //Seta o dataSource com os dados obtidos pela procedure
                            inconsistWidget.dataSource.data = prodsIncons;
                            //Abre o popup de inconsistencia
                            ScreenService.openPopup(inconsistWidget);
                            inconsistWidget.reload();
                            inconsistWidget.activate();
                        }).catch(function(declined){});
                    }
                }
            }).catch(function(error) {
                MessageService.showMessageByCode("UNKNOWN_ERROR");
            });
        } else {
            General.openReport("opl_relatorios#/emissao_pedidos_ol_relatorio", row.reportLabel, row).then(success => {}).catch(error => {
                MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
            });
        }
    };
    
    this.prodQtdeInlineChange = function(widget) {
        const adicionaNovoPedidoWidget = templateManager.container.getWidget("adicionaNovoPedido");
        
        adicionaNovoPedidoWidget.enabled = false;
    };
    
    this.prodQtdeInlineCancel = function(widget) {
        const adicionaNovoPedidoWidget = templateManager.container.getWidget("adicionaNovoPedido");
        
        adicionaNovoPedidoWidget.enabled = true;
        
        widget.rollbackInlineEdit();
        widget.list();
    };
    
    this.prodQtdeInlineSave  = function(widget) {
        const adicionaNovoPedidoWidget = templateManager.container.getWidget("adicionaNovoPedido");
        
        adicionaNovoPedidoWidget.enabled = true;
        
        widget.commitInlineEdit();
        widget.list();
    };
    
    this.onChangeQtdeInline = function(widget) {
        const widgetDetalhesPedido = templateManager.container.getWidget("detalhesPedido");
        const widgetDadosPedido = templateManager.container.getWidget("dadosPedido");
        
        widgetDadosPedido.setEnabled(false);
        widgetDetalhesPedido.setEnabled(false);
        widget.showCheckbox = false;
    };
    
    this.onCancelInlineEdit = function(widget) {
        const widgetDetalhesPedido = templateManager.container.getWidget("detalhesPedido");
        const widgetDadosPedido = templateManager.container.getWidget("dadosPedido");
        
        if(widget.currentRow.NRPEDEXOL) {
            widgetDadosPedido.enabled = true;
            widgetDetalhesPedido.enabled = true;
        }
        
        widget.showCheckbox = true;
        widget.rollbackInlineEdit();
        widget.list();
    };
    
    this.onSaveInlineEdit = function(widget) {
        const widgetDetalhesPedido = templateManager.container.getWidget("detalhesPedido");
        const widgetDadosPedido = templateManager.container.getWidget("dadosPedido");
        const changedRows = widget.dataSource.data.filter(row => {
            return (row.changed === true);
        });
        const rowsLiberadas = widget.dataSource.data.filter(row => {
            return (row.changed === true && (row.IDBAIXEXOL == null || row.IDBAIXEXOL == 0 || row.IDBAIXEXOL == 1) && (row.IDBAIXENPEOL == null || row.IDBAIXENPEOL == 0 || row.IDBAIXENPEOL == 1));
        });
        
        if(rowsLiberadas.length == changedRows.length) {
            MessageService.confirmMessageByCode("QTPROGENPEOL_DELETE_ZERO").then(function(confirmed) {
                rowsLiberadas.forEach(row => {
                   row.NEW_QTPROGENPEOL = row.QTPROGENPEOL_inline;
                   row.OLD_QTPROGENPEOL = row.changed_QTPROGENPEOL;
                   row.CDFILDEST = row.CDFILDEST.substr(0, 4);
                   row.DTPROGENPEOL = moment(row.DTPROGENPEOL, "DD/MM/YYYY").format("DD/MM/YYYY");
                });
                
                General.callRestEngine("opl_relatorios#/alteraQuantidadeItemPedidoOLInline", "Row", rowsLiberadas).then(function(response) {
                    if(widget.currentRow.NRPEDEXOL) {
                        widgetDadosPedido.enabled = true;
                        widgetDetalhesPedido.enabled = true;
                    }
                    
                    widget.showCheckbox = true;
                    widget.commitInlineEdit();
                    widget.list();
                    widget.reload();
                    widget.activate();
                    
                    MessageService.showMessageByCode("QTPROGENPEOL_EDIT_SUCCESS");
                }).catch(function(error) {
                    if(widget.currentRow.NRPEDEXOL) {
                        widgetDadosPedido.enabled = true;
                        widgetDetalhesPedido.enabled = true;
                    }
                    
                    widget.showCheckbox = true;
                    widget.rollbackInlineEdit();
                    widget.list();
                    
                    MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
                });
            });
        } else {
            MessageService.showMessageByCode("ONLY_EMABERTO_PARCIAL_ITENS_PEDIDO_EDIT");
            
            if(widget.currentRow.NRPEDEXOL) {
                widgetDadosPedido.enabled = true;
                widgetDetalhesPedido.enabled = true;
            }
            
            widget.showCheckbox = true;
            widget.rollbackInlineEdit();
            widget.list();
        }
    };
    
    this.cancelaNovoItemPedido = function(widget) {
        MessageService.confirmMessageByCode("CANCEL_NOVO_ITEM_PEDIDO").then(function(confirmed) {
            ScreenService.closeSwipe();
            widget.getParent().activate();
            widget.getParent().list();
        });
    };
    
    this.realizaCalculoPorcentagens = function(widgetAltAutomaticaProd, cdProdutoOld) {
        const fieldAjusteUnidade = widgetAltAutomaticaProd.getField('AJUSTE_UNIDADE');
        const fieldAjusteQuantidade = widgetAltAutomaticaProd.getField('AJUSTE_QUANTIDADE');
        const row = {
            "CDPRODUTO_OLD": cdProdutoOld,
            "CDARVPROD": widgetAltAutomaticaProd.currentRow.CDARVPROD
        };
        
        return General.callRestEngine("opl_relatorios#/calcularAjustesProduto", "Row", row).then(function(response) {
            const ajustes = response.dataset.data[0];
            
            if(!Util.isEmptyOrBlank(ajustes.AJUSTEUN)) {
                if(ajustes.AJUSTEUN == 0 || ajustes.AJUSTEUN == null) {
                    fieldAjusteUnidade.setValue('0');
                } else {
                    fieldAjusteUnidade.setValue(ajustes.AJUSTEUN);
                }
                fieldAjusteUnidade.reload();
            } else {
                fieldAjusteUnidade.setValue('0');
            }
            
            if(!Util.isEmptyOrBlank(ajustes.AJUSTEQTDE)) {
                if(ajustes.AJUSTEQTDE == 0 || ajustes.AJUSTEQTDE == null) {
                    fieldAjusteQuantidade.setValue('0');
                } else {
                    fieldAjusteQuantidade.setValue(ajustes.AJUSTEQTDE);
                }
                fieldAjusteQuantidade.reload();
            } else {
                fieldAjusteQuantidade.setValue('0');
            }
            
            fieldAjusteUnidade.reload();
    		fieldAjusteQuantidade.reload();
        }).catch(function(error) {
            MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
        });
    };
    
    this.verificaProduto = function(field) {
        const widget = field.widget;
        const widgetGrid = widget.getParent();
        const checkedRowsGrid = widgetGrid.getCheckedRows();
        
        if(!Util.isEmptyOrBlank(widget.currentRow.CDARVPROD)) {
            for(let i = 0; i < checkedRowsGrid.length; i++) {
                if(checkedRowsGrid[i].CDARVPROD === widget.currentRow.CDARVPROD) {
                    MessageService.showMessageByCode("NEW_PRODUCT_PRODUCT_ORIGIN");
                    field.clearValue();
                    return;
                }
            }
            this.realizaCalculoPorcentagens(widget, checkedRowsGrid[0].CDARVPROD);
        } else {
            widget.currentRow.AJUSTE_UNIDADE = '0';
            widget.currentRow.AJUSTE_QUANTIDADE = '0';
        }
    };
    
    this.enviaEmail = function(widget) {
        widget.currentRow.MSGOPL = "Email automático enviado pelo Operador Logístico";
        widget.currentRow.MSGDATESENT = "Disponilizado em: ";
        widget.currentRow.DSLINK = "Clique aqui para visualizar o Relatório";
        
        const reportRow = widget.getParent().reportRow;
        const row = {
            "DADOS_EMAIL": widget.currentRow,
            "CURRENT_ROW": reportRow
        };
        
        //Se a extensão for TXT
        if(widget.currentRow.EXTENSAO == "TXT") {
            General.callRestEngine("opl_relatorios#/procedureVALIDA_ITEMAUTF_OL", "Row", reportRow).then(function(response) {
                //Armazena o resultado da procedure
                const arrayResult = response.dataset.data;
                //Se fir retornado dados
                if(arrayResult.length > 0){
                    //Function que valida o tipo de inconsistencia
                    var prodsIncons = validaProdsIncons(arrayResult);
                    //Abre um popup do type "question"
                    MessageService.confirmMessageByCode("INCONS_PROCESSO_EMISSAO").then(function(confirmed) {
                        //Armazena o widget de insconsistencia
                        const inconsistWidget = templateManager.container.getWidget("inconsistenciaProdutosEmissaoWidget");
                        //Seta o dataSource com os dados obtidos pela procedure
                        inconsistWidget.dataSource.data = prodsIncons;
                        //Abre o popup de inconsistencia
                        ScreenService.openPopup(inconsistWidget);
                        inconsistWidget.reload();
                        inconsistWidget.activate();
                    }).catch(function(declined){});
                }
            }).catch(function(error) {
                MessageService.showMessageByCode("UNKNOWN_ERROR");
            });
        } else {
            if(widget.isValid()) {
                ServiceEmissaoPedidoOL.enviaEmailEmissaoPedidoOL(row).then(function(success) {
                    exibeLogEmail(widget, success.messages, false);
                }).catch(function(error) {
                    MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
                });
            }
        }
    };
    
    function exibeLogEmail(widget, success, isGroup) {
        const widgetOrigem = templateManager.container.getActiveWidget();
        const arrayMesssages = widget.currentRow.MSGARRAY;
        let arrayError = [];
        let arraySuccess = [];
        let arrayLogs = [];
        let addHeadSuccess = true;
        let addHeadError = true;
        
        success.forEach(function(row) {
            const logSuccess = row.message.SUCCESS;
            const logError = row.message.ERROR;
        
			if(!Util.isEmptyOrBlank(logSuccess)) {
			    if(addHeadSuccess) {
				    addHeadSuccess = false;
				    arraySuccess = arraySuccess.concat(setArrayLog(logSuccess, arrayMesssages));
				    adicionaCabecalhoAoLog(arraySuccess, arrayMesssages.SUCCESS_MESSAGE);
			    } else {
			        arraySuccess = arraySuccess.concat(setArrayLog(logSuccess, arrayMesssages));
			    }
			}
			
			if(!Util.isEmptyOrBlank(logError)) {
			    if(addHeadError) {
				    addHeadError = false;
				    arrayError = arrayError.concat(setArrayLog(logError, arrayMesssages));
				    adicionaCabecalhoAoLog(arrayError, arrayMesssages.ERROR_MESSAGE);
			    } else {
			        arrayError = arrayError.concat(setArrayLog(logError, arrayMesssages));
			    }
			}
        });

        arrayLogs = arrayError.concat(arraySuccess);
        ScreenService.closePopup();
        General.showErrorMessages(widgetOrigem, arrayLogs, ScreenService.i18n('Log'));
    }
    
    function adicionaCabecalhoAoLog(logArray, titulo) {
        logArray.unshift('----------------------------');
        logArray.unshift(titulo);
        logArray.unshift('----------------------------');
    }
    
    function setArrayLog(messages, arrayMesssages) {
        let result = [];
        
        messages.forEach(row => {
    		result.push(arrayMesssages[row.MESSAGE]);
		});
		
		return result;
    }
    
    this.changeFilterProduct = function(field) {
        field.dataSourceFilter.forEach(function(row) {
            if(row.name == "P_CDFILIOPELOG") {
                row.value = CDFILIOPELOGPROD;
            }
        });
        
        field.reload();
    };
    
    function verificaPermissaoItem(widget, item) {
        if(Util.isEmptyOrBlank(permissoesFinaisOperador)) {
            if(Util.isEmptyOrBlank(permissoesGeraisOperador)) {
                return true;
            } else {
                if(permissoesGeraisOperador.indexOf("BLOL") != -1) {
                    if(item.IDITMPEDOLBLOQ == 'S') {
                        return false;
                    } else {
                        return true;
                    }
                } else {
                    return true;
                }
            }
        } else {
            if(Util.isEmptyOrBlank(permissoesGeraisOperador)) {
                return true;
            } else {
                if(permissoesGeraisOperador.indexOf("BLOL") != -1 && permissoesFinaisOperador.indexOf("BLOL") != -1) {
                    return true;
                } else {
                    if(item.IDITMPEDOLBLOQ == 'S') {
                        return false;
                    } else {
                        return true;
                    }
                }
            }
        }
    }
    
    this.onFieldInlineEdit = function(widget, args) {
        if(!verificaPermissaoItem(widget, args.row)) {
            MessageService.showMessageByCode("OPER_BLOCK");
            widget.rollbackInlineEdit();
            widget.list();
            widget.reload();
            widget.showCheckbox = true;
        }
    };
    
    this.clearProduto = function(widget) {
        widget.getField("NMPRODUTO").clearValue();
        widget.getField("NMPRODUTO").reload();
    };
    
    this.validaSegMercadoProdFili = function(field) {
        ScreenService.showLoader();
        
        var row = {};
        
        
        if(field.widget.name == "adicionaItemPedido") {
            row.CDFILDEST = field.widget.currentRow.CDFILDEST;
        } else {
            field.dataSourceFilter.forEach(f => {
                if(f.name == "CDFILIAL")
                    row.CDFILDEST = f.value;
            });
        }
        
        
        row.CDARVPROD = field.widget.currentRow.CDARVPROD;
        
        if(!Util.isEmptyOrBlank(row.CDARVPROD)) {
            General.callRestEngine("opl_relatorios#/validaSegMercadoProdFili", "Row", row).then(function(response) {
                ScreenService.hideLoader();
            }).catch(function(error) {
                ScreenService.hideLoader();
                
                if(error.data.error == "PRODUTO_NOT_SEGMERCADO" || error.data.error == "PRODUTO_NOT_PRODFILI_ATIVO") {
                    MessageService.showMessageByCode(error.data.error);
                } else {
                    MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
                }
                
                field.clearValue();
            });
        } else {
            ScreenService.hideLoader();
        }
    };
    
    //Ativa o widget principal
    this.activateWidgetPrincipal = function(){
        const widgetCmp04900 = templateManager.container.getWidget("cmp04900");
        widgetCmp04900.activate();
    };
}

Configuration(function(ContextRegister) {
    ContextRegister.register("EmissaoPedidosOLController", EmissaoPedidosOLController);
});

// FILE: ./assets/modules/relatorios/assets/js/controllers/opl00900_listagem_de_corteController.js
var Configuration;
var moment;
var setLocalVar;
var getLocalVar;
var Util;
var angular;
let messages = {
    errosApuracao: "Erros na Apuração",
    timeout: "Tempo limite de conexão excedido."
};
var dadosInconsistencia = {};
var nr_log_corte_ol;
var resultApuracao;
var adqParams = [];

function opl00900_listagem_de_corteController(General, Utilities, RestEngine, ScreenService, MessageService, templateManager, maskEngine, ZhUtil, ZHPromise){
    
    //Referencia a uma constante global onde a mesma armazena funções a serem usadas/aplicadas como terceiro parametro no serviço {MessageService}...
    /*global Constants*/

    //Inicia um novo filtro
    this.startScreen = function(widget) {
        widget.newRow();
        setTimeout( () => {
            ScreenService.showLoader();
            getLocalVar('CDFILIAL');
            this.adqParam();
            ScreenService.hideLoader();
        }, 1000);
        this.setFilterInitValues(widget);
    };
    
    //Busca parametros
    this.adqParam = function(){
        General.callRestEngine("opl_relatorios#/crud/adqParam", "FilterData", [
                {
                    'name': 'CDFILCENTCMP',
                    'operator': '=',
                    'value': getLocalVar('CDFILIAL')
                }
            ]).then(function(response) {
                adqParams = response.dataset.adqParam[0];
        }).catch(function(error) {
            ScreenService.showMessage(error.data.error);
        });
    };
    
    //Seta os filtros iniciais
    this.setFilterInitValues = function(widget){
	    widget.currentRow.L_PER_LEV_PREV_CONS = {};
	    widget.currentRow.L_PER_LEV_PREV_CONS.formattedStart = moment().format('L');
        widget.currentRow.L_PER_LEV_PREV_CONS.formattedEnd = moment().format('L');
	    widget.currentRow.L_PER_LEV_PREV_CONS.start = moment().format('L');
        widget.currentRow.L_PER_LEV_PREV_CONS.end = moment().format('L');
        
	    widget.currentRow.L_PER_LEV_AF = {};
	    widget.currentRow.L_PER_LEV_AF.formattedStart = moment().format('L');
        widget.currentRow.L_PER_LEV_AF.formattedEnd = moment().format('L');
	    widget.currentRow.L_PER_LEV_AF.start = moment().format('L');
        widget.currentRow.L_PER_LEV_AF.end = moment().format('L');
    };
    
    //Preenche o field de Unidades
    this.selectUnidades = function(widget) {
        widget.getField('L_FILIAL').dataSource.name = "opl_relatorios#/crud/opl00900_filial_regiao";
        widget.getField('L_FILIAL').dataSourceFilter = [
            {
                "name": "P_CDFILIAL",
                "operator": "=",
                "value": adqParams.CDFILIAL
            }
        ];
        widget.getField('L_FILIAL').reload();
        this.setNGeracaoNull(widget);
    };
    
    //Seta o field Unidades como vazio/nulo
    this.setUnidadesNull = function(widget){
        widget.getField('L_FILIAL').clearValue();
    };
    
    //Preenche o field Número Geração
    this.selectNGeracao = function(widget) {
        if(widget.currentRow.L_FILIAL) {
            var filial = widget.currentRow.CDFILIAL;
            widget.getField('NR_GERACAO').dataSource.name = "opl_relatorios#/crud/opl00900_nr_geracao";
            widget.getField('NR_GERACAO').dataSourceFilter = [
                {
                    "name": "P_CDFILIOPELOG",
                    "operator": "=",
                    "value": filial
                }
            ];
            widget.getField('NR_GERACAO').reload();
        } else {
            this.setNGeracaoNull(widget);
            this.setUnidadesNull(widget);
            MessageService.showMessageByCode("L_FILIAL_VAZIA");
        }
    };
    
    //Determina o field N.Geração como Null/Vazio
    this.setNGeracaoNull = function(widget) {
        widget.getField('NR_GERACAO').clearValue();
    };
    
    //Validação no field N.Geração
    this.verificaNGeracao = function(args) {
		var widget = args.owner.field.widget;
		var row = widget.currentRow;
		var filialIsSet = this.fieldIsSet(row.L_FILIAL);
        if(!filialIsSet) {
			widget.currentRow.NR_GERACAO = '';
			widget.currentRow.CDFILIAL = '';
			if(widget.name === "opl00900") {
                widget.getField('NR_GERACAO').readOnly = true;
                widget.getField('NR_GERACAO').readOnlyOnEdit = true;
                this.setNGeracaoNull(widget);
			}
        } else if(widget.name === "opl00900") {
            widget.getField('NR_GERACAO').readOnly = false;
            widget.getField('NR_GERACAO').readOnlyOnEdit = false;
            this.setNGeracaoNull(widget);
        }
    };

    //Verifica se o field foi setado
	this.fieldIsSet = function(fieldValue) {
		if (fieldValue) return true;
		else return false;
	};
	
	//Seta o field Produto Inicial
	this.filterProdIni = function(args) {
		var widget = args.owner.field.widget;
		var row = widget.currentRow;
		var prodIniIsSet = this.fieldIsSet(row.CDPRODINI);
		if(!prodIniIsSet) {
			widget.currentRow.NMPRODFIN = '';
			widget.currentRow.CDPRODFIN = '';
		}
        this.checkProductRange(args.owner.field);
	};
	
	//Seta o field Produto Final
	this.filterProdFin = function(args) {
		var widget = args.owner.field.widget;
		var row = widget.currentRow;
		var prodFinIsSet = this.fieldIsSet(row.CDPRODFIN);
		var prodIniIsSet = this.fieldIsSet(row.CDPRODINI);
		if (prodFinIsSet) {
			if (row.CDPRODINI > row.CDPRODFIN) {
                MessageService.showMessageByCode("PRODUTO_INICIAL_MENOR_IGUAL_FINAL");
			}
		} 
		this.checkProductRange(args.owner.field);
	};
	
	//Validação dos fields Prod. Inicial e Final
	this.checkProductRange = function(field) {
	   var currentRow = field.widget.currentRow;
		if (currentRow.CDPRODINI && currentRow.CDPRODFIN) {
			var compproduto = (currentRow.CDPRODFIN) ? currentRow.CDPRODFIN.replace(/[\.\-]/g, '') : null;
			if (!this.comparaPratoProduto(currentRow.CDPRODINI, compproduto, getLocalVar('CDPICTPROD'))) {
				currentRow[field.outData[field.descriptionField]] = null;
				currentRow[field.outData[field.valueField]] = null;
                field.widget.getField('NMPRODINI').clearValue();
                field.widget.getField('NMPRODFIN').clearValue();
                MessageService.showMessageByCode("PRODUTO_INICIAL_MENOR_IGUAL_FINAL");
			}
		}
	};
	
	//Validação dos fields de Produtos
	this.comparaPratoProduto = function(pinicial, pfinal, mascara) {
        var mask = {
          type: "fix",
          params: {
              mask: mascara
          }
        };
        pinicial = Util.applyMask(pinicial, mask, maskEngine, ZhUtil).split('.');
        pfinal = Util.applyMask(pfinal, mask, maskEngine, ZhUtil).split('.');
        var nvinicial = pinicial.length;
        var nvfinal = pfinal.length;
        var resultado = true;
        if(nvinicial != nvfinal) {
            if(nvinicial > nvfinal) {
                resultado = false;
            }
        } else {
            var i = 0;
            do {
                if(pinicial[i] > pfinal[i]) {
                    resultado = false;
                }
                i++;
            }
            while (i<pinicial.length && resultado);
        }
        return resultado;
    };
    
    //Alteração dos fields do formulãrio de acordo com o field N.Geralção
    this.changeFieldsFromForm = function(widget) {
        if (widget.getField('NR_GERACAO').value().length >= 1) {
            //Clear values
            widget.getField('L_PER_LEV_PREV_CONS').clearValue();
            widget.getField('L_PER_LEV_AF').clearValue();
            widget.getField('L_COMPRADOR').clearValue();
            widget.getField('L_REGIAO').clearValue();
            widget.getField('NMPRODINI').clearValue();
            widget.getField('NMPRODFIN').clearValue();
            //Set ReadOnly fields
            widget.getField('L_PER_LEV_PREV_CONS').readOnly = true;
            widget.getField('L_PER_LEV_AF').readOnly = true;
            widget.getField('L_COMPRADOR').readOnly = true;
            widget.getField('L_REGIAO').readOnly = true;
            widget.getField('NMPRODINI').readOnly = true;
            widget.getField('NMPRODFIN').readOnly = true;
            //Delete validations of fields
            delete widget.getField('NMPRODINI').validations.required;
            delete widget.getField('NMPRODFIN').validations.required;
        } else {
            //Alter ReadOnly fields
            widget.getField('L_PER_LEV_PREV_CONS').readOnly = false;
            widget.getField('L_PER_LEV_AF').readOnly = false;
            widget.getField('L_COMPRADOR').readOnly = false;
            widget.getField('L_REGIAO').readOnly = false;
            widget.getField('NMPRODINI').readOnly = false;
            widget.getField('NMPRODFIN').readOnly = false;
            //Alter validations of fields
            widget.getField('NMPRODINI').validations.required = true;
            widget.getField('NMPRODFIN').validations.required = true;
            this.setFilterInitValues(widget);
        }
    };
    
    //Valida o formulário antes de gerar o relatõrio
    this.verificaRelatorio = function(widget) {
        var currentRow = widget.currentRow;
        if(widget.isValid()) {
            if(currentRow.L_PER_LEV_PREV_CONS !== "" && currentRow.L_PER_LEV_AF !== ""){
                var cons_start = currentRow.L_PER_LEV_PREV_CONS.start;
                var af_end = currentRow.L_PER_LEV_AF.end;
                if (moment(cons_start, "DD/MM/YYYY") <= moment(af_end, "DD/MM/YYYY")){
                    MessageService.showMessageByCode("DT_INICIAL_PREVISAO_CONSUMO_MENOR_DT_FINAL_AF", null, Constants.errorMessage);
                    return;
                } else {
                    cons_start = moment(cons_start, "DD/MM/YYYY");
                    af_end = moment(af_end, "DD/MM/YYYY");
                    if (moment(cons_start).diff(af_end, "days") > 1){
                        MessageService.showMessageByCode("PERIODO_NAO_ATENTIDO_ENTRE_DT_FINAL_AF_E_DT_INICIAL_PREVISAO_CONSUMO", null, Constants.alertMessage);
                    }
                    var reportName = currentRow.REPORT_NAME.split('.')[0];
                    General.openReportPopup(widget, this.abreRelatorio, [widget, currentRow, reportName]);      
                }    
            }
        }
    };
    
    //Verifica o formulário e valida o COMPRADOR
    this.verificaFormForCalculo = function(widget) {
        if(widget.isValid()) {
            this.openLoginValidation(widget);
        }
    };
    
    //Abre o relatório gerado
    this.abreRelatorio = function(widget, currentRow, reportName) {
        var row = angular.copy(currentRow);
        row.P_CDFILIALOL = row.CDFILIAL;
        if (row.NR_GERACAO) {
            row.P_NRLOGCORTEOL = row.NR_GERACAO;
        } else {
            row.P_NRLOGCORTEOL = '';
        }
        row.P_DTINICIAL = row.L_PER_LEV_PREV_CONS.start;
        row.P_DTFINAL = row.L_PER_LEV_PREV_CONS.end;
        row.P_DTINICIALAF = row.L_PER_LEV_AF.start;
        row.P_DTFINALAF = row.L_PER_LEV_AF.end;
        row.P_CDREGIAO = row.L_REGIAO ? Array.isArray(row.L_REGIAO) && row.L_REGIAO.length > 0 ? row.L_REGIAO.join('_') : 'T' : 'T';
        row.P_CDOPERADOR = row.L_COMPRADOR ? Array.isArray(row.L_COMPRADOR) && row.L_COMPRADOR.length > 0 ? row.L_COMPRADOR.join('_') : 'T' : 'T';
        row.P_CDPRODINIC = row.CDPRODINI;
        if(row.CDPRODFIN) {
            let concatString = row.CDPRODFIN.concat('ZZZZZZZZZZZZZZZZZZZZ');
            row.P_CDPRODFIN = concatString.substring(0, 20);
        } else {
            row.P_CDPRODFIN = 'ZZZZZZZZZZZZZZZZZZZZ';
        }
        row.P_GERACMP = 'N';
        row.P_ANALITICO = row.ANALITICO;
        row.STRATEGY = row.REPORT_NAME.split('.')[1];
        row.NRORG = getLocalVar('NRORG');
        row.reportLabel = '';
        General.openReport("opl_relatorios#/opl00900_relatorio", reportName, row).then(success => {}).catch(error => {
            MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
        });
    };
    
    //Abre o form para Login
    this.openLoginValidation = function(widget) {
        var DTINICIAL = widget.currentRow.L_PER_LEV_PREV_CONS.start;
        var DTFINAL = widget.currentRow.L_PER_LEV_PREV_CONS.end;
        var DTINICIALAF = widget.currentRow.L_PER_LEV_AF.start;
        var DTFINALAF = widget.currentRow.L_PER_LEV_AF.end;
        var NMOPERADOR = "";
        if(DTINICIAL != "" && DTFINAL != "" && widget.currentRow.L_COMPRADOR != "" && widget.currentRow.L_COMPRADOR !== `T` || DTINICIALAF != "" && DTFINALAF != "" && widget.currentRow.L_COMPRADOR != "" && widget.currentRow.L_COMPRADOR !== `T`) {
            if (widget.currentRow.L_COMPRADOR.length === 1) {
                General.callRestEngine("opl_relatorios#/compValidationListagemCorte", "Row", {
                    "CDCOMPRADOR": widget.currentRow.L_COMPRADOR[0],
                    "CDOPERADOR": getLocalVar('CDOPERADOR'),
                    "CDCENTCMP": adqParams.CDFILIAL
                }).then(function(response) {
                    if (response.dataset.passwordAut.PARAM === 'S') {
                        //Busca o nome do comprador e seta um nova string para o field NMOPERADOR
                        widget.getField("L_COMPRADOR").dataSource.data.forEach(function(item){
                            if(item.CDOPERADOR === widget.currentRow.L_COMPRADOR[0]){
                                NMOPERADOR = item.CDOPERADOR + ' | ' + item.NMOPERADOR;
                            }
                        });
                        widget.container.getWidget('LOGIN').currentRow.CDCOMPRADOR = widget.currentRow.L_COMPRADOR[0];
                        widget.container.getWidget('LOGIN').currentRow.CDOPERADOR = getLocalVar('CDOPERADOR');
                        widget.container.getWidget('LOGIN').getField('NMCOMPRADOR').setValue(NMOPERADOR);
                        ScreenService.openPopup(widget.container.getWidget('LOGIN'));
                    } else if(response.dataset.passwordAut.PARAM === 'N') {
                        MessageService.showMessageByCode("OPERADOR_NAO_AUTORIZADO_APURACAO_COMPRADOR", null, Constants.errorMessage);
                    }
                }).catch(function(error) {
                    ScreenService.showMessage(error.data ? error.data.error : messages.timeout, 'error', 'error');
                    widget.currentRow.CDCOMPRADOR = "";
                });
            } else {
                MessageService.showMessageByCode("INFORMAR_APENAS_UM_COMPRADOR", null, Constants.errorMessage);
            }
        } else {
            if(widget.currentRow.L_COMPRADOR == "" || widget.currentRow.L_COMPRADOR.length === 0 || widget.currentRow.L_COMPRADOR === `T`){
                MessageService.showMessageByCode("INFORMAR_UM_COMPRADOR", null, Constants.alertMessage);
            } else if (DTINICIAL == "" && DTFINAL == "" || DTINICIALAF == "" && DTFINALAF == "") {
                MessageService.showMessageByCode("INFORMAR_PERIODO_LEVANTAMENTO", null, Constants.alertMessage);
            }
        }
    };

    //Valida o Login
    this.loginValidation = function(widget) {
        if(!Util.isEmptyOrBlank(widget.currentRow.PASSWORD)){
            General.callRestEngine("opl_relatorios#/passwordValidation", "Row", widget.currentRow).then(function(response) {
                widget.currentRow = {};
                ScreenService.closePopup();
                //Chama a procedure 
                procedureCalcular();
            }).catch(function(error) {
                if(error.data.error === "Senha inválida"){
                    MessageService.showMessageByCode("INVALID_PASSWORD");
                } else {
                    ScreenService.showMessage(error.data.error);
                }
                widget.currentRow.PASSWORD = "";
            });
        } else {
            MessageService.showMessageByCode("INFORMAR_SENHA_LOGIN", null, Constants.alertMessage);
        }
    };
    
    //Executa procedure de Calcular
    var procedureCalcular = function() {
        var widget = templateManager.container.getWidget('opl00900');
        var dataCONS = widget.currentRow.L_PER_LEV_PREV_CONS;
        var dataAF = widget.currentRow.L_PER_LEV_AF;
        //Valida a data inicial de Consumo
        if(widget.currentRow.L_PER_LEV_PREV_CONS.formattedStart === '__/__/____'){
            dataCONS.start = '';
        }
        //Valida a data final de Consumo
        if(widget.currentRow.L_PER_LEV_PREV_CONS.formattedEnd === '__/__/____'){
            dataCONS.end = '';
        }
        //Valida a data inicial de AF
        if(widget.currentRow.L_PER_LEV_AF.formattedStart === '__/__/____'){
            dataAF.start = '';
        }
        //Valida a data final de AF
        if(widget.currentRow.L_PER_LEV_AF.formattedEnd === '__/__/____'){
            dataAF.end = '';
        }
        ScreenService.showLoader();
        General.callRestEngine("opl_relatorios#/getGeraCorteOL", "Row", {
            "P_CDCENTCMP": adqParams.CDFILIAL,
            "P_CDFILIOPELOG": widget.currentRow.CDFILIAL,
            "P_CDFILLANC": getLocalVar('CDFILIAL'),
            "P_CDOPERLANC": getLocalVar('CDOPERADOR'),
            "P_DTINICIAL": dataCONS,
            "P_DTFINAL": dataCONS,
            "P_DTINICIALAF": dataAF,
            "P_DTFINALAF": dataAF,
            "P_TIPOCONSULTA": '',
            "P_COMPRADOR": widget.currentRow.L_COMPRADOR[0],
            "P_CDREGIAO": widget.currentRow.L_REGIAO ? Array.isArray(widget.currentRow) && widget.currentRow.L_REGIAO.length > 0 ? widget.currentRow.L_REGIAO.join('_') : 'T' : 'T',
            "P_CDPRODINIC": widget.currentRow.CDPRODINI,
            "P_CDPRODFIN": (widget.currentRow.CDPRODFIN + "ZZZZZZZZZZZZZZZZZZZZ").substr(0, 20),
            "P_DTPROCESSA": getLocalVar('DTPROCESSA')
        }).then(function(response) {
            //Se o response for diferente de "NN"
            if(response.dataset.result[0] !== "NN"){
                //Armazena o P_NRSEQAPUR e P_ROWSAFFECT
                nr_log_corte_ol = response.dataset.result[0][1].P_NRSEQAPUR;
                response = response.dataset.result[0][0].P_ROWSAFFECT;
                //Cria um variavel Local
                setLocalVar('paramNRSEQAPUR', nr_log_corte_ol);
            } else {
                //Armazena o response
                response = response.dataset.result[0];
            }
            //Se foi response retornado "NN"
            if (response === "NN") {
                ZHPromise.all(MessageService.showMessageByCode("NAO_HA_DADOS_APURACAO_EFETIVACAO_OL", null, Constants.errorMessage)).then(function(){});
            } else {
                MessageService.confirmMessageByCode("QUESTION_VERIFICAR_INCONSISTENCIA_APURACAO_EFETIVACAO_OL", null, Constants.confirmationMessage).then(function(success) {
                    //Armazena os dados na aray de inconsistencia
                    dadosInconsistencia.P_CDFILIALOL = widget.currentRow.CDFILIAL;
                    dadosInconsistencia.P_CDOPERADOR = widget.currentRow.L_COMPRADOR[0];
                    dadosInconsistencia.P_CDFILCENTCMP = '';
                    dadosInconsistencia.P_NRAPURPREC = '';
                    if(widget.currentRow.L_PER_LEV_PREV_CONS.start !== ''){
                        dadosInconsistencia.P_DTINICIAL = widget.currentRow.L_PER_LEV_PREV_CONS.start;
                    } else if (widget.currentRow.L_PER_LEV_AF.start !== ''){
                        dadosInconsistencia.P_DTINICIAL = widget.currentRow.L_PER_LEV_AF.start;
                    } else {
                        dadosInconsistencia.P_DTINICIAL = '';
                    }
                    if(widget.currentRow.L_PER_LEV_PREV_CONS.end !== ''){
                        dadosInconsistencia.P_DTFINAL = widget.currentRow.L_PER_LEV_PREV_CONS.end;
                    } else if (widget.currentRow.L_PER_LEV_AF.end !== ''){
                        dadosInconsistencia.P_DTFINAL = widget.currentRow.L_PER_LEV_AF.end;
                    } else {
                        dadosInconsistencia.P_DTFINAL = '';
                    }
                    dadosInconsistencia.P_NRLOGCORTEOL = response.substr(1, 9);
                    widget.container.getWidget('opl00900').reload();
                    widget.container.getWidget('gridInconsistencia').reload();
                    ScreenService.openPopup(widget.container.getWidget('gridInconsistencia'));
                }, function(error) {
                    ScreenService.errorNotification(error, 'ERROR');
                });
                //Armazena o resultado da apuracao
                resultApuracao = response.substr(12,1);
            }
            //Se tem response OU se o result é maior que 12(em caracters) e a posição 12 da string é = "N"
            if (!response || response.length >= 13 && response.substr(11,1) === "N") {
                ZHPromise.all(MessageService.showMessageByCode("NAO_HA_DADOS_APURACAO_EFETIVACAO_OL", null, Constants.errorMessage)).then(function(){
                    //Abre a tela de apuração/Efet... OL
                    openWindowApuracaoEfetivacaoOL();
                });
            }
        }).catch(function(error) {
            MessageService.showMessageByCode("ERRO_AO_CALCULAR", null, Constants.errorMessage);
        });
        ScreenService.hideLoader();
    };
    
    //Monta o filtro do datasouce do grid de insconsistencia
    this.setDataSourceFilter = function(){
        var widgetInconsistencia = templateManager.container.getWidget('gridInconsistencia');
        var widgetOpl00900 = templateManager.container.getWidget('opl00900');
        widgetInconsistencia.dataSourceFilter = [
	        {
	            "name": "P_CDFILIALOL",
		        "operator": "=",
		        "value": dadosInconsistencia.P_CDFILIALOL
		    },
		    {
		        "name": "P_CDOPERADOR",
		        "operator": "=",
		        "value": dadosInconsistencia.P_CDOPERADOR
		    },
		    {
		        "name": "P_CDFILCENTCMP",
		        "operator": "=",
		        "value": dadosInconsistencia.P_CDFILCENTCMP
		    },
		    {
		        "name": "P_NRAPURPREC",
		        "operator": "=",
		        "value": dadosInconsistencia.P_NRAPURPREC
		    },
		    {
		        "name": "P_DTINICIAL",
		        "operator": "=",
		        "value": dadosInconsistencia.P_DTINICIAL
		    },
		    {
		        "name": "P_DTFINAL",
		        "operator": "=",
		        "value": dadosInconsistencia.P_DTFINAL
		    },
		    {
		        "name": "P_NRLOGCORTEOL",
		        "operator": "=",
		        "value": dadosInconsistencia.P_NRLOGCORTEOL
		    }
	    ];
	    ScreenService.showLoader();
	    widgetInconsistencia.reload();
	    widgetOpl00900.reload();
	    ScreenService.hideLoader();
    };
    
    //Seta a label do popup Relatório de Insonsistência
    this.setLabel = function(){
        var widgetOpl00900 = templateManager.container.getWidget('opl00900');
        var widgetInconsistencia = templateManager.container.getWidget('gridInconsistencia');
        setTimeout(() => {
            ScreenService.showLoader();
	        var data = widgetInconsistencia.groupedData[0];
	        MessageService.getMessageByCode('LABEL_POPUP_INSCONSISTENCIA').then(function(response){
                var label = response;
                //Replace das datas no label
                label = label.replace("__DT_CONS_INI__", widgetOpl00900.currentRow.L_PER_LEV_PREV_CONS.formattedStart);
    	        label = label.replace("__DT_CONS_FIN__", widgetOpl00900.currentRow.L_PER_LEV_PREV_CONS.formattedEnd);
    	        label = label.replace("__DT_AF_INI__", widgetOpl00900.currentRow.L_PER_LEV_AF.formattedStart);
    	        label = label.replace("__DT_AF_FIN__", widgetOpl00900.currentRow.L_PER_LEV_AF.formattedEnd);
                //Se foram encontrados dados, setam os seguitnes parametros    	        
                if(data !== undefined) {
                    if(data.CDFILIALOL){
                       label = label.replace("__CDFILIALOL__", data.CDFILIALOL);  
                    }
                    if(data.NMFILIALOL){
                       label = label.replace("__NMFILIALOL__", data.NMFILIALOL);  
                    }
                    if(data.CDOPERADOR){
                       label = label.replace("__CDOPERADOR__", data.CDOPERADOR);  
                    }
                    if(data.NMOPERADOR){
                       label = label.replace("__NMOPERADOR__", data.NMOPERADOR);  
                    }
                } else {
                    label = label.replace("__CDFILIALOL__", '');  
                    label = label.replace("__NMFILIALOL__", '');  
                    label = label.replace("__CDOPERADOR__", '');  
                    label = label.replace("__NMOPERADOR__", '');  
                }
                widgetInconsistencia.label = label;
                widgetInconsistencia.redraw();
                ScreenService.hideLoader();
            });
        }, 600);
    };
    
    //Chama a função que abre a tela de apuração;efetivação
    this.callFunctionOpenWindowApuracaoEfetivacaoOL = function() {
        openWindowApuracaoEfetivacaoOL('relatorio_inconsistencia_confimado');  
    };
    
    //Abre a tela de Apuração Efetivação do OL
    var openWindowApuracaoEfetivacaoOL = function (relatorio_inconsistencia_confimado){
        //Armazena o NMOPERADOR
        var NMOPERADOR = ""; 
        //Se o resultado da apuração for igual "N"
        if (resultApuracao === "N") {
            ZHPromise.all(MessageService.showMessageByCode("NAO_HA_DADOS_VERIFICAO_INCONSISTENCIA", null, Constants.errorMessage)).then(function(){});
        } else {
            var widgetOpl00900 = templateManager.container.getWidget('opl00900');
            //Define o comprador
            widgetOpl00900.getField("L_COMPRADOR").dataSource.data.forEach(function(item){
                if(item.CDOPERADOR === widgetOpl00900.currentRow.L_COMPRADOR[0]){
                    NMOPERADOR = item.CDOPERADOR + ' | ' + item.NMOPERADOR;
                }
            });
            //Se o processo anterior foi a exibição do relatõrio de inconsistencia
            if (relatorio_inconsistencia_confimado) {
                var filtro_apuracao_efetivacao = templateManager.container.getWidget('FILTER');
                var widgetInconsistencia = templateManager.container.getWidget('gridInconsistencia');
                var currentRowWidgetInconsistencia = widgetInconsistencia.dataSource.data[0];
                var produtos = [];
                var index = "";
                //Abre a tela de apuração/Efet... OL
                ScreenService.openWindow('opl_apuracaoEfetivacao#apuracao_efetivacao').then(function(){
                    //Widget do filtro
                    var filtro_apuracao_efetivacao = templateManager.container.getWidget('FILTER');
                    //Widget de cotação                
                    let widgetCotacao = templateManager.container.getWidget('widgetOldCot');
                    //Widget do STRIPE
                    let widgetStripe  = templateManager.container.getWidget('STRIPE');
                    setTimeout( () => {
                        //Preenche o filtro
                        filtro_apuracao_efetivacao.getField('CDCOMPRADOR').dataSourceFilter = [
                            {
                	            "name": "CDCOMPRADOR",
                		        "operator": "=",
                		        "value": widgetOpl00900.currentRow.L_COMPRADOR[0]
                		    }
                        ];
                        if(widgetOpl00900.currentRow.L_PER_LEV_AF.start !== ''){
                            filtro_apuracao_efetivacao.currentRow.DTENTREGA.start = widgetOpl00900.currentRow.L_PER_LEV_AF.start;
                        } else if (widgetOpl00900.currentRow.L_PER_LEV_PREV_CONS.start !== ''){
                            filtro_apuracao_efetivacao.currentRow.DTENTREGA.start = widgetOpl00900.currentRow.L_PER_LEV_PREV_CONS.start;
                        }
                        if(widgetOpl00900.currentRow.L_PER_LEV_AF.end !== ''){
                            filtro_apuracao_efetivacao.currentRow.DTENTREGA.end = widgetOpl00900.currentRow.L_PER_LEV_AF.end;
                        } else if (widgetOpl00900.currentRow.L_PER_LEV_PREV_CONS.end !== ''){
                            filtro_apuracao_efetivacao.currentRow.DTENTREGA.end = widgetOpl00900.currentRow.L_PER_LEV_PREV_CONS.end;
                        }
                        filtro_apuracao_efetivacao.getField('PRODUTOINI').dataSourceFilter = [
                            {
                	            "name": "NMPRODUTO",
                		        "operator": "=",
                		        "value": widgetOpl00900.currentRow.NMPRODINI
                		    }
                        ];  
                        filtro_apuracao_efetivacao.getField('PRODUTOFIN').dataSourceFilter = [
                            {
                	            "name": "NMPRODUTO",
                		        "operator": "=",
                		        "value": widgetOpl00900.currentRow.NMPRODFIN
                		    }
                        ]; 
                        filtro_apuracao_efetivacao.currentRow.CDREGIAO = widgetOpl00900.currentRow.L_REGIAO;
            			filtro_apuracao_efetivacao.currentRow.TODOS_PRODUTOS = 'N';
            			filtro_apuracao_efetivacao.currentRow.EXTRA = 'N';
                        //Habilita os fields de produtos
            			resetFieldProduto(filtro_apuracao_efetivacao.getField("LISTAFILIAL"));
            			resetFieldProduto(filtro_apuracao_efetivacao.getField("PRODUTOINI"));
            			resetFieldProduto(filtro_apuracao_efetivacao.getField("PRODUTOFIN"));
            			//Reload e setValue dos fields
            			ScreenService.showLoader();
                        filtro_apuracao_efetivacao.getField('CDCOMPRADOR').reload().then(function(response){
                            let resultCDCOMPRADOR = response.dataset.comprador_operador[0];
                            filtro_apuracao_efetivacao.getField('CDCOMPRADOR').setValue(resultCDCOMPRADOR.CDOPERADOR + " | " + resultCDCOMPRADOR.NMOPERADOR);
                            filtro_apuracao_efetivacao.currentRow.CDOPERADOR = resultCDCOMPRADOR.CDOPERADOR;
                        });
                        filtro_apuracao_efetivacao.getField('PRODUTOINI').reload().then(function(response){
                            let resultProdIni = response.dataset.produto[0];
                            filtro_apuracao_efetivacao.getField('PRODUTOINI').setValue(resultProdIni.NMPRODUTO);
                            filtro_apuracao_efetivacao.currentRow.CDPRODINI = resultProdIni.CDARVPROD;
                        });
                        filtro_apuracao_efetivacao.getField('PRODUTOFIN').reload().then(function(response){
                            let resultProdFin = response.dataset.produto[0];
                            filtro_apuracao_efetivacao.getField('PRODUTOFIN').setValue(resultProdFin.NMPRODUTO);
                            filtro_apuracao_efetivacao.currentRow.CDPRODFIN = resultProdFin.CDARVPROD;
                        });
                        if(widgetOpl00900.currentRow.L_REGIAO.length >= 1){
                            filtro_apuracao_efetivacao.getField('CDREGIAO').reload().then(function(response){
                                let resultCDREGIAO = response.dataset.regiao;
                                filtro_apuracao_efetivacao.getField('CDREGIAO').setValue(resultCDREGIAO);
                                filtro_apuracao_efetivacao.currentRow.CDREGIAO = widgetOpl00900.currentRow.L_REGIAO;
                            });
                        }
                        //Fecha o filtro
                        ScreenService.closePopup();
                        //Preenche o STRIPE
                        var widgetSTRIPE = templateManager.container.getWidget('STRIPE').currentRow;
                        widgetSTRIPE.CDPRODUTO = "";
                        widgetSTRIPE.NMPRODUTO = "";
                        widgetSTRIPE.NMOPERADOR = NMOPERADOR;
                        if(widgetOpl00900.currentRow.L_PER_LEV_AF.start !== ''){
                            widgetSTRIPE.DTINI = widgetOpl00900.currentRow.L_PER_LEV_AF.start;
                        } else if (widgetOpl00900.currentRow.L_PER_LEV_PREV_CONS.start !== ''){
                            widgetSTRIPE.DTINI = widgetOpl00900.currentRow.L_PER_LEV_PREV_CONS.start;
                        }
                        if(widgetOpl00900.currentRow.L_PER_LEV_AF.end !== ''){
                            widgetSTRIPE.DTFIN = widgetOpl00900.currentRow.L_PER_LEV_AF.end;
                        } else if (widgetOpl00900.currentRow.L_PER_LEV_PREV_CONS.end !== ''){
                            widgetSTRIPE.DTFIN = widgetOpl00900.currentRow.L_PER_LEV_PREV_CONS.end;
                        }
                        //Verifica o operador
                        General.callRestEngine("opl_apuracaoEfetivacao#/qryAutGrupOp", "Row", { 'CDOPERADOR': getLocalVar("CDOPERADOR") }).then(function(response) {
                            if (response.dataset.qryAutGrupOp.PARAM != 'S') {
                                MessageService.showMessageByCode("OPR_SEM_PERMISSAO_ESC_PRECO");
                                widgetCotacao.getField('IDITMSELAPUR').events = [];
                            }
                        }.bind(this));
                        //Busca os produtos
                        General.callRestEngine("opl_apuracaoEfetivacao#/crud/adqProduto", "FilterData", [
                            {
                                'name': 'P_CDCENTCMP',
                                'operator': 'IN',
                                'value': adqParams.CDFILIAL
            				},
                            {
                                'name': 'P_NRSEQAPUR',
                                'operator': 'IN',
                                'value': nr_log_corte_ol
            				}
            			]).then(function(response) {
            			    //Armazena os dados
                            produtos = response.dataset.adqProduto;
                            //Seta os dados em uma variável no local storage
                            setLocalVar('dadosAdqProduto', produtos);
                            console.log(getLocalVar('dadosAdqProduto'));
                            //Seta o index como "0"
                            index = 0;
                            if(produtos.length >= 1){
                                this.setCotacaoWithParams();    
                            } else {
                                let mensagem = 'Não há dados a serem listados para essa apuração.';
                                ScreenService.showMessage(mensagem);
                            }
                        }.bind(this));
                        setVisibleActions(widgetCotacao, true);
                        widgetCotacao.reload();
                        widgetStripe.actions.forEach(function(value, index) {
                            widgetStripe.actions[index].isVisible = true;
                        }.bind(this));
                        
                        /* Faz uma requisição em 'Cotação' filtrando com o produto selecionado
                        * no 'STRIPE'.
                        */
                        function getCotacoes() {
                            templateManager.container.getWidget('STRIPE').currentRow.CDPRODUTO = produtos[index].CDARVPROD;
                            templateManager.container.getWidget('STRIPE').currentRow.NMPRODUTO = produtos[index].NMPRODUTO;
                            //Retorna os dados da cotação
                            return General.callRestEngine("opl_apuracaoEfetivacao#/adqCotacao", "Row", {
                                'P_CDCENTCMP': adqParams.CDFILIAL,
                                'P_CDPRODESTO': produtos[index].CDPRODUTO,
                                'P_NRSEQAPUR': nr_log_corte_ol,
                                'P_CDFILIOPELOG': adqParams.CDFILIAL
                            }).then(function(response){
                                const widgetCotacao = templateManager.container.getWidget('widgetOldCot');
                                var widProd = templateManager.container.getWidget('PRODUTOS');
                                widgetCotacao.activate();
                                widgetCotacao.dataSource.setData(response.dataset.cotacao[0]);
                                widProd.dataSource.setData(produtos);
                                widgetCotacao.reload();
                                widProd.reload();
                                widProd.redraw();
                                if (widgetCotacao.dataSource.data.VRPRECUNIAP == 0) {
                                    MessageService.showMessageByCode("PRECO_UNIT_INFORMADO");
                                }
                            }).catch(function(error) {
                                ScreenService.showMessage(error.data ? error.data.error : messages.timeout, 'error', 'error');
                            }); 
                        }
                        
                        this.setCotacaoWithParams = function() {
                            return getCotacoes();
                        };
                        
                        ScreenService.hideLoader();
                    }, 2000);
                });
            }
        }
    };
    
    //Reseta os Fields de Produto
    var resetFieldProduto = function(field) {
        field.readOnly = false;
		deepClearField(field);
		if (field.widget.currentRow.$error) {
        	delete field.widget.currentRow.$error[field.name];
		}
		if (field.name === 'PRODUTOINI' || field.name === 'PRODUTOFIN'){
    		field.validations = {};
		}
    };
    
    //Clear Field
    var deepClearField = function(field) {
        field.clearValue();
    };
    
    //Deixa os actions visiveis
    function setVisibleActions(widget, isVisible, exceptions = []) {
        widget.actions
            .filter(action => !exceptions.includes(action.name))
            .forEach(action => action.isVisible = isVisible);
    }

}

Configuration(function(ContextRegister){
    ContextRegister.register("opl00900_listagem_de_corteController", opl00900_listagem_de_corteController);
});



// FILE: ./assets/modules/documentosFiscais/assets/js/controllers/Dfs72000_EntradaDevolucoesOperadorLogistico_Controller.js
var Dfs72000_EntradaDevolucoesOperadorLogistico_Controller = function(Dfs72000_EntradaDevolucoesOperadorLogistico_Service, MessageService, ScreenService, templateManager, General, localStorageEngine, ZhFilterPreferences){
    
    this.alteraReadOnlyFilhos = function(field, desbloqueiaComValor = true) {
        let widget = field.widget;
        field.filhos.forEach((filho) => {
            let filhoField = widget.getField(filho);
            filhoField.readOnly =  ((field.value() == "") == desbloqueiaComValor);
            if(((field.value() == "") == desbloqueiaComValor)) widget.currentRow[filho] = "";
            if(filhoField.filhos) this.alteraReadOnlyFilhos(filhoField, true);
            widget.getField(filho).reload();
        });
    };
    
    this.preparaFiltro = function(widget) {
        let currentRow = widget.appliedFilter.FILTER_ROW;
        widget.dataSourceFilter = Dfs72000_EntradaDevolucoesOperadorLogistico_Service.buildFilter(["CDOPERLOG", "CDFILIAL", "CDSERIE", "NRNOTAFISC"], currentRow);
        widget.dataSourceFilter.push({name: "P_DTINI", operator: "=", value: currentRow.DTENTRSAID.start});
        widget.dataSourceFilter.push({name: "P_DTFIN", operator: "=", value: currentRow.DTENTRSAID.end});
        widget.reload();

    };
    
    this.openPopup = function() {
        var widgetDevolucao = templateManager.container.getWidget('dadosDevolucao');
        widgetDevolucao.currentRow.CDTIPOOPER = '';
        widgetDevolucao.currentRow.NMTIPOOPER = '';
        widgetDevolucao.currentRow.CDSERIE = '';
        widgetDevolucao.currentRow.DSSERIE = '';
        General.callRestEngine("opl#/crud/paramgeral", "FilterData", []).then((success) => {
            if(success.dataset.paramgeral[0].IDUTSERTPOP == 'S') {
                widgetDevolucao.getField('DSSERIE').isVisible = true;
                widgetDevolucao.getField('DSSERIE').readOnly  = true;
                widgetDevolucao.getField('NMTIPOOPER').events  = [{
                        "name": "FieldOnChange",
                        "code": "Dfs72000_EntradaDevolucoesOperadorLogistico_Controller.tipoOperOnChange(args.owner.field);"
                }];
            }
            else {
                widgetDevolucao.getField('DSSERIE').isVisible = false;
                widgetDevolucao.getField('NMTIPOOPER').events  = [];
            }
            
            Dfs72000_EntradaDevolucoesOperadorLogistico_Service.getDtProcessa().then(
                (data) => {
                    widgetDevolucao.currentRow.DTSAIDA = moment().format("DD/MM/YYYY");
                    widgetDevolucao.isVisible = true;
                    ScreenService.openPopup(widgetDevolucao);
                    widgetDevolucao.activate();
                }
            );
            
        });
        
    };
    
    this.blockFieldsFilhosAndSetEvents = function(widget, filter = true) {
        let fields = widget.fields;
        fields.forEach((field) => {
            if(field.filhos) {
                field.events.push(
                    {
                        "name": "FieldOnChange",
                        "code": "Dfs72000_EntradaDevolucoesOperadorLogistico_Controller.alteraReadOnlyFilhos(args.owner.field)"
                    }
                );
                field.filhos.forEach((filho) => {
                    field = widget.getField(filho);
                    if(!field.filterProperties) widget.filterProperties = {};
                    if(filter)  field.filterProperties.readOnly = true; 
                    else  widget.getField(filho).readOnly = true; 
                });
            }
        });
    };
    
    this.gerarDevolucao = function(widget) {
        if(widget.isValid()) {
            localStorageEngine.getDataSource('opl#/crud/dadosAdic').then((success) => {
                var dadosAdicionais = success;
                var widgetNota       = templateManager.container.getWidget('devolucao_transfOpLogistico');
                var notas = widgetNota.getCheckedRows();
                var data = {
                    notas: notas,
                    dadosGeracao: widget.currentRow,
                    dadosAdicionais: dadosAdicionais
                };
                
                
            });
        }
    };
    
    this.tipoOperOnChange = function(field) {
        var serie = field.widget.getField('DSSERIE');
        if(field.value()) {
            serie.dataSourceFilter[0].value = field.widget.getParent().getParent().appliedFilter.FILTER_ROW.CDFILIAL;
            serie.dataSourceFilter[1].value = field.widget.currentRow.CDTIPOOPER;
            serie.readOnly  = false;
        }
        else {
            serie.readOnly  = true;
        }
    };
    
    
    this.verificaReloadWidget = function(widget) {
        if(widget.inlineEditSave == false) widget.reload(); 
    };
    
    this.closePopup = function(widget, widgetClose) {
        widget.isVisible = false;
        widget.dataSource.data = [];
        ScreenService.closePopup(widget);
        widgetClose = templateManager.container.getWidget(widgetClose);
        widgetClose.activate();
        widgetClose.reload();
        ScreenService.closePopup();
    };
    
    this.setDefaultFilter = function(widget) {
        localStorageEngine.setDataSource('opl#/crud/dadosAdic', []);
        Dfs72000_EntradaDevolucoesOperadorLogistico_Service.getFilial().then((success) => {
            var row = Util.clone(widget.currentRow);
            if(success.dataset.filial[0].IDFUNCAOFILI == 'O') {
                row.CDOPERLOG = success.dataset.filial[0].CDFILIAL;
                row.NMOPERLOG = success.dataset.filial[0].NMFILIAL;
            }
            else {
                row.CDFILIAL = success.dataset.filial[0].CDFILIAL;
                row.NMFILIAL = success.dataset.filial[0].NMFILIAL;
            }
            var dataAtual = formatarData(new Date());
            row.DTENTRSAID = {start : dataAtual, end : dataAtual};
            
            ZhFilterPreferences.setOriginalFilter(widget.id, row);
            ZhFilterPreferences.openFilterWidget(widget, row);
        },
        (error) => {
            ZhFilterPreferences.openFilterWidget(widget);
            console.log(error);
        });
    };
    
    this.openPopupErros = function(errosGeracao) {
        var widgetErros = templateManager.container.getWidget('errosGeracao');
        widgetErros.dataSource.data = errosGeracao;
        widgetErros.isVisible = true;
        ScreenService.openPopup(widgetErros);
        widgetErros.activate();
    };
    
    this.deleteDadosAdic = function(widget) {
        localStorageEngine.getDataSource('opl#/crud/dadosAdic').then(
            (dataLocal) =>  {
                dataLocal = dataLocal.map((row) => {
                    if(!(row.CDMENSAGEM == widget.currentRow.CDMENSAGEM && row.DSMENSAGEM == widget.currentRow.DSMENSAGEM && row.CDFILIAL   == widget.currentRow.CDFILIAL && row.NRLANCTONF   == widget.currentRow.NRLANCTONF)) return row;
                });
                localStorageEngine.setDataSource('opl#/crud/dadosAdic', dataLocal).then(() => {
                    ScreenService.goBack();
                    widget.reload();
                });
            }
        );
    };
    
    // Salvar o produto
    this.saveProdutos = function(widget) {
        widget.dataSource.data.forEach((produto) => {
            if(produto.changed) {
                if(Number(produto.QTDEVOLUCAOOL) == 0 || !produto.QTDEVOLUCAOOL ) {
                    ScreenService.showMessage("Quantidade devolvida deve ser maior que 0. " + produto.NMPRODUTO);
                }
                else if(Number(produto.QTDEVOLUCAOOL) > Number(produto.QTITEMPROD)) {
                    ScreenService.showMessage("Quantidade devolvida não pode ser maior que a quantidade original do produto. " + produto.NMPRODUTO);
                }
                else if(!produto.NMMOTIVODEV) {
                    ScreenService.showMessage("Motivo da devolução deve ser informado. " + produto.NMPRODUTO);
                }
                else {
                    General.callRestEngine("df#/crud/itemproduto/save", "Row", produto).then(function() {
                        widget.reload();
                        delete produto.changed_QTDEVOLUCAOOL;
                        delete produto.changed_NMMOTIVODEV;
                        delete produto.changed_CDMOTIVODEV;
                        delete produto.QTDEVOLUCAOOL_inline;
                        delete produto.NMMOTIVODEV_inline;
                        delete produto.CDMOTIVODEV_inline;
                        produto.changed = false;
                        widget.list();
                    });
                }
            
            }
        });
        
        
    };
    
    function formatarData(data) {
        var d = new Date(data),
        mes = '' + (d.getMonth() + 1),
        dia = '' + d.getDate(),
        ano = d.getFullYear();
    
        if (mes.length < 2) mes = '0' + mes;
        if (dia.length < 2) dia = '0' + dia;
    
        return [dia, mes, ano].join('/');
    }
    
    this.saveDadosAdic = function(widget) {
        var existe = false;
        if(widget.isValid()) {
            localStorageEngine.getDataSource('opl#/crud/dadosAdic').then(
                (dataLocal) =>  {
                    var insertRow = {CDMENSAGEM: widget.currentRow.CDMENSAGEM, 
                                    DSMENSAGEM: widget.currentRow.DSMENSAGEM,
                                    CDFILIAL:  widget.getParent().currentRow.CDFILIAL,
                                    NRLANCTONF: widget.getParent().currentRow.NRLANCTONF
                    };
                    if(widget.currentRow.__is_new) {
                        dataLocal.map(
                            (row) => {
                                if(row.CDMENSAGEM == widget.currentRow.CDMENSAGEM && row.DSMENSAGEM == widget.currentRow.DSMENSAGEM && row.CDFILIAL   == widget.getParent().currentRow.CDFILIAL && row.NRLANCTONF   == widget.getParent().currentRow.NRLANCTONF)
                                existe = true;
                            }        
                        );
                        if(!existe) {
                            dataLocal.push(insertRow);
                        }
                    }
                    else {
                        dataLocal = dataLocal.map((row) => {
                            if(row.CDMENSAGEM == widget.backupRow.CDMENSAGEM && row.DSMENSAGEM == widget.backupRow.DSMENSAGEM && row.CDFILIAL   == widget.backupRow.CDFILIAL && row.NRLANCTONF   == widget.backupRow.NRLANCTONF) {
                                return insertRow;
                                }
                            else if(row.CDMENSAGEM == widget.currentRow.CDMENSAGEM && row.DSMENSAGEM == widget.currentRow.DSMENSAGEM && row.CDFILIAL     == widget.getParent().currentRow.CDFILIAL && row.NRLANCTONF   == widget.getParent().currentRow.NRLANCTONF) {
                                existe = true;
                            }
                            else return row;
                        });
                    }
                    if(!existe) {
                        localStorageEngine.setDataSource('opl#/crud/dadosAdic', dataLocal).then(() => {
                            ScreenService.goBack();
                            widget.reload();
                        });
                    }
                    else ScreenService.showMessage("Registro já existe.");
                }
            );
        }
    };
    
    this.limpaMensagem = function(widget) {
        var cdMensagem = widget.getField('CDMENSAGEM');
        if(cdMensagem.value()) {
            cdMensagem.setValue('');
            cdMensagem.reload();
        }
    };

    this.verificaItem = function(field, args) {
        var widget = field.widget;
        if(field.widget.currentRow.IDDEVOLVIDO == 'S') {
            widget.currentRow[field.name+'_inline'] = widget.currentRow[field.name];
            ScreenService.showMessage("Operação bloqueada. Item já utilizado para devolução do produto.");
        }
    };

};

Configuration(function (ContextRegister){
    ContextRegister.register('Dfs72000_EntradaDevolucoesOperadorLogistico_Controller', Dfs72000_EntradaDevolucoesOperadorLogistico_Controller);
});


// FILE: ./assets/modules/apuracaoEfetivacao/assets/js/controllers/ApuracaoEfetivacaoController.js
function ApuracaoEfetivacaoController(General, ScreenService, MessageService, templateManager, maskEngine, ZhUtil, ZHPromise, Utilities, Cmp03900_LancamentoAutorizacaoDeFornecimento_Service, metaDataFactory, restEngine, ZhFilterPreferences) {
     /*global Constants*/
    var ServiceLancamentoAF = Cmp03900_LancamentoAutorizacaoDeFornecimento_Service;
    let param;
    let index;
    let produtos = [];
    let idjustificativa;
    let podeAbrirInformacao;
    let messages = {
        errosApuracao: "Erros na Apuração",
        timeout: "Tempo limite de conexão excedido."
    };
    let allEntregas;

    /*************************************************************************************/
    /*                           FUNÇÕES GERAIS E DE VALIDAÇÃO                           */
    /*************************************************************************************/

    /*
     * Define a "Central de Filial" e os parâmetros para visualizção de componentes da tela.
     * A visualização campo 'SCCOMPRAS' do filtro e as informações de 'Produtos' 
     * no Stripe.
     */
    this.getParams = function() {
        General.callRestEngine("opl_autorizacaoFornecimento#/getParams", "Row", {}).then(function(response) {

            this.idjustificativa = response.dataset.getParams[1][0].IDEXJUSTESCM;
            var idsisdos = response.dataset.getParams[1][0].IDSISDOS;
            var paramApurExtra = response.dataset.getParams[1][0].IDAPUREFESOLEXT;
            var paramProd = response.dataset.getParams[2][0].IDCONSPRSOL;

            var widgetFilter = templateManager.container.getWidget('FILTER');
            var vrunitario = templateManager.container.getWidget('widgetOldCot').getField('VRPRECUNIAP');
            var widgetStripe = templateManager.container.getWidget('STRIPE');

            setLocalVar('NMFILCENTCMP', response.dataset.getParams[0][0].NMFILCENTCMP);
            setLocalVar('CDFILCENTCMP', response.dataset.getParams[0][0].CDFILCENTCMP);

            if (paramApurExtra == 'N') {
                widgetFilter.getField('EXTRA').isVisible = false;
                widgetFilter.getField('EXTRA').validations = {
                    'required': false
                };
            }

            if (idsisdos == 3) {
                vrunitario.inlineEditable = false;
            }

            this.openFilter();
            
        }.bind(this));
    };

    this.getRow = function(widget) {
        return angular.copy(widget.currentRow);
    };

    this.removeClass = function(element, className) {
        $(element).removeClass(className);
    };

    this.removeColor = function(args) {
        var row = this.getRow(args);
        args.owner.widget.setCurrentRow(row);
        this.removeClass('.lineImportant', 'currentRow');
    };
    
    this.backFromSwipe = function() {
        ScreenService.closeSwipe();
    };
    
    this.backFromPopup = function() {
        ScreenService.closePopup();
    };
    
    /**
     * Retorna a concatenação do array passado pro parâmetro. 
     * @param {Array} arr - array a ser concanetado.
     * @param {string} defaultValue - Valor a ser retornado caso o arr esteja
     * vazio ou em branco.
     * @returns {string} Array concatenado ou o defaultValue passado por
     * parâmetro. Se não houver defaultValue, retorna 'T'.
     */
    function concatArrayForParams(arr, defaultValue = 'T') {
       return !Util.isEmptyOrBlank(arr) ? arr.join('_') : defaultValue;
    }

    function getEventFromWidget(widget, eventName) {
        return widget.events.filter(event => { return event.name === eventName; })[0];
    }
    
    function setCodeOnEventWidgetAfterMoveRow(eventCode) {
        const event = getEventFromWidget(templateManager.container.getWidget('widgetOldCot'), 'WidgetAfterMoveRow');
        
        event.code = eventCode;
    }
    
    this.removeOpenPorEntregaFromWidgetAfterMoveRow = function() {
        const eventCode = "ApuracaoEfetivacaoController.removeClass('.lineImportant', 'currentRow');";
        
        setCodeOnEventWidgetAfterMoveRow(eventCode);
    };
    
    this.addOpenPorEntregaOnWidgetAfterMoveRow = function() {
        const eventCode = "ApuracaoEfetivacaoController.openPorEntrega();ApuracaoEfetivacaoController.removeClass('.lineImportant', 'currentRow');";
        
        setCodeOnEventWidgetAfterMoveRow(eventCode);
    };
    
    function isActionOfInlineEdit(action) {
        return action.showAsAction === 'back_inline_edit' || action.showAsAction === 'never_inline_edit';
    }
    
    function turnActionVisible(action) {
        action.isVisible = true;
    }
    
    function getEditableFields(widget) {
		return widget.fields.filter(function(field) {
			return field.inlineEditable;
		});
	}
    
    function actionsAfterInlineEditOperation(widgetCotacao) {
        widgetCotacao.inlineEditing = false;
		widgetCotacao.list();
		widgetCotacao.actions.filter(isActionOfInlineEdit).map(turnActionVisible);
    }
    
    function removeChangedPropertiesFromRow(widgetCotacao) {
        let editableFields = getEditableFields(widgetCotacao);
        
		widgetCotacao.dataSource.data.forEach(function(row) {
			editableFields.forEach(function(field) {
				if (row.hasOwnProperty('changed_' + field.name)) {
					delete row['changed_' + field.name];
				}
			});
			delete row.changed;
		});
    }
    
    function transferRowData(originRow, destinyRow) {
        for (let property in originRow) {
			destinyRow[property] = originRow[property];
		}
    }
    
    this.permiteExecutarOpenInformacao = function() {
        podeAbrirInformacao = true;
    };
    
    function setProdutos() {      
        let dadosAdqProduto = getLocalVar('dadosAdqProduto');
        //Se a var produtos estiver vazia, seta-a com os produtos
        if(dadosAdqProduto !== undefined && produtos.length == 0){
            produtos = dadosAdqProduto;
            index = 0;
        }
    }
    
    function setParam() {
        let paramNRSEQAPUR = getLocalVar('paramNRSEQAPUR');
        //Se a var param for vazia, seta-a
        if(paramNRSEQAPUR !== undefined && param === undefined){
            param = paramNRSEQAPUR;
        }
    }
    
    /**
     * Função responsável por simular o funcionamento que evita que um evento
     * específico do WidgetAfterMoveRow fosse acionado ao clicar no field.
     * 
     * Originalmente, este recurso foi implementado utilizando a seguinte composição de eventos:
     * - FieldOnClick do field VRPRECUNIAP, acionando a função removeEventFromWidgetAfterMoveRow;
     * - WidgetBeforeInlineEditMoveRow da widget widgetOldCot, acionando a função addEventInWidgetAfterMoveRow.
     * 
     * Para simular, foi utilizada uma promise.
     */
    this.changeEventCodeWidgetAfterMoveRow = function() {
        let deferred = ZHPromise.defer();
        
        setCodeOnEventWidgetAfterMoveRow("ApuracaoEfetivacaoController.updateApuracao()");
        deferred.resolve();
        
        return deferred.promise.then(() => { this.addOpenPorEntregaOnWidgetAfterMoveRow(); });
    };
    
    /*************************************************************************************/
    /*                                 FUNÇÕES DO FILTRO                                 */
    /*************************************************************************************/

    this.openLoginValidation = function(widget) {
        if(widget.currentRow.CDCOMPRADOR != "") {
            General.callRestEngine("opl_apuracaoEfetivacao#/compValidation", "Row", {
                "CDCOMPRADOR": widget.currentRow.CDOPERADOR,
                "CDOPERADOR": getLocalVar('CDOPERADOR'),
                "CDCENTCMP": getLocalVar('CDFILCENTCMP')
            }).then(function(response) {
                if (response.dataset.passwordAut.PARAM === 'S') {
                    widget.container.getWidget('LOGIN').currentRow.CDCOMPRADOR = widget.currentRow.CDCOMPRADOR;
                    widget.container.getWidget('LOGIN').currentRow.CDOPERADOR = widget.currentRow.CDOPERADOR;
                    ScreenService.openPopup(widget.container.getWidget('LOGIN'));
                }
            }).catch(function(error) {
                ScreenService.showMessage(error.data ? error.data.error : messages.timeout, 'error', 'error');
                widget.currentRow.CDCOMPRADOR = "";
            });
        }
    };

    this.loginValidation = function(widget) {
        if(!Util.isEmptyOrBlank(widget.currentRow.PASSWORD)){
            General.callRestEngine("opl_apuracaoEfetivacao#/passwordValidation", "Row", widget.currentRow).then(function(response) {

                widget.currentRow = {};
                ScreenService.closePopup();
    
            }).catch(function(error) {
    
                ScreenService.showMessage(error.data.error);
                widget.currentRow.PASSWORD = "";
            });    
        } else {
            MessageService.showMessageByCode("INFORME_SENHA");
        }
    };

    this.openFilter = function() {
        var popupWidget = templateManager.container.getWidget('FILTER');
        
        popupWidget.getField('DTENTREGA').defaultValue = {
            start: moment().format('DD/MM/YYYY'),
            end: moment().format('DD/MM/YYYY')
        };
        
        ServiceLancamentoAF.retornaComprador().then(function(callback) {
            const comprador = callback.dataset.comprador_operador;
            if (comprador.length) {
                const codigoComprador = comprador[0].CDOPERADOR;
                const nomeComprador = comprador[0].NMOPERADOR;
                const fieldComprador = popupWidget.getField('CDCOMPRADOR');
                fieldComprador.reload().then(() => {
                    ScreenService.openPopup(popupWidget);
                    popupWidget.newRow();
                    popupWidget.currentRow.CDOPERADOR = codigoComprador;
                    popupWidget.currentRow.CDCOMPRADOR = codigoComprador + ' | ' + nomeComprador;
                    if (popupWidget.inEditMode()) {
                        popupWidget.newRow = function() {}; //Faz o newRow ser executado apenas uma vez
                    }
                });
            } else {
                ScreenService.openPopup(popupWidget);
                popupWidget.newRow();
                if (popupWidget.inEditMode()) {
                    popupWidget.newRow = function() {};
                }
            }
        }, function(err) {
            ScreenService.showMessage(err.data.error);
            ScreenService.openPopup(popupWidget);
            popupWidget.newRow();
            if (popupWidget.inEditMode()) {
                popupWidget.newRow = function() {};
            }
        });
    };
    
    function isProdutoValido(currentRow) {
        return General.comparaPratoProduto(currentRow.CDPRODINI, currentRow.CDPRODFIN, getLocalVar('CDPICTPROD'));
    }

    /* Apura os produtos de acordo com os parâmetros passados no popup.
     * 
     * Seta os campos do stripe com os parâmetros do primeiro produto a ser exibido.
     * Defini os parâmetros locais a serem passados na requisição.
     */
    this.applyFilter = function(widget) {
        if (widget.isValid()) {
            if (isProdutoValido(widget.currentRow)) {
                widget.container.getWidget('STRIPE').currentRow = {
                    'CDPRODUTO': "",
                    'NMPRODUTO': "",
                    'NMOPERADOR': widget.currentRow.CDCOMPRADOR,
                    'DTINI': widget.currentRow.DTENTREGA.start,
                    'DTFIN': widget.currentRow.DTENTREGA.end
                };
                
                widget.currentRow.FILIPROC = getLocalVar('CDFILIAL'); //FILIAL LOGADA
                widget.currentRow.CDOPERADORLOG = getLocalVar('CDOPERADOR'); //OPERADOR LOGADO
                widget.currentRow.CDFILIAL = getLocalVar('CDFILIAL'); //FILIAL LOGADA
    
                this.loadProdutos(widget);
            } else {
                MessageService.showMessageByCode("PRODUTO_INICIAL_MENOR_IGUAL_FINAL");
            }
        }
    };
    
    this.limpaCampoUnidades = function() {
        templateManager.container.getWidget('FILTER').getField('LISTAFILIAL').clearValue();
    };

    function updateConditionOnDataSourceFilter(params) {
        const { field, widget, conditionName, operator, newValue, cleaningOperation } = params;

        if (!Util.isEmptyOrBlank(widget.currentRow[conditionName])) {
            const regionCondition = field.dataSourceFilter.filter(filtro => filtro.name == conditionName);

            if (regionCondition.length) {
                regionCondition[0].value = newValue;
            } else {
                field.dataSourceFilter.push({
                    name: conditionName,
                    operator,
                    value: newValue,
                });
            }
        } else {
            cleaningOperation(field, conditionName);
        }
    }

    /* Define as regras para o filtro do campo "Unidades" de acordo
     * com os campos "Regiao" e "Agrupamento de Unidades".
     */
    this.filterUnidades = function(widget) {
        const field = widget.getField('LISTAFILIAL');
        const params = {
            field,
            widget,
        };
        
        params.conditionName = 'CDREGIAO';
        params.operator = 'IN';
        params.newValue = widget.currentRow.CDREGIAO;
        params.cleaningOperation = (field, conditionName) => field.dataSourceFilter = field.dataSourceFilter.filter(filtro => filtro.name != conditionName);
        
        updateConditionOnDataSourceFilter(params);
        
        params.conditionName = 'CDGRUPFILI';
        params.operator = '=';
        params.newValue = concatArrayForParams(widget.currentRow.CDGRUPFILI);
        params.cleaningOperation = (field, conditionName) => {
            const condition = field.dataSourceFilter.filter(filtro => filtro.name == conditionName)[0];

            condition.value = 'T';
        };
        
        field.reload();
    };
    
    function resetFieldProduto(field) {
        field.readOnly = true;
		field.validations = {};
		deepClearField(field);
		if (field.widget.currentRow.$error) {
        	delete field.widget.currentRow.$error[field.name];
		}
    }
    
    function activateFieldProduto(field) {
        field.readOnly = false;
		field.validations = {
			required: true
		};
    }
    
    this.onChangeTodosProdutosAComprar = function() {
        const widgetFilter = templateManager.container.getWidget('FILTER');
        const fieldTodosProdutos = widgetFilter.getField('TODOS_PRODUTOS');
        const fieldProdutoInicial = widgetFilter.getField('PRODUTOINI');
        const fieldProdutoFinal = widgetFilter.getField('PRODUTOFIN');
        
        if (fieldTodosProdutos.checked) {
			resetFieldProduto(fieldProdutoInicial);
			resetFieldProduto(fieldProdutoFinal);
		} else {
			activateFieldProduto(fieldProdutoInicial);
			activateFieldProduto(fieldProdutoFinal);
		}
    };

    this.nextProduto = function() {
        setProdutos();
        console.log(produtos);
        if (index != produtos.length - 1) {
            index++;
            this.setCotacaoWithParams();
        }
    };

    this.previousProduto = function() {
        setProdutos();
        console.log(produtos);
        if (index != 0) {
            index--;
            this.setCotacaoWithParams();
        }
    };
    
    function setVisibleActions(widget, isVisible, exceptions = []) {
        widget.actions
            .filter(action => !exceptions.includes(action.name))
            .forEach(action => action.isVisible = isVisible);
    }

    /*************************************************************************************/
    /*                                 FUNÇÕES 'PRODUTOS'                                */
    /*************************************************************************************/

    /* Roda procedure que retorna dois valores para parametrização dos produtos
     * que serão apurados e em seguida faz a requisição dos produtos de acordo
     * com os parametros recebidos.
     */
    this.loadProdutos = function(widget) {
        ScreenService.confirmMessage("Confirma apuração de dados para efetivação de AF's?",  'question', function(success) {
            let row = angular.copy(widget.container.getWidget('FILTER').currentRow);
        
            row.CDPRODINI = row.CDPRODINI || '';
            row.CDPRODFIN = row.CDPRODFIN || '';
            
            General.callRestEngine("opl_apuracaoEfetivacao#/apuracao", "Row", row).then( function(response) {
                let widgetCotacao = templateManager.container.getWidget('widgetOldCot');
                let widgetStripe  = templateManager.container.getWidget('STRIPE');
                
                param = response.dataset.param[0].P_NRSEQAPUR;
                
                General.callRestEngine("opl_apuracaoEfetivacao#/qryAutGrupOp", "Row", { 'CDOPERADOR': getLocalVar("CDOPERADOR") }).then(function(response) {
                    if (response.dataset.qryAutGrupOp.PARAM != 'S') {
                        MessageService.showMessageByCode("OPR_SEM_PERMISSAO_ESC_PRECO");
                        widgetCotacao.getField('IDITMSELAPUR').events = [];
                    }
                }.bind(this));
    
                General.callRestEngine("opl_apuracaoEfetivacao#/crud/adqProduto", "FilterData", [
                    {
                        'name': 'P_CDCENTCMP',
                        'operator': 'IN',
                        'value': getLocalVar('CDFILCENTCMP')
    				},
                    {
                        'name': 'P_NRSEQAPUR',
                        'operator': 'IN',
                        'value': param
    				}
    			]).then(function(response) {
                    produtos = response.dataset.adqProduto;
                    index = 0;
                    this.setCotacaoWithParams();
                }.bind(this));
    
                setVisibleActions(widgetCotacao, true);
                
                widgetStripe.actions.forEach(function(value, index) {
                    widgetStripe.actions[index].isVisible = true;
                }.bind(this));
                
                ScreenService.closePopup();
    
            }.bind(this)).catch(function(error) {
                let errosEncontrados = error.data;
                let mensagem = 'Não há dados a serem listados para essa apuração.';
                
                if (Array.isArray(errosEncontrados.error)) {
                    if (Util.isEmptyOrBlank(errosEncontrados.error)) {
                        mensagem = mensagem.concat(ScreenService.i18n("Favor verificar o relatório de Produtos não Comprados"));
                    }
                } else {
                    mensagem = errosEncontrados.error;
                }
                
                this.confirmMessageModified(mensagem, error).then(
                    function() {},
                    function(callback) {
                        this.handleInsertErrors(callback);
                    }.bind(this));
            }.bind(this));
        }.bind(this), function(error) {});
    };

    /* Seta no stripe, o produto selecionado.
     */
    this.setCotacaoWithProdutoOnGrid = function(widget) {
        var cdprod = widget.container.getWidget('PRODUTOS').currentRow.CDPRODUTO;

        produtos.forEach(function(value, i) {
            if (cdprod == produtos[i].CDPRODUTO) {
                index = i;
            }
        }.bind(this));
        this.setCotacaoWithParams();
        ScreenService.closePopup();
    };

    this.openPopupProdutos = function() {
        setProdutos();
        var widProd = templateManager.container.getWidget('PRODUTOS');

        widProd.dataSource.setData(produtos);
        ScreenService.openPopup(widProd);
    }; 

    /*************************************************************************************/
    /*                                 FUNÇÕES COTAÇÃO                                   */
    /*************************************************************************************/
    
    /* Faz uma requisição em 'Cotação' filtrando com o produto selecionado
     * no 'STRIPE'.
     */
    function getCotacoes(fillFilterFunction) {
        setProdutos();
        setParam();
        setTimeout(() => {
            templateManager.container.getWidget('STRIPE').currentRow.CDPRODUTO = produtos[index].CDARVPROD;
            templateManager.container.getWidget('STRIPE').currentRow.NMPRODUTO = produtos[index].NMPRODUTO;
            
            return General.callRestEngine("opl_apuracaoEfetivacao#/adqCotacao", "Row", {
                'P_CDCENTCMP': getLocalVar('CDFILCENTCMP'),
                'P_CDPRODESTO': produtos[index].CDPRODUTO,
                'P_NRSEQAPUR': param,
                'P_CDFILIOPELOG': getLocalVar('CDFILIAL')
            }).then(fillFilterFunction).catch(function(error) {
                ScreenService.showMessage(error.data ? error.data.error : messages.timeout, 'error', 'error');
            }); 
        }, 500);
    }
    
    function setCotacao(response) {
        setProdutos();
        setTimeout(() => {
            const widgetCotacao = templateManager.container.getWidget('widgetOldCot');
                
            widgetCotacao.dataSource.setData(response.dataset.cotacao[0]);
            widgetCotacao.reload();
        }, 500);
    }
    
    this.setCotacaoWithParams = function() {
        setProdutos();
        setTimeout(() => {
            return getCotacoes(function(response) {
                const widgetCotacao = templateManager.container.getWidget('widgetOldCot');
                
                setCotacao(response);
                widgetCotacao.activate();
                if (widgetCotacao.dataSource.data.VRPRECUNIAP == 0) {
                    MessageService.showMessageByCode("PRECO_UNIT_INFORMADO");
                }
            });
        }, 500);    
    };
    
    this.setCotacaoWithParamsWithoutActivateWidgetCotacao = function() {
        getCotacoes(setCotacao);
    };

    this.backFilter = function(widget) {
        ScreenService.confirmMessage("Deseja realizar uma nova apuração?", 'question', function(success) {
            widget.container.getWidget('PRODUTOS').dataSource.setData([]);
            widget.container.getWidget('widgetOldCot').dataSource.setData([]);
            widget.container.getWidget('STRIPE').currentRow = [];
            this.openFilter();
        }.bind(this), function(error) {});
    }; 

    this.updateApuracao = function() {
        let widgetCotacao = templateManager.container.getWidget('widgetOldCot');
        let row = this.getRow(widgetCotacao);

        if (row.IDITMSELAPUR == 'S') {
            row.CDCENTITMAP = getLocalVar('CDFILCENTCMP');

            General.callRestEngine("opl_apuracaoEfetivacao#/updateMelhorCotacao", "Row", row).then(function(response) {
                this.setCotacaoWithParams();
            }.bind(this));
        } else {
            let data = widgetCotacao.dataSource.data;
            for (let i = 0; i < data.length; i++) {
                if (row.CDNMREGIAO == data[i].CDNMREGIAO) {
                    if (data[i].IDITMSELAPUR == 'S') {
                        return false;
                    }
                }
            }
            
            if (this.idjustificativa == 'S') {
                let widgetJustificativa = templateManager.container.getWidget('JUSTIFICATIVA');
                
                ScreenService.openPopup(widgetJustificativa);
            } else {
                row.CDCENTITMAP = getLocalVar('CDFILCENTCMP');

                General.callRestEngine("opl_apuracaoEfetivacao#/updateMelhorCotacao", "Row", row).then(function(response) {
                    this.setCotacaoWithParams();
                }.bind(this));
            }
        }

        this.removeClass('.lineImportant', 'currentRow');
    };

    this.confirmarJustificativa = function(widget) {
        if (widget.isValid()) {
            let row = angular.copy(templateManager.container.getWidget('widgetOldCot').currentRow);
            row.OLD_CDCENTITMAP = getLocalVar('CDFILCENTCMP');

            General.callRestEngine("opl_apuracaoEfetivacao#/updateMelhorCotacao", "Row", row).then(function(response) {
                ScreenService.closePopup();
                this.setCotacaoWithParams();
            }.bind(this));
        }
    };
    
    this.updateVrUnitario = function() {
        let widgetCotacao = templateManager.container.getWidget('widgetOldCot');
        ScreenService.confirmMessage("Deseja atualizar a cotação conforme novo preço informado?", 'question', function(success) {
            let row = {
                'ITEM': widgetCotacao.dataSource.data.filter(item => item.changed),
                'PARAMS': {
                    'CDOPERADOR': getLocalVar('CDOPERADOR'),
                    'NMCONTAINER': templateManager.container.name,
                    'NMOPERADOR': getLocalVar('NMOPERADOR'),
                    'NRORG': getLocalVar('NRORG')
                }
            };
            
            setVisibleActions(widgetCotacao, false, ['BACK_APURACAO']);

            General.callRestEngine('opl_apuracaoEfetivacao#/updateVrUnitario', "Row", row).then(function(success) {
    			widgetCotacao.lastInlineEditingElement.find('input').blur();
                widgetCotacao.activate();
                
    			removeChangedPropertiesFromRow(widgetCotacao);
                actionsAfterInlineEditOperation(widgetCotacao);
                
                MessageService.successNotificationByCode("REG_SUCCESS_SAVE");
            }).catch(function(error) {
                widgetCotacao.rollbackInlineEdit();
                
                actionsAfterInlineEditOperation(widgetCotacao);
                
                ScreenService.showMessage(error.data ? error.data.error : messages.timeout, 'error', 'error');
            });
        }.bind(this));
    };
    
    this.realizaEscolhaManualDoPreco = function() {
        this.changeEventCodeWidgetAfterMoveRow();
    };

    this.apurar = function(widget) {
        ScreenService.confirmMessage("Todas as cotações selecionadas serão desmarcadas. Confirma operação?", 'question', function(success) {

            General.callRestEngine('opl_apuracaoEfetivacao#/melhorCotacao', 'Row', {
                'P_CDCENTCMP': getLocalVar('CDFILCENTCMP'),
                'P_NRSEQAPUR': param
            }).then(function(response) {
                this.setCotacaoWithParams().then(function() {
                    General.callRestEngine('opl_apuracaoEfetivacao#/verificaPrecoEconomicoZerado', 'Row', {
                        'ITENS': widget.dataSource.data
                    }).then(function(response) {
                        if (!Util.isEmptyOrBlank(response.messages)) {
                            ScreenService.showMessage(response.messages[0].message);
                        }
                    });
                });
            }.bind(this));
        }.bind(this));
    };

    this.efetivar = function(widget) {
        const filterWidget = templateManager.container.getWidget('FILTER');
        
        //Verifica a var param global
        setParam();
        
        General.callRestEngine('opl_apuracaoEfetivacao#/efetivar', 'Row', {
            'P_CDCENTCMP': getLocalVar('CDFILCENTCMP'),
            'P_NRSEQAPUR': param,
            'P_CDFILIOPELOG': getLocalVar('CDFILIAL'),
            'P_CDCOMPRADOR': templateManager.container.getWidget('FILTER').currentRow.CDOPERADOR,
            'P_CDOPERALANC': getLocalVar('CDOPERADOR'),
            'P_DTAUTOFORN': getLocalVar('DTPROCESSA')
        }).then(function(response) {
            var data = response.dataset.data[0];
            const mensagens = data.MENSAGENS;
            // const inconsistencias = data.INCONSISTENCIAS;
            
            if (!Util.isEmptyOrBlank(mensagens)) {
                ScreenService.showMessage(mensagens[0]);
            }

            MessageService.successNotificationByCode("EFETIVACAO_SUCCESS");
            
            ScreenService.openWindow('opl_autorizacaoFornecimento#sup05100_analise_AF').then(function() {
                
                templateManager.container.getWidget('widgetPrincipal').NRSEQAPUR = data.NRSEQAPUR[0];
                templateManager.container.getWidget('widgetPrincipal').CDFILLANC = getLocalVar('CDFILIAL');
                templateManager.container.getWidget('widgetPrincipal').CDFILCENTCMP = getLocalVar('CDFILCENTCMP');
                templateManager.container.getWidget('widgetPrincipal').CODCOMPRADOR = filterWidget.currentRow.CDCOMPRADOR;
                templateManager.container.getWidget('widgetPrincipal').CDOPERADOR = getLocalVar('CDOPERADOR');
                templateManager.container.getWidget('widgetPrincipal').DTAPURPREC = getLocalVar('DTPROCESSA');
                templateManager.container.getWidget('widgetPrincipal').DTINIAPUPREC = filterWidget.currentRow.DTENTREGA.formattedStart;
                templateManager.container.getWidget('widgetPrincipal').DTFINAPUPREC = filterWidget.currentRow.DTENTREGA.formattedEnd;
                templateManager.container.getWidget('widgetPrincipal').dataSource.data = [];
		    }.bind(this), function(error) {
			    throw error;
		    });
            
        }).catch(function(error) {
            if(error.data.error) {
                if(error.data.error.indexOf('EFETIVAR_AF') != -1 || error.data.error.indexOf('FECHAMENTO_AF') != -1 || error.data.error.indexOf('GERA_CONTAPAGAR_PREVISTA') != -1 || error.data.error.indexOf('ORA-') != -1) {
                    ScreenService.showMessage('Não foi possível efetivar AF(s)!<br>Por favor entre em contato com o Suporte Teknisa!', 'error', 'error');
                } else {
                    ScreenService.showMessage(error.data.error, 'error', 'error');
                }
            } else {
                ScreenService.showMessage(error.data, 'error', 'error');
            }
        });
    };

    /*************************************************************************************/
    /*                                 FUNÇÕES POR ENTREGA                               */
    /*************************************************************************************/
    
    function executeDataSourcePorEntrega(row) {
        const filter = [
            {
                "name": "P_CDCENTITMAP",
                "operator": "=",
                "value": row.CDCENTITMAP
			},
            {
                "name": "P_NRSEQITMAP",
                "operator": "=",
                "value": row.NRSEQITMAP
			},
            {
                "name": "P_CDPRODITMAP",
                "operator": "=",
                "value": row.CDPRODITMAP
			},
            {
                "name": "P_CDREGITMAP",
                "operator": "=",
                "value": row.CDREGITMAP
			}
		];
		
        return General.callRestEngine('opl_apuracaoEfetivacao#/crud/porEntrega', 'FilterData', filter);
    }
    
    function executeDataSourceAllEntregas(row) {
        const filter = [
            {
                "name": "P_CDCENTITMAP",
                "operator": "=",
                "value": row.CDCENTITMAP
			},
            {
                "name": "P_NRSEQITMAP",
                "operator": "=",
                "value": row.NRSEQITMAP
			},
            {
                "name": "P_CDPRODITMAP",
                "operator": "=",
                "value": row.CDARVPROD
			},
            {
                "name": "P_CDREGITMAP",
                "operator": "=",
                "value": row.CDREGITMAP
			}
		];
		
        return General.callRestEngine('opl_apuracaoEfetivacao#/crud/allEntregas', 'FilterData', filter);
    }
    
    this.openPorEntrega = function() {
        let widgetCotacao = templateManager.container.getWidget('widgetOldCot');
        let row = this.getRow(widgetCotacao);

        if (row.IDITMSELAPUR == 'S' && widgetCotacao.getMode() !== 'inline_edit') {
            executeDataSourcePorEntrega(row).then(function(response) {
			    let widgetPorEntrega = templateManager.container.getWidget('POR_ENTREGA');
			    
                widgetPorEntrega.dataSource.setData(response.dataset.porEntrega);
                ScreenService.openSwipe(widgetPorEntrega).then(function(){
    				$('.swipe-tip').before('<div style="position: absolute;left: 0;top: 0;bottom: 0;right: 0;opacity: 0.6;transform: translate(-100%, 0);-webkit-transform: translate(-100%, 0);"></div>');
                    this.removeClass('.lineImportant', 'currentRow');
    			}.bind(this));
            }.bind(this));
        }
        else {
            ScreenService.closeSwipe();
        }
    };
    
    this.openPopupIncluir = function() {
        executeDataSourceAllEntregas(templateManager.container.getWidget('widgetOldCot').currentRow).then(function(response) {
            const widgetIncluir = templateManager.container.getWidget('INCLUIR');
            
            allEntregas = response.dataset.allEntregas;
            
            resetAllFieldsWidgetIncluir(widgetIncluir);
            setDataSourceFieldDataEntrega(widgetIncluir);
            ScreenService.openPopup(widgetIncluir);
            widgetIncluir.newRow();
        });
    };
    
    /**
     * Decodifica informação recebida como código na aba 'POR ENTREGA' e 
     * exibe em popup.
     */
    this.openInformacao = function() {
        let widgetPorEntrega = templateManager.container.getWidget('POR_ENTREGA');
        
        if (podeAbrirInformacao) {
            let widgetInformacao = templateManager.container.getWidget('INFORMACAO');
            let currentRowProduto = this.getRow(widgetPorEntrega);
            let idmotprescaf = currentRowProduto.IDMOTIVPRESC;
            let indexMensagem = '';
            let mensagem = '';
        
            for (var i = 0; i < idmotprescaf.length; i++) {
                indexMensagem = i + idmotprescaf[i];
                mensagem = mensagem + mensagensInformacao(indexMensagem);
            }
        
            if (!mensagem) {
                mensagem = mensagem + mensagensInformacao('M0');
            }
        
            widgetInformacao.currentRow.mensagem = mensagem;
        
            ScreenService.openPopup(widgetInformacao);
            podeAbrirInformacao = false;
        } else {
            let widgetItemPorEntrega = templateManager.container.getWidget('ITEM_POR_ENTREGA');
            
            transferRowData(widgetPorEntrega.currentRow, widgetItemPorEntrega.currentRow);
            
            ScreenService.openSwipe(widgetItemPorEntrega).then(function() {
                widgetItemPorEntrega.view();
            });
        }
    };
    
    function mensagensInformacao(indexMensagem, param) {
        var mensagens = {
            '01': 'Escolhido por Produto Preferencial.\n',
            '17': 'Escolhido por Fornecedor/Marca Obrigatórios.\n',
            '18': 'Escolhido por Fornecedor/Marca Preferenciais.\n',
            '19': 'Escolhido por Fornecedor/Marca Restritivos.\n',
            '24': 'Escolhido por Fornecedor Obrigatório.\n',
            '25': 'Escolhido por Fornecedor Preferencial.\n',
            '26': 'Escolhido por Fornecedor Restritivo.\n',
            '2A': 'Escolhido por Acordo.\n',
            '31': 'Escolhido por Marca Obrigatória.\n',
            '32': 'Escolhido por Marca Preferencial.\n',
            '33': 'Escolhido por Marca Restritiva.\n',
            '41': 'Escolhido da Lista de Preços.\n',
            '42': 'Escolhido da Cotação Fora da Lista.\n',
            '51': 'Apuração para solicitações extras - Fornecedor escolhido não é extra.\n',
            '52': 'Apuração para solicitações extras - Fornecedor escolhido é extra.\n',
            '53': 'Apuração para solicitações não extras.\n',
            'M0': 'Escolhida manualmente.\n',
            'M1': 'Cotação: ' + param + '\n',
            'M2': 'Lista de preços: ' + param + '\n',
            'M3': 'Obs.: Item alterado manualmente.\n'
        };
        return mensagens[indexMensagem] ? mensagens[indexMensagem] : '';
    }
    
    function resetAllFieldsWidgetIncluir(widgetIncluir) {
        widgetIncluir.currentRow = {};
        
        lockField(widgetIncluir.getField('NMFILIAL'));
        lockField(widgetIncluir.getField('NMFANTFORN'));
    }
    
    function getCotacoesLoaded() {
        let widgetCotacao = templateManager.container.getWidget('widgetOldCot');
        let data = widgetCotacao.dataSource.data;
        let values = [];
        let i = 0;
        
        data.forEach(function(value, index) {
            if (data[index].CDNMREGIAO == widgetCotacao.currentRow.CDNMREGIAO && data[index].CDNMPRODUTO == widgetCotacao.currentRow.CDNMPRODUTO) {
                values[i] = angular.copy(data[index]);
                i++;
            }
        }.bind(this));
        
        return values;
    }
    
    function getDate(date) {
        return date.split(' ')[0];
    }
    
    function dateEquals(dateFromItem, dateToBeEqual) {
        return getDate(dateFromItem) === dateToBeEqual;
    }
    
    function unidadeEquals(codigoUnidadeItem, codigoUnidadeToBeEqual) {
        return codigoUnidadeItem === codigoUnidadeToBeEqual;
    }
    
    function mountObjectWithDate(item) {
        return { DTENTRAPUT: getDate(item.DTENTRAPUT) };
    }
    
    function mountObjectWithFilial(item) {
        return { CDFILIAL: item.CDFILIAP, NMFILIAL: item.NMFILIAL };
    }
    
    function getArrayWithUniqueElements(dataToFilter, filterFunction, mountFunction, primitivePropertyToSearch) {
        let dataPrepared;
        
        if (typeof(filterFunction) === 'function') {
            dataPrepared = dataToFilter.filter(filterFunction);
        } else {
            dataPrepared = dataToFilter;
        }
        
        const result = [];
        const map = new Map();
        for (const item of dataPrepared) {
            if(!map.has(item[primitivePropertyToSearch])){
                map.set(item[primitivePropertyToSearch], true); // set any value to Map
                result.push(mountFunction(item));
            }
        }
        
        return result;
    }
    
    function setDataSourceFieldDataEntrega(widgetIncluir) {
        widgetIncluir.getField('DTENTRAPUT').dataSource.setData(getArrayWithUniqueElements(allEntregas, null, mountObjectWithDate, 'DTENTRAPUT'));
    }
    
    function setDataSourceFieldUnidade(fieldUnidade) {
        const filterFunction = function(item) {
            return dateEquals(item.DTENTRAPUT, fieldUnidade.getParent().currentRow.DTENTRAPUT);
        };
        
        fieldUnidade.dataSource.setData(getArrayWithUniqueElements(allEntregas, filterFunction, mountObjectWithFilial, 'CDFILIAP'));
    }
    
    function getQtdeComprarPorEntrega(date, codigoUnidade) {
        const mountFunction = function(item) { return item.QTSOLACOMP; };
        const dateAndUnidadeEqualsTo = function(item) {
            return dateEquals(item.DTENTRAPUT, date) && unidadeEquals(item.CDFILIAP, codigoUnidade);
        };
        
        return getArrayWithUniqueElements(allEntregas, dateAndUnidadeEqualsTo, mountFunction)[0];
    }
    
    function deepClearField(field) {
        field.clearValue();
    }
    
    function clearFieldWithDataSource(field) {
        deepClearField(field);
        field.dataSource.clearCheckedRows();
		field.dataSource.setData([]);
    }
    
    function lockField(field) {
        field.readOnly = true;
        field.validations = {};
    }
    
    function unlockField(field) {
        field.readOnly = false;
        field.validations = { required: true };
    }
    
    this.fieldOnChangeDataEntrega = function() {
        const widgetIncluir = templateManager.container.getWidget('INCLUIR');
        const fieldQtdeComprar = widgetIncluir.getField('QTSOLACOMP');
        const fieldUnidade = widgetIncluir.getField('NMFILIAL');
        const fieldFornecedor = widgetIncluir.getField('NMFANTFORN');
        
        fieldQtdeComprar.clearValue();
        
        clearFieldWithDataSource(fieldUnidade);
        unlockField(fieldUnidade);
        
        clearFieldWithDataSource(fieldFornecedor);
        lockField(fieldFornecedor);
        
        setDataSourceFieldUnidade(fieldUnidade);
    };
    
    function fornecedorEquals(fornecedor, fornecedorToBeFound) {
        return fornecedor.NRINSJURFORN === fornecedorToBeFound.NRINSJURFORN &&
               fornecedor.NRCOLEITMAP === fornecedorToBeFound.NRCOLEITMAP &&
               fornecedor.CDMARCITMAP === fornecedorToBeFound.CDMARCITMAP;
    }
    
    function filtraDataSourceFornecedor() {
        const widgetIncluir = templateManager.container.getWidget('INCLUIR');
        const widgetPorEntrega = templateManager.container.getWidget('POR_ENTREGA');
        const fieldFornecedor = widgetIncluir.getField('NMFANTFORN');
        const dataFilterByDateAndUnidade = widgetPorEntrega.dataSource.data.filter(item => {
            return dateEquals(item.DTENTRAPUT, widgetIncluir.currentRow.DTENTRAPUT) && unidadeEquals(item.CDFILIAP, widgetIncluir.currentRow.CDFILIAP);
        });
        const dataFilterByFornecedorNaoIncluido = fieldFornecedor.dataSource.data.filter(item => {
            return !dataFilterByDateAndUnidade.find(element => fornecedorEquals(element, item));
        });
        
        fieldFornecedor.dataSource.setData(dataFilterByFornecedorNaoIncluido);
    }
    
    this.fieldOnChangeUnidade = function() {
        const widgetIncluir = templateManager.container.getWidget('INCLUIR');
        const fieldQtdeComprar = widgetIncluir.getField('QTSOLACOMP');
        const fieldUnidade = widgetIncluir.getField('NMFILIAL');
        const fieldFornecedor = widgetIncluir.getField('NMFANTFORN');
        
        clearFieldWithDataSource(fieldFornecedor);
        
        if (Util.isEmptyOrBlank(fieldUnidade.value())) {
            fieldQtdeComprar.clearValue();
            lockField(fieldFornecedor);
        } else {
            unlockField(fieldFornecedor);
            
            fieldFornecedor.dataSource.setData(getCotacoesLoaded());
            filtraDataSourceFornecedor();
            
            if (Util.isEmptyOrBlank(fieldFornecedor.dataSource.data)) {
                fieldQtdeComprar.clearValue();
                MessageService.showMessageByCode("SEM_COTACAO_PROD");
            } else {
                fieldQtdeComprar.setValue(getQtdeComprarPorEntrega(widgetIncluir.currentRow.DTENTRAPUT, widgetIncluir.currentRow.CDFILIAP));
            }
        }
    };

    this.incluiFornecedor = function() {
        const widgetIncluir = templateManager.container.getWidget('INCLUIR');
        
        if (widgetIncluir.isValid()) {
            const widgetCotacao = templateManager.container.getWidget('widgetOldCot');
            const widgetPorEntrega = templateManager.container.getWidget('POR_ENTREGA');
            const currentRowIncluir = angular.copy(widgetIncluir.currentRow);
    
            currentRowIncluir.CDCENTITMAP = getLocalVar('CDFILCENTCMP');
            
            const row = {
                NEW_ITEM: currentRowIncluir,
                OLD_ITEM: widgetIncluir.backupRow || currentRowIncluir
            };
    
            General.callRestEngine("opl_apuracaoEfetivacao#/incluirPorEntrega", "Row", row).then(function(response) {
                ScreenService.closePopup();
                MessageService.successNotificationByCode("REG_SUCCESS_SAVE");
                
                this.setCotacaoWithParamsWithoutActivateWidgetCotacao();
                
                executeDataSourcePorEntrega(widgetCotacao.currentRow).then(function(response) {
                    widgetPorEntrega.dataSource.setData(response.dataset.porEntrega);
                });
            }.bind(this))
            .catch(function(error) {
                ScreenService.showMessage(error.data ? error.data.error : messages.timeout, 'error', 'error');
            });
        }
    };
    
    this.saveEdicaoPorEntrega = function() {
        const widgetItemPorEntrega = templateManager.container.getWidget('ITEM_POR_ENTREGA');
        
        if (widgetItemPorEntrega.isValid()) {
            const widgetPorEntrega = templateManager.container.getWidget('POR_ENTREGA');
            const widgetCotacao = templateManager.container.getWidget('widgetOldCot');
            const row = {
                NEW_ITEM: widgetItemPorEntrega.currentRow,
                OLD_ITEM: widgetItemPorEntrega.backupRow
            };
            
            General.callRestEngine('opl_apuracaoEfetivacao#/saveEdicaoPorEntrega', 'Row', row).then(function(response) {
    		    MessageService.successNotificationByCode("REG_SUCCESS_UPDATE");
    		    
    		    executeDataSourcePorEntrega(widgetCotacao.currentRow).then(function(response) {
                    widgetPorEntrega.dataSource.setData(response.dataset.porEntrega);
                });
    		    
    		    widgetItemPorEntrega.view();
            }).catch(function(error) {
                ScreenService.showMessage(error.data ? error.data.error : messages.timeout, 'error', 'error');
            });
        }
    };
    
    this.cancelEdicaoPorEntrega = function() {
        let widgetItemPorEntrega = templateManager.container.getWidget('ITEM_POR_ENTREGA');
        
		widgetItemPorEntrega.view();
		
		transferRowData(widgetItemPorEntrega.backupRow, widgetItemPorEntrega.currentRow);
    };
    
    this.editarEntrega = function() {
        let widgetItemPorEntrega = templateManager.container.getWidget('ITEM_POR_ENTREGA');
        
        General.edit(widgetItemPorEntrega);
    };

    /*************************************************************************************/
    /*                            FUNÇÕES PARA TRATATIVAS DE ERROS                       */
    /*************************************************************************************/
    
    this.confirmMessageModified = function(message, callbackForError) {
        let actions = [
            {
                label: ScreenService.i18n("Ok"),
                "default": true,
                code: function(e, deferred) {
                    deferred.resolve(e);
                }
            }
        ];
        
        if (Array.isArray(callbackForError.data.error) && !Util.isEmptyOrBlank(callbackForError.data.error)) {
            actions.push({
                label: ScreenService.i18n("Detalhes"),
                code: function(e, deferred) {
                    deferred.reject(callbackForError);
                }
            });
        }
        
        return ScreenService.showCustomDialog(message, 'error', 'error', actions);
    };
    
    /**
     * Altera a action 'Exportar' da widget de log de erros, passando uma
     * mensagem modificada, contendo:
     * - cabeçalho contendo o filtro realiazdo;
     * - os erros encontrados;
     */
    function atualizaExportar() {
        let filterWidget = templateManager.container.getWidget('FILTER');
        let messagesWidget = templateManager.container.getActiveWidget();
        let exportarAction = messagesWidget.getAction('exportar');
    
        messagesWidget.headerDataset = [];
    
        messagesWidget.headerDataset.push('-----------------------------------------');
        filterWidget.fields.forEach((field) => {
            if (field.isVisible === true) {
                let fieldValue;
                
                switch(field.name) {
                    case 'DTENTREGA':
                        let tempFieldValue = field.value();
                    
                        fieldValue =  tempFieldValue.start + ' a ' + tempFieldValue.end;
                        break;
                        
                    case 'EXTRA':
                        let tempField = field.dataSource.data.filter(dataItem => { return dataItem.value == field.value(); })[0];
                        
                        fieldValue = tempField.name;
                        break;
                        
                    default:
                        fieldValue = field.value();
                        break;
                }
                
                messagesWidget.headerDataset.push(field.label + ': ' + fieldValue);
            }
        });
        messagesWidget.headerDataset.push('-----------------------------------------');
    
        messagesWidget.bodyMessageDataset = messagesWidget.headerDataset.concat(messagesWidget.messagesDataset);
    
        exportarAction.events = [
            {
                "name": "ActionEvent",
                "code": "General.generateFileByDataSet(args.owner.widget.bodyMessageDataset);"
            }
        ];
    }
    
    this.handleInsertErrors = function (callback) {
        var filterWidget = templateManager.container.getWidget("FILTER");
        var message = messages.timeout;
        var errorMessages = Util.getNestedProperty(callback, ["data", "error"]);
    
        if (Array.isArray(errorMessages)) {
            filterWidget.reload().then(function() {
                let title = messages.errosApuracao;
                if (callback.data && callback.data.error) {
                    title = messages[callback.data.error] || title;
                }
                General.showErrorMessages(filterWidget, errorMessages, ScreenService.i18n(title));
                atualizaExportar();
            });
        } else {
            if (callback.data && callback.data.error) {
                message = messages[callback.data.error] || callback.data.error;
            }
            ScreenService.showMessage(message, "error");
        }
    };
    
    this.setFieldsVisibility = function(widget) {
    	const isReadOnly = getLocalVar('CDFILIAL') !== getLocalVar('CDFILCENTCMP');
    	const fieldFilial = widget.getField('LISTAFILIAL');
    	
    	widget.getField('CDREGIAO').readOnly = isReadOnly;
    	widget.getField('CDGRUPFILI').readOnly = isReadOnly;
    	fieldFilial.readOnly = isReadOnly;
    	
    	if(isReadOnly) {
    	    setUnidadeDestinoDefault(fieldFilial);
    	}
    };
    
    function setUnidadeDestinoDefault(fieldFilial) {
        const codigoUnidade = getLocalVar('CDFILIAL');
        const inFilterExists = function (fieldFilial) {
            return fieldFilial.dataSourceFilter.find(filter => filter.operator === 'IN');
        };
        
        if (!inFilterExists(fieldFilial)) {
			fieldFilial.dataSourceFilter.push({
			    name: 'CDFILIAL',
			    operator: 'IN',
			    value: [ codigoUnidade ]
			});
        }
		
		fieldFilial.dataSource
		    .load(fieldFilial.dataSourceFilter)
		    .then(function() {
			    fieldFilial.setValue([codigoUnidade]);
				const row = fieldFilial.dataSource.getFirstRow();
				
				row.__isSelected = true;
				
				fieldFilial.dataSource.updateCheckedRows();
				
				if (inFilterExists(fieldFilial)) {
				    fieldFilial.dataSourceFilter = fieldFilial.dataSourceFilter.filter(filter => filter.operator !== 'IN');
				}
				
				fieldFilial.dataSource.load(fieldFilial.dataSourceFilter);
			});
		
    }
}

Configuration(function(ContextRegister) {
    ContextRegister.register('ApuracaoEfetivacaoController', ApuracaoEfetivacaoController);
});


// FILE: ./assets/modules/autorizacaoFornecimento/assets/js/controllers/sup05100_analise_AF_Controller.js
function sup05100_analise_AF_Controller(ScreenService, MessageService, templateManager, maskEngine, ZhUtil, General, sup05100_analise_AF_Service, Utilities, ZHPromise, renderEngine) {
    const serviceAnalise = sup05100_analise_AF_Service;
    let params;
    
    this.onEnterOnceWidgetPrincipal = function(args) {
        const wdgetPrincipal = templateManager.container.getWidget('widgetPrincipal');
        
        if(!wdgetPrincipal.backFromRemanejo) {
            serviceAnalise.retornaParaSupriCentralCompras("FILIAL_LOGADA").then(function(parametros){
                params = parametros.dataset.parasupri_central_compras[0];
                
                if(params) {
                    if(!!wdgetPrincipal.NRSEQAPUR) {
                        const dataSourceFilter = [
                            {
                                "name": "CDFILIAL",
                                "operator": "=",
                                "value": params.CDFILIAL
                            },
                            {
                                "name": "CDCOMPRADOR",
                                "operator": "=",
                                "value": ""
                            },
                            {
                                "name": "SITUACAO",
                                "operator": "=",
                                "value": "1"
                            },
                            {
                                "name": "CDOPERADOR",
                                "operator": "=",
                                "value": ""
                            },
                            {
                                "name": "DTINIPERIODO",
                                "operator": "=",
                                "value": ""
                            },
                            {
                                "name": "DTFINPERIODO",
                                "operator": "=",
                                "value": ""
                            },
                            {
                                "name": "DTGERACAO",
                                "operator": "=",
                                "value": ""
                            },
                            {
                                "name": "NRORG",
                                "operator": "=",
                                "value": params.NRORG
                            },
                            {
                                "name": "NRAPURPREC",
                                "operator": "=",
                                "value": wdgetPrincipal.NRSEQAPUR
                            }
                        ];
            
                        wdgetPrincipal.getField('NRAPURPREC').dataSource.filter(dataSourceFilter, function(data) {
                            const { IDSITAPUPREC: situacaoApuracao } = data[0];
                            
                            wdgetPrincipal.currentRow.IDSITAPUPREC = situacaoApuracao;
                            wdgetPrincipal.currentRow.NRAPURPREC = wdgetPrincipal.NRSEQAPUR;
                            wdgetPrincipal.currentRow.CDFILLANC = wdgetPrincipal.CDFILLANC;
                            wdgetPrincipal.currentRow.CDFILCENTCMP = wdgetPrincipal.CDFILCENTCMP;
                            
                            wdgetPrincipal.currentRow.CDOPERADOR = data[0].CDOPERADOR;
                            wdgetPrincipal.currentRow.CDCOMPRADOR = data[0].CDCOMPRADOR;
                            wdgetPrincipal.currentRow.NMCOMPRADOR = data[0].NMCOMPRADOR;
                            wdgetPrincipal.currentRow.NMOPERADOR = data[0].NMOPERADOR;
                            
                            wdgetPrincipal.currentRow.DTAPURPREC = wdgetPrincipal.DTAPURPREC;
                            wdgetPrincipal.currentRow.DTINIAPUPREC = wdgetPrincipal.DTINIAPUPREC;
                            wdgetPrincipal.currentRow.DTFINAPUPREC = wdgetPrincipal.DTFINAPUPREC;
                        
                            Utilities.startFilter(wdgetPrincipal, wdgetPrincipal.currentRow);
                        });
                    } else {
                    	Utilities.startFilter(wdgetPrincipal);
                    }
                    
                } else {
                    MessageService.showMessageByCode("PARASUPRI_NOT_FOUND_FILIOPER", {CDFILIAL: getLocalVar('CDFILIAL')}, Constants.errorMessage);
                }
                
            }).catch(function(error) {
                exibeMensagemErro(error);
            });
        } else {
            wdgetPrincipal.backFromRemanejo = false;
        }
    };
    
    function exibeMensagemErro(erro) {
        MessageService.getMessageByCode("TRY_AGAIN").then( message => {
            let mensagem = message;
            
            if(erro.data) {
                mensagem = erro.data.error;
            } else if(typeof erro === 'string') {
                mensagem = erro;
            }
            
            if(erro.type !== 'click') {
                ScreenService.showMessage(mensagem);
            }
        });
    }
    
    this.limpaApuracao = function() {
        const widgetPrincipal = templateManager.container.getWidget('widgetPrincipal');
        
        widgetPrincipal.currentRow.NRAPURPREC = "";
    };
    
    this.verificaSituacaoRequerida = function(field) {
        const widgetPrincipal = templateManager.container.getWidget('widgetPrincipal');
        const fieldConcluida = widgetPrincipal.getField('CONCLUIDA');
        const fieldAnalise = widgetPrincipal.getField('ANALISE');
        
        if(!fieldConcluida.checked && !fieldAnalise.checked) {
            if(field.name === 'ANALISE') {
                fieldConcluida.checked = true;
                fieldConcluida.setValue('2_3_4');
            } else {
                fieldAnalise.checked = true;
                fieldAnalise.setValue('1');
            }
        }
        
        this.limpaApuracao();
    };
    
    this.getNrApuracao = function(widget) {
    	const currentRow = widget.currentRow;
        const situacao   = [currentRow.ANALISE, currentRow.CONCLUIDA].join("_");
        const apuracaoField = widget.getField("NRAPURPREC");
        
        apuracaoField.dataSourceFilter = [
			{
				'name': 'CDFILIAL',
				'operator': '=',
				'value': getLocalVar('CDFILIAL')
			},
			{
				'name': 'CDCOMPRADOR',
				'operator': '=',
				'value': currentRow.CDCOMPRADOR
			},
			{
				'name': 'SITUACAO',
				'operator': '=',
				'value': situacao
			},
			{
				'name': 'CDOPERADOR',
				'operator': '=',
				'value': getLocalVar('CDOPERADOR')
			},
			{
				'name': 'DTINIPERIODO',
				'operator': '=',
				'value': currentRow.DTPERIODO.start || ''
			},
			{
				'name': 'DTFINPERIODO',
				'operator': '=',
				'value': currentRow.DTPERIODO.end || ''
			},
			{
				'name': 'DTGERACAO',
				'operator': '=',
				'value': currentRow.DATA
			}
		];
        
        //apuracaoField.reload().then(function(callback) {
            currentRow.NRAPURPREC = "";	
        //});
    };
    
    this.filtraApuracao = function(widget) {
        var currentRow = widget.currentRow;
        var situacao   = [currentRow.ANALISE, currentRow.CONCLUIDA].join("_");
        var dataSourceFilter = [];
        currentRow.NRAPURPREC = "";
        
        dataSourceFilter = {
            'CDFILIAL': getLocalVar('CDFILIAL'),
            'CDCOMPRADOR': currentRow.CDCOMPRADOR,
            'SITUACAO': situacao,
            'CDOPERADOR': currentRow.CDOPERADOR,
            'DTINIPERIODO': currentRow.DTPERIODO.start || '',
            'DTFINPERIODO': currentRow.DTPERIODO.end || '',
            'DTGERACAO': currentRow.DATA
        };
        
        General.onClickDependentField(widget.getField("NRAPURPREC"), dataSourceFilter);
    };
    
    /**
     * A apuração atual é a que foi FILTRADA e, portanto, a que se encontra
     * na backupRow, já que essa é atualizada na função confirmarFiltro.
     * 
     * Pode ser diferente da apuração SELECIONADA, já que o usuário pode
     * selecionar uma nova apuração e não realizar o filtro, optando por clicar
     * em cancelar.
     */ 
    function getApuracaoAtual() {
        return templateManager.container.getWidget("stripeWidget").currentRow;
    }
    
    this.setDataSourceFilter = function(args) {
        const stripe = templateManager.container.getWidget('stripeWidget');
        const filterRow = args.e.preference.FILTER_ROW;
        const widget = args.owner;
        
        stripe.filteredRow = filterRow;
        
        widget.dataSourceFilter = [
		    {
		        "name": "P_CDFILLANC",
		        "operator": "=",
		        "value": getLocalVar('CDFILIAL')
		    },
		    {
		        "name": "P_NRSEQAPURAF",
		        "operator": "=",
		        "value": filterRow.NRAPURPREC
		    },
		    {
                "operator": "ORDER_BY",
                "name": [
                    {
                        "name": "CDFILDEST",
                        "direction": "ASC"
                    },
                    {
                        "name": "NMFANTFORN",
                        "direction": "ASC"
                    },
                    {
                        "name": "NRAUTOFORN",
                        "direction": "ASC"
                    }
                ]
            }
		];
		
		widget.reload().then(function(callback) {
		    const actions = widget.actions;
		    const firstRow = callback.dataset.sup05100_unidades.find(x => x!==undefined);
            
            setStripeValues();
            setVisibilityOfActions(actions, !isApuracaoConcluida());
		    widget.activate();
		    widget.showCheckbox = firstRow ? firstRow.IDSITAPUPREC === '1' : true;
		});
		
    };
    
    function setVisibilityOfActions(actions, visibility) {
        actions.map(action => {
            action.isVisible = (action.name === 'reenviarEmail' || action.name === 'salvarRelatorioAF') ? !visibility : visibility;
            
            if(action.name === 'situacaoAF')
                action.isVisible = true;
        });
    }
    
    function aplicarMascara(widget, fieldName) {
        return Util.applyMask(widget.currentRow[fieldName], widget.getField(fieldName).mask, maskEngine, ZhUtil);
    }
    
    function setStripeValues() {
        const stripeWidget = templateManager.container.getWidget('stripeWidget');
        const stripeCurrentRow = stripeWidget.currentRow;
        const widgetPrincipal = templateManager.container.getWidget('widgetPrincipal');
        
        if(widgetPrincipal.dataSource.data.length > 0) {
            const firstRow = widgetPrincipal.dataSource.data[0];
            
            stripeCurrentRow.NRAPURPREC = firstRow.NRAPURPREC;
            stripeCurrentRow.VRTOTALAPURAC = firstRow.VRTOTALAPURAC;
            stripeCurrentRow.DESCCOMPRADOR = firstRow.CDCOMPRADOR.concat(' | ', firstRow.NMOPERADOR);
            stripeCurrentRow.PERIODO = moment(firstRow.DTINIAPUPREC, 'DD/MM/YYYY').format('DD/MM/YYYY').concat(' | ', moment(firstRow.DTFINAPUPREC, 'DD/MM/YYYY').format('DD/MM/YYYY'));
            stripeCurrentRow.IDSITAPUPREC = firstRow.IDSITAPUPREC;
            stripeCurrentRow.DSSITAPUPREC = stripeWidget.getField('DSSITAPUPREC').options[firstRow.IDSITAPUPREC];
            stripeCurrentRow.CDCOMPRADOR = firstRow.CDCOMPRADOR;
            stripeCurrentRow.NMCOMPRADOR = firstRow.NMCOMPRADOR;
            stripeCurrentRow.CDOPERADOR = firstRow.CDOPERADOR;
            stripeCurrentRow.NMOPERADOR = firstRow.NMOPERADOR;
            stripeCurrentRow.DTAPURPREC = firstRow.DTAPURPREC;
            stripeCurrentRow.DTINIAPUPREC = moment(firstRow.DTINIAPUPREC, 'DD/MM/YYYY').format('DD/MM/YYYY');
            stripeCurrentRow.DTFINAPUPREC = moment(firstRow.DTFINAPUPREC, 'DD/MM/YYYY').format('DD/MM/YYYY');
            stripeCurrentRow.CDFILLANC = firstRow.CDFILLANC;
            stripeCurrentRow.CDFILCENTCMP = firstRow.CDFILCENTCMP;
            
            stripeCurrentRow.VRTOTALAPURAC = aplicarMascara(stripeWidget, 'VRTOTALAPURAC');
            
            var dtprogentaf = moment(firstRow.DTPROGENTAF, 'L').format();
            var dtPeriodoIni = moment(stripeCurrentRow.PERIODO.substring(0, 10), 'L').format();
            var dtPeriodoFin = moment(stripeCurrentRow.PERIODO.substring(13), 'L').format();
            
            const fieldDTAPUR = stripeWidget.getField("DTAPUR");
            const fieldDTATUAL= stripeWidget.getField("DTATUAL");
            
            fieldDTAPUR.isVisible = true;
            fieldDTATUAL.isVisible = true;
            
            stripeCurrentRow.DTATUAL = "";
            stripeCurrentRow.DTAPUR = "";
            
            if(stripeCurrentRow.IDSITAPUPREC == '3') {
                stripeWidget.getField("DTAPUR").isVisible = false;
                stripeWidget.getField("DTATUAL").isVisible = false;
            } else {
                if(moment(dtprogentaf).isBefore(moment().format())) {
                    stripeCurrentRow.DTATUAL = "Data de entrega menor que a data atual.";
                    
                    if(moment(dtprogentaf).isBefore(dtPeriodoIni) || moment(dtprogentaf).isAfter(dtPeriodoFin)) {
                        stripeCurrentRow.DTAPUR = "Data de entrega fora do período de apuração.";
                    } else {
                        stripeWidget.getField("DTAPUR").isVisible = false;
                    } 
                } else {
                    if(moment(dtprogentaf).isBefore(dtPeriodoIni) || moment(dtprogentaf).isAfter(dtPeriodoFin)) {
                        stripeCurrentRow.DTAPUR = "Data de entrega fora do período de apuração.";
                        
                        stripeWidget.getField("DTATUAL").isVisible = false;
                    } else {
                        stripeWidget.getField("DTAPUR").isVisible = false;
                        stripeWidget.getField("DTATUAL").isVisible = false;
                    } 
                }
            }
            
            if(fieldDTAPUR.isVisible) {
                setTimeout(() => {
                    fieldDTAPUR.element[0].firstElementChild.style.color = "blue";
                }, 500);
            }
            if(fieldDTATUAL.isVisible) {
                setTimeout(() => {
                    fieldDTATUAL.element[0].firstElementChild.style.color = "green";
                }, 500);
            }
        } else {
            stripeCurrentRow.NRAPURPREC = "";
            stripeCurrentRow.VRTOTALAPURAC = "";
            stripeCurrentRow.NMCOMPRADOR = "";
            stripeCurrentRow.PERIODO = "";
            stripeCurrentRow.IDSITAPUPREC = "";
            stripeCurrentRow.CDCOMPRADOR = "";
            stripeCurrentRow.DTAPURPREC = "";
            stripeCurrentRow.DTINIAPUPREC = "";
            stripeCurrentRow.DTFINAPUPREC = "";
            stripeCurrentRow.CDFILLANC = "";
            stripeCurrentRow.CDFILCENTCMP = "";
        }
    }
    
    this.abreProdutos = function(widget) {
        const tabbed      = widget.container.getWidget("tabbed");
        const produtos    = widget.container.getWidget("produtos");
        
        produtos.dataSource.clearCheckedRows();
        
        produtos.dataSourceFilter = [
            { 'name': 'P_CDFILDEST',   'operator': '=', 'value': widget.currentRow.CDFILDEST   },
			{ 'name': 'P_CDFILLANC',   'operator': '=', 'value': widget.currentRow.CDFILLANC   },
			{ 'name': 'P_NRSEQAPURAF', 'operator': '=', 'value': widget.currentRow.NRAPURPREC  },
			{ 'name': 'P_NRAUTOFORN',  'operator': '=', 'value': widget.currentRow.NRAUTOFORN  },
			{ 'name': 'P_DTPROGENTAF', 'operator': '=', 'value': widget.currentRow.DTPROGENTAF }
		];
		produtos.reload();
		ScreenService.openSwipe(tabbed);
    };
    
    this.voltarAtivar = function(widget) {
        ScreenService.closeSwipe();
        widget.activate();
    };
    
    this.editarProduto = function() {
        const widgetProduto = templateManager.container.getWidget('produtos');
        
        if (Util.isEmptyOrBlank(widgetProduto.currentRow.DTPROGENTAF_ORIG)) {
            widgetProduto.currentRow.DTPROGENTAF_ORIG = moment(widgetProduto.currentRow.DTPROGENTAF, 'L').format('L');
        }
        
        if (isApuracaoConcluida()) {
            MessageService.showMessageByCode("ANALISE_ALREADY_FINISHED", null, Constants.errorMessage);
        } else {
            General.widgetEdit(widgetProduto);
        }
    };
    
    function isApuracaoConcluida() {
        const stripeWidget = templateManager.container.getWidget("stripeWidget");
        
        return (stripeWidget.currentRow && stripeWidget.currentRow.IDSITAPUPREC != '1');
    }
    
    this.salvaEdicaoProduto = function(isDataEntregaValida) {
        const widgetProduto = templateManager.container.getWidget('produtos');
        
        if(widgetProduto.isValid()) {
            if(!isDataEntregaValida) {
                validaDataEntrega();
            } else {
                confirmSaveProduct();
            }
        }
    };
    
    function confirmAtuDeEntrSoli(row) {
        const deferred = ZHPromise.defer();
        
        if(moment(row.DTPROGENTAF_OLD, 'DD/MM/YYYY').format('DD/MM/YYYY') !== moment(row.DTPROGENTAF, 'DD/MM/YYYY').format('DD/MM/YYYY')) {
            return MessageService.confirmMessageByCode("UPDATE_DTPROGENTAF_AF_ITEMSOLI", null, Constants.confirmationMessage);
        } else {
            deferred.resolve();
        }
        
        return deferred.promise;
    }
    
    function confirmSaveProduct() {
        const widgetProduto = templateManager.container.getWidget('produtos');
        const widgetPrincipal = templateManager.container.getWidget('widgetPrincipal');
        const currentRowProduto = widgetProduto.currentRow;
        
        confirmaQuantidade(converteParaFloat(currentRowProduto.QTPROGENTAF)).then(function() {
            currentRowProduto.IDGERAFDTENT = widgetPrincipal.currentRow.IDGERAFDTENT;
            currentRowProduto.CDFORNECED = widgetPrincipal.currentRow.CDFORNECED;
            currentRowProduto.IDFUNCAOFILI = widgetPrincipal.currentRow.IDFUNCAOFILI;
            currentRowProduto.DTPROGENTAF_OLD = widgetProduto.backupRow.DTPROGENTAF;
            currentRowProduto.QTPROGENTAF_OLD = widgetProduto.backupRow.QTPROGENTAF;
            currentRowProduto.ALTERADTENTREGA = currentRowProduto.ALTERADTENTREGA ? currentRowProduto.ALTERADTENTREGA : false;
            
            MessageService.confirmMessageByCode("UPDATE_SOLICITA", null, Constants.confirmationMessage).then(() => {
                confirmAtuDeEntrSoli(currentRowProduto).then(function() {
                    currentRowProduto.ATUSOLICITACMP = true;
                    serviceAnalise.salvaEdicaoProduto(currentRowProduto).then(function(mensagem) {
                        finalizaEdicao(widgetPrincipal, widgetProduto, mensagem);
                    }).catch(function(erro) {
                        exibeMensagemErro(erro);
                    });
                }.bind(this));
            }, function(error) {
                currentRowProduto.ATUSOLICITACMP = false;
                serviceAnalise.salvaEdicaoProduto(currentRowProduto).then(function(mensagem) {
                    finalizaEdicao(widgetPrincipal, widgetProduto, mensagem);
                }).catch(function(erro) {
                    exibeMensagemErro(erro);
                });
            });
        });
    }
    
    function validaDataEntrega() {
        const widgetProduto = templateManager.container.getWidget('produtos');
        const dtprogentafAntiga = widgetProduto.backupRow.DTPROGENTAF.substring(0, 10);
        const dtprogentafAntigaMoment = moment(dtprogentafAntiga, 'DD/MM/YYYY');
        const dtprogentafNova = widgetProduto.currentRow.DTPROGENTAF.substring(0, 10);
        const dtprogentafNovaMoment = moment(dtprogentafNova, 'DD/MM/YYYY');
        const dataAtual = moment(moment().format('DD/MM/YYYY'), 'DD/MM/YYYY');
        
        if(dtprogentafAntiga != dtprogentafNova) {
            if(dtprogentafNovaMoment < dataAtual) {
                MessageService.showMessageByCode("DTPROGENTAF>DTATUAL", null, Constants.alertMessage);
            } else {
                confirmaValidade(dtprogentafNovaMoment, dtprogentafAntigaMoment).then(function() {
                    confirmaAfPorDataEntrega();
                }.bind(this));
            }
        } else {
            confirmSaveProduct();
        }
    }
    
    function confirmaValidade(dtprogentafNova, dtprogentafAntiga) {
        const widgetProduto = templateManager.container.getWidget('produtos');
        const nrDiasValidade = converteParaFloat(widgetProduto.currentRow.NRDIASVALPRFORN);
        const deferred = ZHPromise.defer();
        
        if(nrDiasValidade) {
            const diferencaDias = Math.abs(dtprogentafNova.diff(dtprogentafAntiga, 'days'));
            
            if(diferencaDias > nrDiasValidade) {
                return MessageService.confirmMessageByCode("CONFIRM_VALIDADE_DIAS", null, Constants.confirmationMessage);
            } else {
                deferred.resolve();
            }
        } else {
            deferred.resolve();
        }
        
        return deferred.promise;
    }
    
    function confirmaAfPorDataEntrega() {
        const widgetPrincipal = templateManager.container.getWidget('widgetPrincipal');
        const widgetProduto = templateManager.container.getWidget('produtos');
        const idgerafdtent = widgetPrincipal.currentRow.IDGERAFDTENT;
        
        widgetProduto.currentRow.ALTERADTENTREGA = false;
        
        if(idgerafdtent === 'S') {
            MessageService.confirmMessageByCode("QUESTION_AF_DTPROGENTR", null, Constants.confirmationMessage).then(() => {
                widgetProduto.currentRow.ALTERADTENTREGA = true;
                confirmSaveProduct();
            }, function(error) {
                widgetProduto.currentRow.ALTERADTENTREGA = false;
                MessageService.showMessageByCode("SOMENTE_UMA_DTPROGENTAF", null, Constants.alertMessage);
            });
        } else {
            confirmSaveProduct();
        }
    }
    
    function confirmaQuantidade(quantidade) {
        var deferred = ZHPromise.defer();
        
        if(quantidade == 0) {
            return MessageService.confirmMessageByCode("QTPROGENTAF_ZERO", null, Constants.confirmationMessage);
        } else {
            deferred.resolve();
        }
        
        return deferred.promise;
    }
    
    function converteParaFloat(valor) {
        if(valor) {
            if(typeof valor === 'string') {
                valor = valor.replace(/\./g, '').replace(',', '.');
            }
            
            valor = parseFloat(valor);
        }
        
        return valor;
    }
    
    function finalizaEdicao(widgetAf, widgetProduto, mensagem) {
        var excluido = mensagem.messages[0].message;

        if(excluido.EDITED_ITEM) {
        	ScreenService.closeSwipe().then(function() {
				ScreenService.closeSwipe().then(function() {
					MessageService.successNotificationByCode('SUCCESS_OPERATION');
					widgetAf.activate();
					widgetAf.reload();
				});
        	});
        } else if(!excluido.AF_DELETADA && !excluido.ITEM_DELETADO) {
            ScreenService.closeSwipe().then(function() {
                widgetProduto.activate();
                widgetProduto.reload();
            });
        } else if(excluido.AF_DELETADA) {
            ScreenService.closeSwipe(0).then(function() {
                MessageService.successNotificationByCode('ITEMAUTF_AND_AF_DELETED');
                widgetAf.activate();
                widgetAf.reload();
            });
        } else if(excluido.ITEM_DELETADO) {
            ScreenService.closeSwipe().then(function() {
                MessageService.successNotificationByCode('ITEMAUTF_DELETED');
                widgetProduto.activate();
                widgetProduto.reload();
            });
        }
    }
    
    this.clearApuracao = function(field) {
        field.widget.getField('NRAPURPREC').clearValue();
        field.widget.getField('NMFILIAL').clearValue();
        field.widget.getField('NMFANTFORN').clearValue();
        field.widget.getField('NRAUTOFORN').clearValue();
    };
    
    this.clearUnidadeDestino = function(field) {
        field.widget.getField('NMFILIAL').clearValue();
        field.widget.getField('NMFANTFORN').clearValue();
        field.widget.getField('NRAUTOFORN').clearValue();
    };
    
    this.clearFornecedor = function(field) {
        field.widget.getField('NMFANTFORN').clearValue();
        field.widget.getField('NRAUTOFORN').clearValue();
    };
    
    this.clearAF = function(field) {
        field.widget.getField('NRAUTOFORN').clearValue();
    };
    
    function setPopUpValues(widget) {
        const widgetPrincipal = templateManager.container.getWidget('widgetPrincipal');
        const stripeWidget = templateManager.container.getWidget("stripeWidget");
        
        const fieldComprador = widget.getField('NMCOMPRADOR');
        const fieldApuracao = widget.getField('NRAPURPREC');
        const firstRow = widgetPrincipal.dataSource.data.find(x=>x!==undefined);
        
        setReadOnlyFields(widget, false, allFieldsExceptComprador);
		
        fieldApuracao.dataSourceFilter = [
            {  'name': 'P_CDCOMPRADOR',		'operator': '=',	'value': widget.currentRow.CDCOMPRADOR  },
            {  'name': 'P_1',	            'operator': '=',	'value': 'Em análise'                   },
            {  'name': 'P_CDFILLANC',	    'operator': '=',	'value': stripeWidget.currentRow.CDFILLANC    },
            {  'name': 'P_CDFILCENTCMP',	'operator': '=',	'value': stripeWidget.currentRow.CDFILCENTCMP }
        ];
        
        fieldApuracao.reload().then(function(){
            fieldComprador.setValue(stripeWidget.currentRow.NMOPERADOR);
        	fieldApuracao.setValue([stripeWidget.currentRow.NRAPURPREC]);
    		widget.currentRow.CDCOMPRADOR = firstRow.CDCOMPRADOR;
    		widget.currentRow.CDFILLANC = stripeWidget.currentRow.CDFILLANC;
    
            widget.getField('NMFANTFORN').clearValue();
            widget.getField('NMFILIAL').clearValue();
            widget.getField('NRAUTOFORN').clearValue();
    
    		ScreenService.openPopup(widget);
        });
    }
    
    this.excluirAF = function(widget) {
        if (widget.hasCheckedRows()) {
            MessageService.confirmMessageByCode("CONFIRM_DELETE", null, Constants.confirmationMessage).then(function(success) {
                const row = getRowForExclusaoAF();
                
                serviceAnalise.excluirAF(row).then(function(success) {
                    finalizaExclusaoAF(success);
                }).catch(function(error) {
                    exibeMensagemErro(error);
                });
            });
        } else {
            setPopUpValues(templateManager.container.getWidget('exclusaoAfsEmAnalise'));
        }
    };
    
    function filtraApuracaoAF(widget) {
    	const stripeRow = templateManager.container.getWidget("stripeWidget").currentRow;

        widget.getField("NRAPURPREC").dataSourceFilter = [
            {  'name': 'P_CDCOMPRADOR',		'operator': '=',	'value': widget.currentRow.CDCOMPRADOR  },
            {  'name': 'P_1',	            'operator': '=',	'value': 'Em análise'                   },
            {  'name': 'P_CDFILLANC',	    'operator': '=',	'value': stripeRow.CDFILLANC         },
            {  'name': 'P_CDFILCENTCMP',	'operator': '=',	'value': stripeRow.CDFILCENTCMP         }
        ];
        widget.getField("NRAPURPREC").reload();
    }
    
    function filtraAF(widget) {
        const row         = angular.copy(widget.currentRow);
        const CDCOMPRADOR = row.CDCOMPRADOR || null;
        const APURACAO    = concatArrayForParams(row.NRAPURPREC);
        const CDFORNECED  = concatArrayForParams(row.NMFANTFORN);
        const CDFILIAL    = concatArrayForParams(row.NMFILIAL);
        
        widget.getField('NRAUTOFORN').dataSourceFilter = [
            {  'name': 'P_CDCOMPRADOR',		'operator': '=',	'value': CDCOMPRADOR  },
            {  'name': 'P_NRAPURPREC',	    'operator': '=',	'value': APURACAO     },
            {  'name': 'P_CDFORNECED',		'operator': '=',	'value': CDFORNECED   },
            {  'name': 'P_CDFILIAL',		'operator': '=',	'value': CDFILIAL	  }
        ];
        
        widget.getField('NRAUTOFORN').reload();
    }
    
    this.setDataSourceComprador = function(field) {
    	const widget = templateManager.container.getActiveWidget();
        const row = angular.copy(widget.currentRow);
        const comprador = Array.isArray(row.CDCOMPRADOR) ? concatArrayForParams(row.CDCOMPRADOR) : row.CDCOMPRADOR;
        const apuracao = Array.isArray(row.NRAPURPREC) ? concatArrayForParams(row.NRAPURPREC) : row.NRAPURPREC;
        
        field.dataSourceFilter = [
            {  'name': 'P_CDCOMPRADOR',		'operator': '=',	'value': comprador },
            {  'name': 'P_NRAPURPREC',	    'operator': '=',	'value': apuracao  },
            {  'name': 'P_CDFORNECED',		'operator': '=',	'value': concatArrayForParams(row.NMFANTFORN) },
            {  'name': 'P_CDFILIAL',		'operator': '=',	'value': concatArrayForParams(row.NMFILIAL)	  }
        ];
        
        field.reload();
    };
    
    this.setDataSourceFilterFornecedor = function(field) {
        const widget = templateManager.container.getActiveWidget();
        const row = angular.copy(widget.currentRow);
        const apuracao = Array.isArray(row.NRAPURPREC) ? concatArrayForParams(row.NRAPURPREC) : row.NRAPURPREC;
        
        field.dataSourceFilter = [
            {  'name': 'P_CDFILLANC',	'operator': '=', 'value': row.CDFILLANC },
            {  'name': 'P_NRSEQAPURAF',	'operator': '=', 'value': apuracao },
            {  'name': 'P_CDFILDEST',	'operator': '=', 'value': concatArrayForParams(row.NMFILIAL) },
            {
                "operator": "ORDER_BY",
                "name": [
                    {
                        "name": "IDTPIJURFORN",
                        "direction": "ASC"
                    },
                    {
                        "name": "NRINSJURFORN",
                        "direction": "ASC"
                    }
                ]
            }
        ];
        
        field.reload();
    };
    
    this.setDataSourceFilterAF = function(field) {
    	const widget = templateManager.container.getActiveWidget();
        const row = angular.copy(widget.currentRow);
        const apuracao = Array.isArray(row.NRAPURPREC) ? concatArrayForParams(row.NRAPURPREC) : row.NRAPURPREC;
        
        field.dataSourceFilter = [
            {  'name': 'P_CDCOMPRADOR',		'operator': '=',	'value': row.CDCOMPRADOR },
            {  'name': 'P_NRAPURPREC',	    'operator': '=',	'value': apuracao  },
            {  'name': 'P_CDFORNECED',		'operator': '=',	'value': concatArrayForParams(row.NMFANTFORN) },
            {  'name': 'P_CDFILIAL',		'operator': '=',	'value': concatArrayForParams(row.NMFILIAL)	  }
        ];
        
        field.reload();
    };
    
    function allFieldsExceptComprador(field) {
        return field.name !== 'NMCOMPRADOR';
    }
    
    this.validaApuracao = function(args, field) {
        const widget = templateManager.container.getActiveWidget();
        const stripeRow = templateManager.container.getWidget("stripeWidget").currentRow;
        
        field.dataSourceFilter = [
            {  'name': 'P_CDCOMPRADOR',		'operator': '=',	'value': widget.currentRow.CDCOMPRADOR  },
            {  'name': 'P_1',	            'operator': '=',	'value': 'Em análise'                   },
            {  'name': 'P_CDFILLANC',	    'operator': '=',	'value': stripeRow.CDFILLANC         },
            {  'name': 'P_CDFILCENTCMP',	'operator': '=',	'value': stripeRow.CDFILCENTCMP         }
        ];
        
        field.reload().then(function() {
            if(field.dataSource.data.length == 0) {
                args.e.preventDefault();
                MessageService.showMessageByCode("APURPRECO_NOT_REGISTERED", null, Constants.errorMessage);
            } 
        });
    };
    
    function setReadOnlyFields(widget, readOnlyValue, filterFunction) {
        const fields = filterFunction ? widget.fields.filter(filterFunction) : widget.fields;
        
        fields.map(field => { field.readOnly = readOnlyValue; });
    }
    
    function finalizaExclusaoAF(response) {
        const widgetPrincipal = templateManager.container.getWidget('widgetPrincipal');
        
        widgetPrincipal.reload().then(function(callback) {
            ScreenService.closePopup(true);
            MessageService.successNotificationByCode('SUCCESS_DELETE');
            if (callback.dataset.sup05100_unidades.length){
                widgetPrincipal.dataSource.clearCheckedRows();
            	widgetPrincipal.activate();
            } else {
                widgetPrincipal.currentRow.NRAPURPREC = '';
                
                setStripeValues();
                
                Utilities.startFilter(widgetPrincipal, widgetPrincipal.currentRow);
            }
        });
    }
    
    function getRowForExclusaoAF() {
        const widgetPrincipal = templateManager.container.getWidget('widgetPrincipal');
        const afsSelecionadas = widgetPrincipal.getCheckedRows();
        afsSelecionadas.forEach(row => {
           delete row.__leftActions;
           delete row.__rightActions;
        });
        
        if (Util.isEmptyOrBlank(afsSelecionadas)) {
            const currentRowExclusaoAfs = templateManager.container.getWidget('exclusaoAfsEmAnalise').currentRow;
            
            return {
                AFS_SELECIONADAS: null,
                P_AUTOFORNE: !Util.isEmptyOrBlank(currentRowExclusaoAfs.NRAUTOFORN) ? currentRowExclusaoAfs.CONC_AUTOFORNE : 'T',
                P_NRAPURPREC: concatArrayForParams(currentRowExclusaoAfs.NRAPURPREC),
                P_CDFORNECED: concatArrayForParams(currentRowExclusaoAfs.NMFANTFORN),
                P_CDFILIAL: concatArrayForParams(currentRowExclusaoAfs.NMFILIAL),
                P_CDCOMPRADOR: currentRowExclusaoAfs.CDCOMPRADOR || null
            };
        } else {
            const apuracaoAtual = getApuracaoAtual();
            
            return {
                AFS_SELECIONADAS: afsSelecionadas,
                P_IDQTFRACIONADO: apuracaoAtual.IDQTFRACIONADO,
                P_NRAPURPREC: apuracaoAtual.NRAPURPREC, // widgetPrincipal.currentRow.NRAPURPREC
            };
        }
    }
    
    /**
     * Retorna a concatenação do array passado pro parâmetro. 
     * 
     * @param {Array} arr - array a ser concanetado.
     * @param {string} defaultValue - Valor a ser retornado caso o arr esteja
     * vazio ou em branco.
     * @returns {string} Array concatenado ou o defaultValue passado por
     * parâmetro. Se não houver defaultValue, retorna 'T'.
     */
    function concatArrayForParams(arr, defaultValue = 'T') {
       return !Util.isEmptyOrBlank(arr) ? arr.join('_') : defaultValue;
    }
    
    this.voltarParaWidgetPrincipal = function() {
        const widget = templateManager.container.getWidget('widgetPrincipal');
        
        ScreenService.closePopup();
        widget.unSelectAll();
        
        widget.getAction('remanejarAF').isVisible = false;
        widget.getAction('remanejarAFItens').isVisible = false;
        widget.getAction('remanejarAFItensRelacionados').isVisible = false;
        widget.getAction('remanejarOrcaFina').isVisible = false;
    };
    
    this.onChangeCompradorExclusao = function() {
        const widget = templateManager.container.getWidget('exclusaoAfsEmAnalise');
        const fieldComprador = widget.getField('NMCOMPRADOR');
        
        clearFieldsWidget('exclusaoAfsEmAnalise', allFieldsExceptComprador);
        
        if (!Util.isEmptyOrBlank(fieldComprador.value())) {
            filtraApuracaoAF(widget);
            filtraAF(widget);
        }
    };
    
    function clearFieldsWidget(widgetName, filterFunction) {
        const widget = templateManager.container.getWidget(widgetName);
        const fields = filterFunction ? widget.fields.filter(filterFunction) : widget.fields;
        
        fields.map(field => { field.clearValue(); });
    }
    
    this.confirmarExclusaoAF = function() {
        MessageService.confirmMessageByCode("CONFIRM_OPERATION", null, Constants.confirmationMessage).then(() => {
            const row = getRowForExclusaoAF();
            
            serviceAnalise.excluirAF(row).then(function(success) {
                finalizaExclusaoAF(success);
            }).catch(function(error) {
                exibeMensagemErro(error);
            });
        });
    };
    
    this.liberarAF = function(widget) {
        if (widget.hasCheckedRows()) {
            const apuracao = getApuracaoAtual();
            
            abreEscolhaGerenteDoComprador(apuracao.CDCOMPRADOR);
        } else {
            setPopUpValues(templateManager.container.getWidget('liberarAfsInconsistentes'));
        }
    };
    
    function abreEscolhaGerenteDoComprador(codigoComprador) {
        const widgetGerenteDoComprador = templateManager.container.getWidget('gerenteComprador');
        const fieldGerenteDoComprador = widgetGerenteDoComprador.getField('NMGERENTE');
        
        fieldGerenteDoComprador.dataSourceFilter = [
            {  'name': 'CDOPERGERE',        'operator': '=',    'value': 'T'                                },
            {  'name': 'CDOPERCOMP',        'operator': '=',    'value': codigoComprador                    },
            {  'name': 'NRORG',             'operator': '=',    "value": getLocalVar('NRORG')               }
        ];
        fieldGerenteDoComprador.reload();
        
        ScreenService.openPopup(widgetGerenteDoComprador);
    }
    
    this.confirmarLiberacaoAF = function() {
        const widgetLiberarInconsistencias = templateManager.container.getWidget('liberarAfsInconsistentes');
        
        if (widgetLiberarInconsistencias.isValid()) {
            serviceAnalise.validarBeforeLiberarAF(widgetLiberarInconsistencias.currentRow).then(function() {
                MessageService.confirmMessageByCode("CONFIRM_OPERATION", null, Constants.confirmationMessage).then(() => {
                    abreEscolhaGerenteDoComprador(widgetLiberarInconsistencias.currentRow.CDCOMPRADOR);
                });
            }).catch(function(erro) {
                exibeMensagemErro(erro);
            });
        }
    };
    
    this.onChangeComprador = function() {
        const widgetLiberarInconsistencias = templateManager.container.getWidget('liberarAfsInconsistentes');
        const fieldComprador = widgetLiberarInconsistencias.getField('NMCOMPRADOR');
        
        clearFieldsWidget('liberarAfsInconsistentes', allFieldsExceptComprador);
        
        if (!Util.isEmptyOrBlank(fieldComprador.value())) {
            compradorPossuiGerentes(widgetLiberarInconsistencias).then(function() {
                setReadOnlyFields(widgetLiberarInconsistencias, false, allFieldsExceptComprador);
                filtraApuracaoAF(widgetLiberarInconsistencias);
                filtraAF(widgetLiberarInconsistencias);
            }.bind(this), function(erro) {
                setReadOnlyFields(widgetLiberarInconsistencias, true, allFieldsExceptComprador);
                
                fieldComprador.clearValue();
                widgetLiberarInconsistencias.currentRow.CDCOMPRADOR = '';
                
                exibeMensagemErro(erro);
            });
        } else {
            setReadOnlyFields(widgetLiberarInconsistencias, true, allFieldsExceptComprador);
        }
    };
    
    function compradorPossuiGerentes(widget) {
        return serviceAnalise.verificarGerenteComprador(widget.currentRow);
    }
    
    this.validaAF = function(args, field) {
        const widget = templateManager.container.getActiveWidget();
        
        field.dataSourceFilter = [
            {  'name': 'P_CDCOMPRADOR',		'operator': '=',	'value': widget.currentRow.CDCOMPRADOR },
            {  'name': 'P_NRAPURPREC',	    'operator': '=',	'value': concatArrayForParams(widget.currentRow.NRAPURPREC) },
            {  'name': 'P_CDFORNECED',		'operator': '=',	'value': concatArrayForParams(widget.currentRow.NMFANTFORN) },
            {  'name': 'P_CDFILIAL',		'operator': '=',	'value': concatArrayForParams(widget.currentRow.NMFILIAL)	  }
        ];
        
        field.reload().then(function() {
            if(field.dataSource.data.length === 0) {
                args.e.preventDefault();
                MessageService.showMessageByCode("NAO_HA_AF_INCONSISTENTE", null, Constants.errorMessage);
            } 
        });
    };
    
    this.voltarEscolhaGerenteDoComprador = function() {
        const widget = templateManager.container.getActiveWidget();
        
        clearFieldsWidget('gerenteComprador');
        ScreenService.closePopup();
        
        widget.activate();
    };
    
    this.confirmarEscolhaGerenteDoComprador = function() {
        const widgetGerenteComprador = templateManager.container.getWidget('gerenteComprador');
        
        if (widgetGerenteComprador.isValid()) {
            const currentRowGerenteComprador = widgetGerenteComprador.currentRow;
            
            serviceAnalise.validarSenhaGerente(currentRowGerenteComprador).then(function(response) {
                const row = getRowForLiberacaoAF();
                
                widgetGerenteComprador.currentRow = {};
                
                if(row.AFS_SELECIONADAS != null) {
                    const afsLiberadas = row.AFS_SELECIONADAS.filter(r => {
                        return r.IDAFFORALIM == 'N' && r.IDSITUATUAAF == null;
                    });
                    
                    if(afsLiberadas.length == row.AFS_SELECIONADAS.length) {
                        MessageService.showMessageByCode("AFS_CONSISTENTE_NAO_PODE_LIBERAR");
                    } else if(afsLiberadas.length == 0) {
                            General.callRestEngine("opl_autorizacaoFornecimento#/sup05100_liberar_af_inconsistente", "Row", row).then(function(success) {
                                const widgetPrincipal = templateManager.container.getWidget('widgetPrincipal');
                                
                                widgetPrincipal.reload().then(function() {
                                    ScreenService.closePopup(true);
                                    
                                    widgetPrincipal.dataSource.clearCheckedRows();
                                    widgetPrincipal.activate();
                                    
                                    if (success.messages) {
                                        ScreenService.showMessage(success.messages[0].message);
                                    }
                                    
                                    MessageService.successNotificationByCode('SUCCESS_OPERATION');
                                });
                            });
                    } else {
                        MessageService.confirmMessageByCode("QUESTION_LIBERAR_AFS_CONSISTENTES").then(function(success) {
                            General.callRestEngine("opl_autorizacaoFornecimento#/sup05100_liberar_af_inconsistente", "Row", row).then(function(success) {
                                const widgetPrincipal = templateManager.container.getWidget('widgetPrincipal');
                                
                                widgetPrincipal.reload().then(function() {
                                    ScreenService.closePopup(true);
                                    
                                    widgetPrincipal.dataSource.clearCheckedRows();
                                    widgetPrincipal.activate();
                                    
                                    if (success.messages) {
                                        ScreenService.showMessage(success.messages[0].message);
                                    }
                                    
                                    MessageService.successNotificationByCode('SUCCESS_OPERATION');
                                });
                            });
                        });
                    }
                } else {
                    General.callRestEngine("opl_autorizacaoFornecimento#/sup05100_liberar_af_inconsistente", "Row", row).then(function(success) {
                        const widgetPrincipal = templateManager.container.getWidget('widgetPrincipal');
                                
                        widgetPrincipal.reload().then(function() {
                            ScreenService.closePopup(true);
                                    
                            widgetPrincipal.dataSource.clearCheckedRows();
                            widgetPrincipal.activate();
                                    
                            if(success.messages) {
                                ScreenService.showMessage(success.messages[0].message);
                            }
                                    
                            MessageService.successNotificationByCode('SUCCESS_OPERATION');
                        });
                    });
                }
            }).catch(function(erro) {
                exibeMensagemErro(erro);
                currentRowGerenteComprador.PASSWORD = "";
            });
        }
    };
    
    function getRowForLiberacaoAF() {
        const widgetPrincipal = templateManager.container.getWidget('widgetPrincipal');
        const afsSelecionadas = widgetPrincipal.getCheckedRows();
        afsSelecionadas.forEach(row => {
           delete row.__leftActions;
           delete row.__rightActions;
        });
        const currentRowGerenteComprador = templateManager.container.getWidget('gerenteComprador').currentRow;
        
        if (Util.isEmptyOrBlank(afsSelecionadas)) {
            const currentRowLiberacaoAfs = templateManager.container.getWidget('liberarAfsInconsistentes').currentRow;
            
            return {
                AFS_SELECIONADAS: null,
                P_AUTOFORNE: !Util.isEmptyOrBlank(currentRowLiberacaoAfs.NRAUTOFORN) ? currentRowLiberacaoAfs.CONC_AUTOFORNE : 'T', // Utilizado apenas para o Liberar AF's pela widget 'liberarAfsInconsistentes'
                P_NRAPURPREC: concatArrayForParams(currentRowLiberacaoAfs.NRAPURPREC),
                P_CDFORNECED: concatArrayForParams(currentRowLiberacaoAfs.NMFANTFORN),
                P_CDFILIAL: concatArrayForParams(currentRowLiberacaoAfs.NMFILIAL),
                P_CDCOMPRADOR: currentRowLiberacaoAfs.CDCOMPRADOR,
                P_CDGERENTE: currentRowGerenteComprador.CDGERENTE
            };
        } else {
            const apuracaoAtual = getApuracaoAtual();
            
            var rowFinal = {
                "IDSITAPUPREC": apuracaoAtual.IDSITAPUPREC,
                "P_NRAPURPREC": widgetPrincipal.currentRow.NRAPURPREC, 
                "P_CDGERENTE": currentRowGerenteComprador.CDGERENTE,
                "AFS_SELECIONADAS": afsSelecionadas
            };
            
            return rowFinal;
        }
    }
    
    this.relatorioAnalise = function() {
        const widgetPrincipal = templateManager.container.getWidget('widgetPrincipal');
        
        if(widgetPrincipal.hasCheckedRows()) {
            openPopUpRelatorioAnalise(true);
        } else {
            openPopUpRelatorioAnalise(false);
        }
    };
    
    function openPopUpRelatorioAnalise(hasCheckedRows) {
        const popupWidget = templateManager.container.getWidget('popupRelatorioAnalise');
        
        General.callRestEngine("cmp#/lib_getDataReportField", "Row", ["LIB045"]).then(function(success) {
            var data = getFormattedData(popupWidget.getField("REPORT_NAME"), success.dataset.dataReport);
            setDataSourceCamporReport(popupWidget.getField("REPORT_NAME"), data);
        });
        
        serviceAnalise.retornaCookieEmail({}).then(function(success) {
            popupWidget.getField('ASSUNTO').setValue(success.messages[0].message);
            popupWidget.getField('MENSAGEM').setValue(success.messages[1].message);
            popupWidget.getField('enviarCopiaOperador').setValue(success.messages[2].message);
            
            popupWidget.getField('REPORT_NAME').setValue('padraoEnvioAF.BIRT');
            popupWidget.getField('QR2TYPE').setValue('PDF');
            popupWidget.getField('enviarEmailAF').setValue('S');
            popupWidget.getField('CLASSE').setValue('N');
            
            popupWidget.currentRow.EMITIR_AF = 'N';

            popupWidget.getField('NMFANTFORN').isVisible = !hasCheckedRows;
            popupWidget.getField('NMFILIAL').isVisible = !hasCheckedRows;
            popupWidget.getField('NRAUTOFORN').isVisible = !hasCheckedRows;
            
            setFilterFields(popupWidget);
            
            MessageService.getMessageByCode("MSG_SEND_OPERATOR").then( message => {
                popupWidget.getField('enviarCopiaOperador').label = message + getLocalVar('NMOPERADOR');
            });
            
            ScreenService.openPopup(popupWidget);
        }).catch(function(error) {
            exibeMensagemErro(error);
        });
    }
    
    this.concluirAnalise = function() {
        const widgetPrincipal = templateManager.container.getWidget('widgetPrincipal');
        
        if(widgetPrincipal.hasCheckedRows()) {
            openPopUpConcluirAnalise(true);
        } else {
            openPopUpConcluirAnalise(false);
        }
    };
    
    function openPopUpConcluirAnalise(hasCheckedRows) {
        const popupWidget = templateManager.container.getWidget('popupConcluirAnalise');
        
        General.callRestEngine("cmp#/lib_getDataReportField", "Row", ["LIB045"]).then(function(success) {
            var data = getFormattedData(popupWidget.getField("REPORT_NAME"), success.dataset.dataReport);
            setDataSourceCamporReport(popupWidget.getField("REPORT_NAME"), data);
        });
        
        serviceAnalise.retornaCookieEmail({}).then(function(success) {
            popupWidget.getField('ASSUNTO').setValue(success.messages[0].message);
            popupWidget.getField('MENSAGEM').setValue(success.messages[1].message);
            popupWidget.getField('enviarCopiaOperador').setValue(success.messages[2].message);
            
            popupWidget.getField('REPORT_NAME').setValue('padraoEnvioAF.BIRT');
            popupWidget.getField('QR2TYPE').setValue('PDF');
            popupWidget.getField('enviarEmailAF').setValue('S');
            popupWidget.getField('CLASSE').setValue('N');
            
            popupWidget.currentRow.EMITIR_AF = 'N';

            popupWidget.getField('NMFANTFORN').isVisible = !hasCheckedRows;
            popupWidget.getField('NMFILIAL').isVisible = !hasCheckedRows;
            popupWidget.getField('NRAUTOFORN').isVisible = !hasCheckedRows;
            
            setFilterFields(popupWidget);
            
            MessageService.getMessageByCode("MSG_SEND_OPERATOR").then( message => {
                popupWidget.getField('enviarCopiaOperador').label = message + getLocalVar('NMOPERADOR');
            });
            
            ScreenService.openPopup(popupWidget);
        }).catch(function(error) {
            exibeMensagemErro(error);
        });
    }
    
    function getFormattedData(fieldToChangeData, data) {
        return data
                .filter(function(reportElement) {
                    return !Array.isArray(reportElement);
                })
                .map(function(reportElement) {
                    if (Array.isArray(reportElement)) return;
                    
                    const newElement = {};
                    
                    newElement[fieldToChangeData.valueField] = reportElement.value;
                    newElement[fieldToChangeData.descriptionField] = reportElement.description;
                    newElement[fieldToChangeData.strategyField] = reportElement.strategy;
                    
                    return newElement;
                });
    }
    
    function setDataSourceCamporReport(fieldToChangeData, data) {
        if (!fieldToChangeData.dataSource.data || fieldToChangeData.dataSource.data.length == 0) {
            fieldToChangeData.dataSource.data = data;
        } else {
            const valueField = fieldToChangeData.valueField;
            const descriptionField = fieldToChangeData.descriptionField;
            const strategyField = fieldToChangeData.strategyField;
            
            const removingDuplicatedReports = function(report, index, reports) {
                return index === reports.findIndex(function(r) {
                    return r[valueField] === report[valueField] &&
                           r[descriptionField] === report[descriptionField] &&
                           r[strategyField] === report[strategyField];
                });
            };
            
            const newData = fieldToChangeData.dataSource.data.concat(data);
            
            fieldToChangeData.dataSource.data = newData.filter(removingDuplicatedReports);
        }
    }
    
    function finalizaConclusoaAnalise(success) {
        const widgetPrincipal = templateManager.container.getWidget('widgetPrincipal');
        const actions = widgetPrincipal.actions;
        const afInconsist = success.messages.length ? success.messages[0].message.AF_INCONSIST : false;
        
        if(afInconsist) {
            MessageService.showMessageByCode("INCONSISTENT_NRAPURPREC", {NRAPURPREC: success.messages[0].message.NEW_NRAPURPREC}, Constants.errorMessage);
        } else {
            MessageService.successNotificationByCode('SUCCESS_OPERATION');
        }
        
        ScreenService.closePopup(true);
        widgetPrincipal.reload().then(function(callback) {
            const firstRow = callback.dataset.sup05100_unidades.find(x => x!==undefined);
            
            setStripeValues();
            setVisibilityOfActions(actions, !isApuracaoConcluida());
            widgetPrincipal.showCheckbox = firstRow ? firstRow.IDSITAPUPREC === '1' : true;
            widgetPrincipal.getField('NRAPURPREC').reload();
            widgetPrincipal.unSelectAll();
            widgetPrincipal.reload();
            widgetPrincipal.activate();
            exibeLogEnviosAF(success);
        });
    }
    
    function concluirAF() {
        serviceAnalise.concluirAF(getRowForConclusaoAnalise()).then(function(success) {
            finalizaConclusoaAnalise(success);
        }).catch(function(error) {
            exibeMensagemErro(error);
        });
    }
    
    function salvarRelatorioDeAf() {
        const popupAnalise = templateManager.container.getWidget('popupConcluirAnalise');
        
        MessageService.confirmMessageByCode("VIEW_REPORT", null, Constants.confirmationMessage).then(function(success) {
            popupAnalise.currentRow.EMITIR_AF = 'S';
            concluirAF();
        }, function (error) {
            popupAnalise.currentRow.EMITIR_AF = 'N';
            concluirAF();   
        });
    }
    
    this.confirmarConclusaoAnalise = function() {
        const widgetPrincipal = templateManager.container.getWidget('widgetPrincipal');
        const popUpAnalise = templateManager.container.getWidget('popupConcluirAnalise');
        
        if(popUpAnalise.getField('enviarEmailAF').checked){
            stenviarEmailAF = 'S'; 
            popUpAnalise.currentRow.EMITIR_AF = 'N';
            
            serviceAnalise.defineCookieEmail(popUpAnalise.currentRow).then(function(success) {
                return serviceAnalise.concluirAF(getRowForConclusaoAnalise()).then(function(success) {
                    finalizaConclusoaAnalise(success);
                });
            }).catch(function(error) {
                exibeMensagemErro(error);
                widgetPrincipal.getField('NRAPURPREC').reload();
                widgetPrincipal.unSelectAll();
                widgetPrincipal.reload();
                widgetPrincipal.activate();
            });
        } else {
            stenviarEmailAF = 'N';
            salvarRelatorioDeAf();
        }
    };
    
    this.setVisibilityOfClasse = function(widget) {
        const field = widget.getField('CLASSE');
        
        field.isVisible = widget.getField('enviarEmailAF').checked ? true : false;
    };
    
    function getRowForConclusaoAnalise() {
        const currentRowConclusaoAnalise = templateManager.container.getWidget('popupConcluirAnalise').currentRow;
        const widgetPrincipal = templateManager.container.getWidget('widgetPrincipal');
        const widgetPopUpSelect = templateManager.container.getWidget('popupConcluirAnalise');
        const afsSelecionadas = widgetPrincipal.getCheckedRows();
        afsSelecionadas.forEach(row => {
           delete row.__leftActions;
           delete row.__rightActions;
        });
        const allDataApur = widgetPrincipal.dataSource.data;
        allDataApur.forEach(row => {
           delete row.__leftActions;
           delete row.__rightActions;
        });
        const apurAtual = getApuracaoAtual(); 
        if(stenviarEmailAF === 'S'){
            return {
                "ALL_DATA_APURACAO": allDataApur,
                "CURRENT_ROW": widgetPopUpSelect.currentRow,
                "DADOS_APURACAO": apurAtual,
                "AFS_SELECIONADAS": afsSelecionadas,
                "CLASSE": currentRowConclusaoAnalise.CLASSE ? currentRowConclusaoAnalise.CLASSE : 'N',
                "DADOS_RELATORIO": {
                    "NOME_RELATORIO": currentRowConclusaoAnalise.REPORT_NAME,
                    "EXTENSAO": currentRowConclusaoAnalise.QR2TYPE,
                    "CLASSE": currentRowConclusaoAnalise.CLASSE,
                    "EMITIR_AF": currentRowConclusaoAnalise.EMITIR_AF,
                    "EMAIL_AF": currentRowConclusaoAnalise.enviarEmailAF.checked
                },
                "DADOS_EMAIL": {
                    "ASSUNTO": currentRowConclusaoAnalise.ASSUNTO,
                    "MENSAGEM": Utilities.changeTagRichText(currentRowConclusaoAnalise.MENSAGEM),
                    "enviarCopiaOperador": currentRowConclusaoAnalise.enviarCopiaOperador
                }
            };
        }else{ 
            return {
                "ALL_DATA_APURACAO": allDataApur,
                "CURRENT_ROW": widgetPopUpSelect.currentRow,
                "DADOS_APURACAO": apurAtual,
                "AFS_SELECIONADAS": afsSelecionadas,
                "CLASSE": currentRowConclusaoAnalise.CLASSE ? currentRowConclusaoAnalise.CLASSE : 'N',
                "DADOS_RELATORIO": {
                    "NOME_RELATORIO": currentRowConclusaoAnalise.REPORT_NAME,
                    "EXTENSAO": currentRowConclusaoAnalise.QR2TYPE,
                    "CLASSE": currentRowConclusaoAnalise.CLASSE,
                    "EMITIR_AF": currentRowConclusaoAnalise.EMITIR_AF,
                    "EMAIL_AF": currentRowConclusaoAnalise.enviarEmailAF.checked
                },
                "DADOS_EMAIL": {
                    "ASSUNTO": "",
                    "MENSAGEM": "",
                    "enviarCopiaOperador": ""
                }
            };
        }    
    }
    
    function exibeLogEnviosAF(success) {
        const logSucesso = success.messages[0].message.SUCESSO;
        const logErro = success.messages[0].message.ERRO;
        const widgetOrigem = templateManager.container.getActiveWidget();
        let popupConcluirAnalise = templateManager.container.getWidget('popupConcluirAnalise');
        
        if (!Util.isEmptyOrBlank(logSucesso)) {
            if(popupConcluirAnalise.currentRow.EMITIR_AF === 'S'){
                logSucesso.forEach(log => {
                    openRelatorio(log);
                });
            } else {
                adicionaCabecalhoAoLog(logSucesso, 'Sucesso');
            }
        }
    
        if (!Util.isEmptyOrBlank(logErro)) {
            adicionaCabecalhoAoLog(logErro, 'Erro');
        }
        
        if(popupConcluirAnalise.currentRow.enviarEmailAF === 'S'){
            showLogMessages(widgetOrigem, logErro, logSucesso);
        } else {
            if (!Util.isEmptyOrBlank(logErro)) {
                showLogMessages(widgetOrigem, logErro, logSucesso);
            }
        }
    }
    
    function openRelatorio(url) {
        let popup_window = window.open(url, '_blank');
        
        if (!popup_window) {
            ScreenService.showMessage('Pop-up Blocker is enabled! Please add this site to your exception list.');
        }
    }
    
    function adicionaCabecalhoAoLog(logArray, titulo) {
        logArray.unshift('----------------------------');
        logArray.unshift(titulo);
        logArray.unshift('----------------------------');
    }
    
    function showLogMessages(widgetOrigem, logErro, logSucesso) {
        let mensagem = logErro.concat(logSucesso);
        
        General.showErrorMessages(widgetOrigem, mensagem, ScreenService.i18n('Log'));
    }
    
    this.abreInformacao = function(widgetInformacao) {
        var currentRowProduto = widgetInformacao.container.getWidget('produtos').currentRow;
        var idmotprescaf = currentRowProduto.IDMOTPRESCAF;
        var idtipolanitm = currentRowProduto.IDTIPOLANITM;
        var nrcotpreitaf = currentRowProduto.NRCOTPREITAF ? currentRowProduto.NRCOTPREITAF : '';
        var nrlistaitaf = currentRowProduto.NRLISTAITAF ? currentRowProduto.NRLISTAITAF : '';
        var indexMensagem = '';
        var mensagem = '';
        
        for(var i = 0; i < idmotprescaf.length; i++) {
            indexMensagem = i + idmotprescaf[i];
            mensagem = mensagem + mensagensInformacao(indexMensagem);
        }
        
        if(!mensagem) {
            mensagem = mensagem + mensagensInformacao('M0');
        }
        
        mensagem = mensagem + mensagensInformacao('M1', nrcotpreitaf) + mensagensInformacao('M2', nrlistaitaf);
        
        if(idtipolanitm === 'M') {
            mensagem = mensagem + mensagensInformacao('M3');
        }

        widgetInformacao.currentRow.mensagem = mensagem;
        
        ScreenService.openPopup(widgetInformacao);
    };
    
    function mensagensInformacao(indexMensagem, param) {
        var mensagens = {
            '01': 'Escolhido por Produto Preferencial.\n',
            '17': 'Escolhido por Fornecedor/Marca Obrigatórios.\n',
            '18': 'Escolhido por Fornecedor/Marca Preferenciais.\n',
            '19': 'Escolhido por Fornecedor/Marca Restritivos.\n',
            '24': 'Escolhido por Fornecedor Obrigatório.\n',
            '25': 'Escolhido por Fornecedor Preferencial.\n',
            '26': 'Escolhido por Fornecedor Restritivo.\n',
            '2A': 'Escolhido por Acordo.\n',
            '31': 'Escolhido por Marca Obrigatória.\n',
            '32': 'Escolhido por Marca Preferencial.\n',
            '33': 'Escolhido por Marca Restritiva.\n',
            '41': 'Escolhido da Lista de Preços.\n',
            '42': 'Escolhido da Cotação Fora da Lista.\n',
            '51': 'Apuração para solicitações extras - Fornecedor escolhido não é extra.\n',
            '52': 'Apuração para solicitações extras - Fornecedor escolhido é extra.\n',
            '53': 'Apuração para solicitações não extras.\n',
            'M0': 'Escolhida manualmente.\n',
            'M1': 'Cotação: ' + param + '\n',
            'M2': 'Lista de preços: ' + param + '\n',
            'M3': 'Obs.: Item alterado manualmente.\n'
        };
        
        return mensagens[indexMensagem] ? mensagens[indexMensagem] : '';
    }
    
    this.abreSituacao = function(widgetSituacao) {
        var currentRowProdutos = widgetSituacao.container.getWidget('produtos').currentRow;
        var mensagemSituacao = '';
        var mensagemValidacao = '';
        
        if(currentRowProdutos.DSINCONSITAF) {
            mensagemSituacao = mensagemSituacao + currentRowProdutos.DSINCONSITAF;
        }
        
        //mensagemSituacao = mensagemSituacao.replace(/\s+/g,' ').trim().replace('/', '');
        
        //mensagemSituacao = mensagemSituacao.replaceAll('/', '\n');
        
        widgetSituacao.currentRow.mensagemSituacao = mensagemSituacao;
        
        mensagemValidacao = constroiErrosValidacao(currentRowProdutos.CDPRODUTO + currentRowProdutos.CDMARCA);
        
        if(mensagemValidacao) {
            widgetSituacao.getField('mensagemValidacao').isVisible = true;
            widgetSituacao.currentRow.mensagemValidacao = mensagemValidacao;
        } else {
            widgetSituacao.getField('mensagemValidacao').isVisible = false;
        }
        
        ScreenService.openPopup(widgetSituacao);
    };
    
    this.abreSituacaoAF = function(widgetSituacao) {
        var currentRowAF = widgetSituacao.container.getWidget('widgetPrincipal').currentRow;
        var currentRowStripe = widgetSituacao.container.getWidget('stripeWidget').currentRow;
        var mensagemSituacao = '';
        var dtprogentaf = moment(currentRowAF.DTPROGENTAF, 'L').format();
        var dtPeriodoIni = moment(currentRowStripe.PERIODO.substring(0, 10), 'L').format();
        var dtPeriodoFin = moment(currentRowStripe.PERIODO.substring(13), 'L').format();
        
        if(currentRowAF.IDAFFORALIM == 'S') {
            mensagemSituacao = "AF Fora do Limite.\n";
        }
        if(moment(dtprogentaf).isBefore(moment().format())) {
            mensagemSituacao =  mensagemSituacao +"Data de entrega menor que a data atual.\n";
        }
        if(moment(dtprogentaf).isBefore(dtPeriodoIni) || moment(dtprogentaf).isAfter(dtPeriodoFin)) {
            mensagemSituacao = mensagemSituacao + "Data de entrega fora do período de apuração.\n";
        }
        if(currentRowAF.DSINCONSAF) {
            mensagemSituacao = mensagemSituacao + currentRowAF.DSINCONSAF;
        }
        
        widgetSituacao.currentRow.mensagemSituacao = mensagemSituacao;
        
        ScreenService.openPopup(widgetSituacao);
    };
    
    function constroiErrosValidacao(widgetProduto, prodMarca) {
        var erros = {};
        var mensagemValidacao = '';
        
        if(erros.length) {
            if(erros[prodMarca][0] === 'S') {
                mensagemValidacao = 'Produto não qualificado para o fornecedor da AF informada. \n';
            }
            
            if(erros[prodMarca][1] === 'S') {
                mensagemValidacao = mensagemValidacao + 'Fornecedor da AF informada não possui preço para o produto ou não atende as particularidades do produto na filial. \n';
            }
            
            if(erros[prodMarca][2] === 'S') {
                mensagemValidacao = mensagemValidacao + 'Produto não cadastrado para o fornecedor da AF informada. \n';
            }
            
            if(erros[prodMarca][3] === 'S') {
                mensagemValidacao = mensagemValidacao + 'Não é permitido remanejar item de AF não atendido pelo fornecedor logístico obrigatório, para uma AF com status OL. \n';
            }   
        }
        
        return mensagemValidacao;
    }
    
    /*Remanejamento*/
    
    this.remanejarAF = function(widget = templateManager.container.getActiveWidget(), trocaProd = false) {
        const stripeRow = templateManager.container.getWidget("stripeWidget").currentRow;
        const afsSelecionadas = retornaAFsParaRemanejar();
        
        verificaConfirmarRemanejoAF().then(function() {
            return verificaTodasAFsSelecionadas(afsSelecionadas, stripeRow);
        }).then(function() {
        	const cdfildest = [...new Set(afsSelecionadas.map(row => row.CDFILDEST))];
        	abreEscolhaAF(afsSelecionadas, widget, trocaProd, cdfildest, stripeRow.CDFILLANC, stripeRow.NRAPURPREC);
        }).catch(function(erro) {
            exibeMensagemErro(erro);
        });
    };
    
    function verificaConfirmarRemanejoAF() {
        const deferred = ZHPromise.defer();
        
        if(params.IDCONFREMANEJAF === 'N') {
            return MessageService.confirmMessageByCode("CONFIRM_REMANEJAMENTO", null, Constants.confirmationMessage);
        } else {
            deferred.resolve();  
        }
        
        return deferred.promise;
    }
    
    function verificaTodasAFsSelecionadas(afsSelecionadas, stripeRow) {
        const deferred = ZHPromise.defer();
        const cdfildest = [...new Set(afsSelecionadas.map(row => row.CDFILDEST))];
        
        serviceAnalise.retornaCountAF(cdfildest, stripeRow.CDFILLANC, stripeRow.NRAPURPREC).then(function(callback) {
            const quantidadeAF = callback.dataset.sup05100_afs_count.length ? callback.dataset.sup05100_afs_count[0].QUANTIDADE_AFS : null;
            
            if(afsSelecionadas.length === parseFloat(quantidadeAF)) {
                return MessageService.showMessageByCode("ALL_SELECTED_AF", {CDFILDEST: cdfildest}, Constants.alertMessage);
            } else {
                deferred.resolve();
            }
        });
        
        return deferred.promise;
    }
    
    function abreEscolhaAF(afsSelecionadas, widgetAtiva, trocaProd, cdfildest, cdfillanc, nrseqapuraf) {
        const widgetPrincipal = templateManager.container.getWidget('widgetPrincipal');
        const widgetRemanejo = widgetAtiva.container.getWidget("remanejo");
        const fieldNrautoforn = widgetRemanejo.getField("NRAUTOFORN");
        const principalData = widgetPrincipal.dataSource.data;
        const allRows = principalData.filter(function(afs) {
            return afs.CDFILDEST === cdfildest[0] && afs.CDFILLANC === cdfillanc && afs.NRAPURPREC === nrseqapuraf && !afs.__isSelected;
        });
        
        fieldNrautoforn.dataSource.data = allRows;
        widgetRemanejo.WIDGET_PAI = widgetAtiva.name;
        widgetRemanejo.TROCA_PROD = trocaProd;
        ScreenService.openPopup(widgetRemanejo).then(function() {
            widgetRemanejo.applyDefaultValue();
        });
    }
    
    this.beforeSelectPrincipalRow = function(args) {
        const widgetPrincipal = templateManager.container.getWidget('widgetPrincipal');
        const activeWidget = templateManager.container.getActiveWidget();
        
        if(widgetPrincipal !== activeWidget) {
            ScreenService.closePopup(true);
            ScreenService.closeSwipe();
            widgetPrincipal.activate();
        }
    };
    
    this.verifyDifferentUnidades = function(args) {
        const widgetPrincipal = templateManager.container.getWidget('widgetPrincipal');
        const afsSelecionadas = retornaAFsParaRemanejar();
        const uniqueRows = [...new Set(afsSelecionadas.map(row => row.CDFILDEST))];
        
        setVisibilityOfRemanejarAFActions(widgetPrincipal, uniqueRows.length == 1);
    };
    
    function getActionsByName(widget, namesToFind) {
        return widget.actions.filter(action => { return namesToFind.includes(action.name); });
    }
    
    this.enableRemanejo = function(widget) {
        setVisibilityOfRemanejarAFActions(widget, true);
    };
    
    function setVisibilityOfRemanejarAFActions(widget, isVisible) {
        const orcaOut = widget.dataSource.data.filter(function(afs) {
            return afs.IDORCAFINULTRAP === 'S';
        });
        
        const actionsToFind = [
            'remanejarAF',
            'remanejarAFItens',
            'remanejarAFItensRelacionados',
            'remanejarProdAF',
            'remanejarTrocarProduto'
        ];
        
        if(widget.getAction('remanejarOrcaFina')){
            widget.getAction('remanejarOrcaFina').isVisible = false;
        }
        
        if(orcaOut.length > 0) {
            actionsToFind.push('remanejarOrcaFina');
        }
        
        const actions = getActionsByName(widget, actionsToFind);
        
        isVisible = isVisible && !isApuracaoConcluida();
        setVisibilityOfActions(actions, isVisible);
        widget.activate();
    }
    
    function retornaAFsParaRemanejar() {
        const activeWidget = templateManager.container.getActiveWidget();
        const widgetPrincipal = templateManager.container.getWidget('widgetPrincipal');
        let afsSelecionadas;
        
        if (activeWidget.name === 'actions_widget') {
            afsSelecionadas = widgetPrincipal.getCheckedRows();
            
            if (Util.isEmptyOrBlank(afsSelecionadas)) {
                afsSelecionadas = [widgetPrincipal.currentRow];
            }
        } else {
            afsSelecionadas = widgetPrincipal.getCheckedRows();
        }
        
        afsSelecionadas.forEach(row => {
           delete row.__leftActions;
           delete row.__rightActions;
        });
        
        return afsSelecionadas;
    }
    
    this.confirmarRemanejoAF = function(widgetRemanejo) {
        if(widgetRemanejo.isValid()) {
            const afsSelecionadas = retornaAFsParaRemanejar();
            const afDestino = widgetRemanejo.currentRow;
            const validacaoBlocoAFs = validaBlocoAFs(afsSelecionadas, afDestino);
            const currentRowRemanejo = widgetRemanejo.currentRow;
            const apuracaoAtual = getApuracaoAtual();
            
            exibeMensagemConfirmacao(validacaoBlocoAFs.AF_INCONS).then(function() {
                return exibeMensagemConfirmacao(validacaoBlocoAFs.GERA_DTENTREGA);
            }).then(function() {
                return exibeMensagemConfirmacao(validacaoBlocoAFs.PRORROGAR_DT);
            }).then(function() {
                return exibeMensagemConfirmacao(validacaoBlocoAFs.VALIDADE);
            }).then(function() {
                if(widgetRemanejo.TROCA_PROD) {
                    const prodSelecionados = widgetRemanejo.container.getWidget('produtos').getCheckedRows()[0];
                    abreEscolhaProduto(widgetRemanejo, afDestino, prodSelecionados);
                } else {
                	if(widgetRemanejo.WIDGET_PAI === 'produtos') {
                	    const prodSelecionados = widgetRemanejo.container.getWidget('produtos').getCheckedRows();
                	    
                	    serviceAnalise.remanejarItensAF(prodSelecionados, afDestino, currentRowRemanejo, apuracaoAtual.IDSITAPUPREC).then(function(callback) {
							const messageRemanejo = callback.messages ? callback.messages[0].message : null;
							
							finalizaRemanejamento(messageRemanejo);
						}, function(error) {
							exibeMensagemErroRemanejamento(error);
						});
                	} else {
						serviceAnalise.remanejarAF(afsSelecionadas, afDestino, currentRowRemanejo, apuracaoAtual.IDSITAPUPREC).then(function(callback) {
							const messageRemanejo = callback.messages ? callback.messages[0].message : null;
							
                            finalizaRemanejamento(messageRemanejo);
						}, function(error) {
							exibeMensagemErroRemanejamento(error);
						});
                    }
                }
            }).catch(function(erro) {
                exibeMensagemErro(erro);
            });
        }
    };
    
    function showErrorsRemanejamento(selected_rows) {
        const widgetOrigem = templateManager.container.getActiveWidget();
        let promises = [];
        
    	promises.push(MessageService.getMessageByCode("PRODUCTS_WITHOUT_PRICE"));
    	promises.push(MessageService.getMessageByCode("DISQUALIFIED_PRODUCT"));
    	promises.push(MessageService.getMessageByCode("PRODUCTS_N_REGISTERED_SUPPLIER"));
    	
    	Promise.all(promises).then((messages) => {
            let arrayMesssages = [];
            let arrayError = [];
            	
            if(messages[0]) arrayMesssages.PRODUCTS_WITHOUT_PRICE = messages[0];
            if(messages[1]) arrayMesssages.DISQUALIFIED_PRODUCT = messages[1]; 
            if(messages[2]) arrayMesssages.PRODUCTS_N_REGISTERED_SUPPLIER = messages[2];

            selected_rows.forEach(function(row) {
        		let messageFunction;
            	
            	if(row.P_RESULT_ERROS === 'NNN') {
            	    return MessageService.successNotificationByCode('SUCCESS_OPERATION');
            	}
        		
        		arrayError = setHeader(arrayError, row);
                        
                row.PRODUCTS.forEach(function(product) {
                    if(product.ERROR.substr(0, 1) === 'S') {
						messageFunction = replaceMessage(arrayMesssages.DISQUALIFIED_PRODUCT, product);
						arrayError = arrayError.concat(messageFunction);
					} 
					if(product.ERROR.substr(1, 1) === 'S') {
						messageFunction = replaceMessage(arrayMesssages.PRODUCTS_WITHOUT_PRICE, product);
						arrayError = arrayError.concat(messageFunction);
					} 
					if(product.ERROR.substr(2, 1) === 'S') {
					    messageFunction = replaceMessage(arrayMesssages.PRODUCTS_N_REGISTERED_SUPPLIER, product);
					    arrayError = arrayError.concat(messageFunction);
					}
                });
            });
            
            if(arrayError.length){
                General.showErrorMessages(widgetOrigem, arrayError, ScreenService.i18n('Log'));
            }
    	});
    }
    
    function setHeader(arrayError, row) {
    	let title_array = [];
    	
    	if(!arrayError.includes(row.NRAUTOFORN.concat(' | ', moment(row.DTPROGENTAF, 'DD/MM/YYYY').format('DD/MM/YYYY')))) {
    		title_array.unshift('----------------------------');
            title_array.unshift(row.NRAUTOFORN.concat(' | ', moment(row.DTPROGENTAF, 'DD/MM/YYYY').format('DD/MM/YYYY')));
            title_array.unshift('----------------------------');
    	}
    	
    	return arrayError.concat(title_array);
    }
    
    function replaceMessage(message, row) {
        return message.replace('__NMFANTFORN__', row.NMFANTFORN).replace('__CDARVPROD__', row.CDARVPROD);
    }
    
    function exibeMensagemErroRemanejamento(error) {
        var widgetProdutos = templateManager.container.getWidget('produtos');
        
        if(error.data) {
            if(error.data.errorCode == 100) {
                widgetProdutos.ERROS_REMANEJAMENTO = error.data.error;
                MessageService.showMessageByCode("INVALID_REMANEIO");
                finalizaRemanejamento();
            } else if(error.data.errorCode == 200) {
                widgetProdutos.ERROS_REMANEJAMENTO = error.data.error;
                ScreenService.showMessage(error.data.error);
                finalizaRemanejamento();
            } else {
                exibeMensagemErro(error);
            }
        }
    }
    
    function finalizaRemanejamento(messages) {
        const widgetPrincipal = templateManager.container.getWidget('widgetPrincipal');
        const actions = widgetPrincipal.actions;
        
        ScreenService.closePopup(true);
        ScreenService.closeSwipe();
        widgetPrincipal.reload().then(function() {
            setStripeValues();
            setVisibilityOfActions(actions, !isApuracaoConcluida());
            widgetPrincipal.unSelectAll();
            widgetPrincipal.activate();
            if(messages){
                showErrorsRemanejamento(messages);	
            }
        });
    }
    
    function abreEscolhaProduto(widget, afDestino, prodSelecionados) {
        var widgetEscolhaProd = widget.container.getWidget('remanejoTrocaProd');
        var fieldProduto = widgetEscolhaProd.getField('NMPRODUTO');
        var dtprogentaf = moment(prodSelecionados.DTPROGENTAF, 'DD/MM/YYYY').format('DD/MM/YYYY');
        
        fieldProduto.dataSourceFilter = [
            { 'name': 'CDPRODESTO',     'operator': '=',    'value': prodSelecionados.CDPRODESTO        },
            { 'name': 'CDPRODUTO',      'operator': '=',    'value': prodSelecionados.CDPRODUTO         },
            { 'name': 'CDFORNECED',     'operator': '=',    'value': afDestino.CDFORNECED               },
            { 'name': 'CDFILDEST',      'operator': '=',    'value': prodSelecionados.CDFILDEST         },
            { 'name': 'DTPROGENTAF',    'operator': '=',    'value': dtprogentaf                        },
            { 'name': 'IDMOTIVPRESC',   'operator': '=',    'value': prodSelecionados.IDMOTPRESCAF      },
            { 'name': 'CONSPARTFILDEST','operator': '=',    'value': widget.currentRow.CONSPARTFILDEST  },
            {
                "operator": "ORDER_BY",
                "name": [
                    {
                        "name": "CDARVPROD",
                        "direction": "ASC"
                    },
                    {
                        "name": "VRPRECUNIITM",
                        "direction": "ASC"
                    }
                ]
            }
        ];
        
        fieldProduto.reload().then(function(produtos) {
            produtos = produtos.dataset.sup05100_produtos_itemcole_particularidades ? produtos.dataset.sup05100_produtos_itemcole_particularidades[0] : produtos.dataset.sup05100_produtos_itemcole[0];

            if(produtos) {
                ScreenService.openPopup(widgetEscolhaProd).then(function() {
                    widgetEscolhaProd.applyDefaultValue();
                });
            } else {
                exibeMensagemErro('Não há produtos de mesmo grupo de estoque cotados para o fornecedor da AF de destino ou o mesmo não atende as particularidades do produto na filial.');
            }
        });
    }
    
    function exibeMensagemConfirmacao(mensagem) {
        var deferred = ZHPromise.defer();
        
        if(mensagem) {
            return ScreenService.confirmMessage(mensagem, "question");
        } else {
            deferred.resolve();  
        }

        return deferred.promise;
    }
    
    function validaBlocoAFs(afsSelecionadas, afDestino) {
        const dtprogentafDestinoMoment = moment(afDestino.DTPROGENTAF, 'DD/MM/YYYY');
        const validacaoBlocoAFs = {
            'AF_INCONS': false,
            'GERA_DTENTREGA': false,
            'PRORROGAR_DT': false,
            'VALIDADE': false
        };
        
        afsSelecionadas.forEach(function(af) {
            const dtprogentafOrigemMoment = moment(af.DTPROGENTAF, 'DD/MM/YYYY');
            const nrDiasValidade = converteParaFloat(af.MIN_PRODVALIDADE);
            
            validacaoBlocoAFs.AF_INCONS = !validacaoBlocoAFs.AF_INCONS ? validaAFInconsistente(af.IDSITUATUAAF, af.IDAFFORALIM) : validacaoBlocoAFs.AF_INCONS;
            validacaoBlocoAFs.GERA_DTENTREGA = !validacaoBlocoAFs.GERA_DTENTREGA ? validaDtentregaRemanejamento(afDestino.IDGERAFDTENT, dtprogentafOrigemMoment, dtprogentafDestinoMoment) : validacaoBlocoAFs.GERA_DTENTREGA;
            validacaoBlocoAFs.PRORROGAR_DT = !validacaoBlocoAFs.PRORROGAR_DT ? validaProrrogaDtentrega(dtprogentafOrigemMoment, dtprogentafDestinoMoment) : validacaoBlocoAFs.PRORROGAR_DT;
            validacaoBlocoAFs.VALIDADE = !validacaoBlocoAFs.VALIDADE ? validaValidadeProduto(nrDiasValidade, dtprogentafDestinoMoment, dtprogentafOrigemMoment) : validacaoBlocoAFs.VALIDADE;
        });

        return validacaoBlocoAFs;
    }
    
    
    function validaAFInconsistente(idsituatuaaf, idafforalim) {
        if(!idsituatuaaf && idafforalim === 'N') {
            return "AF não está inconsistente. <br> Deseja continuar?";
        } else {
            return false;
        }
    }
    
    function validaDtentregaRemanejamento(idgerafdtent, dtprogentafOrigem, dtprogentafDestino) {
        if(idgerafdtent === 'S' && dtprogentafDestino.format('DD/MM/YYYY') != dtprogentafOrigem.format('DD/MM/YYYY')) {
            return "Fornecedor da AF destino possui entrega diferente da do Fornecedor da AF origem. <br> Entrega será alterada. <br> Deseja continuar?";
        } else {
            return false;
        }
        
    }
    
    function validaProrrogaDtentrega(dtprogentafOrigem, dtprogentafDestino) {
        if(dtprogentafOrigem < dtprogentafDestino) {
            return "Tem certeza que deseja prorrogar a entrega do produto?";
        } else {
            return false;
        }
    }
    
    
    function validaValidadeProduto(nrDiasValidade, dtprogentafNova, dtprogentafAntiga) {
        if(nrDiasValidade) {
            var diferencaDias = Math.abs(dtprogentafNova.diff(dtprogentafAntiga, 'days'));

            if(diferencaDias > nrDiasValidade) {
                return 'A "Validade (dias)" de um ou mais itens é inferior à diferença de dias entre a entrega atual e a nova data de entrega. <br> Deseja prosseguir?';
            } else {
                return false;
            }
        } else {
            return false;
        }
    }
    
    this.voltarAcoes = function(widget, nomeWidgetActivate) {
        ScreenService.closePopup();
        widget.container.getWidget(nomeWidgetActivate).activate();
    };
    
    this.confirmarRemanejoTrocaProd = function() {
        const widgetRemanejo = templateManager.container.getWidget('remanejo');
        const selectProduct = templateManager.container.getWidget('produtos').getCheckedRows();
    	const apuracaoAtual = getApuracaoAtual();
    	const currentRowRemanejo = widgetRemanejo.currentRow;
    	const currentRowRemanejoTrocaProd = templateManager.container.getWidget('remanejoTrocaProd').currentRow;
    	
        serviceAnalise.remanejarAFTrocaProd(currentRowRemanejo, currentRowRemanejoTrocaProd, selectProduct, apuracaoAtual.IDSITAPUPREC).then(function(callback) {
            const messageRemanejo = callback.messages ? callback.messages[0].message : null;
            
            finalizaRemanejamento(messageRemanejo);
		}, function(error) {
			exibeMensagemErroRemanejamento(error);
		});
    };
    
    this.remanejarAFTrocaProd = function(widgetProduto) {
        const prodSelecionados = widgetProduto.getCheckedRows();
        
        if(validaQuantProdSelecionados(prodSelecionados)) {
            this.remanejarAF(widgetProduto, true);
        }
        
    };
    
    function validaQuantProdSelecionados(prodSelecionados) {
        if(prodSelecionados.length > 1) {
            exibeMensagemErro('É permitido alterar apenas um produto por vez.');
            return false;
        } else {
            return true;
        }
    }
    
    this.checkGridAF = function(widget) {
        const widgetPrincipal = templateManager.container.getWidget('widgetPrincipal');
        
        widgetPrincipal.currentRow.__isSelected = true;
        widgetPrincipal.updateCheckedRows();
    };
    
    this.uncheckGridAF = function(widget) {
        const widgetPrincipal = templateManager.container.getWidget('widgetPrincipal');
        
        if(!widget.getCheckedRows().length) {
            widgetPrincipal.unSelectAll();
        }
    };
    
    this.salvarRelatorioAF = function() {
        MessageService.getMessageByCode("SALVAR_RELATORIO").then( message => {
            openPopUpReenviarEmailSalvarRelatorio(message, false);
        });
    };
    
    this.reenviarEmail = function() {
        MessageService.getMessageByCode("REENVIAR_EMAIL").then( message => {
            openPopUpReenviarEmailSalvarRelatorio(message);
        });
    };
    
    function openPopUpReenviarEmailSalvarRelatorio(label, email = true) {
        const popupWidget = templateManager.container.getWidget('popupReenviarEmailSalvarRelatorio');
        
        General.callRestEngine("cmp#/lib_getDataReportField", "Row", ["LIB045"]).then(function(success) {
            var data = getFormattedData(popupWidget.getField("NOME_RELATORIO"), success.dataset.dataReport);
            
            setDataSourceCamporReport(popupWidget.getField("NOME_RELATORIO"), data);
        });
        
        popupWidget.currentRow.ISRESENDEMAIL = email;
        
        serviceAnalise.retornaCookieEmail(popupWidget.currentRow).then(function(success) {
            popupWidget.label = label;
            popupWidget.getField('NOME_RELATORIO').setValue('padraoEnvioAF.BIRT');
            popupWidget.getField('EXTENSAO').setValue('PDF');
            
            popupWidget.getField('ASSUNTO').isVisible = email;
            popupWidget.getField('ASSUNTO').setValue(success.messages[0].message);
            popupWidget.getField('MENSAGEM').isVisible = email;
            popupWidget.getField('MENSAGEM').setValue(success.messages[1].message);
            
            
            popupWidget.getField('emailNaoEnviado').isVisible = email;
            popupWidget.getField('emailNaoEnviado').setValue('S');
            popupWidget.getField('emailEnviado').isVisible = email;
            popupWidget.getField('emailEnviado').setValue('S');
            
            popupWidget.getField('enviarCopiaOperador').isVisible = email;
            popupWidget.getField('enviarCopiaOperador').setValue(success.messages[2].message);
            
            MessageService.getMessageByCode("MSG_SEND_OPERATOR").then( message => {
                popupWidget.getField('enviarCopiaOperador').label = message + getLocalVar('NMOPERADOR');
            });

            setFilterFields(popupWidget);
            
            ScreenService.openPopup(popupWidget);
        }).catch(function(error) {
            exibeMensagemErro(error);
        });
    }
    
    function setFilterFields(widget) {
        const stripeWidget = templateManager.container.getWidget('stripeWidget');
        
        widget.currentRow.NRAPURPREC = stripeWidget.currentRow.NRAPURPREC;
        widget.currentRow.CDCOMPRADOR = stripeWidget.currentRow.CDCOMPRADOR;
        widget.currentRow.CDFILLANC = stripeWidget.currentRow.CDFILLANC;

        widget.getField('NMFANTFORN').clearValue();
        widget.getField('NMFILIAL').clearValue();
        widget.getField('NRAUTOFORN').clearValue();
    }
    
    function getRowForReenvio(salvarRelatAF) {
        const stripeWidget = templateManager.container.getWidget('stripeWidget');
        const gridWidget = templateManager.container.getWidget('widgetPrincipal');
        const popupWidget = templateManager.container.getWidget('popupReenviarEmailSalvarRelatorio');
        const currentRow = popupWidget.currentRow;
        
        currentRow.CDFILLANC = stripeWidget.currentRow.CDFILLANC;
        currentRow.NRAPURPREC = stripeWidget.currentRow.NRAPURPREC;
        currentRow.CDFILCENTCMP = stripeWidget.currentRow.CDFILCENTCMP;
        currentRow.DTINIAPUPREC = stripeWidget.currentRow.DTINIAPUPREC;
        currentRow.DTFINAPUPREC = stripeWidget.currentRow.DTFINAPUPREC;
        currentRow.IDSITAPUPREC = stripeWidget.currentRow.IDSITAPUPREC;
        currentRow.EMITIR_AF = salvarRelatAF ? 'S' : 'N';
        
        return {
            "ALL_DATA_APURACAO": gridWidget.dataSource.data,
            "CURRENT_ROW": currentRow
        };
    }
    
    function exibeLogReenvioAF(success) {
        const logSucesso = success.messages[0].message.SUCESSO;
        const logErro = success.messages[0].message.ERRO;
        const widgetOrigem = templateManager.container.getActiveWidget();
        const popupWidget = templateManager.container.getWidget('popupReenviarEmailSalvarRelatorio');
        
        if (!Util.isEmptyOrBlank(logSucesso)) {
            if(popupWidget.currentRow.EMITIR_AF === 'S'){
                logSucesso.forEach(log => {
                    openRelatorio(log);
                });      
            } else {
                adicionaCabecalhoAoLog(logSucesso, 'Sucesso');
            }
        }
        
        if (!Util.isEmptyOrBlank(logErro)) {
            adicionaCabecalhoAoLog(logErro, 'Erro');
        }
        
        if(popupWidget.currentRow.ISRESENDEMAIL){
            showLogMessages(widgetOrigem, logErro, logSucesso);
        } else {
            if (!Util.isEmptyOrBlank(logErro)) {
                showLogMessages(widgetOrigem, logErro, logSucesso);
            }
        }
    }
    
    function finalizaReenvio(success) {
        const widgetPrincipal = templateManager.container.getWidget('widgetPrincipal');
        const actions = widgetPrincipal.actions;
        
        widgetPrincipal.reload().then(function(){
            //ScreenService.closePopup(true);
            //setStripeValues();
            //setVisibilityOfActions(actions, !isApuracaoConcluida());
            //widgetPrincipal.getField('NRAPURPREC').reload();
            //widgetPrincipal.activate();
            exibeLogReenvioAF(success);
        });
    }
    
    function saveReportsByCDFORNECEDS() {
        const rowResend = getRowForReenvio(true);
        var fornecedores = [];
            
        rowResend.ALL_DATA_APURACAO.forEach(row => {
            if (fornecedores.indexOf(row.CDFORNECED) == -1) {
                fornecedores.push(row.CDFORNECED);
            }
        });
        return serviceAnalise.resendEmail(getRowForReenvio(true)).then(function(success) {
                //finalizaReenvio(success);
        });
    }
    
    this.confirmaReenvioEmailRelatorio = function() {
        const popupWidget = templateManager.container.getWidget('popupReenviarEmailSalvarRelatorio');
        
        if(popupWidget.currentRow.ISRESENDEMAIL) {
            if(popupWidget.currentRow.emailEnviado === 'N' && popupWidget.currentRow.emailNaoEnviado === 'N') {
                MessageService.showMessageByCode("ERROR_RESEND_NOT_CHECKED", null, Constants.errorMessage);  
            } else {
                serviceAnalise.defineCookieEmail(popupWidget.currentRow).then(function(success) {
                    return serviceAnalise.resendEmail(getRowForReenvio(false)).then(function(success) {
                        finalizaReenvio(success);
                    });
                }).catch(function(error) {
                    exibeMensagemErro(error);
                });   
            }
        } else {
            return serviceAnalise.resendEmail(getRowForReenvio(true)).then(function(success) {
                finalizaReenvio(success);
            });
        }
    };
    
    this.remanejarAFItensApuracao = function(widget, itemRelac) {
        const produtosRemaneja = templateManager.container.getWidget('popupRemanejamentoApuracao');
        let nrAutoForn = [];
    	let cdFilDest = [];
    	let cdFilLanc = [];
    	let cdProduto = [];
    	let nrApurPrec = [];
        
        ScreenService.closePopup(true);
        
        if(widget.name === 'produtos') {
            ScreenService.closeSwipe();
            
            widget.getCheckedRows().forEach(function(af) {
                nrAutoForn.push(af.NRAUTOFORN);
                cdFilDest.push(af.CDFILDEST);
                cdFilLanc.push(af.CDFILLANC);
                nrApurPrec.push(af.NRAPURPREC);
                cdProduto.push(af.CDPRODUTO);
            });
        } else {
            widget.getCheckedRows().forEach(function(af) {
                nrAutoForn.push(af.NRAUTOFORN);
                cdFilDest.push(af.CDFILDEST);
                cdFilLanc.push(af.CDFILLANC);
                nrApurPrec.push(af.NRAPURPREC);
            });
        }
        
        produtosRemaneja.dataSourceFilter = [
            {  'name': 'P_CDFILDEST',      'operator': '=',    'value': concatArrayForParams([...new Set(cdFilDest)]) },
			{  'name': 'P_CDFILLANC',      'operator': '=',    'value': concatArrayForParams([...new Set(cdFilLanc)]) },
			{  'name': 'P_NRSEQAPURAF',    'operator': '=',    'value': concatArrayForParams([...new Set(nrApurPrec)]) },
			{  'name': 'P_CDPRODUTO',      'operator': '=',    'value': concatArrayForParams([...new Set(cdProduto)]) },
			{  'name': 'P_NRAUTOFORN',     'operator': '=',    'value': concatArrayForParams([...new Set(nrAutoForn)]) },
			{  'name': 'P_ITENSRELAC',     'operator': '=',    'value': itemRelac }
		];
        
        produtosRemaneja.reload();
        
        ScreenService.openPopup(produtosRemaneja);
    };
    
    this.concluiRemanejamentoApuracao = function(){
        const widgetPrincipal = templateManager.container.getWidget('widgetPrincipal');
        const widget = templateManager.container.getWidget('popupRemanejamentoApuracao');
        
        serviceAnalise.concluiRemanejamentoApuracao(widget.getCheckedRows()).then(function(mensagem) {
            ScreenService.closePopup(true);
            widgetPrincipal.unSelectAll();
            widgetPrincipal.reload();
            widgetPrincipal.activate();
            MessageService.successNotificationByCode('SUCCESS_OPERATION');
        }).catch(function(erro) {
            exibeMensagemErro(erro);
        });
        
    };
    
    this.onSelectAllRemanejamento = function(widget) {
        widget.dataSource.data.forEach(register => {
            register.__notSelectable = true;
        });
    };
    
    this.onSelectRowRemanejamento = function(args) {
        if (args.selectedRow.ID) {
            args.owner.dataSource.removeCheckedRows([args.selectedRow]);
		} else {
		    var rows = args.owner.dataSource.data.filter(function(item) {
    			return item.PARENT && item.__isSelected && item.PARENT === args.selectedRow.PARENT;
    		});
    		
    		if(rows.length > 1){
    		    args.owner.dataSource.removeCheckedRows([args.selectedRow]);    
    		}
		}
    };
    
    this.remanejarOrcaFina = function(widget) {
        const firstRow = widget.dataSource.getFirstRow();
        
        serviceAnalise.openRemanejoEmpresa(widget.getCheckedRows()).then(function(response) {
            ScreenService.openWindow('opl_autorizacaoFornecimento#sup05100_remaneja_empresa').then(function() {
                const widgetRemanejEmpr = templateManager.container.getWidget('widgetRemanejoEmpresa');
                
                widgetRemanejEmpr.dataSource.data = response.dataset.autoforne;
                widgetRemanejEmpr.activate();
                
                serStripeOrcaFina(firstRow);
                
            });
        }).catch(function(error) {
            exibeMensagemErro(error);
        });
    };
    
    function serStripeOrcaFina(row){
        const stripeWidget = templateManager.container.getWidget('stripeRemanejoEmpresa');
    
        stripeWidget.currentRow.NRAPURPREC = row.NRAPURPREC;
        stripeWidget.currentRow.VRTOTALAPURAC = row.VRTOTALAPURAC;
        stripeWidget.currentRow.DESCCOMPRADOR = row.CDCOMPRADOR.concat(' | ', row.NMOPERADOR);
        stripeWidget.currentRow.PERIODO = moment(row.DTINIAPUPREC, 'DD/MM/YYYY').format('DD/MM/YYYY').concat(' | ', moment(row.DTFINAPUPREC, 'DD/MM/YYYY').format('DD/MM/YYYY'));
        stripeWidget.currentRow.IDSITAPUPREC = row.IDSITAPUPREC;
        stripeWidget.currentRow.DSSITAPUPREC = stripeWidget.getField('DSSITAPUPREC').options[row.IDSITAPUPREC];
        stripeWidget.currentRow.CDCOMPRADOR = row.CDCOMPRADOR;
        stripeWidget.currentRow.NMCOMPRADOR = row.NMCOMPRADOR;
        stripeWidget.currentRow.CDOPERADOR = row.CDOPERADOR;
        stripeWidget.currentRow.NMOPERADOR = row.NMOPERADOR;
        stripeWidget.currentRow.DTAPURPREC = row.DTAPURPREC;
        stripeWidget.currentRow.DTINIAPUPREC = moment(row.DTINIAPUPREC, 'DD/MM/YYYY').format('DD/MM/YYYY');
        stripeWidget.currentRow.DTFINAPUPREC = moment(row.DTFINAPUPREC, 'DD/MM/YYYY').format('DD/MM/YYYY');
        stripeWidget.currentRow.CDFILLANC = row.CDFILLANC;
        stripeWidget.currentRow.CDFILCENTCMP = row.CDFILCENTCMP;
        
        stripeWidget.currentRow.VRTOTALAPURAC = aplicarMascara(stripeWidget, 'VRTOTALAPURAC');
    }
    
    function loadVencimentos(widget, newEmpresa = null, newClassFina = null){
        const vencimentoWidget = templateManager.container.getWidget("vencimentoWidget");
        
        vencimentoWidget.dataSourceFilter = [
            {
                "name": "P_CDFILDEST",
                "operator": "=",
                "value": widget.currentRow.CDFILDEST
            },
            {
                "name": "P_CDFILLANC",
                "operator": "=",
                "value": widget.currentRow.CDFILLANC
            },
            {
                "name": "P_NRAUTOFORN",
                "operator": "=",
                "value": widget.currentRow.NRAUTOFORN
            },
            {
                "name": "P_NEWEMPRESA",
                "operator": "=",
                "value": newEmpresa
            },
            {
                "name": "P_NEWCLASSFINA",
                "operator": "=",
                "value": newClassFina
            }
        ];
        
        vencimentoWidget.reload().then(function(callback){
            vencimentoWidget.activate();
        });
        
    }
    
    function actionsControl(isEdit) {
        const vencimentoWidget = templateManager.container.getWidget("vencimentoWidget");
        
        vencimentoWidget.getAction('voltarGridAF').isVisible = !isEdit;
        vencimentoWidget.getAction('saveRemanejo').isVisible = isEdit;
        vencimentoWidget.getAction('cancelRemanejo').isVisible = isEdit;
    }
    
    this.afterMoveRowGridRemanejaEmpresa = function(widget) {
        const tabbedWidget = templateManager.container.getWidget("tabbedWidget");
        
        tabbedWidget.currentRow = widget.dataSource.data[widget.currentRow.__index];
        
        loadVencimentos(widget);
        
        tabbedWidget.getField('NMEMPRESA').dataSourceFilter = [
            {
                "name": "P_CDFILIAL",
                "operator": "=",
                "value": tabbedWidget.currentRow.CDFILDEST
            }
        ];
        
        tabbedWidget.getField('DSTPCTPAGAR').dataSourceFilter = [
            {
                "name": "P_CDEMPRESA",
                "operator": "=",
                "value": tabbedWidget.currentRow.CDEMPRESA
            }
        ];
        
        ScreenService.openSwipe(tabbedWidget, true);
        actionsControl(false);
    };
    
    this.cancelarRemanejEmpresa = function(widget) {
        renderEngine.changeContainer(`opl_autorizacaoFornecimento#sup05100_analise_AF`);
        const widgetPrincipal = templateManager.container.getWidget("widgetPrincipal");
        
        widgetPrincipal.backFromRemanejo = true;
    };
    
    this.backToGridRemanejo = function(widget) {
        const widgetListaAF = templateManager.container.getWidget("widgetRemanejoEmpresa");
        
        serviceAnalise.openRemanejoEmpresa(widgetListaAF.dataSource.data).then(function(response) {
            widgetListaAF.dataSource.data = response.dataset.autoforne;
            
            ScreenService.closeSwipe();
            widgetListaAF.list();
            actionsControl(false);
            
        }).catch(function(error) {
            exibeMensagemErro(error);
        });
    };
    
    this.cancelRemanejo = function(widget) {
        const widgetListaAF = templateManager.container.getWidget("widgetRemanejoEmpresa");
        const tabbedWidget = templateManager.container.getWidget("tabbedWidget");
        
        serviceAnalise.openRemanejoEmpresa(widgetListaAF.dataSource.data).then(function(response) {
            widgetListaAF.dataSource.data = response.dataset.autoforne;
            tabbedWidget.currentRow = widgetListaAF.dataSource.data[widgetListaAF.currentRow.__index];
            
            ScreenService.closeSwipe();
            widgetListaAF.list();
            actionsControl(false);
            
        }).catch(function(error) {
            exibeMensagemErro(error);
        });
        
    };
    
    this.clearTipoConta = function() {
        const widget = templateManager.container.getWidget('tabbedWidget');
        
        widget.getField('DSTPCTPAGAR').dataSourceFilter = [
            {
                "name": "P_CDEMPRESA",
                "operator": "=",
                "value": widget.currentRow.CDEMPRESA
            }
        ];
        
        widget.currentRow.CDTPCTPAGAR = '';
        widget.currentRow.CDCLASSFINA = '';
        widget.currentRow.DSCLASSFINA = '';
        widget.currentRow.DSCLFINANCEIRA = '';
        widget.currentRow.DSTIPOCTPAGAR = '';
        widget.currentRow.DSTPCTPAGAR = '';
        
        if(widget.currentRow.CDEMPRESA && widget.currentRow.CDCLASSFINA){
            loadVencimentos(widget, widget.currentRow.CDEMPRESA, widget.currentRow.CDCLASSFINA);
        } else {
            clearVencimentos();
        }
        
        actionsControl(true);
    };
    
    function clearVencimentos() {
        templateManager.container.getWidget("vencimentoWidget").dataSource.data = [];
    }
    
    this.showOrcaFina = function() {
        const tabbedWidget = templateManager.container.getWidget('tabbedWidget');
        
        if(tabbedWidget.currentRow.CDEMPRESA && tabbedWidget.currentRow.CDCLASSFINA){
            loadVencimentos(tabbedWidget, tabbedWidget.currentRow.CDEMPRESA, tabbedWidget.currentRow.CDCLASSFINA);
        } else {
            clearVencimentos();
        }
        
        actionsControl(true);
    };
    
    this.saveRemanejo = function(widget) {
        const widgetListaAF = templateManager.container.getWidget("widgetRemanejoEmpresa");
        const tabbedWidget = templateManager.container.getWidget("tabbedWidget");
        
        serviceAnalise.saveRemanejoEmpresa({'ROW': tabbedWidget.currentRow, 'DATA': widgetListaAF.dataSource.data}).then(function(response) {
            widgetListaAF.dataSource.data = response.dataset.autoforne;
            tabbedWidget.currentRow = widgetListaAF.dataSource.data[widgetListaAF.currentRow.__index];
            
            ScreenService.closeSwipe();
            widgetListaAF.list();
            actionsControl(false);
            
        }).catch(function(error) {
            exibeMensagemErro(error);
        });
    };
    
    this.validaIcone = function(row) {
        if((row.IDSITUATUAAF == '1' && !Util.isEmptyOrBlank(row.DSINCONSAF)) || (row.IDAFFORALIM == 'S')) {
            return true;
        } else {
            return false;
        }
    };
    
    this.validaControleAF = function(row) {
        var currentRowStripe = templateManager.container.getWidget('stripeWidget').currentRow;
        
        var dtprogentaf = moment(row.DTPROGENTAF, 'L').format();
        var dtPeriodoIni = moment(currentRowStripe.PERIODO.substring(0, 10), 'L').format();
        var dtPeriodoFin = moment(currentRowStripe.PERIODO.substring(13), 'L').format();
        
        if(currentRowStripe.IDSITAPUPREC == '3') {
            return 'N';
        } else {
            if(moment(dtprogentaf).isBefore(moment().format())) {
                return "AT";
            } else {
                if(moment(dtprogentaf).isBefore(dtPeriodoIni) || moment(dtprogentaf).isAfter(dtPeriodoFin)) {
                    return "AP";
                } else {
                    return 'N';
                } 
            }
        }
    };
    
    this.stripeDataAtual = function(row) {
        return true;
    };
    
    this.stripeDataApur = function(row) {
        return true;
    };
    
    this.validaDataEntregaDiaLimite = function(field) {
        if(params.NRDIALIMITITMAF != null && Number(params.NRDIALIMITITMAF) > 0) {
            var dataParametro = moment(field.value(), 'L').subtract(Number(params.NRDIALIMITITMAF), 'days').format('L');
            var dataAtual = moment().format('L');
            var dataOriginal  = field.widget.currentRow.DTPROGENTAF_ORIG;
            
            if(moment(moment(dataAtual, 'L').format()).isAfter(moment(dataParametro, 'L').format())) {
                MessageService.showMessageByCode("NRDIALIMITITMAF_BLOQUEIO");
                
                field.setValue(dataOriginal);
                field.widget.currentRow.DTPROGENTAF = dataOriginal;
            }
        }
    };
}

Configuration(function(ContextRegister) {
    ContextRegister.register('sup05100_analise_AF_Controller', sup05100_analise_AF_Controller);
});

// FILE: ./assets/modules/consolidacao/assets/modules/autoforne/assets/js/controllers/PrioridadeSeparacaoOLController.js
function PrioridadeSeparacaoOLController(ScreenService, templateManager,RestEngine, General, maskEngine, ZhFilterPreferences, Utilities) {

    this.setStripeValues = function(widget) {
        
        var filterRow = widget.appliedFilter.FILTER_ROW;
        var stripe = templateManager.container.getWidget('stripe');
       
        stripe.getField('labelStripeUnidade').label ="Operador Logístico: " + filterRow.CDFILIAL + ' - ' + filterRow.NMFILIAL;
    };
    
    this.verificaProjectCorp = function(widget){
        if(window.projectCorp){
            widget.getField("NMFILIAL").filterProperties.readOnly = false;
        } else{
            widget.getField("NMFILIAL").filterProperties.readOnly = true;
        }
    };
    
    this.onEnter = function (widget) {
        var filterRow = {};
        this.verificaProjectCorp(widget);
	    filterRow.NRORG    = getLocalVar('NRORG');
        Utilities.startFilter(templateManager.container.getActiveWidget(), filterRow);
    };
    
    this.dataSourceFilterProduto = function(widget){
        var widgetListUnidade = widget.container.getWidget('listFiliais');
        var gridPrioridade = widget.container.getWidget('gridPrioridade');
        if (gridPrioridade.appliedFilter){
            gridPrioridade._filterInfo[0].label = 'OL';
            widgetListUnidade.dataSourceFilter = [
                {
                    "name": "P_CDFILIOPELOG",
                    "operator": "=",
                    "value": gridPrioridade.appliedFilter.FILTER_ROW.CDFILIAL
                }
            ];
            gridPrioridade.dataSourceFilter = [
                {
                    "name": "P_CDFILIOPELOG",
                    "operator": "=",
                    "value": gridPrioridade.appliedFilter.FILTER_ROW.CDFILIAL
                }
            ];
            enterDashBoard(widget);
        }
    };
    
    this.moveSelectedRowsToGridPrioridade = function(widget){
        moveRowsToGridPrioridade(widget, widget.container.getWidget('listFiliais').dataSource.getCheckedRows());
    };
    
    this.moveAllRegistersToRight = function(widget){
        moveRowsToGridPrioridade(widget, widget.container.getWidget('listFiliais').dataSource.data);   
    };
    
    var moveRowsToGridPrioridade = function(widget, dataset){
        var tamanho = widget.container.getWidget('gridPrioridade').dataSource.data.length;
        var nrPrioridade = 1;
        if(tamanho > 0){
            nrPrioridade = widget.container.getWidget('gridPrioridade').dataSource.data[tamanho-1].NRPRIORIDADE+1;
        }
        dataset.forEach(function(unidade){
            unidade.NRPRIORIDADE = nrPrioridade;
            nrPrioridade = nrPrioridade+1;
        });
        General.callRestEngine('opl_autoforne#/prioridadeOLController/moveSelectedRowsToPrioridade','DataSet',dataset).then(function(calback) {
            enterDashBoard(widget);
        });
    };
    
    this.upRegisterOnPrioridade = function(widget){
        if(widget.dataSource.getCheckedRows().length == 1){
            var index = widget.dataSource.data.indexOf(widget.dataSource.getCheckedRows()[0]);
            var nrPrioridade = widget.dataSource.data[index-1].NRPRIORIDADE;
            
            widget.dataSource.data[index-1].NRPRIORIDADE = widget.dataSource.getCheckedRows()[0].NRPRIORIDADE;
            widget.dataSource.getCheckedRows()[0].NRPRIORIDADE = nrPrioridade;
            General.callRestEngine('opl_autoforne#/prioridadeOLController/updateRegisterOnPrioridade','DataSet',widget.dataSource.data).then(function(calback) {
                enterDashBoard(widget);
            });
        }
    };
    
    this.upFirstRegisterOnPrioridade = function(widget){
        if(widget.dataSource.getCheckedRows().length == 1){
            var index = widget.dataSource.data.indexOf(widget.dataSource.getCheckedRows()[0]);
            widget.dataSource.getCheckedRows()[0].NRPRIORIDADE = widget.dataSource.data[0].NRPRIORIDADE;
            for(var i = 0; i < index; i++) {
                widget.dataSource.data[i].NRPRIORIDADE = widget.dataSource.data[i].NRPRIORIDADE+1;
            }
            General.callRestEngine('opl_autoforne#/prioridadeOLController/updateRegisterOnPrioridade','DataSet',widget.dataSource.data).then(function(calback) {
                enterDashBoard(widget);
            });
        }
    };
    
    this.dowLastRegisterOnPrioridade = function(widget){
        if(widget.dataSource.getCheckedRows().length == 1){
            var index = widget.dataSource.data.indexOf(widget.dataSource.getCheckedRows()[0]);
            var maior = widget.dataSource.data.length;
            widget.dataSource.getCheckedRows()[0].NRPRIORIDADE = widget.dataSource.data[maior-1].NRPRIORIDADE;
            for(var i = maior-1; i > index; i--) {
                widget.dataSource.data[i].NRPRIORIDADE = widget.dataSource.data[i].NRPRIORIDADE-1;
            }
            General.callRestEngine('opl_autoforne#/prioridadeOLController/updateRegisterOnPrioridade','DataSet',widget.dataSource.data).then(function(calback) {
                enterDashBoard(widget);
            });
        }
    };
    
    this.dowRegisterOnPrioridade = function(widget){
        if(widget.dataSource.getCheckedRows().length == 1){
            var index = widget.dataSource.data.indexOf(widget.dataSource.getCheckedRows()[0]);
            var nrPrioridade = widget.dataSource.data[index+1].NRPRIORIDADE;
            
            widget.dataSource.data[index+1].NRPRIORIDADE = widget.dataSource.getCheckedRows()[0].NRPRIORIDADE;
            widget.dataSource.getCheckedRows()[0].NRPRIORIDADE = nrPrioridade;
            General.callRestEngine('opl_autoforne#/prioridadeOLController/updateRegisterOnPrioridade','DataSet',widget.dataSource.data).then(function(calback) {
                enterDashBoard(widget);
            });
        }
    };
    
    var enterDashBoard = function(widget){
        var widgetListUnidade = widget.container.getWidget('listFiliais');
        var gridPrioridade = widget.container.getWidget('gridPrioridade');
        
    	widgetListUnidade.dataSource.clearCheckedRows();
		widgetListUnidade.refreshData = false;
		widgetListUnidade.reload();

		gridPrioridade.dataSource.clearCheckedRows();
		gridPrioridade.refreshData = false;
		gridPrioridade.reload();	
		gridPrioridade.activate();
    };
    
    this.activateActionMoveAllRows = function(widget){
        var widgetListUnidade = widget.container.getWidget('listFiliais');
        var gridPrioridade = widget.container.getWidget('gridPrioridade');
        var dashboardPrioridade = widget.container.getWidget('dashboardPrioridade');
        dashboardPrioridade.getAction('moveAllToRight_always').isVisible = widgetListUnidade.dataSource.data.length > 0;
		gridPrioridade.getAction('moveAllToRight_list').isVisible = widgetListUnidade.dataSource.data.length > 0;     
    };
    
    this.activateWidgetOnSelectRow = function(widget){
		widget.activate();
	};
	
	this.unselectAllRows = function(widgetName){
		var widget = templateManager.container.getWidget(widgetName);
		
		widget.dataSource.clearCheckedRows();
	};
	
	this.activateWidgetOnUnselectAll = function(widget){
		if(widget.dataSource.getCheckedRows().length == 0){
			widget.activate();
		}
	};
	
	this.activateWidgetOnUnselectAll = function(widget, widgetTargetName){
		var widgetTarget = templateManager.container.getWidget(widgetTargetName);
		if(widget.dataSource.getCheckedRows().length == 0){
			widgetTarget.activate();
		}
	};
	
	this.changeMoveButtonsVisibility = function(widget){
		var dataSource = widget.dataSource;
		widget.activate();
		if(dataSource.getCheckedRows().length>1){
			
			widget.getAction('moveUp').isVisible = false;
			widget.getAction('moveUpAll').isVisible = false;
			widget.getAction('moveDown').isVisible = false;
			widget.getAction('moveDownAll').isVisible = false;
		} else {
			var index = dataSource.data.indexOf(dataSource.getCheckedRows()[0]);
			
			widget.getAction('moveUp').isVisible = index == 0 ? false : true;
			widget.getAction('moveUpAll').isVisible = index == 0 ? false : true;
			widget.getAction('moveDown').isVisible = index == dataSource.data.length-1 ? false : true;
			widget.getAction('moveDownAll').isVisible = index == dataSource.data.length-1 ? false : true;
		}
	}; 
	
	this.excluirPrioridade = function (gridPrioridade) {
		General.deleteCrudCheckedRows(gridPrioridade).then(function () {
			gridPrioridade.dataSource.save().then(function () {
				enterDashBoard(gridPrioridade.parent);
			});
		});
	};

}
Configuration(function (ContextRegister) {
	ContextRegister.register('PrioridadeSeparacaoOLController', PrioridadeSeparacaoOLController);
});

// FILE: ./assets/modules/consolidacao/assets/modules/solicitacao/assets/js/controllers/CalculoDaNecessidadeOLController.js
var CalculoDaNecessidadeOLController = function (ScreenService, MessageService, General, restEngine, templateManager) {
    var self = this;
    var idutilconssoliol;
    var grupo;
    var arrayNeceComp;
    var nrseqOL;
    var parametrosParaSupri;
    
    this.getAgrupamentoProdutoOL = function(widget) {
        var nmsubgrprod = widget.getField('NMSUBGRPROD');
        nmsubgrprod.dataSourceFilter = [
            {"name": "CDFILIAL",    "value": widget.currentRow.CDFILIALOL, "operator": "="},
            {"name": "NRORG",       "value": getLocalVar('NRORG'),         "operator": "="},
            {"operator": "ORDER_BY", "name": [{"name": "CDSUBGRPROD", "direction": "ASC"}]}
        ];
        nmsubgrprod.reload();
    };
    
    this.validaFilialOL = function(args){
        if(!args.owner.field.widget.currentRow.CDFILIALOL) {
            MessageService.showMessageByCode("INFORMAR_OL");
            args.e.preventDefault();
            return false; 
        }
    };
	
	this.setDataMin = function (widget){
        widget.getField('DTFIM').value('');
        widget.getField('DTFIM').minDate = widget.currentRow.DTINI;
        widget.getField('DTFIM').defaultValue = widget.currentRow.DTINI;
    };
    
    this.intervaloChange = function(field) {
        let widget = field.widget;
        widget.currentRow.DTINI = widget.currentRow.INTERVALO.start;
        widget.currentRow.DTFIM = widget.currentRow.INTERVALO.end;
    };

    
    this.setProdFinalMin = function(widget){
        var nmprodfin = widget.getField('NMPRODFIN');
        nmprodfin.dataSourceFilter = [
            {"name": "CDARVPROD",    "value": widget.currentRow.CDPRODINI, "operator": ">="},
            {"name": "NRORG",       "value": getLocalVar('NRORG'),         "operator": "="},
            {"operator": "ORDER_BY", "name": [{"name": "CDARVPROD", "direction": "ASC"}]}
        ];
        nmprodfin.reload();
    };
    
    var validaAcrecimos = function(field){
        if(field < 0 || field > 100) {
            ScreenService.showMessage(mensagem);
            return false;
        } else {
            return true;
        }
    };
    
    var validaProduto = function(prodInicial, prodFinal) {
        if (!General.comparaPratoProduto(prodInicial, prodFinal, getLocalVar('CDPICTPROD'))) {
            MessageService.showMessageByCode("PRODUTO_INICIAL_MENOR_IGUAL_FINAL");
            return false;
        }
        return true;
    };
    
    var validaProdutoFinal = function(row) { 
        var aux = 'ZZZZZZZZZZZZZZZZZZZZ';
        var str = row.CDPRODFIN;
        var produto = str + aux.substr(0, aux.length - str.length); 
        return produto;
    };
    
    var validaDataInicial = function(dtinicial) {
        if (moment(dtinicial, 'DD/MM/YYYY') < moment(getLocalVar('DTPROCESSA'), 'DD/MM/YYYY')) {
            MessageService.showMessageByCode("DATA_MAIOR_IGUAL_PROCESSAMENTO");
            return false;
        }
        return true;
    };
    
    
    this.setDadosTela = function (args){
        var widget = args.owner.getWidget('calculoNecessidadeComprasOL');
        var resp;
        
        General.callRestEngine("opl_solicitacao#/getCentralCompras", "Row", {}).then(function(response) {
            resp = response.dataset.data;
            
            const filter = [
                {
        			"name": "CDFILIAL",
        			"operator": "=",
        			"value": resp.CDFILIAL
        		},
        		{
        			"name": "NRORG",
        			"operator": "=",
        			"value": resp.NRORG
        		}
        	];
        	
            General.callRestEngine("opl#/crud/parasupri", "FilterData", filter).then(function(response) {
                parametrosParaSupri = response.dataset.parasupri[0];
            }).catch(function(error) {
                MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
            });
        }).catch(function(error) {
            if(error.data.error == "CDFILCENTCMP_NOT_REGISTERED") {
                MessageService.showMessageByCode(error.data.error);
            } else {
                MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
            }
        });
        
        General.callRestEngine('/setDadosCalculo', 'Row', widget.currentRow).then(function(calback) {
            var resposta = calback.dataset.resposta;
            idutilconssoliol = resposta.IDUTILCONSSOLIOL;
            grupo = resposta.CDGRUPPROD;
            
            if(resposta.IDGERACMPOLPER == 'S') {
                widget.getField("geraSolicitacaOL").isVisible = true;
            } else {
                widget.getField("geraSolicitacaOL").isVisible = false;
            }
            if(resposta.IDUTILCONSSOLIOLEXT == 'S') {
                widget.getField("geraConsolidacaoOL").isVisible = true;
            } else {
                widget.getField("geraConsolidacaoOL").isVisible = false;
            }
            
            widget.currentRow.geraConsolidacaoOL = 'T';
            widget.currentRow.geraSolicitacaOL = 'N';
            widget.currentRow.DTINI = moment().format('L');
            widget.currentRow.DTFIM = moment().format('L');
        }.bind());                                                               
    };
    
    var setSubgrupo = function(row){
        if(row.naoConsidera == 'T'){
            return 'T';
        }  else{
            return row.NMSUBGRPROD.join('_');
        }
    };
    
    var dataSourceFilterSolicitacao = function(widget) {
		var filtro = [
			{
			    "name": "P_CDFILIAL",
			    "operator": "=",
			    "value": widget.currentRow.CDFILSOLI ? widget.currentRow.CDFILSOLI : null
			},
			{
			    "name": "P_DTINI",
			    "operator": "=",
			    "value": widget.currentRow.DTINI ? widget.currentRow.DTINI : null
			},
			{
			    "name": "P_DTFIN",
			    "operator": "=",
			    "value": widget.currentRow.DTFIM ? widget.currentRow.DTFIM : null
			},
			{
			    "name": "P_CDPRODUTOINI",
			    "operator": "=",
			    "value": widget.currentRow.CDPRODINI ? widget.currentRow.CDPRODINI : null
			},
			{
			    "name": "P_CDPRODUTOFIN",
			    "operator": "=",
			    "value": widget.currentRow.CDPRODFIN ? (angular.copy(widget.currentRow.CDPRODFIN) + "ZZZZZZZZZZZZZZZZZZZZ").substr(0, 20) : null
			},
			{
			    "name": "P_SUBGRUPO",
			    "operator": "=",
			    "value": setSubgrupo(widget.currentRow) ? setSubgrupo(widget.currentRow) : null
			}
		];
		return filtro;
	};
    
    var verificaSolicitacao = function(widget) {
        if(widget.isValid()) {
			var widgetSolic = widget.container.getWidget('sup07500_existemSolicitacoes');
			
			widget.currentRow.CDFILSOLI = widget.currentRow.CDFILIALOL;
			
			widgetSolic.dataSourceFilter = dataSourceFilterSolicitacao(widget); 
			widgetSolic.reload().then(function(callback) {
			    if(callback.dataset.resposta.length > 0) {
			        ScreenService.openPopup(widgetSolic);
			        
				    widgetSolic.activate();
			    } else {
			        calcula(widget);
			    }
			});
		}
    };
    
    var calcula = function(widget) {
        widget.currentRow.DATMOMENT = moment().format('DD/MM/YYYY');
        widget.currentRow.CDGRUPPROD = grupo;
        
        if(widget.currentRow.consPrevisaoConsumo == 'S') {
            self.CalcPrevCons(widget);
        } else {
            self.CalcNecesComp(widget);
        }
    };
    
    this.existemSolicitacoes = function(widget) {
        ScreenService.closePopup();
        
        widget.getParent().activate();
        
        calcula(widget.getParent());
    };
    
    var gravaMsgInconsistencia = function(resposta) {
        switch(resposta) {
            case "1": return "Item de solicitação não aprovado.";
            case "2": return "Item de solicitação já consolidado.";
            case "3": return "Embalagem utilizada para compra não parametrizada para a filial OL.";
            case "4": return "Embalagem utilizada para compra inativa para a filial OL.";
            case "5": return "Item de solicitação definido para entrega direta.Item de solicitação não aprovado.";
            case "6": return "Embalagem utilizada para compra sem relacionamento com o produto do OL.";
            case "7": return "Item de solicitação sem periodicidade para a filial OL.";
            case "8": return "Item de solicitação sem embalagem ativa para compra.";
            case "9": return "Não existe marca padrão cadastrada.";
            case "0": return "Embalagem selecionada para compras relacionada com produto de compra da árvore do OL.";
            case "I": return "Item relacionado com produto do OL sem cotação válida para o período.";
            default: return "Erro!";
        }
    };
    
    var verificaInconsConsOL = function(widget) {
        if(widget.isValid()) {
            widget.currentRow.CDSUBGRUPO = setSubgrupo(widget.currentRow);
            widget.currentRow.geraConsolidacaoOL = Util.isEmptyOrBlank(widget.currentRow.geraConsolidacaoOL) ? 'T' : widget.currentRow.geraConsolidacaoOL;
            widget.currentRow.geraSolicitacaOL = Util.isEmptyOrBlank(widget.currentRow.geraSolicitacaOL) ? 'N' : widget.currentRow.geraSolicitacaOL;
            
            General.callRestEngine('/verificaConsOL', 'Row', widget.currentRow).then(function(callback) {
    			var widgetConsol = widget.container.getWidget('sup07500_verificaConsolidacaoOL');
    			
			    if(callback.dataset.relatIncons.length > 0) {
			        MessageService.confirmMessageByCode("INCONS_PROCESSO_CONSOLIDACAO").then(function (success) {
			            widgetConsol.dataSource.data = callback.dataset.relatIncons;
			            
			            for(var i = 0; i < callback.dataset.relatIncons.length; i++) {
                            callback.dataset.relatIncons[i].IDVERIFCONSOL = gravaMsgInconsistencia(callback.dataset.relatIncons[i].IDVERIFCONSOL);
                        }
                        
			            ScreenService.openPopup(widgetConsol);
			            
			            widgetConsol.reload();
				        widgetConsol.activate();
			        }, function(error) {
                        calculaNeceComp(widget);   
                    });
			    } else {
			        calculaNeceComp(widget); 
			    }
            });
		}
    };
    
    this.existemInconsistencias = function(widget) {
        ScreenService.closePopup();
        
        widget.getParent().activate();
        
        calculaNeceComp(widget.getParent());
    };
    
    var calculaNeceComp = function(widget) {
        widget.currentRow.DATMOMENT = moment().format('DD/MM/YYYY');
        widget.currentRow.CDGRUPPROD = grupo;
        
        if(widget.currentRow.consPrevisaoConsumo != 'S') {
            General.callRestEngine('/GetPrxNeceComp', 'Row', widget.currentRow).then(function(calculo) {
                nrseqOL = calculo.dataset.resposta[0].substr(0, 10);
                
                if(calculo.dataset.resposta[0].substr(-1) == 'N') {
                    MessageService.showMessageByCode("CALC_NAO_APUROU");
                } else {
                    if(calculo.dataset.resposta[1] == null) {
                        self.openConsolidacaoOL(widget);
                    } else {
                        MessageService.showMessageByCode("ERRO_ENCONTRADO", {"PARAM": calculo.dataset.resposta[1]});
                    }
                }
            }.bind()).catch(function(error) {
                var errorMessage = "Timeout";
                let textContentError = '';
                
                if(error.data) {
                    errorMessage = "ERR_GENERICO";
                    textContentError = error.data.error;
                }
                MessageService.showMessageByCode(errorMessage, { "PARAM": textContentError });
            });
        } else {
            openFilterAction(widget);   
        }
    };
    
    this.confirmaCalculo = function(widget) {
        var row = widget.currentRow;
        
        if(widget.isValid() && validaDataInicial(row.DTINI) && validaProduto(row.CDPRODINI, row.CDPRODFIN) && validaAcrecimos(General.valueToFloat(row.PEACRESCIMO))) {
            MessageService.confirmMessageByCode("CONFIRMA_CALCULO").then(function (success) {
                if(idutilconssoliol != 'S') {
                    var descParIdutilconssoliol = "UTIL_CONSOLIDACAO";
                    
                    MessageService.showMessageByCode("OPBLOCK_PARAMETRO_DESMARCADO", { "PARAM": descParIdutilconssoliol });
                    
                    return false;
                } else {
                    if (!row.PEACRESCIMO) {
                        row.PEACRESCIMO = 0;
                    }
                    
                    row.PRODUTOFIN = validaProdutoFinal(row);
                    row.GROUPFILI = '';
                    row.TCFILI = '';
                    
                    verificaSolicitacao(widget);
                }   
            });
        }
    };
    
    this.previsoesBloqueadas = function(widget){
        
        MessageService.confirmMessageByCode("CONF_CALC_PREVISOES_BLOCK").then(function (success) {
            ScreenService.closePopup();
            widget.getParent().activate();
            verificaSolicitacao(widget.getParent());

        }, function(error){
            ScreenService.closePopup();
            widget.getParent().activate();

        });
    };
    
    this.CalcPrevCons = function (widget) {
        General.callRestEngine('/previsaoConsumo', 'Row', widget.currentRow).then(function(calback) {
            if(calback.dataset.resposta.MSG == null) {
                self.CalcNecesComp(widget);
            } else {
                MessageService.showMessageByCode("PARAMETRO_DEFAULT");
            }
        });
    };
    
    this.CalcNecesComp = function (widget) {
        verificaInconsConsOL(widget);
    };
    
    this.excluiInconsistencias = function(widget){
        General.callRestEngine('/excluiInconsistencias', 'Row', widget.dataSource.data).then(function(calback) {
            ScreenService.closePopup();
            widget.getParent().activate();
        });
    };
    
    this.openConsolidacaoOL = function(widget) {
        var filtro = dataSourceFilterConsOL(widget);
        var cdfilial = widget.currentRow.CDFILIALOL + ' - ' + widget.currentRow.NMFILIALOL;
        var periodo = (widget.currentRow.DTINI) ? widget.currentRow.DTINI + ' até: ' + widget.currentRow.DTFIM : "";

        ScreenService.openWindow('opl_solicitacao#sup07600_consolidacaoOL').then(function() {
			var widgetPrinc = templateManager.container.getWidget("sup07600_consolidacaoOL_GRID");
			var widgetFiltro = templateManager.container.getWidget("sup07600_consolidacaoOL_FILTER");
			var stripeWidget = templateManager.container.getWidget("stripeWidget");
			
			widgetFiltro.CDFILIALOL = widget.currentRow.CDFILIALOL;
			widgetFiltro.NMFILIALOL = widget.currentRow.NMFILIALOL;
			widgetFiltro.NRSEQUCONSOL = nrseqOL;
			widgetFiltro.CDFILIOPELOG = widget.currentRow.CDFILIALOL;
			widgetFiltro.NMFILIOPELOG = widget.currentRow.NMFILIALOL;
			widgetFiltro.DTCONSSOLOL = widget.currentRow.DATMOMENT.substr(0, 10);
			widgetFiltro.CDPRODINICONSOL = widget.currentRow.CDPRODINI;
			widgetFiltro.CDPRODFINCONSOL = widget.currentRow.CDPRODFIN;
			
			widgetFiltro.getField("NRSEQUCONSOL").reload();
			
			widgetFiltro.activate();
			
			widgetPrinc.dataSourceFilter = filtro;
			widgetPrinc.reload().then(function() {
				ScreenService.closePopup(widgetFiltro);
				
			    widgetPrinc.activate();
			    
			    widgetPrinc.list();
				
        	    widgetPrinc.getAction('excluir').isVisible = true;
				//widgetPrinc.activate();

                stripeWidget.getField('NRSEQUCONSOL').label = 'Consolidação: ' + nrseqOL;
                stripeWidget.getField('CDFILIOPELOG').label = 'Operador Logístico: ' + cdfilial;
                stripeWidget.getField('PERIODO').label = 'Período: ' + periodo;
                
				General.callRestEngine('/consOLController/setEstoqueConsOL', 'DataSet', widgetPrinc.dataSource.data).then(function(calback) {
                    widgetPrinc.dataSource.data = calback.dataset.resposta;
                    
                    if(calback.dataset.resposta[0].QTESTUTILCONSOL == 0 && calback.dataset.resposta[0].IDCALESTCONSOL == 'S') {
                        MessageService.showMessageByCode("OPBLOCK_NAO_HA_ESTOQUE");    
                    }
                });
			});
		});
    };
    
    var dataSourceFilterConsOL = function(widget) {
		var cdfiliopelog = widget.currentRow.CDFILIALOL;
        var cdprodini = widget.currentRow.CDPRODINI;
        var cdprodfin = widget.currentRow.CDPRODFIN;
		var filtro = [
			{
			    "name": "P_NRSEQUCONSOL",
			    "operator": "=",
			    "value": nrseqOL ? nrseqOL : null
			},
			{
			    "name": "P_CDFILSOLI",
			    "operator": "=",
			    "value": cdfiliopelog ? cdfiliopelog : null
			},
			{
			    "name": "P_CDPRODINI",
			    "operator": "=",
			    "value": cdprodini ? cdprodini : null
			},
			{
			    "name": "P_CDPRODFIN",
			    "operator": "=",
			    "value": cdprodfin ? cdprodfin : null
			}
		];
		
		return filtro;
	};
	
    var openFilterAction = function(widget) {
        var popupWidget = templateManager.container.getWidget('FILTRO');
        ScreenService.openPopup(popupWidget);
        popupWidget.newRow();
        if (popupWidget.inEditMode()) {
            popupWidget.newRow = function() {};
        }
        
    };
        
    this.criaRelatorio = function(widget) {
        var row = widget.getParent().container.getWidget('calculoNecessidadeComprasOL').currentRow;
        var reportName  = widget.currentRow.REPORT_NAME; 
        General.callRestEngine('/GetPrxNeceComp','Row',row).then(function(calculo) {
            nrseqOL = calculo.dataset.resposta[0].substr(0, 10);
            if(row.consPrevisaoConsumo == 'S'){
                if(calculo.dataset.resposta[2].length>0){
                    arrayNeceComp = calculo.dataset.resposta[2];
                    
                    widget.currentRow.DATAINI = widget.getParent().currentRow.DTINI;
                    widget.currentRow.DATAFIN = widget.getParent().currentRow.DTFIM;
                    widget.currentRow.FILIPROC = getLocalVar('CDFILIAL');
                    widget.currentRow.NRNECECOMP = arrayNeceComp[0].PREVCONS;
                     widget.currentRow.CDFILIAL = '_';
                    for(var i=0;i<arrayNeceComp.length; i++) {
                         widget.currentRow.CDFILIAL = widget.currentRow.CDFILIAL.concat(arrayNeceComp[i].CDFILNECECMP.concat('_'));
                     }
                    if (widget.isValid()) {    
                        General.openReportPopup(widget, abreRelatorio, [widget, widget.currentRow, reportName]);  
                    }
                }
            }
        });
    };
    
    var abreRelatorio = function(widget, currentRow, reportName) {
   	    General.openReport('/previaNecessidadeOL', reportName, currentRow);
   	    
        ScreenService.closePopup();
        
        widget.getParent().activate();
        
        self.openConsolidacaoOL(widget.getParent().container.getWidget('calculoNecessidadeComprasOL'));
    };
    
    this.deletaTrabNece = function(widget) {
   	    General.callRestEngine('/delTrabNece','Row', arrayNeceComp).then(function(calculo) {
   	        widget.currentRow.NRNECECOMP = arrayNeceComp[0].PREVCONS;    
   	    });
    };
};

Configuration(function (ContextRegister) {
	ContextRegister.register('CalculoDaNecessidadeOLController', CalculoDaNecessidadeOLController);
});

// FILE: ./assets/modules/consolidacao/assets/modules/solicitacao/assets/js/controllers/ConsolidacaoOLController.js
var ConsolidacaoOLController = function (ScreenService, MessageService, Utilities, templateManager, General, maskEngine, ZhUtil, ZHPromise) {
    
    var self = this;
    
    this.openFiltro = function(widget) {
        var widgetFiltro = widget.container.getWidget('sup07600_consolidacaoOL_FILTER');
        
        this.defineDefaultValue(widgetFiltro);
        
        widgetFiltro.getField('NRSEQUCONSOL').reload();
	    
	    this.getNrSequConsOL(widgetFiltro.getField('NRSEQUCONSOL'));
	    
	    this.defineDefaultNrSeq(widgetFiltro.getField('NRSEQUCONSOL'));
        
        ScreenService.openPopup(widgetFiltro);
    };
    
	this.defineDefaultValue = function(widgetFiltro) {
		widgetFiltro.getField('DSSITUACAO').setValue([ "P", "C" ]);
	};
	
	this.defineDefaultNrSeq = function(field) {
	    field.widget.getField('NRSEQUCONSOL').setValue('');
	    
	    this.getNrSequConsOL(field.widget.getField('NRSEQUCONSOL'));
	};
	
	this.getNrSequConsOL = function(field) {
        var row = field.widget.currentRow;
        var cdcomprador = '_';
        
        if(row.CDCOMPRADOR) {
            row.CDCOMPRADOR.forEach(function(valor) {
                cdcomprador = cdcomprador.concat(valor.concat('_'));
            });    
        } else  {
            cdcomprador = '';
        }
        if(cdcomprador == '_') {
            cdcomprador = '';
        }
        
        var idsituacao = '_';
        
        if(row.DSSITUACAO) {
            row.DSSITUACAO.forEach(function(valor) {
                idsituacao = idsituacao.concat(valor.concat('_'));
            });
        } else {
            idsituacao = '';
        }
        if(idsituacao == '_') {
            idsituacao = '';
        }
        
        var dt_inicial = (row.INTERVAL_VALIDADE) ? row.INTERVAL_VALIDADE.start : "";
        var dt_final = (row.INTERVAL_VALIDADE) ? row.INTERVAL_VALIDADE.end : "";
        var dt_consol_ini = (row.INTERVAL_CONSOLIDACAO) ? row.INTERVAL_CONSOLIDACAO.start : "";
        var dt_consol_fin = (row.INTERVAL_CONSOLIDACAO) ? row.INTERVAL_CONSOLIDACAO.end : "";
        
        field.dataSourceFilter = [
			{ 'name': 'P_CDFILIOPELOG',  'operator': '=', 'value': row.CDFILIALOL },
			{ 'name': 'P_CDOPERADOR',    'operator': '=', 'value': cdcomprador },
			{ 'name': 'P_IDSITUCONSSOL', 'operator': '=', 'value': idsituacao },
			{ 'name': 'P_DTINICONSSOLOL','operator': '=', 'value': dt_inicial },
			{ 'name': 'P_DTFINCONSSOLOL','operator': '=', 'value': dt_final },
			{ 'name': 'P_DTCONSSOLOLINI','operator': '=', 'value': dt_consol_ini },
			{ 'name': 'P_DTCONSSOLOLFIN','operator': '=', 'value': dt_consol_fin },
			{ 'name': 'P_NRSEQUCONSOL',  'operator': '=', 'value': row.NRSEQUCONSOL }
		];
		
		field.reload();
		field.widget.activate();
    };
	
    this.getProdutoGrid = function (widget) {
		if(widget.isValid()) {
			var widgetPrinc = widget.container.getWidget('sup07600_consolidacaoOL_GRID');
			
			widgetPrinc.dataSourceFilter = dataSourceFilterProdutoGrid(widget); 
			widgetPrinc.reload().then(function() {
				ScreenService.closePopup();
				widgetPrinc.activate();
				defineStripeHeader(widget);
				
				if(widgetPrinc.dataSource.data.length > 0) {
				    widgetPrinc.getAction("excluir").isVisible = true;
				    widgetPrinc.getAction("gerarSolicitacao").isVisible = true;
				    widgetPrinc.getAction("calcularEstoque").isVisible = true;
				    widgetPrinc.getAction("incluirProduto").isVisible = true;
				    widgetPrinc.getAction("verificarConsolidacaoOL").isVisible = true;
				    
				    if(widgetPrinc.dataSource.data[0].IDSITUCONSSOL == 'C') {
    				    delete widgetPrinc.getField('QTESTUTILCONSOL').inlineEditable;
                        widgetPrinc.actions.forEach(function(action) {
                            if(action.name != 'VOLTAR_VIEW' && action.name != 'excluir' && action.name != 'cancel' && action.name != 'save') {
                                action.isVisible = false;
                            } else {
                                action.isVisible = true;
                            }
                        });    
                    } else {
                        widgetPrinc.getField('QTESTUTILCONSOL').inlineEditable  = "number";
                        widgetPrinc.actions.forEach(function(action){
                            action.isVisible = true;   
                        });
                    }
                    
                    defineActionGridEntregaVisible(widget.container.getWidget('sup07600_entregaConsOL_GRID'));
				} else {
				    widgetPrinc.getAction("excluir").isVisible = false;
				    widgetPrinc.getAction("gerarSolicitacao").isVisible = false;
				    widgetPrinc.getAction("calcularEstoque").isVisible = false;
				    widgetPrinc.getAction("incluirProduto").isVisible = false;
				    widgetPrinc.getAction("verificarConsolidacaoOL").isVisible = false;
				}
			});
		}
	};
	
	this.defineActionGridEstoqueVisible = function(widget) {
        if(widget.dataSource.data.length > 0) {
            if(widget.getParent().currentRow.IDSITUCONSSOL == 'C') {
                widget.getAction('editConsiderarEstoque').isVisible = false;
            } else {
                widget.getAction('editConsiderarEstoque').isVisible = true;
            }
        } else {
            widget.getAction('editConsiderarEstoque').isVisible = false;
        }
    };
    
    var defineActionGridEntregaVisible = function(widget) {
        if(widget.getParent().dataSource.data[0].IDSITUCONSSOL == 'C') {
            widget.getAction('entregaViaOL').isVisible = false;
        } else {
            widget.getAction('entregaViaOL').isVisible = true;
        }
    };
	
	var dataSourceFilterProdutoGrid = function(widget) {
		var filtro = [
			{
			    "name": "P_NRSEQUCONSOL",
			    "operator": "=",
			    "value": widget.currentRow.NRSEQUCONSOL || ''
			},
			{
			    "name": "P_CDFILSOLI",
			    "operator": "=",
			    "value": widget.currentRow.CDFILIOPELOG || ''
			},
			{
			    "name": "P_CDPRODINI",
			    "operator": "=",
			    "value": widget.currentRow.CDPRODINICONSOL || ''
			},
			{
			    "name": "P_CDPRODFIN",
			    "operator": "=",
			    "value": widget.currentRow.CDPRODFINCONSOL || ''
			}
		];
		return filtro;
	};
	
	var defineStripeHeader = function(widget) {
	    if(widget) {
    		var widgetStripe = widget.container.getWidget('stripeWidget');
    		
    		if(widget.currentRow.NRSEQUCONSOL) {
        		widgetStripe.getField('NRSEQUCONSOL').label = 'Consolidação: ' + widget.currentRow.NRSEQUCONSOL;
        		widgetStripe.getField('CDFILIOPELOG').label = 'Operador Logístico: ' + widget.currentRow.NMFILIOPELOG;
        		widgetStripe.getField('PERIODO').label = (widget.currentRow.DTINICONSSOLOL) ? 'Período: ' + widget.currentRow.DTINICONSSOLOL + ' até: ' + widget.currentRow.DTFINCONSSOLOL : "";
    		} else {
    		    delete widgetStripe.getField('NRSEQUCONSOL').label;
        		delete widgetStripe.getField('CDFILIOPELOG').label;
        		delete widgetStripe.getField('PERIODO').label;
    		}
	    }
	};
	
	var defineDescricaoRow = function(widget) {
	    widget.currentRow.DSESTUTIL = 'Estoque - ';
        widget.currentRow.DSVIAOL = 'Via OL - ';
    	widget.currentRow.DSVIAPONTO = 'Direta - ';
	};
	
	var defineStripeFooter = function(owner, callback) {
	    var stripeFooter  = owner.container.getWidget('sup07600_entregaConsol_STRIPE');
	    
	    stripeFooter.currentRow.SUMQTENTRCONSOL = callback.dataset.resposta[0].SUMQTENTRCONSOL ? callback.dataset.resposta[0].SUMQTENTRCONSOL.toFixed(3).replace('.', ',') : "0,000";
    	stripeFooter.currentRow.SUMQTSOLIPROD   = callback.dataset.resposta[0].SUMQTSOLIPROD ? callback.dataset.resposta[0].SUMQTSOLIPROD.toFixed(3).replace('.', ',') : "0,000";
    	stripeFooter.currentRow.SUMQTDCOMPRAR   = callback.dataset.resposta[0].SUMQTDCOMPRAR ? callback.dataset.resposta[0].SUMQTDCOMPRAR.toFixed(3).replace('.', ',') : "0,000";
	};
	
	this.openProduto = function(owner) {
		var widgetGrid    = owner.container.getWidget('sup07600_consolidacaoOL_GRID');
		var widgetSwipe   = owner.container.getWidget('sup07600_entregaConsOL_GRID');
		var widgetEstoque = owner.container.getWidget('sup07600_estoqueConsOL_GRID');
		var filterSwipe   = dataSourceFilterSwipe(widgetGrid);
		
		if(!widgetGrid.editing) {
		    widgetSwipe.dataSourceFilter = filterSwipe;
    		widgetSwipe.reload().then(function(callback) {
    		    defineDescricaoRow(widgetGrid);
    		    
    		    defineStripeFooter(owner, callback);
    		    
    		    widgetGrid.updateSwipeTip(widgetGrid.currentRow);
    		    
    			widgetEstoque.dataSourceFilter = filterSwipe;
    			widgetEstoque.reload().then(function(callback) {
        			widgetGrid.updateSwipeTip(widgetGrid.currentRow);
        		});
    		});   
		}
	};
	
	var dataSourceFilterSwipe = function(grid) {
		var nrsequconsol = grid.currentRow.NRSEQUCONSOL ? grid.currentRow.NRSEQUCONSOL : grid.dataSource.data[0].NRSEQUCONSOL;
		var cdfilsoli    = grid.currentRow.CDFILSOLI ? grid.currentRow.CDFILSOLI : grid.dataSource.data[0].CDFILSOLI;
		var cdfillan     = grid.currentRow.CDFILLAN ? grid.currentRow.CDFILLAN : grid.dataSource.data[0].CDFILLAN;
		var cdproduto    = grid.currentRow.CDPRODUTO ? grid.currentRow.CDPRODUTO : grid.dataSource.data[0].CDPRODUTO;
		
		var filterProd = [
			{
			    "name": "P_NRSEQUCONSOL",
			    "operator": "=",
			    "value": nrsequconsol ? nrsequconsol : null
			},
			{
			    "name": "P_CDFILSOLI",
			    "operator": "=",
			    "value": cdfilsoli ? cdfilsoli : null
			},  
			{
			    "name": "P_CDFILLAN",
			    "operator": "=",
			    "value": cdfillan ? cdfillan : null
			},  
			{
			    "name": "P_CDPRODUTO",
			    "operator": "=",
			    "value": cdproduto ? cdproduto : null
			}
		];
		return filterProd;
	};
	
	this.openFilialEntrega = function(owner) {
	    var widgetGrid    = owner.container.getWidget('sup07600_entregaConsOL_GRID');
		var widgetSwipe   = owner.container.getWidget('sup07600_filialConsOL_GRID');
		var widgetTabbed  = owner.container.getWidget('sup07600_filialConsOL_TABBED');
		
		widgetSwipe.dataSourceFilter = dataSourceFilterFilialEntrega(widgetGrid); 
		widgetSwipe.reload().then(function(callback) {
			ScreenService.openSwipe(widgetTabbed).then(function() {
				widgetSwipe.updateSwipeTip(widgetGrid.currentRow);
			});
		});
	};
	
	var dataSourceFilterFilialEntrega = function(grid){
		var filterProd = [
			{name: "P_NRSEQUCONSOL", value: grid.currentRow.NRSEQUCONSOL || '', operator: "="},
			{name: "P_DTENTRCONSOL", value: grid.currentRow.DTENTRCONSOL || '', operator: "="},  
			{name: "P_CDPRODESTO",	 value: grid.currentRow.CDPRODESTO	 || '', operator: "="},  
			{name: "P_CDFILIOPELOG", value: grid.currentRow.CDFILSOLI	 || '', operator: "="},
			{name: "P_CDFILLAN",	 value: grid.currentRow.CDFILLAN	 || '', operator: "="}
		];
		return filterProd;
	};
	
	this.fechaSwipe = function(widgetActivate) {
        ScreenService.closeSwipe();
        widgetActivate.activate();
    };
    
    this.backToList = function(widget) {
		 ScreenService.closeSwipe();
		 widget.list();
		 widget.activate();
	};
	
	this.salvarEstUtil = function(widget) {
	    widget.currentRow.DSMETODO = 'setQtdeEstUtl';
        if(widget.currentRow.IDAUDALTSOL == 'S'){
            widget.currentRow.DSJUSTCONSOL = 'Consolidação OL';
            defineDescricaoRow(widget);
            General.callRestEngine('opl_solicitacao#/consOLController/setQtdeEstUtl', 'Row', widget.currentRow).then(function(success) {
                widget.currentRow.QTANTESTUTIL = widget.currentRow.QTESTUTILCONSOL;
                salvaGridEditavel(widget);
            }, function (error) {
    			var errorMessage = "Timeout";
                let textContentError = '';
                if (error.data){
                    errorMessage = "ERR_GENERICO";
                    textContentError = error.data.error;
                }
                MessageService.showMessageByCode(errorMessage, {"PARAM":textContentError});
    		});
        } else {
            var popupJust = widget.container.getWidget('sup07600_justificativa');
            ScreenService.openPopup(popupJust);
        }
    };
    
    this.confirmarJustificativa = function(widget) {
        if(widget.currentRow.TXJSUTIFICATIVA.length > 0){
            var widgetConsOL = widget.container.getWidget('sup07600_consolidacaoOL_GRID');
        
            if(widgetConsOL.currentRow.DSMETODO == 'setIdEntregaviaOL'){
    	        var widgetEdit = widget.container.getWidget('sup07600_entregaEdit_FORM');
                widgetEdit.currentRow.IDAUDALTSOL = widgetConsOL.currentRow.IDAUDALTSOL;
                widgetEdit.currentRow.DSJUSTCONSOL = widget.currentRow.TXJSUTIFICATIVA;
                General.callRestEngine('opl_solicitacao#/consOLController/setIdEntregaviaOL', 'Row', widgetEdit.currentRow).then(function(success) {
                    var widgetEntrega = widget.container.getWidget('sup07600_entregaConsOL_GRID');
                    widget.currentRow.TXJSUTIFICATIVA = '';
                    ScreenService.closePopup();
                    self.fechaSwipe(widgetEntrega);
                    widgetEntrega.reload();
                }, function (error) {
        			var errorMessage = "Timeout";
                    let textContentError = '';
                    if (error.data){
                        errorMessage = "ERR_GENERICO";
                        textContentError = error.data.error;
                    }
                    MessageService.showMessageByCode(errorMessage, {"PARAM":textContentError});
        		});
            } else {
                if(widgetConsOL.currentRow.DSMETODO == 'setQtdeEstUtl'){
                    widgetConsOL.currentRow.DSJUSTCONSOL = widget.currentRow.TXJSUTIFICATIVA;
                    defineDescricaoRow(widgetConsOL);
                    General.callRestEngine('opl_solicitacao#/consOLController/setQtdeEstUtl', 'Row', widgetConsOL.currentRow).then(function(success) {
                        widget.currentRow.TXJSUTIFICATIVA = '';
                        ScreenService.closePopup();
                        widgetConsOL.currentRow.QTANTESTUTIL = widgetConsOL.currentRow.QTESTUTILCONSOL;
                        salvaGridEditavel(widgetConsOL);
                    }, function (error) {
            			var errorMessage = "Timeout";
                        let textContentError = '';
                        if (error.data){
                            errorMessage = "ERR_GENERICO";
                            textContentError = error.data.error;
                        }
                        MessageService.showMessageByCode(errorMessage, {"PARAM":textContentError});
            		});
                } else {
                    if(widgetConsOL.currentRow.DSMETODO == 'setConsideraEstoque'){
                        var widgetEstoque = widget.container.getWidget('sup07600_estoqueConsOL_GRID');
                        widgetEstoque.currentRow.DSJUSTCONSOL = widget.currentRow.TXJSUTIFICATIVA;
                        widgetEstoque.currentRow.QTANTESTUTIL = widgetConsOL.currentRow.QTESTUTILCONSOL;
                        defineDescricaoRow(widgetEstoque);
                        General.callRestEngine('opl_solicitacao#/consOLController/setConsideraEstoque', 'Row', widgetEstoque.currentRow).then(function(success) {
                            widget.currentRow.TXJSUTIFICATIVA = '';
                            ScreenService.closePopup();
                            widget.container.getWidget('sup07600_entregaConsOL_GRID').dataSource.data = success.dataset.resposta[0];
                            widget.container.getWidget('sup07600_estoqueConsOL_GRID').dataSource.data = success.dataset.resposta[1];
                            General.widgetCancelForm(widgetEstoque);
                            self.backToList(widgetConsOL);
                            widgetConsOL.reload();
                        }, function (error) {
                			var errorMessage = "Timeout";
                            let textContentError = '';
                            if (error.data){
                                errorMessage = "ERR_GENERICO";
                                textContentError = error.data.error;
                            }
                            MessageService.showMessageByCode(errorMessage, {"PARAM":textContentError});
                		});
                        
                    }
                }
            }    
        }
    };
    
    var salvaGridEditavel = function (widget) {
		widget.commitInlineEdit();
		widget.list();
		widget.editing = false;
	};
    
    this.cancelarJustificativa = function(widget) {
        widget.currentRow.TXJSUTIFICATIVA = '';
        ScreenService.closePopup();
        widget.getParent().activate();
    };
	
	this.excluirConsOL = function(widget) {
        var deferred = ZHPromise.defer();
        
        MessageService.confirmMessageByCode("EXCLUIR_SOLICI_OL").then(function(success) {
            General.callRestEngine('opl_solicitacao#/consOLController/deleteConsolidacaoOL', 'DataSet', widget.dataSource.data).then(function(success) {
                widget.reload().then(function() {
        			MessageService.showMessageByCode("EXCLUSAO_REALIZADA");
        			widget.activate();
        			defineStripeHeader(widget);
        			
        			widget.getAction("excluir").isVisible = false;
				    widget.getAction("gerarSolicitacao").isVisible = false;
				    widget.getAction("calcularEstoque").isVisible = false;
				    widget.getAction("incluirProduto").isVisible = false;
				    widget.getAction("verificarConsolidacaoOL").isVisible = false;
        		});
            }, function(error) {
				var errorMessage = "Timeout";
                let textContentError = '';
                if (error.data){
                    errorMessage = "ERR_GENERICO";
                    textContentError = error.data.error;
                }
                MessageService.showMessageByCode(errorMessage, {"PARAM":textContentError});
				deferred.reject();
			});
        });
    };
    
    this.editarIdEntrega = function(widget){
		var widgetSwipe   = widget.container.getWidget('sup07600_entregaEdit_FORM');
		
		widgetSwipe.newRow();
		widgetSwipe.currentRow.NRSEQUCONSOL = widget.currentRow.NRSEQUCONSOL;
		widgetSwipe.currentRow.CDFILSOLI = widget.currentRow.CDFILSOLI;
		widgetSwipe.currentRow.CDFILLAN = widget.currentRow.CDFILLAN;
		widgetSwipe.currentRow.CDPRODUTO = widget.currentRow.CDPRODUTO;
		widgetSwipe.currentRow.CDARVPROD = widget.currentRow.CDARVPROD;
		widgetSwipe.currentRow.CDPRODESTO = widget.currentRow.CDPRODESTO;
		widgetSwipe.currentRow.QTESTOCONSOL = widget.currentRow.QTESTOCONSOL;
		widgetSwipe.currentRow.IDENTREGAVIAOL = widget.currentRow.IDENTREGAVIAOL;
		widgetSwipe.currentRow.DTENTRCONSOL = widget.currentRow.DTENTRCONSOL;
		widgetSwipe.currentRow.QTENTRCONSOL = widget.currentRow.QTENTRCONSOL;
		widgetSwipe.currentRow.QTSOLIPROD = widget.currentRow.QTSOLIPROD;
		widgetSwipe.currentRow.QTDCOMPRAR = widget.currentRow.QTDCOMPRAR;
		widgetSwipe.currentRow.NRORG = getLocalVar('NRORG');

    	General.widgetEdit(widgetSwipe);
    	widgetSwipe.backupRow = Util.clone(widgetSwipe.currentRow);
        
		ScreenService.openSwipe(widgetSwipe).then(function(){
    		widgetSwipe.fields.forEach(function(field) {
                if(field.showOnView && field.name != 'IDENTREGAVIAOL') {
                    widgetSwipe.getField(field.name).readOnly = true;
                } else {
                    if(field.name == 'IDENTREGAVIAOL'){
                        widgetSwipe.getField(field.name).readOnly = false;
                    }
                }
            });
		});
	};
	
	this.cancelarIdEntrega = function(widget) {
	    widget.fields.forEach(function(field) {
			if(field.showOnView && field.name != 'IDENTREGAVIAOL') {
				widget.getField(field.name).readOnly = true;
			} else {
				if(field.name == 'IDENTREGAVIAOL'){
					widget.getField(field.name).readOnly = false;
				}
			}
		});
		
		self.fechaSwipe(widget.container.getWidget('sup07600_entregaConsOL_GRID'));
    };
    
    
    this.salvarIdEntrega = function(widget) {
	    if(widget.currentRow.IDENTREGAVIAOL != widget.backupRow.IDENTREGAVIAOL){
	        var widgetConsOL = widget.getParent().container.getWidget('sup07600_consolidacaoOL_GRID');
            widgetConsOL.currentRow.DSMETODO = 'setIdEntregaviaOL';
            if(widgetConsOL.currentRow.IDAUDALTSOL == 'S'){
                widget.currentRow.DSJUSTCONSOL = 'Consolidação OL';
                widget.currentRow.IDAUDALTSOL = widgetConsOL.currentRow.IDAUDALTSOL;
                General.callRestEngine('opl_solicitacao#/consOLController/setIdEntregaviaOL', 'Row', widget.currentRow).then(function(success) {
                    var widgetEntrega = widget.container.getWidget('sup07600_entregaConsOL_GRID');
                    self.fechaSwipe(widgetEntrega);
                    widgetEntrega.reload();
                }, function (error) {
        			var errorMessage = "Timeout";
                    let textContentError = '';
                    if (error.data){
                        errorMessage = "ERR_GENERICO";
                        textContentError = error.data.error;
                    }
                    MessageService.showMessageByCode(errorMessage, {"PARAM":textContentError});
        		});
            } else {
	            var popupJust = widget.getParent().container.getWidget('sup07600_justificativa');
                ScreenService.openPopup(popupJust);
            }	        
	    } else {
	        self.cancelarIdEntrega(widget);
	    }
    };
    
    this.setEstoque = function(widget){
        var widgetPrinc = templateManager.container.getWidget('sup07600_consolidacaoOL_GRID');	
        General.callRestEngine('/consOLController/setEstoqueConsOL','DataSet',widgetPrinc.dataSource.data).then(function(calback) {
            widgetPrinc.dataSource.data = calback.dataset.resposta;
            
            if(calback.dataset.resposta[0].QTESTUTILCONSOL == 0 && calback.dataset.resposta[0].IDCALESTCONSOL == 'S'){
                MessageService.showMessageByCode("OPBLOCK_NAO_HA_ESTOQUE");
            }
        });  
    };
    
    this.editConsiderarEstoque = function(widget){
        General.widgetEdit(widget);
        widget.fields.forEach(function(field) {
            if(field.showOnView && field.name != 'IDUTESTCONSOL') {
                widget.getField(field.name).readOnly = true;
            } else {
                if(field.name == 'IDUTESTCONSOL'){
                    widget.getField(field.name).readOnly = false;
                }
            }
        });
    };
    
    this.cancelarConsiderarEstoque = function(widget){
        General.widgetCancelForm(widget);
    };
    
    this.salvarConsiderarEstoque = function(widget){
        if(widget.currentRow.IDUTESTCONSOL != widget.backupRow.IDUTESTCONSOL){
            var widgetConsOL = widget.getParent().container.getWidget('sup07600_consolidacaoOL_GRID');
            widgetConsOL.currentRow.DSMETODO = 'setConsideraEstoque';
            
            widget.currentRow.DTINCLUSAO = widgetConsOL.currentRow.DTINCLUSAO;
            widget.currentRow.CDPRODINI = widgetConsOL.currentRow.CDPRODINI;
            widget.currentRow.CDPRODFIN = widgetConsOL.currentRow.CDPRODFIN;
            widget.currentRow.NRORG = getLocalVar('NRORG');
            widget.currentRow.QTANTESTUTIL = widgetConsOL.currentRow.QTESTUTILCONSOL;
            
            if(widgetConsOL.currentRow.IDAUDALTSOL == 'S'){
                widget.currentRow.DSJUSTCONSOL = 'Consolidação OL';
                defineDescricaoRow(widget);
                General.callRestEngine('opl_solicitacao#/consOLController/setConsideraEstoque', 'Row', widget.currentRow).then(function(success) {
                    widget.container.getWidget('sup07600_entregaConsOL_GRID').dataSource.data = success.dataset.resposta[0];
                    widget.container.getWidget('sup07600_estoqueConsOL_GRID').dataSource.data = success.dataset.resposta[1];
                    self.backToList(widgetConsOL);    
                    widgetConsOL.reload();
                }, function (error) {
        			var errorMessage = "Timeout";
                    let textContentError = '';
                    if (error.data){
                        errorMessage = "ERR_GENERICO";
                        textContentError = error.data.error;
                    }
                    MessageService.showMessageByCode(errorMessage, {"PARAM":textContentError});
        		});
            } else {
	            var popupJust = widget.getParent().container.getWidget('sup07600_justificativa');
                ScreenService.openPopup(popupJust);
            }
        } else {
            self.cancelarConsiderarEstoque(widget);
        }
    };
    
    this.calcularEstoque = function(widget) {
        if(Util.isEmptyOrBlank(widget.dataSource.data)) {
            MessageService.showMessageByCode("OPBLOCK_EMPTY_GRID");
        } else {
            General.callRestEngine('/consOLController/setEstoqueConsOL', 'DataSet', widget.dataSource.data).then(function(calback) {
                widget.dataSource.data = calback.dataset.resposta;
                
                ScreenService.closePopup();
                
    			widget.activate();
    			
    			widget.getAction('excluir').isVisible = true;
    			
                if(calback.dataset.resposta[0].QTESTUTILCONSOL == 0 && calback.dataset.resposta[0].IDCALESTCONSOL == 'S') {
                    MessageService.showMessageByCode("OPBLOCK_NAO_HA_ESTOQUE");
                } else {
                    MessageService.showMessageByCode("OPERACAO_SUCESSO");
                }
            }).catch(function(error) {
                MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
            });
        }
    };
    
    var dataSourceFilterSolicitacao = function(widget) {
		var filtro = [
			{name: "P_CDFILIAL",     value: widget.dataSource.data[0].CDFILSOLI || '',operator: "="},
			{name: "P_DTINI",	     value: widget.dataSource.data[0].DTINI || '',operator: "="},
			{name: "P_DTFIN",	     value: widget.dataSource.data[0].DTFIN || '',operator: "="},
			{name: "P_CDPRODUTOINI", value: widget.dataSource.data[0].CDPRODINI || '',operator: "="},
			{name: "P_CDPRODUTOFIN", value: widget.dataSource.data[0].CDPRODFIN || '',operator: "="}
		];
		return filtro;
	};
    
    this.gerarSolicitacao = function(widget) {
        if(widget.isValid()) {
			var widgetSolic = widget.container.getWidget('sup07600_Solicitacoes');
			
			widgetSolic.dataSourceFilter = dataSourceFilterSolicitacao(widget); 
			widgetSolic.reload().then(function(callback) {
			    if(callback.dataset.resposta.length > 0) {
			        ScreenService.openPopup(widgetSolic);
				    widgetSolic.activate();
			    } else {
			        self.confirmarGerarSolicitacoes(widgetSolic);
			    }
			});
		}
    };
    
    this.cancelarGerarSolicitacoes = function(widget){
        ScreenService.closePopup(); 
        widget.getParent().activate();
    };
    
    this.confirmarGerarSolicitacoes = function(widget) {
        General.callRestEngine('/geraSolicitacaoOL', 'DataSet', widget.getParent().dataSource.data).then(function(calback) {
            widget.getParent().reload().then(function() {
				ScreenService.closePopup();
				
				widget.getParent().activate();
				
				if(widget.getParent().dataSource.data[0].IDSITUCONSSOL == 'C') {
                    widget.getParent().actions.forEach(function(action) {
                        if(action.name != 'VOLTAR_VIEW' && action.name != 'excluir')
                            action.isVisible = false;
                    });
                }
				if(calback.dataset.resposta.P_ROWSAFFECT.length > 0) {
				    var rowsaffect = calback.dataset.resposta.P_ROWSAFFECT;
                    MessageService.showMessageByCode("SOLICITACAO_GERADA", {"PARAM": rowsaffect});
                } else {
                    MessageService.showMessageByCode("QTDE_ESTOQUE_DISPONIVEL");
                }
			});
        });    
    };
    
    this.incluirProduto = function(widget){
        var popupIncluir = widget.container.getWidget('sup07600_incluirProduto');
        ScreenService.openPopup(popupIncluir);
    };
    
    this.cancelarInclusaoProduto = function(widget){
        ScreenService.closePopup();
        widget.getParent().activate();
    };
    
    this.getTotalSolicitado = function(field){
		field.widget.dataSourceFilter = dataSourceFilterTotalSolicitado(field); 
		field.widget.reload().then(function(callback){
		    if(callback.dataset.resposta.length > 0){
		        field.widget.currentRow.QTDESOLICITADA = callback.dataset.resposta[0].QTSOLIPROD.toFixed(3).replace('.', ',')   || 0;   
		    } else {
                field.widget.currentRow.QTDESOLICITADA = 0;
		    }
		});
		
    };
    
    var dataSourceFilterTotalSolicitado = function(field) {
        var widgetCnsol = field.widget.container.getWidget('sup07600_consolidacaoOL_GRID');
        field.widget.currentRow.DTINICIAL = widgetCnsol.dataSource.data[0].DTINI.substr(0, 10);
        field.widget.currentRow.DTFINAL   = widgetCnsol.dataSource.data[0].DTFIN.substr(0, 10);
        field.widget.currentRow.CDFILIAL  = widgetCnsol.dataSource.data[0].CDFILSOLI;
        
		var filtro = [
			{name: "P_CDFILIAL",  value: widgetCnsol.dataSource.data[0].CDFILSOLI || '',operator: "="},
			{name: "P_DTINICIAL", value: widgetCnsol.dataSource.data[0].DTINI.substr(0, 10) || '',operator: "="},
			{name: "P_DTFINAL",	  value: widgetCnsol.dataSource.data[0].DTFIN.substr(0, 10) || '',operator: "="},
			{name: "P_CDPRODINC", value: field.widget.currentRow.CDPRODUTO || '',operator: "="}
		];
		return filtro;
	};
    
    this.confirmarInclusaoProduto = function(widget){
        if(widget.currentRow.QTDESOLICITADA <= 0){
            MessageService.showMessageByCode("OPBLOCK_NAO_QTDE_CALC");
        } else {
            widget.dataSource.data[0].CDFILIAL  = widget.getParent().dataSource.data[0].CDFILSOLI;
            widget.dataSource.data[0].CDFILLAN = widget.getParent().dataSource.data[0].CDFILLAN;
            widget.dataSource.data[0].NRSEQUCONSOL = widget.getParent().dataSource.data[0].NRSEQUCONSOL;
            widget.dataSource.data[0].DTINICIAL = widget.getParent().dataSource.data[0].DTINI.substr(0, 10);
            widget.dataSource.data[0].DTFINAL   = widget.getParent().dataSource.data[0].DTFIN.substr(0, 10);
            widget.dataSource.data[0].IDEMBESTCONSOL = widget.getParent().dataSource.data[0].IDEMBESTCONSOL;
            widget.dataSource.data[0].IDCONSPREVCONOL = widget.getParent().dataSource.data[0].IDCONSPREVCONOL;
            General.callRestEngine('/incluirProduto', 'DataSet', widget.dataSource.data).then(function(calback) {
            var widgetFilter = widget.container.getWidget('sup07600_consolidacaoOL_FILTER');
            widget.getParent().dataSourceFilter = dataSourceFilterProdutoGrid(widgetFilter); 
            widget.getParent().reload().then(function(){
				ScreenService.closePopup();
				widget.getParent().activate();
				if(widget.getParent().dataSource.data[0].IDSITUCONSSOL == 'C'){
                    widget.getParent().actions.forEach(function(action){
                        if(action.name != 'VOLTAR_VIEW' && action.name != 'excluir')
                        action.isVisible = false;
                    });    
                }
				if(calback.dataset.resposta.P_ROWSAFFECT == 'S'){
				    var nrsequconsol = widget.getParent().dataSource.data[0].NRSEQUCONSOL;
                    MessageService.showMessageByCode("SOLICITACAO_GERADA", {"PARAM": nrsequconsol});
                }else{
                    MessageService.showMessageByCode("CALC_NAO_APUROU_INF");
                }
			});
        });
        }
    };
    
    this.verificaInconsConsOL = function(widget){
		widget.dataSourceFilter = dataSourceFilterInconsistencia(widget); 
		widget.reload().then(function(callback){
		    if(callback.dataset.resposta.length > 0){
		        for(var i=0;i<callback.dataset.resposta.length; i++) {
                    callback.dataset.resposta[i].IDVERIFCONSOL = gravaMsgInconsistencia(callback.dataset.resposta[i].IDVERIFCONSOL);
                }
		        ScreenService.openPopup(widget.container.getWidget('sup07600_verificaConsolidacaoOL'));
		    } else {
                MessageService.showMessageByCode("NAO_HA_DADOS_LISTADOS");
		    }
		});
		
    };
    
    var dataSourceFilterInconsistencia = function(widget) {
		var filtro = [
			{name: "P_CDFILIOPELOG",  value:  widget.getParent().dataSource.data[0].CDFILSOLI || '',operator: "="},
			{name: "P_DTINICIAL", value: widget.getParent().dataSource.data[0].DTINI.substr(0, 10) || '',operator: "="},
			{name: "P_DTFINAL",	  value: widget.getParent().dataSource.data[0].DTFIN.substr(0, 10) || '',operator: "="},
			{name: "P_CDPRODINI", value: widget.getParent().dataSource.data[0].CDPRODINI || '',operator: "="},
			{name: "P_CDPRODFIN", value: widget.getParent().dataSource.data[0].CDPRODFIN || '',operator: "="}
		];
		return filtro;
	};
        
    var gravaMsgInconsistencia = function(resposta){
        switch(resposta) {
            case "1": return "Item de solicitação não aprovado.";
            case "2": return "Item de solicitação já consolidado.";
            case "3": return "Embalagem utilizada para compra não parametrizada para a filial OL.";
            case "4": return "Embalagem utilizada para compra inativa para a filial OL.";
            case "5": return "Item de solicitação definido para entrega direta.Item de solicitação não aprovado.";
            case "6": return "Embalagem utilizada para compra sem relacionamento com o produto do OL.";
            case "7": return "Item de solicitação sem periodicidade para a filial OL.";
            case "8": return "Item de solicitação sem embalagem ativa para compra.";
            case "9": return "Não existe marca padrão cadastrada.";
            case "0": return "Embalagem selecionada para compras relacionada com produto de compra da árvore do OL.";
            case "I": return "Item relacionado com produto do OL sem cotação válida para o período.";
            default: return "Erro!";
        }
    };
    
    this.fecharRelatorio = function(widget){
        ScreenService.closePopup();
		widget.getParent().activate();
    };
    
    
};

Configuration(function (ContextRegister) {
	ContextRegister.register('ConsolidacaoOLController', ConsolidacaoOLController);
});

// FILE: ./assets/modules/consolidacao/assets/modules/solicitacao/assets/js/controllers/Opl00100LoteDeEnvioDePedidosDoOL_Controller.js
function Opl00100LoteDeEnvioDePedidosDoOL_Controller(ScreenService, templateManager, ZhFilterPreferences, General, restEngine, ZhReports, MessageService) {
    
    this.openFilter = function(widget) {
    	ScreenService.showLoader();
        this.setFieldsGerais(widget);
        var rowsToSet = {};
		rowsToSet.defaultFilter = widget.dataSourceFilter;
		rowsToSet.TCDLOTENVITOL = 'T';
		widget.getField("P_CDLOTENVITOL").filterProperties.readOnly = true;
		widget.getField("P_CDLOTENVITOL").filterProperties.readOnlyOnEdit = true;
		delete widget.getField("P_CDLOTENVITOL").filterProperties.validations.required;
		delete widget.getField("P_CDLOTENVITOL").validations.required;
		
		ZhFilterPreferences.openFilterWidget(widget, rowsToSet).then(opened => {
			ScreenService.hideLoader();
		}).catch(error => {
			console.log(error);
			ScreenService.hideLoader();
		});
    };

	this.setFieldsGerais = function(widget) {
		templateManager.container.fieldsGerais = widget.fields.map(function(field) { return field.name; });
	};
	
	this.changeFieldLote = function(args) {
		var widget = args.owner.field.widget;
		ScreenService.showLoader();
		if(args.row.TCDLOTENVITOL == 'T') {
			if(widget.name === "zhFilterPreferencesSelectConditions") {
				setTimeout(() => {
					widget.getField("P_CDLOTENVITOL").readOnly = true;
					widget.getField("P_CDLOTENVITOL").readOnlyOnEdit = true;
					delete widget.getField("P_CDLOTENVITOL").validations.required;
					widget.currentRow.P_CDLOTENVITOL = "";
					widget.currentRow.NMLOTENVITOL = "";
					widget.getField("P_CDLOTENVITOL").clearValue();
					widget.getField("P_CDLOTENVITOL").reload();
					ScreenService.hideLoader();
				}, 200);
			}
		} else if(args.row.TCDLOTENVITOL == 'L') {
			if(widget.name === "zhFilterPreferencesSelectConditions") {
				setTimeout(() => {
					widget.getField("P_CDLOTENVITOL").readOnly = false;
					widget.getField("P_CDLOTENVITOL").readOnlyOnEdit = false;
					widget.getField("P_CDLOTENVITOL").validations.required = true;
					widget.getField("P_CDLOTENVITOL").reload();
					ScreenService.hideLoader();
				}, 200);
			}
		}
	};
	
	this.saveEdit = function(widget) {
		if(widget.isValid()) {
			widget.saveRow().then(function(response) {
				widget.dataSource.data.pop();
				
				ScreenService.closeSwipe();
				
				widget.reload();
				
				MessageService.showMessageByCode("OPERACAO_SUCESSO");
			}, function(error) {
				MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
			});
		}
	};
	
	this.newLote = function(widget) {
    	widget.getField("CDLOTENVITOL").readOnly = true;
        widget.getField("CDLOTENVITOL").validations.required = true;
        widget.getField("CDLOTENVITOL").minlength = 10;
        widget.getField("CDLOTENVITOL").maxlength = 10;
        
        General.callRestEngine("opl_solicitacao#/getNewLoteCode", "Row", {}).then(function(response) {
        	var novoCodigo = response.dataset.opl00100_newCode[0];
        	
        	if(novoCodigo) {
        		var geraNovoCodigo = false;
        		
        		widget.newRow();
        		
        		widget.dataSource.data.forEach(function(row) {
        			if(row.CDLOTENVITOL == novoCodigo)
        				geraNovoCodigo = true;
        		});
        		
        		if(geraNovoCodigo) {
	        		novoCodigo = widget.dataSource.data[widget.dataSource.data.length - 2].CDLOTENVITOL;
	            	novoCodigo = parseInt(novoCodigo);
	        		novoCodigo++;
	        		novoCodigo = novoCodigo.toString();
	        		novoCodigo = novoCodigo.padStart(10, 0);
        		}
        		
        		widget.currentRow.CDLOTENVITOL = novoCodigo;
        		widget.getField("CDLOTENVITOL").setValue(novoCodigo);
        	} else {
        		widget.view();
				widget.enabled = true;
				widget.reload();
        		MessageService.showMessageByCode("UNKNOWN_ERROR");
        	}
        }).catch(function(error) {
        	widget.view();
			widget.enabled = true;
			widget.reload();
        	MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
        });
	};
	
	this.fillField = function(args) {
		var field = args.owner.field.widget.getField("CDLOTENVITOL");
		var value = field.value();
		var row = args.row;
		value = value.padStart(10, '0');
		field.setValue(value);
		field.value(value);
		row.CDLOTENVITOL = value;
		field.reload();
	};

    this.validateReport = function(widget, type) {
    	var REPORT_JSON = "./modules/consolidacao/assets/modules/solicitacao/assets/json/containers/opl00100_lote_de_envio_de_pedidos_do_OL.json";
    	
    	ScreenService.showLoader();
    	
        restEngine.requestMetaData(REPORT_JSON).then(function(reportMetaData) {
            ScreenService.hideLoader();
            
            ZhReports.openReport(reportMetaData.data, widget, null, null, type).then(function(success) {
            	
            }).catch(error1 => {
            	MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error1.data.error });
            });
        }).catch(error => {
        	MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
        });
    };
    
    this.cancelEditNew = function(args) {
    	const widget = args.owner.widget;
    	
    	General.backOrCancel(args).then(function(response) {
    		ScreenService.closeSwipe();
    		widget.reload();
    	});
    };
}

Configuration(function(ContextRegister) {
	ContextRegister.register('Opl00100LoteDeEnvioDePedidosDoOL_Controller', Opl00100LoteDeEnvioDePedidosDoOL_Controller);
});

// FILE: ./assets/modules/consolidacao/assets/modules/solicitacao/assets/js/controllers/Opl00200_TipoOperacaoOperadorLogistico_Controller.js
function Opl00200_TipoOperacaoOperadorLogistico_Controller(ScreenService, templateManager, ZhFilterPreferences, General) {
	
	var var_CDFILIOPELOG;
	var var_NMFILIALOL;
    
    this.openFilter = function(widget) {
        ScreenService.showLoader();
        this.setFieldsGerais(widget);
        var rowsToSet = {};
		rowsToSet.defaultFilter = widget.dataSourceFilter;
		rowsToSet.TNMFILIAL = 'T';
		delete widget.getField("NMFILIALL").validations.required;
		delete widget.getField("NMFILIALL").filterProperties.validations.required;
		ZhFilterPreferences.openFilterWidget(widget, rowsToSet).then(opened => {
			ScreenService.hideLoader();
		}).catch(error => {
			console.log(error);
			ScreenService.hideLoader();
		});
    };
    
	this.setFieldsGerais = function(widget) {
		templateManager.container.fieldsGerais = widget.fields.map(function(field) { return field.name; });
	};
	
	this.changeFieldListaUnidades = function(args) {
		var widget = args.owner.field.widget;
		var row = args.row;
		ScreenService.showLoader();
		if(!row.CDFILIOPELOG) {
			if(widget.name === "zhFilterPreferencesSelectConditions") {
				setTimeout(() => {
					widget.getField("TNMFILIAL").readOnly = true;
					widget.getField("TNMFILIAL").readOnlyOnEdit = true;
					widget.currentRow.TNMFILIAL = "T";
					widget.currentRow.CDFILIAL = "";
					widget.getField("NMFILIALL").clearValue();
					delete widget.getField("NMFILIALL").validations.required;
					delete widget.getField("NMFILIALL").filterProperties.validations.required;
					widget.getField("NMFILIALL").reload();
					widget.getField("TNMFILIAL").reload();
					this.changeFieldUnidade(args);
					ScreenService.hideLoader();
				}, 200);
			} else if(widget.name === "widgetTipoOperacao") {
				widget.getField("NMFILIAL").clearValue();
				widget.getField("NMFILIAL").readOnly = true;
				widget.getField("NMFILIAL").readOnlyOnEdit = true;
				widget.getField("NMFILIAL").dataSourceFilter = [
					{
						"name": "P_CDFILIAL",
                    	"operator": "=",
                    	"value": args.row.CDFILIOPELOG
					},
					{
						"name": "P_CDOPERADOR",
						"operator": "=",
						"value": getLocalVar("CDOPERADOR")
					
					}
				];
				widget.getField("NMFILIAL").reload();
				ScreenService.hideLoader();
			} else {
				ScreenService.hideLoader();
			}
		} else if(row.CDFILIOPELOG) {
			var_CDFILIOPELOG = row.CDFILIOPELOG;
			var_NMFILIALOL = row.NMFILIALOL;
			if(widget.name === "zhFilterPreferencesSelectConditions") {
				setTimeout(() => {
					widget.getField("TNMFILIAL").readOnly = false;
					widget.getField("TNMFILIAL").readOnlyOnEdit = false;
					widget.getField("NMFILIALL").clearValue();
					widget.getField("NMFILIALL").reload();
					widget.getField("TNMFILIAL").reload();
					this.changeFieldUnidade(args);
					ScreenService.hideLoader();
				}, 200);
			} else if(widget.name === "widgetTipoOperacao") {
				widget.getField("NMFILIAL").clearValue();
				widget.getField("NMFILIAL").readOnly = false;
				widget.getField("NMFILIAL").readOnlyOnEdit = false;
				widget.getField("NMFILIAL").dataSourceFilter = [
					{
						"name": "P_CDFILIAL",
                    	"operator": "=",
                    	"value": args.row.CDFILIOPELOG
					},
					{
						"name": "P_CDOPERADOR",
						"operator": "=",
						"value": getLocalVar("CDOPERADOR")
					
					}
				];
				widget.getField("NMFILIAL").reload();
				ScreenService.hideLoader();
			} else {
				ScreenService.hideLoader();
			}
		}
	};
	
	this.changeFieldUnidade = function(args) {
		var widget = args.owner.field.widget;
		ScreenService.showLoader();
		if(args.row.TNMFILIAL == 'T') {
			if(widget.name === "zhFilterPreferencesSelectConditions") {
				setTimeout(() => {
					widget.getField("NMFILIALL").readOnly = true;
					widget.getField("NMFILIALL").readOnlyOnEdit = true;
					delete widget.getField("NMFILIALL").validations.required;
					widget.currentRow.NMFILIALL = "";
					widget.currentRow.CDFILIAL = "";
					widget.getField("NMFILIALL").reload();
					ScreenService.hideLoader();
				}, 200);
			}
		} else if(args.row.TNMFILIAL == 'L') {
			if(widget.name === "zhFilterPreferencesSelectConditions") {
				setTimeout(() => {
					widget.getField("NMFILIALL").readOnly = false;
					widget.getField("NMFILIALL").readOnlyOnEdit = false;
					widget.getField("NMFILIALL").validations.required = true;
					widget.getField("NMFILIALL").dataSourceFilter = [
						{
							"name": "P_CDFILIAL",
                            "operator": "=",
                            "value": args.row.CDFILIOPELOG
						},
						{
							"name": "P_CDOPERADOR",
							"operator": "=",
							"value": getLocalVar("CDOPERADOR")
						}
					];
					widget.getField("NMFILIALL").reload();
					ScreenService.hideLoader();
				}, 200);
			}
		} else if(widget.name === "widgetTipoOperacao") {
			widget.getField("NMFILIAL").dataSourceFilter = [
				{
					"name": "P_CDFILIAL",
                    "operator": "=",
                    "value": args.row.CDFILIOPELOG
				},
				{
					"name": "P_CDOPERADOR",
					"operator": "=",
					"value": getLocalVar("CDOPERADOR")
					
				}
			];
			widget.getField("NMFILIALL").reload();
			ScreenService.hideLoader();
		} else {
			args.row.TNMFILIAL = "T";
			widget.currentRow.TNMFILIAL = "T";
			ScreenService.hideLoader();
		}
	};
	
	this.newType = function(widget) {
		widget.newRow();
		widget.getField("NMFILIALOL").readOnly = true;
		widget.currentRow.NMFILIALOL = var_NMFILIALOL;
		widget.currentRow.CDFILIOPELOG = var_CDFILIOPELOG;
		widget.getField("NMFILIALOL").reload();
		widget.getField("NMFILIAL").readOnly = false;
		widget.getField("NMFILIAL").dataSourceFilter = [
				{
					"name": "P_CDFILIAL",
                    "operator": "=",
                    "value": var_CDFILIOPELOG
				},
				{
					"name": "P_CDOPERADOR",
					"operator": "=",
					"value": getLocalVar("CDOPERADOR")
					
				}
			];
		widget.getField("NMFILIAL").reload();
		widget.getField("IDTIPOOPERENTR").setValue("E");
		widget.getField("IDTIPOOPERENTR").reload();
		widget.getField("IDTIPOOPERSAID").setValue("S");
		widget.getField("IDTIPOOPERSAID").reload();
	};
	
	this.editType = function(widget) {
		widget.edit();
		widget.getField("NMFILIALOL").readOnly = true;
		widget.currentRow.NMFILIALOL = var_NMFILIALOL;
		widget.currentRow.CDFILIOPELOG = var_CDFILIOPELOG;
		widget.currentRow.CDFILDEST = widget.currentRow.CDFILIAL;
		widget.getField("NMFILIALOL").reload();
		widget.getField("NMFILIAL").readOnlyOnEdit = true;
		widget.getField("NMFILIAL").reload();
		widget.getField("CDFILDEST").setValue(widget.currentRow.CDFILIAL);
		widget.getField("CDFILDEST").reload();
		widget.getField("CDSERIE").readOnly = false;
		widget.getField("CDSERIE").readOnlyOnEdit = false;
		widget.getField("CDSERIE").dataSourceFilter = [
			{
				"name": "P_CDFILIAL",
				"operator": "=",
				"value": widget.currentRow.CDFILIAL
			}
		];
		widget.getField("CDSERIE").reload();
		widget.getField("IDTIPOOPERENTR").setValue("E");
		widget.getField("IDTIPOOPERENTR").reload();
		widget.getField("IDTIPOOPERSAID").setValue("S");
		widget.getField("IDTIPOOPERSAID").reload();
	};
	
	this.deleteType = function(widget) {
		widget.currentRow.CDFILDEST = widget.currentRow.CDFILIAL;
		widget.currentRow.CDFILIOPELOG = var_CDFILIOPELOG;
		General.deleteCrud(widget);
	};
	
	this.changeFieldSerieNF = function(args) {
		var widget = args.owner.field.widget;
		ScreenService.showLoader();
		if(args.row.CDFILIAL) {
			widget.getField("CDFILDEST").setValue(args.row.CDFILIAL);
			args.row.CDFILDEST = args.row.CDFILIAL;
			widget.getField("CDSERIE").readOnly = false;
			widget.getField("CDSERIE").readOnlyOnEdit = false;
			widget.getField("CDSERIE").clearValue();
			widget.getField("CDSERIE").dataSourceFilter = [
				{
					"name": "P_CDFILIAL",
					"operator": "=",
					"value": args.row.CDFILIAL
				}
			];
			widget.getField("CDSERIE").reload();
			widget.getField("CDFILDEST").reload();
			ScreenService.hideLoader();
		} else {
			widget.getField("CDSERIE").readOnly = true;
			widget.getField("CDSERIE").clearValue();
			widget.getField("CDSERIE").reload();
			ScreenService.hideLoader();
		}
	};
}

Configuration(function(ContextRegister) {
    ContextRegister.register("Opl00200_TipoOperacaoOperadorLogistico_Controller", Opl00200_TipoOperacaoOperadorLogistico_Controller);
});

// FILE: ./assets/modules/consolidacao/assets/modules/solicitacao/assets/js/controllers/opl00300_acompanhamento_pedido_OL_Controller.js
function opl00300_acompanhamento_pedido_OL_Controller(ScreenService, templateManager, ZhFilterPreferences, General, MessageService) {

    //Armazena o CDFILIAL
    var var_beforeCDFILIAL;
    var var_CDFILIAL;
    
    //Armazena a data de entrega
    var var_DATAENTREGA_start;
    var var_DATAENTREGA_end;
    
    //Armazena a data de solicitação
    var var_DATASOLICITACAO_start;
    var var_DATASOLICITACAO_end;
    
    //Armazena o valor do QTDPEDIDO
    var var_QTDPEDIDO;

    //Abre o filtro
	this.openFilter = function(widget) {
    	ScreenService.showLoader();
        var rowsToSet = {};
		rowsToSet.STATUS = 'T';
		rowsToSet.ITEMCONSOL = 'T';
		rowsToSet.PEDGERADO = 'T';
        widget.getField("UNIDADE").filterProperties.readOnly = true;
        widget.getField("NRSEQUCONSOL").filterProperties.readOnly = true;
		ZhFilterPreferences.openFilterWidget(widget, rowsToSet).then(opened => {
			ScreenService.hideLoader();
		}).catch(error => {
			ScreenService.hideLoader();
		});
    };
    
    //Seta o filtro a trazer os dados para o grid
    this.setDataSourceFilter = function (args) {
        const widget = templateManager.container.getWidget('gridUnidadeSolicitante');
        const row = args.e.preference.FILTER_ROW;
        //Continua a construção dos parametros do filtro
        widget.dataSourceFilter.forEach(function(item, index) {
            if(item.name === "FILIALOL"){
                widget.dataSourceFilter.splice(index, index);
            }
            if(item.name === "PEDIDOMAIOR"){
                widget.dataSourceFilter.splice(index, index);
            }
            if(item.name === "PEDIDOMENOR"){
                widget.dataSourceFilter.splice(index, index);
            }
            if(item.name === "PEDIDOIGUAL"){
                widget.dataSourceFilter.splice(index, index);
            }
            if(item.name === "P_DTSOLI"){
                widget.dataSourceFilter.splice(index, index);
            }
            if(item.name === "P_TFILSOLI"){
                widget.dataSourceFilter.splice(index, index);
            }
            if(item.name === "P_TCONSOL"){
                widget.dataSourceFilter.splice(index, index);
            }
            if(item.name === "P_CDPROD"){
                widget.dataSourceFilter.splice(index, index);
            }
        });
        //Se a data de solicitação não for informada
        if(row.DATASOLICITACAO.start === '' || row.DATASOLICITACAO.start === null && row.DATASOLICITACAO.end === '' || row.DATASOLICITACAO.end === null){
            widget.dataSourceFilter.push(
                {
                    "name": "P_DTSOLI",
                    "operator": "=",
                    "value": "T"
                }
            );
        }  
        //Se não for informada Unidade
        if(row.UNIDADE.length < 1){
            widget.dataSourceFilter.push(
                {
                    "name": "P_TFILSOLI",
                    "operator": "=",
                    "value": "T"
                }
            );
        }        
        //Se não for informada Consolidação
        if(row.NRSEQUCONSOL.length < 1){
            widget.dataSourceFilter.push(
                {
                    "name": "P_TCONSOL",
                    "operator": "=",
                    "value": "T"
                }
            );
        }       
        //Se o produto inicial e final não forem informados
        if(row.CDPRODINI === '' || row.CDPRODINI === null || row.CDPRODINI === undefined && row.CDPRODFIN === '' || row.CDPRODFIN === null || row.CDPRODFIN === undefined){
            widget.dataSourceFilter.push(
                {
                    "name": "P_CDPROD",
                    "operator": "=",
                    "value": "T"
                }
            );
        }                
        widget.reload();
    };
    
    //Altera o comportamento do campo UNIDADE
    this.changeFieldUnidade = function(args){
    	var widget = args.owner.field.widget;
		ScreenService.showLoader();
        if(var_CDFILIAL === ""){    
     		if(widget.name === "zhFilterPreferencesSelectConditions") {
    			setTimeout(() => {
    				widget.getField("UNIDADE").readOnly = true;
    				widget.currentRow.CDFILIAL = "";
    				widget.currentRow.NMFILIAL = "";
    				widget.getField("UNIDADE").clearValue();
    			}, 200);
    		}
		} else if(var_CDFILIAL !== var_beforeCDFILIAL) {
 			if(widget.name === "zhFilterPreferencesSelectConditions") {
				setTimeout(() => {
					widget.getField("UNIDADE").readOnly = false;
					widget.currentRow.CDFILIAL = "";
					widget.currentRow.NMFILIAL = "";
					widget.getField("UNIDADE").clearValue();
    				widget.getField("UNIDADE").reload();
				}, 200);
			}  
		}
		ScreenService.hideLoader();
    };
    
	//Altera o comportamento do campo CONSOLIDAÇÃO
    this.changeFieldConsolidacao = function(args){
    	var widget = args.owner.field.widget;
		ScreenService.showLoader();
        if(var_CDFILIAL !== '' && var_DATAENTREGA_start && var_DATAENTREGA_end || var_DATASOLICITACAO_start && var_DATASOLICITACAO_end){
	        if(widget.name === "zhFilterPreferencesSelectConditions") {
			    setTimeout(() => {
					widget.getField("NRSEQUCONSOL").readOnly = false;
					widget.currentRow.CODIGO = "";
					widget.currentRow.NOME = "";
					widget.getField("NRSEQUCONSOL").clearValue();
					widget.getField("NRSEQUCONSOL").reload();
			    }, 200);
	        }
		} else{
 			if(widget.name === "zhFilterPreferencesSelectConditions") {
				setTimeout(() => {
					widget.getField("NRSEQUCONSOL").readOnly = true;
					widget.currentRow.CODIGO = "";
					widget.currentRow.NOME = "";
					widget.getField("NRSEQUCONSOL").clearValue();
				}, 200);
			}  
		}
		ScreenService.hideLoader();
    };
    
    //Altera a funcionaldiade dos campos relacionados aos fields de status e item consolidado
    this.changeStatusAndItemConsolidado = function(args){
    	var widget = args.owner.owner.widget;
		ScreenService.showLoader();
		if(widget.name === "zhFilterPreferencesSelectConditions") {
			setTimeout(() => {
        		if(args.owner.owner.widget.currentRow.NRSEQUCONSOL.length < 1){
        			widget.getField("STATUS").readOnly = false;
        			widget.currentRow.STATUS = "T";
        			widget.getField("ITEMCONSOL").readOnly = false;
        			widget.currentRow.ITEMCONSOL = "T";
        		} else {
        	    	widget.getField("STATUS").readOnly = true;
        	    	widget.getField("STATUS").reload();
        			widget.currentRow.STATUS = "OL";
        			widget.getField("ITEMCONSOL").readOnly = true;
        			widget.currentRow.ITEMCONSOL = "SIM";
        		}
        		widget.reload();
			}, 800);
		}
		ScreenService.hideLoader();
    };
    
    //Armazena o valor do CDFILIAL selecionado anteriormente
    this.storeBeforeCDFILIAL = function(args){
        var splitFilialOL = args.owner.owner.widget.currentRow.FILIALOL.split(' ');
        var_beforeCDFILIAL = splitFilialOL[0];
    };
    
    //Armazena o valor do CDFILIAL
    this.storeCDFILIAL = function(args){
        var_CDFILIAL = args.owner.owner.widget.currentRow.CDFILIAL;
    };
    
    //Armazena o valor do DATA DE ENTREGA
    this.storeDATAENTREGA = function(args){
        var_DATAENTREGA_start = args.owner.owner.widget.currentRow.DATAENTREGA.start;
        var_DATAENTREGA_end = args.owner.owner.widget.currentRow.DATAENTREGA.end;
    };
    
    //Armazena o valor do DATA DE SOLICITAÇÃO
    this.storeDATASOLICITACAO = function(args){
        var_DATASOLICITACAO_start = args.owner.owner.widget.currentRow.DATASOLICITACAO.start;
        var_DATASOLICITACAO_end = args.owner.owner.widget.currentRow.DATASOLICITACAO.end;
    };
    
    //Retorna os valores do filtro
    this.getFieldValueFilter = function(fieldName, widgetName) {
        var container =  templateManager.container;
        if(container) {
            var filterWidget;
            var filterBeforeApply = templateManager.container.getActiveWidget();
            
            //test about how widget is... (field or filter)
    	    if(filterBeforeApply.label != 'Filtro'){		
    		    filterBeforeApply = filterBeforeApply.lastActiveWidget;
                filterWidget = filterBeforeApply;
                
            }
            if(filterBeforeApply.name == 'zhFilterPreferencesSelectConditions') {
            	filterWidget = filterBeforeApply;
            }
            else {
                var f = container.getWidget(widgetName);
                if(f) {
                     filterWidget = container.getWidget(widgetName).appliedFilter;
                }
            }
            
            // Insert values
            if(filterWidget) {
                var valueField;
                if(filterBeforeApply.name == 'zhFilterPreferencesSelectConditions')
                    valueField = filterWidget.currentRow[fieldName];
                else
                    valueField = filterWidget.FILTER_ROW[fieldName];
                return valueField || null;
            }
            else return null;
        }
        else return null;
    };
    
    //Retorna o valor do CDFILIAL
    this.getFieldValueCDFILIAL = function(){
        return var_CDFILIAL;
    };
    
    //Retorna a data Entrada da DATA DE ENTRADA
    this.getEntradaDataEntrega = function(data_entrada) {
        if (data_entrada) {
            return data_entrada.start;
        } else {
            return null;  
        }
    };
    
    //Retorna a data Final da DATA DE ENTRADA
    this.getFinalDataEntrega = function(data_entrada) {
        if (data_entrada) {
            return data_entrada.end;
        } else {
            return null;  
        }
    };
    
    //Retorna a data Entrada da DATA DE SOLICITAÇÃO
    this.getEntradaDataSolicitacao = function(data_solicitacao) {
        if (data_solicitacao) {
            return data_solicitacao.start;
        } else {
            return null;  
        }
    };
    
    //Retorna a data Final da DATA DE SOLICITAÇÃO
    this.getFinalDataSolicitacao = function(data_solicitacao) {
        if (data_solicitacao) {
            return data_solicitacao.end;
        } else {
            return null;  
        }
    };
    
    //Retorna as data de inicio necessária como parametro para a dataRourceFilter do campo CONSOLIDAÇÃO
    this.getDataInicialForNumeroConsolidacao = function(parameter) {
        if(parameter === 'inicio'){
            if(var_DATAENTREGA_start && var_DATAENTREGA_end) {
                return var_DATAENTREGA_start;
            } else if(var_DATASOLICITACAO_start && var_DATASOLICITACAO_end) {
                return var_DATASOLICITACAO_start;
            } else {
                return null;
            }
        }
    };
    
    //Retorna as data final necessária como parametro para a dataRourceFilter do campo CONSOLIDAÇÃO
    this.getDataFinalForNumeroConsolidacao = function(parameter) {
        if(parameter === 'fim'){
            if(var_DATAENTREGA_start && var_DATAENTREGA_end) {
                return var_DATAENTREGA_end;
            } else if(var_DATASOLICITACAO_start && var_DATASOLICITACAO_end) {
                return var_DATASOLICITACAO_end;
            } else {
                return null;
            }
        }
    };
    
    //Verifica se o produto inicial ou final foram selecionados
    this.verificaFieldsProdutos = function(args) {
    	var widget = args.owner.owner.widget;
		ScreenService.showLoader();
		if(widget.name === "zhFilterPreferencesSelectConditions") {
			setTimeout(() => {
        	    if(widget.currentRow.NMPRODUTOINI) {
        	        widget.getField('NMPRODUTOINI').validations = {required : {message: "Campo obrigatório"}};
                    widget.getField('NMPRODUTOFIN').validations = {required : {message: "Campo obrigatório"}};
        	    } else if(widget.currentRow.NMPRODUTOFIN) {
        	        widget.getField('NMPRODUTOINI').validations = {required : {message: "Campo obrigatório"}};
                    widget.getField('NMPRODUTOFIN').validations = {required : {message: "Campo obrigatório"}};
        	    } else {
        	        delete widget.getField('NMPRODUTOINI').validations.required;
        	        delete widget.getField('NMPRODUTOFIN').validations.required;
        	    }
                widget.reload();
			}, 200);
		}
		ScreenService.hideLoader();
    };
    
    //Verifica o status da field STATUS a ser filtrado
    this.verificaStatus = function(STATUS) {
        //Se o STATUS selecionado for ED
        if(STATUS == "ED"){
            return "S";
        //Se o STATUS selecionado for OL
        } else if(STATUS == "OL"){
            return "N";
        //Se o STATUS selecionado for AMBOS
        } else if (STATUS == "T"){
            return "T";
        }
    };
    
    //Verifica o item consolidado da field ITEM CONSOLIDADO a ser filtrado
    this.verificaItemConsolidado = function(ITEMCONSOL) {
        //Se o ITEMCONSOL selecionado for Sim
        if(ITEMCONSOL == "SIM"){
            return "S";
        //Se o ITEMCONSOL selecionado for Não
        } else if(ITEMCONSOL == "NAO"){
            return "N";
        //Se o ITEMCONSOL selecionado for AMBOS
        } else if (ITEMCONSOL == "T"){
            return "T";
        }
    };
    
    //Verifica o pedido gerado da field PEDIDO GERADO a ser filtrado
    this.verificaPedidoGerado = function(PEDGERADO) {
        //Se o PEDIDOGERADO selecionado for Sim
        if(PEDGERADO == "SIM"){
            return "S";
        //Se o PEDIDOGERADO selecionado for Não
        } else if(PEDGERADO == "NAO"){
            return "N";
        //Se o PEDIDOGERADO selecionado for AMBOS
        } else if (PEDGERADO == "T"){
            return "T";
        }
    };
    
    //Verifica os campos da field QNTD. PEDIDO a ser filtrado
    this.verificaQtdPedido = function(PEDIDOMAIOR, PEDIDOMENOR, PEDIDOIGUAL) {
        //Armazena o valor
        var value = '';
        //Se somente a opção Maior que o solicitado estiver marcado
        if(PEDIDOMAIOR == "S" && PEDIDOMENOR == "N" && PEDIDOIGUAL == "N"){
            value = "A";
        //Se somente a opção Menor que o Solicitado estiver marcado
        } else if(PEDIDOMAIOR == "N" && PEDIDOMENOR == "S" && PEDIDOIGUAL == "N"){
            value = "B";
        //Se somente a opção Igual ao Solicitado estiver marcado
        } else if(PEDIDOMAIOR == "N" && PEDIDOMENOR == "N" && PEDIDOIGUAL == "S"){
            value = "C";
        //Se somente as opções Maior que o Solicitado e Igual ao Solicitado estiverem marcados
        } else if(PEDIDOMAIOR == "S" && PEDIDOMENOR == "N" && PEDIDOIGUAL == "S"){
            value = "D";
        //Se somente as opções Menor que o Solicitado e Igual ao Solicitado estiverem marcados
        } else if(PEDIDOMAIOR == "N" && PEDIDOMENOR == "S" && PEDIDOIGUAL == "S"){
            value = "E";
        //Se somente as opções Maior que o Solicitado e Menor que o Solicitado estiverem marcados
        } else if(PEDIDOMAIOR == "S" && PEDIDOMENOR == "S" && PEDIDOIGUAL == "N"){
            value = "F";
        //Se todos estiverem marcados
        } else if(PEDIDOMAIOR == "S" && PEDIDOMENOR == "S" && PEDIDOIGUAL == "S"){
            value = "T";
        }
        //Armazena o valor do QTDPEDIDO
        var_QTDPEDIDO = value;
        return value;
    };
    
    //Altera o label da tab que exibe os detalhes do registro do grid principal
    this.setLabelDetail = function(args){
        var currentRow = args.currentRow;
        args.descriptionOrder = currentRow.CDFILSOLI  + " - " + currentRow.NMFILIAL + " - " + currentRow.NRSOLICMP + " - " + currentRow.CDARVPROD + " - " + currentRow.NMPRODUTO + " - " + currentRow.NRSEQUCONSOL + " - " + currentRow.IDPEDIDOOL; 
    };
    
    //Define a tab padrão ao clicar em um registro do grid principal
    this.setDefaultTab = function(args){
        const widget = templateManager.container.getWidget('gridPedidoOl');
        widget.activate();
    };
    
    //Carrega o grid de produtos do pedido da solicitação da PEDIDO OL
    this.loadGridProdutoPedidoSolicitacao = function(args){
        //Armazena o widget do primeiro grid da tab
        const widgetGridProdutoPedidoSolicitacao = templateManager.container.getWidget('gridProdutoPedidoSolicitacao');
        //Armazena o widget do segundo grid da tab
        const widgetGridProdutoRelacionamentoOL = templateManager.container.getWidget('gridProdutoRelacionamentoOL');
        //Se a data de entrada do item for diferente de nulo
        if (args.row.DTPROGENTR !== null) {
            var dtentrega = args.row.DTPROGENTR.split(' ');
            args.row.DTPROGENTR = dtentrega[0];    
        }
        //Se NRSEQUCONSOL for nulo
        if (args.row.NRSEQUCONSOL === null) {
            args.row.NRSEQUCONSOL = '';
        }
        //Limpa a array de dados agrupados
        delete widgetGridProdutoPedidoSolicitacao.groupedData;
        //Define o DSFilter do gridProdutoPedidoSolicitacao
        widgetGridProdutoPedidoSolicitacao.dataSourceFilter = [
            {
                "name": "P_CDFILIAL",
                "operator": "=",
                "value": args.row.CDFILSOLI
            },
            {
                "name": "P_CDFILIALOL",
                "operator": "=",
                "value": var_CDFILIAL
            },
            {
                "name": "P_DTPROGENTR",
                "operator": "=",
                "value": args.row.DTPROGENTR
            },  
            {
                "name": "P_CDPRODESTO",
                "operator": "=",
                "value": args.row.CDPRODESTO
            },  
            {
                "name": "P_NRSEQUCONSOL",
                "operator": "=",
                "value": args.row.NRSEQUCONSOL
            },  
            {
                "name": "P_QTPEDIDO",
                "operator": "=",
                "value": var_QTDPEDIDO
            }
        ];
        //Reload widget gridProdutoPedidoSolicitacao
        widgetGridProdutoPedidoSolicitacao.reload();
        //Após reload do gridProdutoPedidoSolicitacao, faz a validação
        setTimeout(() => {
            //Se a array estiver populada, busca os registros do primeiro item para popular o gridProdutoRelacionamentoOL
            if (widgetGridProdutoPedidoSolicitacao.groupedData && widgetGridProdutoPedidoSolicitacao.groupedData.length >= 1) {
                //Seta a primeira ROW como selecionada
                widgetGridProdutoPedidoSolicitacao.setCurrentRow(widgetGridProdutoPedidoSolicitacao.groupedData[0]);
                //Chama a função que carrega o segundo grid da tab passando a primeira row como parametro
                this.loadGridProdutoRelacionamentoOL(null, widgetGridProdutoPedidoSolicitacao.groupedData[0]);
            } else {
                //Limpa o filtro gridProdutoRelacionamentoOL
                widgetGridProdutoRelacionamentoOL.dataSourceFilter = [];
                //Reload widget gridProdutoRelacionamentoOL
                widgetGridProdutoRelacionamentoOL.reload();    
            }
        }, 1400);
    };
    
    //Carrega o grid de produtos de relacionamento ol da PEDIDO OL
    this.loadGridProdutoRelacionamentoOL = function(args, firstItemGridProduto){
        //Armazena o widget do primeiro grid da tab
        const widgetGridProdutoRelacionamentoOL = templateManager.container.getWidget('gridProdutoRelacionamentoOL');
        //Pega o primeiro item do grid de Produto e busca registros relacionados a ele para popular o grid Produto Relacionamento OL
        if (firstItemGridProduto) {
            //Define o DSFilter do gridProdutoRelacionamentoOL
            widgetGridProdutoRelacionamentoOL.dataSourceFilter = [
                {
                    "name": "P_QUANT_ESTOQUE",
                    "operator": "=",
                    "value": firstItemGridProduto.QTPROGENPEOL
                },
                {
                    "name": "P_NRAUTOFORN",
                    "operator": "=",
                    "value": firstItemGridProduto.NRPEDEXOL
                },  
                {
                    "name": "P_CDFILDEST",
                    "operator": "=",
                    "value": firstItemGridProduto.CDFILDEST
                },  
                {
                    "name": "P_CDFILLANC",
                    "operator": "=",
                    "value": firstItemGridProduto.CDFILLANC
                },  
                {
                    "name": "P_DTPROGENTAF",
                    "operator": "=",
                    "value": firstItemGridProduto.DTPROGENPEOL
                },  
                {
                    "name": "P_CDPRODUTO",
                    "operator": "=",
                    "value": firstItemGridProduto.CDARVPROD
                },  
                {
                    "name": "P_CDMARCA",
                    "operator": "=",
                    "value": firstItemGridProduto.CDMARCA
                },  
                {
                    "name": "P_CDFILIOPELOG",
                    "operator": "=",
                    "value": var_CDFILIAL
                }
            ];
        } else {
            //Define o DSFilter do gridProdutoRelacionamentoOL
            widgetGridProdutoRelacionamentoOL.dataSourceFilter = [
                {
                    "name": "P_QUANT_ESTOQUE",
                    "operator": "=",
                    "value": args.row.QTPROGENPEOL
                },
                {
                    "name": "P_NRAUTOFORN",
                    "operator": "=",
                    "value": args.row.NRPEDEXOL
                },  
                {
                    "name": "P_CDFILDEST",
                    "operator": "=",
                    "value": args.row.CDFILDEST
                },  
                {
                    "name": "P_CDFILLANC",
                    "operator": "=",
                    "value": args.row.CDFILLANC
                },  
                {
                    "name": "P_DTPROGENTAF",
                    "operator": "=",
                    "value": args.row.DTPROGENPEOL
                },  
                {
                    "name": "P_CDPRODUTO",
                    "operator": "=",
                    "value": args.row.CDARVPROD
                },  
                {
                    "name": "P_CDMARCA",
                    "operator": "=",
                    "value": args.row.CDMARCA
                },  
                {
                    "name": "P_CDFILIOPELOG",
                    "operator": "=",
                    "value": var_CDFILIAL
                }
            ];    
        }
        //Reload widget gridProdutoRelacionamentoOL
        widgetGridProdutoRelacionamentoOL.reload();
    };
    
    //Reponsável por ativar o widget principal e retornar sua view
    this.actvateView = function() {
        //widget principal
        const widgetUnidadeSolicitante = templateManager.container.getWidget('gridUnidadeSolicitante');
        widgetUnidadeSolicitante.activate();
        widgetUnidadeSolicitante.view();
        this.actvateList();
    };
    
    //Reponsável por ativar o widget principal e retornar sua list
    this.actvateList = function() {
        //widget principal
        const widgetUnidadeSolicitante = templateManager.container.getWidget('gridUnidadeSolicitante');
        widgetUnidadeSolicitante.list();
    };
    
    this.setItemColor = function(row) {
        //Armazena o widget e o field Unidade
        const widget = templateManager.container.getWidget('gridProdutoPedidoSolicitacao');
        const field_unidade = widget.getField("QTPROGENPEOL");
        //Se a QTPROGENPEOL multiplicada pelo VRFATOCONV for maior que a QTSOLIPROD altera a cor para vermelho,
        //Se for menor, retorna a cor azul
        //Se for igual, entra no else e  continua a cor padrão(preto).....
        if ((row.QTPROGENPEOL * row.VRFATOCONV) > row.QTSOLIPROD) {
            field_unidade.element[0].firstElementChild.style.color = "red";
        } else {
            if ((row.QTPROGENPEOL * row.VRFATOCONV) < row.QTSOLIPROD) {
                field_unidade.element[0].firstElementChild.style.color = "blue";
            }
        }        
    };
    
    //Concatenação de parametros
    this.concatArrayForParams = function(arr, defaultValue) {
        return !Util.isEmptyOrBlank(arr) ? arr.join('_') : defaultValue;
    };
}

Configuration(function(ContextRegister) {
    ContextRegister.register("opl00300_acompanhamento_pedido_OL_Controller", opl00300_acompanhamento_pedido_OL_Controller);
});

// FILE: ./assets/modules/consolidacao/assets/modules/solicitacao/assets/js/controllers/Sup07200_lancamento_de_pedidos_Controller.js
function Sup07200_lancamento_de_pedidos_Controller(ScreenService, templateManager, ZhFilterPreferences, MessageService, maskEngine, ZhUtil, General, Sup07200_lancamento_de_pedidos_Service) {
    var parametrosParaSupri;
    var parametrosGerais;
    var parametrosParCmpsup;
    var ServiceLancamentoPedidoOL = Sup07200_lancamento_de_pedidos_Service;
    var self = this;
    var opEmissao;
    var CDFILIOPELOGPROD;
    var permissoesGeraisOperador;
    var permissoesFinaisOperador;
    
    this.onEnterOnceWidgetPedidos = function(args) {
        const widget = args.owner;
        const rowsToSet = {};
        const widgetDadosPedido = templateManager.container.getWidget("dadosPedido");
        const widgetDetalhesPedido = templateManager.container.getWidget("detalhesPedido");
        var resp;
        
        widgetDadosPedido.enabled = false;
        widgetDetalhesPedido.enabled = false;
        
        ScreenService.showLoader();
        
        rowsToSet.defaultFilter = widget.dataSourceFilter;
        rowsToSet.TCDLOTENVITOL = 'N';
        rowsToSet.IDBAIXAAF = [ '0', '1', '2', '3', '4', '5' ];
        rowsToSet.PEDOLEXTR = [ 'S', 'N' ];
        rowsToSet.TRESERVA = [ 'S', 'N' ];
        
        General.callRestEngine("opl#/crud/parcmpsup", "FilterData", [
            {
        		"name": "CDFILIAL",
        		"operator": "=",
        		"value": "FILIAL_LOGADA"
        	}
        ]).then(function(response) {
            parametrosParCmpsup = response.dataset.parcmpsup[0];
        }).catch(function(error) {
            MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
        });
        
        General.callRestEngine("opl_solicitacao#/permissoesGrupoOperador", "Row", {}).then(function(response) {
            permissoesGeraisOperador = response.dataset.permissoesGeraisOperador.map(function(row) {
                return row.IDAUTGRUPOP;
            }).join("_");
            permissoesFinaisOperador = Util.isEmptyOrBlank(response.dataset.permissoesFinaisOperador) ? "" : response.dataset.permissoesFinaisOperador.map(function(row) {
                return row.IDAUTGRUPOP;
            }).join("_");
        }).catch(function(error) {
            MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
        });
        
        General.callRestEngine("opl_solicitacao#/getCentralCompras", "Row", {}).then(function(response) {
            resp = response.dataset.data;
                
            if(resp) {
                if(resp.CDFILIAL == resp.CDFILCENTCMP) {
                    rowsToSet.NMFILIAL = [ resp.CDFILCENTCMP ];
                    
                    widget.currentRow.NMFILIAL = [ resp.CDFILCENTCMP ];
                } else {
                    rowsToSet.NMFILIAL = [ resp.CDFILIAL ];
                    
                    widget.currentRow.NMFILIAL = [ resp.CDFILIAL ];
                }
            }
            
            widget.getField("NMFILIAL").reload().then(function(resposta) {
                ZhFilterPreferences.openFilterWidget(widget, rowsToSet).then(opened => {
                    const filterWidget = templateManager.container.getActiveWidget();
                    const excluirReserva = widget.getAction("excluirReserva");
                    const incluirReserva = widget.getAction("incluirReserva");
                    const bloquearItemPedido = widget.getAction("bloquearItemPedido");
                    const desbloquearItemPedido = widget.getAction("desbloquearItemPedido");
                    const filter = [
                        {
        					"name": "CDFILIAL",
        					"operator": "=",
        					"value": resp.CDFILIAL
        				},
        				{
        					"name": "NRORG",
        					"operator": "=",
        					"value": resp.NRORG
        				}
        			];
        			
        			if(resp) {
        			    if(resp.CDFILIAL == resp.CDFILCENTCMP)
                            filterWidget.getField("NMFILIAL").readOnly = false;
                        else
                            filterWidget.getField("NMFILIAL").readOnly = true;
        			}
        			
        			bloquearItemPedido.isVisible = true;
        			desbloquearItemPedido.isVisible = true;
        			
                    filterWidget.getField("NMFILIAL").reload();
                    
                    filterWidget.activate();
        			
                    ScreenService.hideLoader();
                    
                    General.callRestEngine("opl#/crud/paramgeral", "FilterData", []).then(function(response) {
                        parametrosGerais = response.dataset.paramgeral[0];
                        
                        General.callRestEngine("opl#/crud/parasupri", "FilterData", filter).then(function(response) {
                            parametrosParaSupri = response.dataset.parasupri[0];
                            
                            if(parametrosParaSupri && parametrosParaSupri.IDUTRESPEDEXOL === 'S') {
                                excluirReserva.isVisible = true;
                                incluirReserva.isVisible = true;
                            } else {
                                excluirReserva.isVisible = false;
                                incluirReserva.isVisible = false;
                            }
                            
                            if(parametrosParaSupri && parametrosParaSupri.IDENVIOITMPEDOL == 'S') {
                                widget.getField("DSINCONITMOLEXP").isVisible = true;
                            } else {
                                widget.getField("DSINCONITMOLEXP").isVisible = false;
                            }
                            var boHabilita;
                            boHabilita = false;
                            if(permissoesGeraisOperador.indexOf("BLOL") == -1) {
                                boHabilita =  false;
                            } else {
                                if(permissoesFinaisOperador.indexOf("BLOL") != -1) {
                                    boHabilita = true;    
                                } else {
                                    boHabilita = false;
                                }
                            }
                            bloquearItemPedido.isVisible   = boHabilita;
                            desbloquearItemPedido.isVisible = boHabilita;    
                        }).catch(function(error) {
                            excluirReserva.isVisible = false;
                            incluirReserva.isVisible = false;
                            
                            MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
                        });
                    }).catch(function(error) {
                        MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
                    });
                    
                }).catch(error => {
                    ScreenService.hideLoader();
                });
            });
        }).catch(function(error) {
            if(error.data.error == "CDFILCENTCMP_NOT_REGISTERED") {
                MessageService.showMessageByCode(error.data.error);
            } else {
                MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
            }
        });
    };
    
    this.changeFieldsRegiaoRotaUnidade = function(widget) {
        const fieldRegiao = widget.getField("CDREGIAO");
        const fieldRota = widget.getField("CDROTATRANS");
        const fieldUnidade = widget.getField("NMFILIAL");
        
        widget.currentRow.CDREGIAO = null;
        widget.currentRow.CDROTATRANS = null;
        widget.currentRow.CDFILIAL = null;
        widget.currentRow.NMFILIAL = null;
        
        fieldRegiao.clearValue();
        fieldRegiao.reload();
        
        fieldRota.clearValue();
        fieldRota.reload();
        
        fieldUnidade.clearValue();
        fieldUnidade.reload();
        fieldUnidade.dataSourceFilter = [
            {
                "name": "P_CDOPERADOR",
                "operator": "=",
                "value": "@getLocalVar('CDOPERADOR')@"
            },
            {
                "name": "P_TCDREGIAO",
                "operator": "=",
                "value": "T"
            },
            {
                "name": "P_CDREGIAO",
                "operator": "=",
                "value": ""
            },
            {
                "name": "P_CDGRUPFILI",
                "operator": "=",
                "value": widget.currentRow.CDGRUPFILI ? widget.currentRow.CDGRUPFILI : 'T'
            },
            {
                "name": "P_CDROTA",
                "operator": "=",
                "value": "T"
            }
        ];
        fieldUnidade.reload();
        
        widget.activate();
    };
    
    this.changeFieldsRotaUnidade = function(widget) {
        const fieldRota = widget.getField("CDROTATRANS");
        const fieldUnidade = widget.getField("NMFILIAL");
        
        widget.currentRow.CDROTATRANS = null;
        widget.currentRow.CDFILIAL = null;
        widget.currentRow.NMFILIAL = null;
        
        fieldRota.clearValue();
        fieldRota.reload();
        
        fieldUnidade.clearValue();
        fieldUnidade.reload();
        fieldUnidade.dataSourceFilter = [
            {
                "name": "P_CDOPERADOR",
                "operator": "=",
                "value": "@getLocalVar('CDOPERADOR')@"
            },
            {
                "name": "P_TCDREGIAO",
                "operator": "=",
                "value": widget.currentRow.CDREGIAO ? (widget.currentRow.CDREGIAO.length > 0) ? "" : 'T' : 'T'
            },
            {
                "name": "P_CDREGIAO",
                "operator": "=",
                "value": widget.currentRow.CDREGIAO ? (widget.currentRow.CDREGIAO.length > 0) ? widget.currentRow.CDREGIAO.join('_') : "" : ""
            },
            {
                "name": "P_CDGRUPFILI",
                "operator": "=",
                "value": widget.currentRow.CDGRUPFILI ? widget.currentRow.CDGRUPFILI : 'T'
            },
            {
                "name": "P_CDROTA",
                "operator": "=",
                "value": "T"
            }
        ];
        fieldUnidade.reload();
        
        widget.activate();
    };
    
    this.changeFieldsUnidade = function(widget) {
        const fieldUnidade = widget.getField("NMFILIAL");
        
        widget.currentRow.CDFILIAL = null;
        widget.currentRow.NMFILIAL = null;
        
        fieldUnidade.clearValue();
        fieldUnidade.reload();
        fieldUnidade.dataSourceFilter = [
            {
                "name": "P_CDOPERADOR",
                "operator": "=",
                "value": "@getLocalVar('CDOPERADOR')@"
            },
            {
                "name": "P_TCDREGIAO",
                "operator": "=",
                "value": widget.currentRow.CDREGIAO ? (widget.currentRow.CDREGIAO.length > 0) ? "" : 'T' : 'T'
            },
            {
                "name": "P_CDREGIAO",
                "operator": "=",
                "value": widget.currentRow.CDREGIAO ? (widget.currentRow.CDREGIAO.length > 0) ? widget.currentRow.CDREGIAO.join('_') : "" : ""
            },
            {
                "name": "P_CDGRUPFILI",
                "operator": "=",
                "value": widget.currentRow.CDGRUPFILI ? widget.currentRow.CDGRUPFILI : 'T'
            },
            {
                "name": "P_CDROTA",
                "operator": "=",
                "value": widget.currentRow.CDROTATRANS ? (widget.currentRow.CDROTATRANS.length > 0) ? widget.currentRow.CDROTATRANS.join('_') : 'T' : 'T'
            }
        ];
        fieldUnidade.reload();
        
        widget.activate();
    };
    
    this.changeFieldLote = function(widget) {
        const fieldlote = widget.getField("CDLOTE");
        
        if(widget.currentRow.TCDLOTENVITOL === 'L') {
            fieldlote.readOnly = false;
            fieldlote.validations = {
                "required": true
            };
            fieldlote.reload();
            fieldlote.setValue(null);
        } else {
            fieldlote.readOnly = true;
            fieldlote.reload();
            fieldlote.setValue(null);
            delete fieldlote.validations;
        }
        
        widget.activate();
        widget.sync();
    };
    
    this.changeFieldSubgrupo = function(widget) {
        const fieldSubgrupo = widget.getField("CDSUBGRPROD");
        
        if(widget.currentRow.NCONSIDERASUBGRUPO === 'N') {
            fieldSubgrupo.readOnly = false;
            fieldSubgrupo.reload();
            fieldSubgrupo.setValue(null);
        } else {
            fieldSubgrupo.readOnly = true;
            fieldSubgrupo.reload();
            fieldSubgrupo.setValue(null);
        }
        
        widget.activate();
    };
    
    this.filterProdIni = function(args) {
		var widget = args.owner.field.widget;
		var row = widget.currentRow;
		var prodIniIsSet = row.CDPRODINI ? true : false;
		
		if(!prodIniIsSet) {
			widget.currentRow.NMPRODFIN = '';
			widget.currentRow.CDPRODFIN = '';
            //widget.getField('NMPRODFIN').readOnly = true;
            //widget.getField('NMPRODFIN').readOnlyOnEdit = true;
		} else {
            //widget.getField('NMPRODFIN').readOnly = false;
            //widget.getField('NMPRODFIN').readOnlyOnEdit = false;
		}
        this.checkProductRange(args.owner.field);
	};
	
	this.filterProdFin = function(args) {
		var widget = args.owner.field.widget;
		var row = widget.currentRow;
		var prodFinIsSet = row.CDPRODFIN ? true : false;
		var prodIniIsSet = row.CDPRODINI ? true : false;
		
		if (prodFinIsSet) {
			if (row.CDPRODINI > row.CDPRODFIN) {
                MessageService.showMessageByCode("PRODUTO_INICIAL_MENOR_IGUAL_FINAL");
			}
		} else if(!prodIniIsSet) {
            //widget.getField('NMPRODFIN').readOnly = true;
            //widget.getField('NMPRODFIN').readOnlyOnEdit = true;
            widget.currentRow.NMPRODFIN = null;
            widget.currentRow.CDPRODFIN = null;
		}
		
		this.checkProductRange(args.owner.field);
	};
	
	this.checkProductRange = function(field) {
	   var currentRow = field.widget.currentRow;

		if (currentRow.CDPRODINI && currentRow.CDPRODFIN) {
			var compproduto = (currentRow.CDPRODFIN) ? currentRow.CDPRODFIN.replace(/[\.\-]/g, '') : null;

			if (!this.comparaPratoProduto(currentRow.CDPRODINI, compproduto, getLocalVar('CDPICTPROD'))) {
				currentRow[field.outData[field.descriptionField]] = null;
				currentRow[field.outData[field.valueField]] = null;

                field.widget.getField('NMPRODINI').clearValue();
                field.widget.getField('NMPRODFIN').clearValue();
                MessageService.showMessageByCode("PRODUTO_INICIAL_MENOR_IGUAL_FINAL");
			}
		}
	};
	
	this.comparaPratoProduto = function(pinicial, pfinal, mascara) {
        var mask = {
          type: "fix",
          params: {
              mask: mascara
          }
        };
        pinicial = Util.applyMask(pinicial, mask, maskEngine, ZhUtil).split('.');
        pfinal = Util.applyMask(pfinal, mask, maskEngine, ZhUtil).split('.');
        var nvinicial = pinicial.length;
        var nvfinal = pfinal.length;
        var resultado = true;
        if(nvinicial != nvfinal) {
            if(nvinicial > nvfinal) {
                resultado = false;
            }
        } else {
            var i = 0;
            do {
                if(pinicial[i] > pfinal[i]) {
                    resultado = false;
                }
                i++;
            }
            while (i<pinicial.length && resultado);
        }
        return resultado;
    };
    
    this.changeFieldBlock = function(widget) {
        const fieldBlock = widget.getField("DTBLOQ");
        
        if(widget.currentRow.TDTBLOQ === 'S') {
            fieldBlock.readOnly = false;
            fieldBlock.clearValue();
        } else {
            fieldBlock.readOnly = true;
            fieldBlock.clearValue();
        }
        
        widget.currentRow.DTBLOQ = {
            "start": "",
            "end": "",
            "formattedStart": "__/__/____",
            "formattedEnd": "__/__/____"
        };
        
        widget.activate();
    };
    
    this.changeFieldUnblock = function(widget) {
        const fieldUnblock = widget.getField("DTNBLOQ");
        
        if(widget.currentRow.TDTNBLOQ === 'S') {
            fieldUnblock.readOnly = false;
            fieldUnblock.clearValue();
        } else {
            fieldUnblock.readOnly = true;
            fieldUnblock.clearValue();
        }
        
        widget.currentRow.DTNBLOQ = {
            "start": "",
            "end": "",
            "formattedStart": "__/__/____",
            "formattedEnd": "__/__/____"
        };
        
        widget.activate();
    };
    
    this.setDataSourceFilter = function(args) {
        const filterRow = args.e.preference.FILTER_ROW;
        const widget = args.owner;
        const parametrosFinais = {
            "P_CDGRUPFILI": filterRow.CDGRUPFILI ? filterRow.CDGRUPFILI : null,
            "P_CDREGIAO": (!filterRow.CDREGIAO || filterRow.CDREGIAO.length == 0) ? null : '_' + filterRow.CDREGIAO.join('_') + '_',
            "P_TCDREGIAO": (!filterRow.CDREGIAO || filterRow.CDREGIAO.length == 0) ? 'T' : null,
            "P_CDFILIOPELOG": (!filterRow.NMFILIALOL || filterRow.NMFILIALOL.length == 0) ? null : '_' + filterRow.NMFILIALOL.join('_') + '_',
            "P_TCDFILIOPELOG": (!filterRow.NMFILIALOL || filterRow.NMFILIALOL.length == 0) ? 'T' : null,
            "P_CDFILIAL": (!filterRow.NMFILIAL || filterRow.NMFILIAL.length == 0) ? null : '_' + filterRow.NMFILIAL.join('_') + '_',
            "P_TCDFILIAL": (!filterRow.NMFILIAL || filterRow.NMFILIAL.length == 0) ? 'T' : null,
            "P_DTPEDINI": filterRow.DTPEDEXOL.start ? filterRow.DTPEDEXOL.start : null,
            "P_DTPEDFIN": filterRow.DTPEDEXOL.end ? filterRow.DTPEDEXOL.end : null,
            "P_DTEMBINI": filterRow.DTPROGEMBARQ.start ? filterRow.DTPROGEMBARQ.start : null,
            "P_DTEMBFIN": filterRow.DTPROGEMBARQ.end ? filterRow.DTPROGEMBARQ.end : null,
            "P_DTENTINI": filterRow.DTPROGENPEOL.start ? filterRow.DTPROGENPEOL.start : null,
            "P_DTENTFIN": filterRow.DTPROGENPEOL.end ? filterRow.DTPROGENPEOL.end : null,
            "P_CDPRODINI": filterRow.CDPRODINI ? filterRow.CDPRODINI : null,
            "P_CDPRODFIN": filterRow.CDPRODFIN ? (filterRow.CDPRODFIN + "ZZZZZZZZZZZZZZZZZZZZ").substr(0, 20) : null,
            "P_CDOPERADOR": getLocalVar('CDOPERADOR'),
            "P_DTBLOQINI": filterRow.TDTBLOQ === 'S' ? filterRow.DTBLOQ.start ? filterRow.DTBLOQ.start : null : null,
            "P_DTBLOQFIN": filterRow.TDTBLOQ === 'S' ? filterRow.DTBLOQ.end ? filterRow.DTBLOQ.end : null : null,
            "P_TBLOQ": (filterRow.TDTBLOQ === 'S' && !Util.isEmptyOrBlank(filterRow.DTBLOQ.start) && !Util.isEmptyOrBlank(filterRow.DTBLOQ.end)) ? null : filterRow.TDTBLOQ === 'S' ? 'T' : null,
            "P_BLOQ": filterRow.TDTBLOQ === 'S' ? 'S' : 'N',
            "P_DTNBLOQINI": filterRow.TDTNBLOQ === 'S' ? filterRow.DTNBLOQ.start ? filterRow.DTNBLOQ.start : null : null,
            "P_DTNBLOQFIN": filterRow.TDTNBLOQ === 'S' ? filterRow.DTNBLOQ.end ? filterRow.DTNBLOQ.end : null : null,
            "P_TNBLOQ": (filterRow.TDTNBLOQ === 'S' && !Util.isEmptyOrBlank(filterRow.DTNBLOQ.start) && !Util.isEmptyOrBlank(filterRow.DTNBLOQ.end)) ? null : filterRow.TDTNBLOQ === 'S' ? 'T' : null,
            "P_NBLOQ": filterRow.TDTNBLOQ === 'S' ? 'N' : 'S',
            "P_PEDOLEXTR": filterRow.PEDOLEXTR.length == 2 ? 'T' : filterRow.PEDOLEXTR[0] === 'S' ? 'S' : 'N',
            "P_CDLOTENVIOL": filterRow.TCDLOTENVITOL === 'N' ? 'T' : filterRow.TCDLOTENVITOL == 'S' ? 'S' : (!filterRow.CDLOTE || filterRow.CDLOTE.length == 0) ? 'T' : '_' + filterRow.CDLOTE.join('_') + '_',
            "P_TRESERVA": filterRow.TRESERVA.length == 2 ? '1' : filterRow.TRESERVA[0] === 'S' ? '2' : '3',
            "P_IDUTLSUBGRPRODFIL": parametrosParaSupri.IDUTLSUBGRPRODFIL,
            "P_SUBGRUPO": filterRow.NCONSIDERASUBGRUPO === 'S' ? 'N' : (!filterRow.CDSUBGRPROD || filterRow.CDSUBGRPROD.length == 0) ? 'N' : '_' + filterRow.CDSUBGRPROD.join('_') + '_',
            "P_CDGRUPPROD": parametrosParaSupri.CDGRUPPROD,
            "P_CDROTA": (!filterRow.CDROTATRANS || filterRow.CDROTATRANS.length == 0) ? 'T' : '_' + filterRow.CDROTATRANS.join('_') + '_',
            "P_IDBAIXAAF": (!filterRow.IDBAIXAAF || filterRow.IDBAIXAAF.length == 0) ? null : filterRow.IDBAIXAAF.length == 1 ? filterRow.IDBAIXAAF[0] :  '_' + filterRow.IDBAIXAAF.join('_') + '_'
        };
        const adicionaItemPedidoAction = widget.getAction("adicionaItemPedido");
        const adicionaNovoPedidoAction = widget.getAction("adicionaNovoPedido");
        
        if(parametrosFinais.P_TRESERVA == 3) {
            widget.getField("QTRESERVESTOL").isVisible = false;
        } else {
            widget.getField("QTRESERVESTOL").isVisible = true;
        }
        
        CDFILIOPELOGPROD = parametrosFinais.P_CDFILIOPELOG.substr(1, 4);
        
        widget.dataSourceFilter = [
		    {
		        "name": "P_CDGRUPFILI",
		        "operator": "=",
		        "value": parametrosFinais.P_CDGRUPFILI
		    },
		    {
		        "name": "P_CDREGIAO",
		        "operator": "=",
		        "value": parametrosFinais.P_CDREGIAO
		    },
		    {
		        "name": "P_TCDREGIAO",
		        "operator": "=",
		        "value": parametrosFinais.P_TCDREGIAO
		    },
		    {
		        "name": "P_CDFILIOPELOG",
		        "operator": "=",
		        "value": parametrosFinais.P_CDFILIOPELOG
		    },
		    {
		        "name": "P_TCDFILIOPELOG",
		        "operator": "=",
		        "value": parametrosFinais.P_TCDFILIOPELOG
		    },
		    {
		        "name": "P_CDFILIAL",
		        "operator": "=",
		        "value": parametrosFinais.P_CDFILIAL
		    },
		    {
		        "name": "P_TCDFILIAL",
		        "operator": "=",
		        "value": parametrosFinais.P_TCDFILIAL
		    },
		    {
		        "name": "P_DTPEDINI",
		        "operator": "=",
		        "value": parametrosFinais.P_DTPEDINI
		    },
		    {
		        "name": "P_DTPEDFIN",
		        "operator": "=",
		        "value": parametrosFinais.P_DTPEDFIN
		    },
		    {
		        "name": "P_DTEMBINI",
		        "operator": "=",
		        "value": parametrosFinais.P_DTEMBINI
		    },
		    {
		        "name": "P_DTEMBFIN",
		        "operator": "=",
		        "value": parametrosFinais.P_DTEMBFIN
		    },
		    {
		        "name": "P_DTENTINI",
		        "operator": "=",
		        "value": parametrosFinais.P_DTENTINI
		    },
		    {
		        "name": "P_DTENTFIN",
		        "operator": "=",
		        "value": parametrosFinais.P_DTENTFIN
		    },
		    {
		        "name": "P_CDPRODINI",
		        "operator": "=",
		        "value": parametrosFinais.P_CDPRODINI
		    },
		    {
		        "name": "P_CDPRODFIN",
		        "operator": "=",
		        "value": parametrosFinais.P_CDPRODFIN
		    },
		    {
		        "name": "P_CDOPERADOR",
		        "operator": "=",
		        "value": parametrosFinais.P_CDOPERADOR
		    },
		    {
		        "name": "P_DTBLOQINI",
		        "operator": "=",
		        "value": parametrosFinais.P_DTBLOQINI
		    },
		    {
		        "name": "P_DTBLOQFIN",
		        "operator": "=",
		        "value": parametrosFinais.P_DTBLOQFIN
		    },
		    {
		        "name": "P_TBLOQ",
		        "operator": "=",
		        "value": parametrosFinais.P_TBLOQ
		    },
		    {
		        "name": "P_BLOQ",
		        "operator": "=",
		        "value": parametrosFinais.P_BLOQ
		    },
		    {
		        "name": "P_DTNBLOQINI",
		        "operator": "=",
		        "value": parametrosFinais.P_DTNBLOQINI
		    },
		    {
		        "name": "P_DTNBLOQFIN",
		        "operator": "=",
		        "value": parametrosFinais.P_DTNBLOQFIN
		    },
		    {
		        "name": "P_TNBLOQ",
		        "operator": "=",
		        "value": parametrosFinais.P_TNBLOQ
		    },
		    {
		        "name": "P_NBLOQ",
		        "operator": "=",
		        "value": parametrosFinais.P_NBLOQ
		    },
		    {
		        "name": "P_PEDOLEXTR",
		        "operator": "=",
		        "value": parametrosFinais.P_PEDOLEXTR
		    },
		    {
		        "name": "P_CDLOTENVIOL",
		        "operator": "=",
		        "value": parametrosFinais.P_CDLOTENVIOL
		    },
		    {
		        "name": "P_TRESERVA",
		        "operator": "=",
		        "value": parametrosFinais.P_TRESERVA
		    },
		    {
		        "name": "P_IDUTLSUBGRPRODFIL",
		        "operator": "=",
		        "value": parametrosFinais.P_IDUTLSUBGRPRODFIL
		    },
		    {
		        "name": "P_SUBGRUPO",
		        "operator": "=",
		        "value": parametrosFinais.P_SUBGRUPO
		    },
		    {
		        "name": "P_CDGRUPPROD",
		        "operator": "=",
		        "value": parametrosFinais.P_CDGRUPPROD
		    },
		    {
		        "name": "P_CDROTA",
		        "operator": "=",
		        "value": parametrosFinais.P_CDROTA
		    },
		    {
		        "name": "P_IDBAIXAAF",
		        "operator": "=",
		        "value": parametrosFinais.P_IDBAIXAAF
		    }
		];
		
		widget.reload().then(function(callback) {
            widget.activate();
            
            if(callback.dataset.sup07200_lancamento_de_pedidos_grid.length == 0) {
                adicionaItemPedidoAction.isVisible = false;
                adicionaNovoPedidoAction.isVisible = true;
            } else {
                adicionaItemPedidoAction.isVisible = true;
                adicionaNovoPedidoAction.isVisible = false;
            }
		});
    };
    
    this.widgetAfterMoveRow = function(args) {
        const widgetItensPedido = args.owner;
        const widgetDadosPedido = templateManager.container.getWidget("dadosPedido");
        const widgetDetalhesPedido = templateManager.container.getWidget("detalhesPedido");
        const widgetStripe = templateManager.container.getWidget("stripeWidget");
        
        ScreenService.showLoader();
        
        if(widgetItensPedido.currentRow.NRPEDEXOL) {
            if(widgetItensPedido.mode === "inline_edit") {
                widgetDadosPedido.enabled = false;
                widgetDetalhesPedido.enabled = false;
            } else {
                widgetDadosPedido.enabled = true;
                widgetDetalhesPedido.enabled = true;
            }
            
            widgetDetalhesPedido.dataSourceFilter = [
                {
                    "name": "P_CDPRODUTO",
                    "operator": "=",
                    "value": widgetItensPedido.currentRow.CDARVPROD
                },
                {
                    "name": "P_CDMARCA",
                    "operator": "=",
                    "value": widgetItensPedido.currentRow.CDMARCA
                },
                {
    		        "name": "P_CDFILLANC",
    		        "operator": "=",
    		        "value": widgetItensPedido.currentRow.CDFILLANC
    		    },
    		    {
    		        "name": "P_DTPROGENPEOL",
    		        "operator": "=",
    		        "value": moment(widgetItensPedido.currentRow.DTPROGENPEOL, 'L').format('L')
    		    },
    		    {
    		        "name": "P_CDFILDEST",
    		        "operator": "=",
    		        "value": widgetItensPedido.currentRow.CDFILDEST.split(" - ")[0]
    		    },
    		    {
    		        "name": "P_NRPEDEXOL",
    		        "operator": "=",
    		        "value": widgetItensPedido.currentRow.NRPEDEXOL
    		    }
            ];
            
            widgetDetalhesPedido.reload();
            
            widgetStripe.currentRow.NRPEDEXOL = widgetItensPedido.currentRow.NRPEDEXOL;
            widgetStripe.currentRow.CDFILLANC = widgetItensPedido.currentRow.CDFILLANC;
            widgetStripe.currentRow.IDBAIXENPEOL = widgetStripe.getField("IDBAIXENPEOL").options[widgetItensPedido.currentRow.IDBAIXENPEOL];
            widgetStripe.currentRow.IDBAIXEXSAI = widgetStripe.getField("IDBAIXEXSAI").options[widgetItensPedido.currentRow.IDBAIXEXSAI];
            widgetStripe.currentRow.QTEFETENPEOL = widgetItensPedido.currentRow.QTEFETENPEOL == null ? '0,000' : widgetItensPedido.currentRow.QTEFETENPEOL + ',000';
            widgetStripe.currentRow.IDBAIXEXOL = widgetStripe.getField("IDBAIXEXOL").options[widgetItensPedido.currentRow.IDBAIXEXOL];
            widgetStripe.currentRow.DTPEDEXOL = moment(widgetItensPedido.currentRow.DTPEDEXOL, 'L').format('L');
            widgetStripe.currentRow.IDTIPOEXOL = widgetStripe.getField("IDTIPOEXOL").options[widgetItensPedido.currentRow.IDTIPOEXOL];
            widgetStripe.currentRow.IDITMPEDOLBLOQ = widgetStripe.getField("IDITMPEDOLBLOQ").options[widgetItensPedido.currentRow.IDITMPEDOLBLOQ];
            widgetStripe.currentRow.IDBAIXAOLSAI = widgetStripe.getField("IDBAIXAOLSAI").options[widgetItensPedido.currentRow.IDBAIXAOLSAI];
            
            General.callRestEngine("opl_solicitacao#/carregaDadosPedido", "Row", widgetItensPedido.currentRow).then(function(response) {
                const result = response.dataset.opl07200_dados_pedido;
                
                if(result) {
                    widgetDadosPedido.currentRow.NMFILLANC = result.NMFILLANC;
                    widgetDadosPedido.currentRow.CDFILLANC = result.CDFILLANC;
                    widgetDadosPedido.currentRow.NMFILDEST = result.NMFILDEST;
                    widgetDadosPedido.currentRow.CDFILDEST = result.CDFILDEST;
                    widgetDadosPedido.currentRow.NMFILIOPELOG = result.NMFILIOPELOG;
                    widgetDadosPedido.currentRow.CDFILIOPELOG = result.CDFILIOPELOG;
                    widgetDadosPedido.currentRow.DTPEDEXOL = result.DTPEDEXOL;
                    widgetDadosPedido.currentRow.IDPEDEXOLEXTR = result.IDPEDEXOLEXTR;
                    widgetDadosPedido.currentRow.CDEMPRESA = result.CDEMPRESA;
                    widgetDadosPedido.currentRow.IDTIPOEMITAF = result.IDEMITEXOL;
                    widgetDadosPedido.currentRow.NMTIPOEMITAF = result.IDEMITEXOL == '1' ? "Empresa da Unidade" : result.IDEMITEXOL == '2' ? "Empresa Informada" : "Cliente Principal";
                    widgetDadosPedido.currentRow.CDLOTENVITOL = widgetItensPedido.currentRow.CDLOTENVITOL ? widgetItensPedido.currentRow.CDLOTENVITOL : "";
                    widgetDadosPedido.currentRow.CDTIPCOB = result.CDTIPCOB;
                    widgetDadosPedido.currentRow.NMTIPOCOBR = result.NMTIPOCOBR;
                    widgetDadosPedido.currentRow.IDTIPOFRETAF = result.IDTPFRETEXOL;
                    widgetDadosPedido.currentRow.CDTPCTPAGAR = result.CDTPCTPAGAR;
                    widgetDadosPedido.currentRow.DSTPCTPAGAR = result.DSTPCTPAGAR;
                    widgetDadosPedido.currentRow.NRINSJURTRAN = result.NRINSJTREXOL;
                    widgetDadosPedido.currentRow.NMRAZSOCTRAN = result.NMRAZSOCTRAN;
                    widgetDadosPedido.currentRow.IDTPIJURTRAN = result.IDTPJTREXOL;
                    widgetDadosPedido.currentRow.IDBAIXEXOL = result.IDBAIXEXOL;
                    widgetDadosPedido.currentRow.IDBAIXEXSAI = result.IDBAIXEXSAI;
                    widgetDadosPedido.currentRow.NRPEDEXOL = result.NRPEDEXOL;
                    
                    widgetDadosPedido.getField("NMEMPRESA").dataSourceFilter[0].value = result.CDFILDEST;
                    widgetDadosPedido.getField("NMEMPRESA").dataSourceFilter[1].value = result.CDEMPRESA;
                    
                    widgetDadosPedido.getField("NMRAZSOCTRAN").dataSourceFilter[0].value = result.CDFILDEST;
                    widgetDadosPedido.getField("NMRAZSOCTRAN").dataSourceFilter[1].value = "";
                    widgetDadosPedido.getField("NMRAZSOCTRAN").dataSourceFilter[2].value = "";
                    
                    widgetDadosPedido.getField("NMLOTENVITOL").reload().then(data => {
                        let resultLote = data.dataset.lotes_all.filter(function(row) {
                            return row.CDLOTENVITOL == widgetItensPedido.currentRow.CDLOTENVITOL;
                        });
                        widgetDadosPedido.currentRow.NMLOTENVITOL = resultLote.length > 0 ? resultLote[0].NMLOTENVITOL : "";
                        widgetDadosPedido.currentRow.CDLOTENVITOL = resultLote.length > 0 ? resultLote[0].CDLOTENVITOL : "";
                    });
                    
                    self.destinatarioNF(widgetDadosPedido);
                    
                    if(result.IDBAIXEXOL == null || result.IDBAIXEXOL == '0' || result.IDBAIXEXOL == '1') {
                        widgetDadosPedido.getAction("editaDadosPedido").isVisible = true;
                        widgetDadosPedido.getAction("baixaManualPedido").isVisible = true;
                        widgetDadosPedido.getAction("cancelarPedido").isVisible = true;
                        widgetDadosPedido.getAction("encerrarPedido").isVisible = true;
                    } else {
                        widgetDadosPedido.getAction("editaDadosPedido").isVisible = false;
                        widgetDadosPedido.getAction("baixaManualPedido").isVisible = false;
                        widgetDadosPedido.getAction("cancelarPedido").isVisible = false;
                        widgetDadosPedido.getAction("encerrarPedido").isVisible = false;
                    }
                    
                    if(result.IDBAIXEXOL == '3' || result.IDBAIXEXOL == '4' || result.IDBAIXEXOL == '5') {
                        widgetDadosPedido.getAction("emAbertoPedido").isVisible = true;
                    } else {
                        widgetDadosPedido.getAction("emAbertoPedido").isVisible = false;
                    }
                    
                    if(result.IDBAIXEXOL == null || result.IDBAIXEXOL == '0') {
                        widgetDadosPedido.getAction("excluiPedido").isVisible = true;
                    } else {
                        widgetDadosPedido.getAction("excluiPedido").isVisible = false;
                    }
                    
                    if((parametrosParaSupri && parametrosParaSupri.IDENVIOITMPEDOL == 'S') && (result.IDBAIXEXOL == null || result.IDBAIXEXOL == '0')) {
                        widgetDadosPedido.getAction("exportarPedido").isVisible = true;
                    } else {
                        widgetDadosPedido.getAction("exportarPedido").isVisible = false;
                    }
                    
                    ScreenService.hideLoader();
                } else {
                    ScreenService.hideLoader();
                    
                    MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": "Não foi possível carregar os dados do pedido." });
                }
            }).catch(function(error) {
                ScreenService.hideLoader();
                
                MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
            });
        } else {
            widgetDadosPedido.enabled = false;
            widgetDetalhesPedido.enabled = false;
            
            ScreenService.hideLoader();
        }
    };
    
    this.adicionaItemPedido = function(widget) {
        const widgetAdicionaItemPedido = templateManager.container.getWidget("adicionaItemPedido");
        
        //var mascaraProduto = getLocalVar('CDPICTPROD');
        var fieldProduto = widgetAdicionaItemPedido.getField('NMPRODUTO');
        
        //mascaraProduto = mascaraProduto.split('.');
        
        //var nivelProduto = mascaraProduto.length;
        
        fieldProduto.dataSourceFilter.forEach(function(filtro) {
            if(filtro.name == "P_PRODCMP")
                filtro.value = parametrosParaSupri.IDUTLPROCMP;
            if(filtro.name == "P_CDFILSOLI")
                filtro.value = "FILIAL_LOGADA";
        });
        
        if(widget.currentRow.NRPEDEXOL) {
            widgetAdicionaItemPedido.currentRow.NRPEDEXOL = widget.currentRow.NRPEDEXOL;
            widgetAdicionaItemPedido.currentRow.DTPROGENPEOL = moment(widget.currentRow.DTPROGENPEOL, 'L').format('L');
            //widgetAdicionaItemPedido.currentRow.CDPRODUTO = widget.currentRow.CDPRODUTO;
            //widgetAdicionaItemPedido.currentRow.CDARVPROD = widget.currentRow.CDARVPROD;
            //widgetAdicionaItemPedido.currentRow.CDPRODESTO = widget.currentRow.CDPRODESTO;
            //widgetAdicionaItemPedido.currentRow.NMPRODUTO = widget.currentRow.NMPRODUTO;
            //widgetAdicionaItemPedido.currentRow.SGUNIDADE = widget.currentRow.SGUNIDADE;
            widgetAdicionaItemPedido.currentRow.CDMARCA = widget.currentRow.CDMARCA;
            widgetAdicionaItemPedido.currentRow.NMMARCA = widget.currentRow.NMMARCA;
            widgetAdicionaItemPedido.currentRow.CDFILLANC = getLocalVar("CDFILIAL");
            widgetAdicionaItemPedido.currentRow.NMFILLANC = getLocalVar("NMFILIAL");
            widgetAdicionaItemPedido.currentRow.CDFILDEST = widget.currentRow.CDFILDEST.split(' - ')[0];
            widgetAdicionaItemPedido.currentRow.NMFILDEST = widget.currentRow.CDFILDEST.split(' - ')[1];
            widgetAdicionaItemPedido.currentRow.QTPROGENPEOL = widget.currentRow.QTPROGENPEOL;
            widgetAdicionaItemPedido.currentRow.CDFILIOPELOG = widget.currentRow.CDFILIOPELOG;
            
            widgetAdicionaItemPedido.getField("NMFILIOPELOG").reload().then(data => {
                let result = data.dataset.filial_ol.filter(function(row) {
                    return row.CDFILIAL == widget.currentRow.CDFILIOPELOG;
                });
                widgetAdicionaItemPedido.currentRow.NMFILIOPELOG = result[0].NMFILIAL;
            });
            
            widgetAdicionaItemPedido.getField("NRPEDEXOL").readOnly = true;
        } else {
            if(widget.dataSource.data.length > 0) {
                widgetAdicionaItemPedido.currentRow.NRPEDEXOL = widget.dataSource.data[0].NRPEDEXOL;
                widgetAdicionaItemPedido.currentRow.DTPROGENPEOL = moment(widget.dataSource.data[0].DTPROGENPEOL, 'L').format('L');
                //widgetAdicionaItemPedido.currentRow.CDPRODUTO = widget.dataSource.data[0].CDPRODUTO;
                //widgetAdicionaItemPedido.currentRow.CDARVPROD = widget.dataSource.data[0].CDARVPROD;
                //widgetAdicionaItemPedido.currentRow.CDPRODESTO = widget.dataSource.data[0].CDPRODESTO;
                //widgetAdicionaItemPedido.currentRow.NMPRODUTO = widget.dataSource.data[0].NMPRODUTO;
                //widgetAdicionaItemPedido.currentRow.SGUNIDADE = widget.dataSource.data[0].SGUNIDADE;
                widgetAdicionaItemPedido.currentRow.CDMARCA = widget.dataSource.data[0].CDMARCA;
                widgetAdicionaItemPedido.currentRow.NMMARCA = widget.dataSource.data[0].NMMARCA;
                widgetAdicionaItemPedido.currentRow.CDFILLANC = getLocalVar("CDFILIAL");
                widgetAdicionaItemPedido.currentRow.NMFILLANC = getLocalVar("NMFILIAL");
                widgetAdicionaItemPedido.currentRow.CDFILDEST = widget.dataSource.data[0].CDFILDEST.split(' - ')[0];
                widgetAdicionaItemPedido.currentRow.NMFILDEST = widget.dataSource.data[0].CDFILDEST.split(' - ')[1];
                widgetAdicionaItemPedido.currentRow.QTPROGENPEOL = widget.dataSource.data[0].QTPROGENPEOL;
                widgetAdicionaItemPedido.currentRow.CDFILIOPELOG = widget.dataSource.data[0].CDFILIOPELOG;
                
                widgetAdicionaItemPedido.getField("NMFILIOPELOG").reload().then(data => {
                    let result = data.dataset.filial_ol.filter(function(row) {
                        return row.CDFILIAL == widget.dataSource.data[0].CDFILIOPELOG;
                    });
                    widgetAdicionaItemPedido.currentRow.NMFILIOPELOG = result[0].NMFILIAL;
                });
                
                widgetAdicionaItemPedido.getField("NRPEDEXOL").readOnly = true;
            } else {
                widgetAdicionaItemPedido.currentRow.CDFILLANC = getLocalVar("CDFILIAL");
                widgetAdicionaItemPedido.currentRow.NMFILLANC = getLocalVar("NMFILIAL");
                widgetAdicionaItemPedido.currentRow.DTPROGENPEOL = moment().format('L');
                
                widgetAdicionaItemPedido.getField("NRPEDEXOL").readOnly = false;
            }
        }
        
        if(parametrosParaSupri.IDUTILCONSSOLIOLEXT === 'S') {
            widgetAdicionaItemPedido.getField("CDLOTENVITOL").readOnly = true;
            widgetAdicionaItemPedido.getField("CDLOTENVITOL").isVisible = true;
        } else {
            widgetAdicionaItemPedido.getField("CDLOTENVITOL").readOnly = true;
            widgetAdicionaItemPedido.getField("CDLOTENVITOL").isVisible = false;
        }
        
        ScreenService.openSwipe(widgetAdicionaItemPedido);
    };
    
    this.salvaAdicaoItemPedido = function(widget) {
        const dataProc = moment(getLocalVar("DTPROCESSA"), "DD/MM/YYYY").format("MM-DD-YYYY");
        const dataEscd = moment(widget.currentRow.DTPROGENPEOL, "DD/MM/YYYY").format("MM-DD-YYYY");
        
        widget.currentRow.FINAL = permissoesFinaisOperador;
        widget.currentRow.GERAL = permissoesGeraisOperador;
        
        if(widget.isValid()) {
            if(moment(dataEscd).isSameOrAfter(dataProc)) {
                General.callRestEngine("opl_solicitacao#/adqRelacProdOL", "Row", widget.currentRow).then(function(resp) {
                    
                    if(Util.isEmptyOrBlank(resp.dataset.data)) {
                        if(parametrosParaSupri.IDBLQLANITSEMRELACOL == 'S') {
                            MessageService.showMessageByCode("PRODUTO_ITEM_SEM_RELACAO_PRODOL");
                            MessageService.showMessageByCode("PARAM_IDBLQLANITSEMRELACOL");
                        } else {
                            MessageService.showMessageByCode("PRODUTO_ITEM_SEM_RELACAO_PRODOL");
                            
                            General.callRestEngine("opl_solicitacao#/checkIgualdadeItemPedidoOL", "Row", widget.currentRow).then(function(callback) {
                                General.callRestEngine("opl_solicitacao#/insereItemPedidoOL", "Row", widget.currentRow).then(function(response) {
                                    widget.currentRow = {};
                                    
                                    MessageService.showMessageByCode("OPERACAO_SUCESSO");
                                    
                                    ScreenService.closeSwipe();
                                    
                                    const widgetItensPedido = widget.getParent();
                                    
                                    widgetItensPedido.activate();
                                    widgetItensPedido.reload();
                                }).catch(function(error) {
                                    if(error.data.error == "QTPROGENPEOL_EQUALS_ZERO")
                                        MessageService.showMessageByCode(error.data.error);
                                    else
                                        MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
                                });
                            }).catch(function(error) {
                                if(error.data.error == "ITEM_ALREADY_EXISTS_PEDIDO" || error.data.error == "ERRO_QUERY") {
                                    MessageService.showMessageByCode(error.data.error);
                                } else {
                                    MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
                                }
                            });
                        }
                    } else {
                        General.callRestEngine("opl_solicitacao#/checkIgualdadeItemPedidoOL", "Row", widget.currentRow).then(function(callback) {
                            General.callRestEngine("opl_solicitacao#/insereItemPedidoOL", "Row", widget.currentRow).then(function(response) {
                                widget.currentRow = {};
                                
                                MessageService.showMessageByCode("OPERACAO_SUCESSO");
                                
                                ScreenService.closeSwipe();
                                
                                const widgetItensPedido = widget.getParent();
                                
                                widgetItensPedido.activate();
                                widgetItensPedido.reload();
                            }).catch(function(error) {
                                if(error.data.error == "QTPROGENPEOL_EQUALS_ZERO")
                                    MessageService.showMessageByCode(error.data.error);
                                else
                                    MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
                            });
                        }).catch(function(error) {
                            if(error.data.error == "ITEM_ALREADY_EXISTS_PEDIDO" || error.data.error == "ERRO_QUERY") {
                                MessageService.showMessageByCode(error.data.error);
                            } else {
                                MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
                            }
                        });
                    }
                }).catch(function(error) {
                    MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
                });
            } else {
                MessageService.showMessageByCode("DATA_MAIOR_IGUAL_PROCESSAMENTO");
            }
        } else {
            MessageService.showMessageByCode("OBRIGATORY_FIELDS");
        }
    };
    
    this.excluiItemPedido = function(widget) {
        const rowsSelecionadas = widget.getCheckedRows();
        const rowsEmAberto = rowsSelecionadas.filter(function(row) {
            return ((row.IDBAIXENPEOL == null || row.IDBAIXENPEOL == 0) && (row.IDBAIXEXOL == null || row.IDBAIXEXOL == 0));
        });
        var rowsBloqueadas = [];
        
        rowsSelecionadas.forEach(row => {
           row.DTPROGENPEOL = moment(row.DTPROGENPEOL, "DD/MM/YYYY").format("DD/MM/YYYY");
           
           if(!verificaPermissaoItem(widget, row)) {
               rowsBloqueadas.push(row);
           }
        });
        
        if(rowsEmAberto.length == rowsSelecionadas.length) {
            if(rowsBloqueadas.length >= 1) {
                var rowsToMessage = [];
                var stringItem = "";
                
                rowsBloqueadas.forEach(row => {
					var prod = "Pedido: " + row.NRPEDEXOL + ", Produto: " + row.NMPRODUTO + ", Marca: " + row.NMMARCA + ", Entrega: " + row.DTPROGENPEOL;
										
					rowsToMessage.push(prod);
			    });
			    
			    stringItem = rowsToMessage.join("<br><br>");
			    
			    MessageService.showMessageByCode("OPER_BLOCK_ITEM_GRUPOOPER", { ITEM: stringItem });
            } else {
                MessageService.confirmMessageByCode("CONFIRMA_EXCLUSAO_ITENS").then(function(confirmed) {
                    General.callRestEngine("opl_solicitacao#/excluiItemPedidoOL", "Row", rowsSelecionadas).then(function(response) {
                        widget.activate();
                        widget.reload();
                        
                        MessageService.showMessageByCode("EXCLUSAO_REALIZADA");
                    }).catch(function(error) {
                        MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
                    });
                });
            }
        } else {
            MessageService.showMessageByCode("ONLY_EM_ABERTO_ITENS_PEDIDO_DELETE");
        }
    };
    
    this.openWidgetAlteracaoDataEntregaItemPedido = function(widget) {
        const popUpWidget = templateManager.container.getWidget("alteracaoDataEntregaItemPedidoWidget");
        const rowsSelecionadas = widget.getCheckedRows();
        const rowsEmAberto = rowsSelecionadas.filter(function(row) {
            return ((row.IDBAIXENPEOL == null || row.IDBAIXENPEOL == 0) && (row.IDBAIXEXOL == null || row.IDBAIXEXOL == 0));
        });
        var rowsBloqueadas = [];
        
        rowsSelecionadas.forEach(row => {
           if(!verificaPermissaoItem(widget, row)) {
               rowsBloqueadas.push(row);
           }
        });
        
        popUpWidget.currentRow = {};
        
        if(rowsEmAberto.length == rowsSelecionadas.length) {
            if(rowsBloqueadas.length >= 1) {
                var rowsToMessage = [];
                var stringItem = "";
                
                rowsBloqueadas.forEach(row => {
					var prod = "Pedido: " + row.NRPEDEXOL + ", Produto: " + row.NMPRODUTO + ", Marca: " + row.NMMARCA + ", Entrega: " + row.DTPROGENPEOL;
										
					rowsToMessage.push(prod);
			    });
			    
			    stringItem = rowsToMessage.join("<br><br>");
			    
			    MessageService.showMessageByCode("OPER_BLOCK_ITEM_GRUPOOPER", { ITEM: stringItem });
            } else {
                ScreenService.openPopup(popUpWidget);
            }
        } else {
            MessageService.showMessageByCode("ONLY_EM_ABERTO_ITENS_PEDIDO_EDIT");
        }
    };
    
    this.salvaAlteracaoDataEntregaItemPedido = function(widget) {
        const dataProc = moment(getLocalVar("DTPROCESSA"), "DD/MM/YYYY").format("MM-DD-YYYY");
        const dataEscd = moment(widget.currentRow.NOVADTENTREGA, "DD/MM/YYYY").format("MM-DD-YYYY");
        const widgetItensPedido = widget.getParent();
        const rowsSelecionadas = widgetItensPedido.getCheckedRows();
        
        rowsSelecionadas.forEach(row => {
           row.NEW_DTPROGENPEOL = moment(widget.currentRow.NOVADTENTREGA, "DD/MM/YYYY").format("DD/MM/YYYY");
           row.DTPROGENPEOL = moment(row.DTPROGENPEOL, "DD/MM/YYYY").format("DD/MM/YYYY");
        });
        
        if(widget.isValid()) {
            if(moment(dataEscd).isSameOrAfter(dataProc)) {
                General.callRestEngine("opl_solicitacao#/alteraDataEntregaItemPedidoOL", "Row", rowsSelecionadas).then(function(response) {
                    ScreenService.closePopup();
                    ScreenService.closePopup();
                    
                    widgetItensPedido.reload();
                    
                    MessageService.showMessageByCode("DTPROGENPEOL_EDIT_SUCCESS");
                }).catch(function(error) {
                    if(error.data.error == "DTPROGENPEOL_ALREADY_EXISTS_PEDIDO" || error.data.error == "ERRO_QUERY") {
                        MessageService.showMessageByCode(error.data.error);
                    } else {
                        MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
                    }
                    ScreenService.closePopup();
                    ScreenService.closePopup();
                    
                    widgetItensPedido.reload();
                });
            } else {
                MessageService.showMessageByCode("DATA_MAIOR_IGUAL_PROCESSAMENTO");
            }
        } else {
            MessageService.showMessageByCode("OBRIGATORY_FIELDS");
        }
    };
    
    this.openWidgetAlteracaoMarcaItemPedido = function(widget) {
        const popUpWidget = templateManager.container.getWidget("alteracaoMarcaItemPedidoWidget");
        const rowsSelecionadas = widget.getCheckedRows();
        const rowsEmAberto = rowsSelecionadas.filter(function(row) {
            return ((row.IDBAIXENPEOL == null || row.IDBAIXENPEOL == 0) && (row.IDBAIXEXOL == null || row.IDBAIXEXOL == 0));
        });
        var rowsBloqueadas = [];
        
        rowsSelecionadas.forEach(row => {
           if(!verificaPermissaoItem(widget, row)) {
               rowsBloqueadas.push(row);
           }
        });
        
        popUpWidget.currentRow = {};
        
        if(rowsEmAberto.length == rowsSelecionadas.length) {
            if(rowsBloqueadas.length >= 1) {
                var rowsToMessage = [];
                var stringItem = "";
                
                rowsBloqueadas.forEach(row => {
					var prod = "Pedido: " + row.NRPEDEXOL + ", Produto: " + row.NMPRODUTO + ", Marca: " + row.NMMARCA + ", Entrega: " + row.DTPROGENPEOL;
										
					rowsToMessage.push(prod);
			    });
			    
			    stringItem = rowsToMessage.join("<br><br>");
			    
			    MessageService.showMessageByCode("OPER_BLOCK_ITEM_GRUPOOPER", { ITEM: stringItem });
            } else {
                ScreenService.openPopup(popUpWidget);
            }
        } else {
            MessageService.showMessageByCode("ONLY_EM_ABERTO_ITENS_PEDIDO_EDIT");
        }
    };
    
    this.salvaAlteracaoMarcaItemPedido = function(widget) {
        const widgetItensPedido = widget.getParent();
        const rowsSelecionadas = widgetItensPedido.getCheckedRows();
        
        rowsSelecionadas.forEach(row => {
           row.NEW_CDMARCA = widget.currentRow.CDMARCA;
           row.OLD_CDMARCA = row.CDMARCA;
           row.DTPROGENPEOL = moment(row.DTPROGENPEOL, "DD/MM/YYYY").format("DD/MM/YYYY");
        });
        
        if(widget.isValid()) {
            General.callRestEngine("opl_solicitacao#/alteraMarcaItemPedidoOL", "Row", rowsSelecionadas).then(function(response) {
                ScreenService.closePopup();
                ScreenService.closePopup();
                    
                widgetItensPedido.reload();
                    
                MessageService.showMessageByCode("CDMARCA_EDIT_SUCCESS");
            }).catch(function(error) {
                if(error.data.error == "CDMARCA_ALREADY_EXISTS_PEDIDO" || error.data.error == "ERRO_QUERY") {
                    MessageService.showMessageByCode(error.data.error);
                } else {
                    MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
                }
                ScreenService.closePopup();
                ScreenService.closePopup();
                
                widgetItensPedido.reload();
            });
        } else {
            MessageService.showMessageByCode("OBRIGATORY_FIELDS");
        }
    };
    
    this.openWidgetAlteracaoProdutoItemPedido = function(widget) {
        const popUpWidget = templateManager.container.getWidget("alteracaoProdutoItemPedidoWidget");
        const rowsSelecionadas = widget.getCheckedRows();
        const rowBase = rowsSelecionadas[0];
        const rowsEmAberto = rowsSelecionadas.filter(function(row) {
            return ((row.IDBAIXENPEOL == null || row.IDBAIXENPEOL == 0) && (row.IDBAIXEXOL == null || row.IDBAIXEXOL == 0));
        });
        var permiteOperacao = true;
        var rowsBloqueadas = [];
        
        rowsSelecionadas.forEach(row => {
           if(!verificaPermissaoItem(widget, row)) {
               rowsBloqueadas.push(row);
           }
        });
        
        for(let i = 0; i < rowsSelecionadas.length; i++) {
            if(rowsSelecionadas[i].CDARVPROD !== rowBase.CDARVPROD) {
                permiteOperacao = false;
                break;
            }
        }
        
        var mascaraProduto = getLocalVar('CDPICTPROD');
        var fieldProduto = popUpWidget.getField('NMPRODUTO');
        
        mascaraProduto = mascaraProduto.split('.');
        
        var nivelProduto = mascaraProduto.length;
        
        /*fieldProduto.dataSourceFilter.forEach(function(filtro) {
            if(filtro.name == 'CDNVPRODUTO')
                filtro.value = nivelProduto;
        });*/
        
        fieldProduto.dataSourceFilter.forEach(function(row) {
            if(row.name == "P_CDFILIOPELOG") {
                row.value = CDFILIOPELOGPROD;
            }
        });
        
        popUpWidget.currentRow = {};
        
        popUpWidget.currentRow.AJUSTE_UNIDADE = '0';
		popUpWidget.currentRow.AJUSTE_QUANTIDADE = '0';
        
        if(rowsEmAberto.length == rowsSelecionadas.length && permiteOperacao) {
            if(rowsBloqueadas.length >= 1) {
                var rowsToMessage = [];
                var stringItem = "";
                
                rowsBloqueadas.forEach(row => {
					var prod = "Pedido: " + row.NRPEDEXOL + ", Produto: " + row.NMPRODUTO + ", Marca: " + row.NMMARCA + ", Entrega: " + row.DTPROGENPEOL;
										
					rowsToMessage.push(prod);
			    });
			    
			    stringItem = rowsToMessage.join("<br><br>");
			    
			    MessageService.showMessageByCode("OPER_BLOCK_ITEM_GRUPOOPER", { ITEM: stringItem });
            } else {
                ScreenService.openPopup(popUpWidget);
            }
        } else if(!permiteOperacao) {
            MessageService.showMessageByCode("OPR_BLOCK_DIFF_PRODUCTS");
        } else {
            MessageService.showMessageByCode("ONLY_EM_ABERTO_ITENS_PEDIDO_EDIT");
        }
    };
    
    this.onChangeAjuste = function(field) {
        var value = angular.copy(field.value()),
        	minValue = '-99.99';
        
        if(typeof(value) == 'string') {
            value = value.split('.').join('');
            value = value.replace(',', '.');
        }
        
        if(value && parseFloat(value) < parseFloat(minValue)) {
            field.setValue('0');
            MessageService.showMessageByCode("VLR_MENOR_MENOS_99");
        }
        
        if (Util.isEmptyOrBlank(field.value())) {
    		field.setValue('0');
    	}
    };
    
    this.salvaAlteracaoProdutoItemPedido = function(widget) {
        const widgetItensPedido = widget.getParent();
        const rowsSelecionadas = widgetItensPedido.getCheckedRows();
        
        rowsSelecionadas.forEach(row => {
           row.NEW_CDPRODUTO = widget.currentRow.CDPRODUTO;
           row.NEW_CDPRODESTO = widget.currentRow.CDPRODESTO;
           row.NEW_CDARVPROD = widget.currentRow.CDARVPROD;
           row.NEW_VRFATOCONV = widget.currentRow.VRFATOCONV;
           row.OLD_CDPRODUTO = row.CDPRODUTO;
           row.OLD_CDPRODESTO = row.CDPRODESTO;
           row.OLD_CDARVPROD = row.CDARVPROD;
           row.OLD_VRFATOCONV = row.VRFATOCONV;
           row.AJUSTE_UNIDADE = widget.currentRow.AJUSTE_UNIDADE;
           row.AJUSTE_QUANTIDADE = widget.currentRow.AJUSTE_QUANTIDADE;
           row.CDFILDEST = row.CDFILDEST.substr(0, 4);
           row.DTPROGENPEOL = moment(row.DTPROGENPEOL, "DD/MM/YYYY").format("DD/MM/YYYY");
           row.CONSIDERASOL = widget.currentRow.CONSIDERASOL;
        });
        
        if(widget.isValid()) {
            General.callRestEngine("opl_solicitacao#/alteraProdutoItemPedidoOL", "Row", rowsSelecionadas).then(function(response) {
                ScreenService.closePopup();
                ScreenService.closePopup();
                    
                widgetItensPedido.reload();
                
                if(response.messages.length > 0) {
                    response.messages.forEach(m => {
                        if(m.message == "ALL_ROWS_UPDATED") {
                            MessageService.showMessageByCode("CDPRODUTO_EDIT_SUCCESS");
                        }
                        if(m.message == "SOME_ROWS_UPDATED") {
                            MessageService.showMessageByCode("CDPRODUTO_SOME_EDIT_SUCCESS");
                        }
                        if(m.message == "NO_ROWS_UPDATED") {
                            MessageService.showMessageByCode("CDPRODUTO_NONE_EDIT_SUCCESS");
                        }
                    });
                }
            }).catch(function(error) {
                if(error.data.error == "CDPRODUTO_ALREADY_EXISTS_PEDIDO" || error.data.error == "ERRO_QUERY") {
                    MessageService.showMessageByCode(error.data.error);
                } else {
                    MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
                }
                ScreenService.closePopup();
                ScreenService.closePopup();
                
                widgetItensPedido.reload();
            });
        } else {
            MessageService.showMessageByCode("OBRIGATORY_FIELDS");
        }
    };
    
    this.openWidgetAlteracaoQuantidadeItemPedido = function(widget) {
        const popUpWidget = templateManager.container.getWidget("alteracaoQuantidadeItemPedidoWidget");
        const rowsSelecionadas = widget.getCheckedRows();
        const rowsEmAbertoParcial = rowsSelecionadas.filter(function(row) {
            return ((row.IDBAIXENPEOL == null || row.IDBAIXENPEOL == 0 || row.IDBAIXENPEOL == 1) && (row.IDBAIXEXOL == null || row.IDBAIXEXOL == 0 || row.IDBAIXEXOL == 1));
        });
        var rowsBloqueadas = [];
        
        rowsSelecionadas.forEach(row => {
           if(!verificaPermissaoItem(widget, row)) {
               rowsBloqueadas.push(row);
           }
        });
        
        popUpWidget.currentRow = {};
        
        if(rowsEmAbertoParcial.length == rowsSelecionadas.length) {
            if(rowsBloqueadas.length >= 1) {
                var rowsToMessage = [];
                var stringItem = "";
                
                rowsBloqueadas.forEach(row => {
					var prod = "Pedido: " + row.NRPEDEXOL + ", Produto: " + row.NMPRODUTO + ", Marca: " + row.NMMARCA + ", Entrega: " + row.DTPROGENPEOL;
										
					rowsToMessage.push(prod);
			    });
			    
			    stringItem = rowsToMessage.join("<br><br>");
			    
			    MessageService.showMessageByCode("OPER_BLOCK_ITEM_GRUPOOPER", { ITEM: stringItem });
            } else {
                ScreenService.openPopup(popUpWidget);
            }
        } else {
            MessageService.showMessageByCode("ONLY_EMABERTO_PARCIAL_ITENS_PEDIDO_EDIT");
        }
    };
    
    this.salvaAlteracaoQuantidadeItemPedido = function(widget) {
        const widgetItensPedido = widget.getParent();
        const rowsSelecionadas = widgetItensPedido.getCheckedRows();
        
        rowsSelecionadas.forEach(row => {
           row.NEW_QTPROGENPEOL = widget.currentRow.QTPROGENPEOL;
           row.OLD_QTPROGENPEOL = row.QTPROGENPEOL;
           row.CDFILDEST = row.CDFILDEST.substr(0, 4);
           row.DTPROGENPEOL = moment(row.DTPROGENPEOL, "DD/MM/YYYY").format("DD/MM/YYYY");
        });
        
        if(widget.isValid()) {
            if(widget.currentRow.QTPROGENPEOL === "0,000" || widget.currentRow.QTPROGENPEOL === 0) {
                MessageService.confirmMessageByCode("CONFIRMA_EXCLUSAO_ITENS").then(function(confirmed) {
                    General.callRestEngine("opl_solicitacao#/excluiItemPedidoOL", "Row", rowsSelecionadas).then(function(response) {
                        ScreenService.closePopup();
                        ScreenService.closePopup();
                        
                        widgetItensPedido.reload();
                        
                        MessageService.showMessageByCode("EXCLUSAO_REALIZADA");
                    }).catch(function(error) {
                        ScreenService.closePopup();
                        ScreenService.closePopup();
                        
                        widgetItensPedido.reload();
                        
                        MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
                    });
                }).catch(function(error) {});
            } else {
                General.callRestEngine("opl_solicitacao#/alteraQuantidadeItemPedidoOL", "Row", rowsSelecionadas).then(function(response) {
                    ScreenService.closePopup();
                    ScreenService.closePopup();
                        
                    widgetItensPedido.reload();
                        
                    MessageService.showMessageByCode("QTPROGENPEOL_EDIT_SUCCESS");
                }).catch(function(error) {
                    ScreenService.closePopup();
                    ScreenService.closePopup();
                    
                    widgetItensPedido.reload();
                    
                    MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
                });
            }
        } else {
            MessageService.showMessageByCode("OBRIGATORY_FIELDS");
        }
    };
    
    this.incluirLote = function(widget) {
        const popUpWidget = templateManager.container.getWidget("inclusaoDeLoteItemPedidoWidget");
        const rowsSelecionadas = widget.getCheckedRows();
        const rowsEmAberto = rowsSelecionadas.filter(function(row) {
            return ((row.IDBAIXENPEOL == null || row.IDBAIXENPEOL == 0) && (row.IDBAIXEXOL == null || row.IDBAIXEXOL == 0));
        });
        var rowsBloqueadas = [];
        
        rowsSelecionadas.forEach(row => {
           if(!verificaPermissaoItem(widget, row)) {
               rowsBloqueadas.push(row);
           }
        });
        
        popUpWidget.currentRow = {};
        
        if(rowsEmAberto.length == rowsSelecionadas.length) {
            if(rowsBloqueadas.length >= 1) {
                var rowsToMessage = [];
                var stringItem = "";
                
                rowsBloqueadas.forEach(row => {
					var prod = "Pedido: " + row.NRPEDEXOL + ", Produto: " + row.NMPRODUTO + ", Marca: " + row.NMMARCA + ", Entrega: " + row.DTPROGENPEOL;
										
					rowsToMessage.push(prod);
			    });
			    
			    stringItem = rowsToMessage.join("<br><br>");
			    
			    MessageService.showMessageByCode("OPER_BLOCK_ITEM_GRUPOOPER", { ITEM: stringItem });
            } else {
                ScreenService.openPopup(popUpWidget);
            }
        } else {
            MessageService.showMessageByCode("ONLY_EM_ABERTO_ITENS_PEDIDO_EDIT");
        }
    };
    
    this.salvaInclusaoDeLoteItemPedido = function(widget) {
        const widgetItensPedido = widget.getParent();
        const rowsSelecionadas = widgetItensPedido.getCheckedRows();
        const rowPai = rowsSelecionadas[0];
        
        rowPai.CDFILDEST1 = rowPai.CDFILDEST.split(" - ")[0];
        
        var inclusaoDeLote = false;
        
        rowsSelecionadas.forEach(row => {
            row.CDFILDEST1 = row.CDFILDEST.split(" - ")[0];
            row.NEW_CDLOTENVITOL = widget.currentRow.CDLOTENVITOL;
            row.OLD_CDLOTENVITOL = row.CDLOTENVITOL;
            row.DTPROGENPEOL = moment(row.DTPROGENPEOL, "DD/MM/YYYY").format("DD/MM/YYYY");
            
            if(row.CDFILIOPELOG == rowPai.CDFILIOPELOG && row.CDFILLANC == rowPai.CDFILLANC && row.CDFILDEST1 == rowPai.CDFILDEST1 && row.NRPEDEXOL == rowPai.NRPEDEXOL) {
                
            } else {
                inclusaoDeLote = true;
            }
        });
        
        if(inclusaoDeLote) {
            if(widget.isValid()) {
                General.callRestEngine("opl_solicitacao#/incluiItemPedidoLoteDiversos", "Row", rowsSelecionadas).then(function(response) {
                   ScreenService.closePopup();
                   ScreenService.closePopup();
                   
                   widgetItensPedido.reload();
                   
                   MessageService.showMessageByCode("CDLOTENVITOL_NEW_SUCCESS");
                }).catch(function(error) {
                    ScreenService.closePopup();
                    ScreenService.closePopup();
                    
                    widgetItensPedido.reload();
                    
                    MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
                });
            } else {
                MessageService.showMessageByCode("OBRIGATORY_FIELDS");
            }
        } else {
           if(widget.isValid()) {
               General.callRestEngine("opl_solicitacao#/incluiItemPedidoLote", "Row", rowsSelecionadas).then(function(response) {
                   ScreenService.closePopup();
                   ScreenService.closePopup();
                   
                   widgetItensPedido.reload();
                   
                   MessageService.showMessageByCode("CDLOTENVITOL_NEW_SUCCESS");
                }).catch(function(error) {
                    ScreenService.closePopup();
                    ScreenService.closePopup();
                    
                    widgetItensPedido.reload();
                    
                    MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
                });
            } else {
                MessageService.showMessageByCode("OBRIGATORY_FIELDS");
            } 
        }
    };
    
    this.incluirReserva = function(widget) {
        const rowsSelecionadas = widget.getCheckedRows();
        const rowsEmAberto = rowsSelecionadas.filter(function(row) {
            return ((row.IDBAIXENPEOL == null || row.IDBAIXENPEOL == 0) && (row.IDBAIXEXOL == null || row.IDBAIXEXOL == 0));
        });
        var rowsBloqueadas = [];
        
        rowsSelecionadas.forEach(row => {
           if(!verificaPermissaoItem(widget, row)) {
               rowsBloqueadas.push(row);
           }
        });
        
        if(rowsEmAberto.length == rowsSelecionadas.length) {
            if(rowsBloqueadas.length >= 1) {
                var rowsToMessage = [];
                var stringItem = "";
                
                rowsBloqueadas.forEach(row => {
					var prod = "Pedido: " + row.NRPEDEXOL + ", Produto: " + row.NMPRODUTO + ", Marca: " + row.NMMARCA + ", Entrega: " + row.DTPROGENPEOL;
										
					rowsToMessage.push(prod);
			    });
			    
			    stringItem = rowsToMessage.join("<br><br>");
			    
			    MessageService.showMessageByCode("OPER_BLOCK_ITEM_GRUPOOPER", { ITEM: stringItem });
            } else {
                MessageService.confirmMessageByCode("RESERVA_QUESTION_INSERT").then(function(confirmed) {
                    General.callRestEngine("opl_solicitacao#/inclusaoReservaItemPedido", "Row", rowsSelecionadas).then(function(response) {
                        ScreenService.closePopup();
                        
                        widget.reload();
                        
                        MessageService.showMessageByCode("RESEVA_NEW_SUCCESS");
                    }).catch(function(error) {
                        ScreenService.closePopup();
                        
                        widget.reload();
                        
                        if(error.data.error == "QTD_INDISPONIVEL_RESERVA") {
                            MessageService.showMessageByCode(error.data.error);
                        } else {
                            MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
                        }
                    });
                });
            }
        } else {
            MessageService.showMessageByCode("ONLY_EM_ABERTO_ITENS_PEDIDO_EDIT");
        }
    };
    
    this.excluirReserva = function(widget) {
        const rowsSelecionadas = widget.getCheckedRows();
        const rowsEmAberto = rowsSelecionadas.filter(function(row) {
            return ((row.IDBAIXENPEOL == null || row.IDBAIXENPEOL == 0) && (row.IDBAIXEXOL == null || row.IDBAIXEXOL == 0));
        });
        var rowsBloqueadas = [];
        
        rowsSelecionadas.forEach(row => {
           if(!verificaPermissaoItem(widget, row)) {
               rowsBloqueadas.push(row);
           }
        });
        
        if(rowsEmAberto.length == rowsSelecionadas.length) {
            if(rowsBloqueadas.length >= 1) {
                var rowsToMessage = [];
                var stringItem = "";
                
                rowsBloqueadas.forEach(row => {
					var prod = "Pedido: " + row.NRPEDEXOL + ", Produto: " + row.NMPRODUTO + ", Marca: " + row.NMMARCA + ", Entrega: " + row.DTPROGENPEOL;
										
					rowsToMessage.push(prod);
			    });
			    
			    stringItem = rowsToMessage.join("<br><br>");
			    
			    MessageService.showMessageByCode("OPER_BLOCK_ITEM_GRUPOOPER", { ITEM: stringItem });
            } else {
                MessageService.confirmMessageByCode("RESERVA_QUESTION_DELETE").then(function(confirmed) {
                    General.callRestEngine("opl_solicitacao#/exclusaoReservaItemPedido", "Row", rowsSelecionadas).then(function(response) {
                        ScreenService.closePopup();
                        
                        widget.reload();
                        
                        MessageService.showMessageByCode("RESEVA_DELETE_SUCCESS");
                    }).catch(function(error) {
                        ScreenService.closePopup();
                        
                        widget.reload();
                        
                        MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
                    });
                });
            }
        } else {
            MessageService.showMessageByCode("ONLY_EM_ABERTO_ITENS_PEDIDO_EDIT");
        }
    };
    
    this.baixaManualItemPedido = function(widget) {
        const rowsSelecionadas = widget.getCheckedRows();
        const rowsEmAbertoParcial = rowsSelecionadas.filter(function(row) {
            return ((row.IDBAIXENPEOL == null || row.IDBAIXENPEOL == 0 || row.IDBAIXENPEOL == 1) && (row.IDBAIXEXOL == null || row.IDBAIXEXOL == 0 || row.IDBAIXEXOL == 1));
        });
        var rowsBloqueadas = [];
        
        rowsSelecionadas.forEach(row => {
           row.NEW_IDBAIXAOLSAI = '3';
           row.NEW_CDOPERBAIXA = getLocalVar("CDOPERADOR");
           row.NEW_DTBAIXTMPEOL = moment().format("DD/MM/YYYY");
           row.DTPROGENPEOL = moment(row.DTPROGENPEOL, "DD/MM/YYYY").format("DD/MM/YYYY");
           
           if(!verificaPermissaoItem(widget, row)) {
               rowsBloqueadas.push(row);
           }
        });
        
        if(rowsEmAbertoParcial.length == rowsSelecionadas.length) {
            if(rowsBloqueadas.length >= 1) {
                var rowsToMessage = [];
                var stringItem = "";
                
                rowsBloqueadas.forEach(row => {
					var prod = "Pedido: " + row.NRPEDEXOL + ", Produto: " + row.NMPRODUTO + ", Marca: " + row.NMMARCA + ", Entrega: " + row.DTPROGENPEOL;
										
					rowsToMessage.push(prod);
			    });
			    
			    stringItem = rowsToMessage.join("<br><br>");
			    
			    MessageService.showMessageByCode("OPER_BLOCK_ITEM_GRUPOOPER", { ITEM: stringItem });
            } else {
                MessageService.confirmMessageByCode("CONFIRMA_BAIXA_MANUAL").then(function(confirmed) {
                    General.callRestEngine("opl_solicitacao#/baixaManualItemPedidoOL", "Row", rowsSelecionadas).then(function(response) {
                        ScreenService.closePopup();
                        
                        widget.reload();
                        
                        MessageService.showMessageByCode("BAIXA_MANUAL_SUCCESS");
                    }).catch(function(error) {
                        ScreenService.closePopup();
                        
                        widget.reload();
                        
                        MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
                    });
                });
            }
        } else {
            MessageService.showMessageByCode("ONLY_EMABERTO_PARCIAL_ITENS_PEDIDO_EDIT");
        }
    };
    
    this.desbloquearItemPedido = function(widget) {
        const rowsSelecionadas = widget.getCheckedRows();
        const rowsEmAberto = rowsSelecionadas.filter(function(row) {
            return ((row.IDBAIXENPEOL == null || row.IDBAIXENPEOL == 0) && (row.IDBAIXEXOL == null || row.IDBAIXEXOL == 0));
        });
        const rowsDesbloqueadas = rowsSelecionadas.filter(function(row) {
            return (row.IDITMPEDOLBLOQ === 'N');
        });
        const rowsBloqueadas = rowsSelecionadas.filter(function(row) {
            return (row.IDITMPEDOLBLOQ === 'S' && ((row.IDBAIXENPEOL == null || row.IDBAIXENPEOL == 0) && (row.IDBAIXEXOL == null || row.IDBAIXEXOL == 0)));
        });
        var rowBlockOper = [];
        
        rowsBloqueadas.forEach(row => {
           row.NEW_CDOPERADOR = getLocalVar("CDOPERADOR");
           row.NEW_IDITMPEDOLBLOQ = 'N';
           row.NEW_DTBLOQITMPEDOL = moment().format("DD/MM/YYYY");
           row.DTPROGENPEOL = moment(row.DTPROGENPEOL, "DD/MM/YYYY").format("DD/MM/YYYY");
           
           if(!verificaPermissaoItem(widget, row)) {
               rowBlockOper.push(row);
           }
        });
        
        if(rowsDesbloqueadas.length == rowsSelecionadas.length) {
            MessageService.showMessageByCode("ITEM_ALREADY_DESBLOQUEADO");
        } else {
            if(rowsEmAberto.length == rowsSelecionadas.length) {
                if(rowBlockOper.length >= 1) {
                    var rowsToMessage = [];
                    var stringItem = "";
                    
                    rowBlockOper.forEach(row => {
    					var prod = "Pedido: " + row.NRPEDEXOL + ", Produto: " + row.NMPRODUTO + ", Marca: " + row.NMMARCA + ", Entrega: " + row.DTPROGENPEOL;
    										
    					rowsToMessage.push(prod);
    			    });
    			    
    			    stringItem = rowsToMessage.join("<br><br>");
    			    
    			    MessageService.showMessageByCode("OPER_BLOCK_ITEM_GRUPOOPER", { ITEM: stringItem });
                } else {
                    MessageService.confirmMessageByCode("CONFIRMA_DESBLOQUEIO_ITEM").then(function(confirmed) {
                        General.callRestEngine("opl_solicitacao#/desbloqueioBloqueioItemPedidoOL", "Row", rowsBloqueadas).then(function(response) {
                            widget.reload();
                            
                            MessageService.showMessageByCode("DESBLOQUEIO_SUCCESS");
                        }).catch(function(error) {
                            widget.reload();
                            
                            MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
                        });
                    });
                }
            } else {
                MessageService.showMessageByCode("ONLY_EM_ABERTO_ITENS_PEDIDO_EDIT");
            }
        }
    };
    
    this.bloquearItemPedido = function(widget) {
        const rowsSelecionadas = widget.getCheckedRows();
        const rowsEmAberto = rowsSelecionadas.filter(function(row) {
            return ((row.IDBAIXENPEOL == null || row.IDBAIXENPEOL == 0) && (row.IDBAIXEXOL == null || row.IDBAIXEXOL == 0));
        });
        const rowsDesbloqueadas = rowsSelecionadas.filter(function(row) {
            return (row.IDITMPEDOLBLOQ === 'N' && ((row.IDBAIXENPEOL == null || row.IDBAIXENPEOL == 0) && (row.IDBAIXEXOL == null || row.IDBAIXEXOL == 0)));
        });
        const rowsBloqueadas = rowsSelecionadas.filter(function(row) {
            return (row.IDITMPEDOLBLOQ === 'S');
        });
        var rowBlockOper = [];
        
        rowsDesbloqueadas.forEach(row => {
           row.NEW_CDOPERADOR = getLocalVar("CDOPERADOR");
           row.NEW_IDITMPEDOLBLOQ = 'S';
           row.NEW_DTBLOQITMPEDOL = moment().format("DD/MM/YYYY");
           row.DTPROGENPEOL = moment(row.DTPROGENPEOL, "DD/MM/YYYY").format("DD/MM/YYYY");
           
           if(!verificaPermissaoItem(widget, row)) {
               rowBlockOper.push(row);
           }
        });
        
        if(rowsBloqueadas.length == rowsSelecionadas.length) {
            MessageService.showMessageByCode("ITEM_ALREADY_BLOQUEADO");
        } else {
            if(rowsEmAberto.length == rowsSelecionadas.length) {
                if(rowBlockOper.length >= 1) {
                    var rowsToMessage = [];
                    var stringItem = "";
                    
                    rowBlockOper.forEach(row => {
                        var prod = "Pedido: " + row.NRPEDEXOL + ", Produto: " + row.NMPRODUTO + ", Marca: " + row.NMMARCA + ", Entrega: " + row.DTPROGENPEOL;
                        
                        rowsToMessage.push(prod);
    			    });
    			    
    			    stringItem = rowsToMessage.join("<br><br>");
    			    
    			    MessageService.showMessageByCode("OPER_BLOCK_ITEM_GRUPOOPER", { ITEM: stringItem });
                } else {
                    MessageService.confirmMessageByCode("CONFIRMA_BLOQUEIO_ITEM").then(function(confirmed) {
                        General.callRestEngine("opl_solicitacao#/desbloqueioBloqueioItemPedidoOL", "Row", rowsDesbloqueadas).then(function(response) {
                            widget.reload();
                            
                            MessageService.showMessageByCode("BLOQUEIO_SUCCESS");
                        }).catch(function(error) {
                            widget.reload();
                            
                            MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
                        });
                    });
                }
            } else {
                MessageService.showMessageByCode("ONLY_EM_ABERTO_ITENS_PEDIDO_EDIT");
            }
        }
    };
    
    this.entregaDiretaItemPedido = function(widget) {
        const popUpWidget = templateManager.container.getWidget("entregaDiretaItemPedidoWidget");
        const rowsSelecionadas = widget.getCheckedRows();
        const rowsEmAberto = rowsSelecionadas.filter(function(row) {
            return ((row.IDBAIXENPEOL == null || row.IDBAIXENPEOL == 0) && (row.IDBAIXEXOL == null || row.IDBAIXEXOL == 0));
        });
        var rowsBloqueadas = [];
        
        rowsSelecionadas.forEach(row => {
           if(!verificaPermissaoItem(widget, row)) {
               rowsBloqueadas.push(row);
           }
        });
        
        popUpWidget.currentRow = {};
        
        if(rowsEmAberto.length == rowsSelecionadas.length) {
            if(rowsBloqueadas.length >= 1) {
                var rowsToMessage = [];
                var stringItem = "";
                
                rowsBloqueadas.forEach(row => {
					var prod = "Pedido: " + row.NRPEDEXOL + ", Produto: " + row.NMPRODUTO + ", Marca: " + row.NMMARCA + ", Entrega: " + row.DTPROGENPEOL;
										
					rowsToMessage.push(prod);
                });
                
                stringItem = rowsToMessage.join("<br><br>");
                
                MessageService.showMessageByCode("OPER_BLOCK_ITEM_GRUPOOPER", { ITEM: stringItem });
            } else {
                ScreenService.openPopup(popUpWidget);
            }
        } else {
            MessageService.showMessageByCode("ONLY_EM_ABERTO_ITENS_PEDIDO_EDIT");
        }
    };
    
    this.validaFieldOperador = function(widget) {
        widget.getField("SENHA").clearValue();
        widget.currentRow.SENHA = "";
        
        if(widget.currentRow.CDOPERADOR == getLocalVar("CDOPERADOR")) {
            delete  widget.getField("SENHA").validations;
            widget.getField("SENHA").readOnly = true;
        } else {
            widget.getField("SENHA").validations = {
                "required": true
            };
            widget.getField("SENHA").readOnly = false;
        }
        widget.activate();
    };
    
    this.validacoesLoginED = function(widget) {
        const widgetItensPedido = widget.getParent();
        const rowsSelecionadas = widgetItensPedido.getCheckedRows();
        
        rowsSelecionadas.forEach(row => {
            row.DTPROGENPEOL = moment(row.DTPROGENPEOL, "DD/MM/YYYY").format("DD/MM/YYYY");
            row.CDOPERADOR = widget.currentRow.CDOPERADOR;
        });
        
        if(widget.isValid()) {
            if(widget.currentRow.CDOPERADOR == getLocalVar("CDOPERADOR")) {
                General.callRestEngine("opl_solicitacao#/processoEntregaDiretaItemPedidoOL", "Row", rowsSelecionadas).then(function(response) {
                    ScreenService.closePopup();
                    ScreenService.closePopup();
                        
                    widgetItensPedido.reload();
                        
                    MessageService.showMessageByCode("ENTREGA_DIRETA_ITEM_SUCCESS");
                }).catch(function(error) {
                    MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
                });
            } else {
                General.callRestEngine("opl_solicitacao#/validacaoSenhaED", "Row", widget.currentRow).then(function(response) {
                    General.callRestEngine("opl_solicitacao#/processoEntregaDiretaItemPedidoOL", "Row", rowsSelecionadas).then(function(response) {
                        ScreenService.closePopup();
                        ScreenService.closePopup();
                            
                        widgetItensPedido.reload();
                            
                        MessageService.showMessageByCode("ENTREGA_DIRETA_ITEM_SUCCESS");
                    }).catch(function(error) {
                        MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
                    }); 
                }).catch(function(error) {
                    if(error.data.error == "INVALID_PASSWORD") {
                        MessageService.showMessageByCode(error.data.error);
                    } else {
                        MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
                    }
                });
            }
        } else {
            MessageService.showMessageByCode("OBRIGATORY_FIELDS");
        }
    };
    
    this.destinatarioNF = function(widget) {
        if(widget.currentRow.IDTIPOEMITAF == '1') {
            widget.getField("NMEMPRESA").validations = { required: true };
            
            ServiceLancamentoPedidoOL.empresasPorUnidade(widget.currentRow).then(function(callback) {
                widget.currentRow.CDEMPRESA = callback.dataset.sup07200_empresas_por_unidade[0].CDEMPRESA;
				widget.currentRow.NMEMPRESA = callback.dataset.sup07200_empresas_por_unidade[0].NMEMPRESA;
				
				widget.getField("NMEMPRESA").readOnly = true;
            }).catch(function(error) {
                MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
            });
        } else if(widget.currentRow.IDTIPOEMITAF == '2') {
            widget.getField("NMEMPRESA").validations = { required: true };
			widget.getField("NMEMPRESA").dataSourceFilter[0].value = widget.currentRow.CDFILDEST;
			widget.getField("NMEMPRESA").readOnly = false;
			widget.getField("NMEMPRESA").reload();
			
			widget.currentRow.NMEMPRESA = '';
			widget.currentRow.CDEMPRESA = '';
        } else if(widget.currentRow.IDTIPOEMITAF == '3') {
            ServiceLancamentoPedidoOL.empresaClientePrincipal(widget.currentRow).then(function(callback) {
                if (callback.dataset.sup07200_empresa_cliente_principal.length) {
                    widget.currentRow.NMEMPRESA = callback.dataset.sup07200_empresa_cliente_principal[0].NMEMPRESA;
    			    widget.currentRow.CDEMPRESA = callback.dataset.sup07200_empresa_cliente_principal[0].CDEMPRESA;
                } else {
                    widget.currentRow.NMEMPRESA = '';
    			    widget.currentRow.CDEMPRESA = '';    
                }
                
                if (callback.dataset.sup07200_empresa_cliente_principal.length === 0) {
                    MessageService.showMessageByCode("SEM_CLIENTE_PRINCIPAL_FILIAL");
                    widget.currentRow.IDTIPOEMITAF = '2';
                    widget.currentRow.NMTIPOEMITAF = "Empresa Informada";
                    
                    widget.getField("NMEMPRESA").readOnly = false;
                    widget.getField("NMEMPRESA").validations = { required: true };
                    return false;
                } else {
                    widget.getField("NMEMPRESA").readOnly = true;
                    widget.getField("NMEMPRESA").validations = {};
                }
            }).catch(function(error) {
                MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
            });
        } else {
            widget.getField("NMEMPRESA").readOnly = true;
            widget.getField("NMEMPRESA").validations = {};
            
            widget.currentRow.NMEMPRESA = '';
			widget.currentRow.CDEMPRESA = '';
        }
    };
    
    this.editaDadosPedido = function(widget) {
        const oldRow = angular.copy(widget.currentRow);
        const itensPedidosWidget = templateManager.container.getWidget("itensPedidosWidget");
        const detalhesPedido = templateManager.container.getWidget("detalhesPedido");
        
        widget.oldRow = oldRow;
        widget.template = "widget/form.html";
        widget.edit();
        
        itensPedidosWidget.enabled = false;
        detalhesPedido.enabled = false;
    };
    
    this.cancelaEditaDadosPedido = function(args) {
        const activeWidget = templateManager.container.getActiveWidget();
        const itensPedidosWidget = templateManager.container.getWidget("itensPedidosWidget");
        const detalhesPedido = templateManager.container.getWidget("detalhesPedido");
        
        activeWidget.template = "widget/form-view.html";
        activeWidget.reload();
        
        General.backOrCancel(args);
        
        activeWidget.list();
        activeWidget.reload();
        
        activeWidget.currentRow = activeWidget.oldRow;
        
        itensPedidosWidget.enabled = true;
        detalhesPedido.enabled = true;
    };
    
    this.salvaDadosPedido = function(widget) {
        const row = angular.copy(widget.currentRow);
        const itensPedidosWidget = templateManager.container.getWidget("itensPedidosWidget");
        const detalhesPedido = templateManager.container.getWidget("detalhesPedido");
        
        delete row.__rightActions;
        delete row.__leftActions;
        
        row.__isNew = false;
        
        row.DTPEDEXOL = moment(row.DTPEDEXOL, "DD/MM/YYYY").format("DD/MM/YYYY");
        
        if(widget.isValid()) {
            General.callRestEngine("opl_solicitacao#/salvaDadosPedido", "Row", row).then(function(response) {
                widget.template = "widget/form-view.html";
                widget.list();
                widget.reload();
                
                itensPedidosWidget.enabled = true;
                detalhesPedido.enabled = true;
                
                MessageService.showMessageByCode("PEDIDO_EDIT_SUCCESS");
            }).catch(function(error) {
                MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
            });
        }
    };
    
    this.adicionaNovoPedido = function(widget) {
        const widgetAdicionaNovoPedido = templateManager.container.getWidget("adicionaNovoPedido");
        const widgetTabbedNovoPedido = templateManager.container.getWidget("tabbedNovoPedidoWidget");
        const prodsNovoPedidoWidget = templateManager.container.getWidget("prodsNovoPedidoWidget");
        const itensPedidosWidget = templateManager.container.getWidget("itensPedidosWidget");
        const detalhesPedidoWidget = templateManager.container.getWidget("detalhesPedido");
        
        widgetAdicionaNovoPedido.currentRow = widget.name === "dadosPedido" ? angular.copy(widget.currentRow) : {};
        
        if(Util.isEmptyOrBlank(widgetAdicionaNovoPedido.currentRow.CDFILDEST)) {
            widgetAdicionaNovoPedido.currentRow.CDFILDEST = getLocalVar("CDFILIAL");
            widgetAdicionaNovoPedido.currentRow.NMFILDEST = getLocalVar("NMFILIAL");
        }
        
        if(Util.isEmptyOrBlank(widgetAdicionaNovoPedido.currentRow.IDTIPOEMITAF)) {
            if(!Util.isEmptyOrBlank(parametrosParCmpsup.IDTIPEMITGER)) {
                if(parametrosParCmpsup.IDTIPEMITGER == '1') {
                    widgetAdicionaNovoPedido.currentRow.IDTIPOEMITAF = '1';
                    widgetAdicionaNovoPedido.currentRow.NMTIPOEMITAF = "Empresa da Unidade";
                } else if(parametrosParCmpsup.IDTIPEMITGER == '2') {
                    widgetAdicionaNovoPedido.currentRow.IDTIPOEMITAF = '2';
                    widgetAdicionaNovoPedido.currentRow.NMTIPOEMITAF = "Empresa Informada";
                } else {
                    widgetAdicionaNovoPedido.currentRow.IDTIPOEMITAF = '3';
                    widgetAdicionaNovoPedido.currentRow.NMTIPOEMITAF = "Cliente Principal";
                }
            }
        }
        
        self.destinatarioNF(widgetAdicionaNovoPedido);
        
        prodsNovoPedidoWidget.enabled = false;
        
        prodsNovoPedidoWidget.dataSource.data = [];
        
        delete widgetAdicionaNovoPedido.currentRow.NRPEDEXOL;
        
        widgetAdicionaNovoPedido.currentRow.DTPEDEXOL = moment().format("L");
        widgetAdicionaNovoPedido.currentRow.CDFILLANC = getLocalVar("CDFILIAL");
        widgetAdicionaNovoPedido.currentRow.NMFILLANC = getLocalVar("NMFILIAL");
        widgetAdicionaNovoPedido.currentRow.IDPEDEXOLEXTR = 'N';
        
        if(parametrosParaSupri.IDUTILCONSSOLIOLEXT === 'S') {
            widgetAdicionaNovoPedido.getField("IDPEDEXOLEXTR").readOnly = false;
            widgetAdicionaNovoPedido.getField("NMLOTENVITOL").readOnly = false;
        } else {
            widgetAdicionaNovoPedido.getField("IDPEDEXOLEXTR").readOnly = true;
            widgetAdicionaNovoPedido.getField("NMLOTENVITOL").readOnly = true;
        }
        
        itensPedidosWidget.enabled = false;
        
        detalhesPedidoWidget.enabled = false;
        
        self.destinatarioNF(widgetAdicionaNovoPedido);
        
        ScreenService.openSwipe(widgetTabbedNovoPedido);
    };
    
    this.baixaManualPedido = function(widget) {
        const itensPedidosWidget = templateManager.container.getWidget("itensPedidosWidget");
        
        widget.currentRow.NEW_IDBAIXEXOL = 3;
        widget.currentRow.NEW_DTBAIXTMPEOL = moment().format('L');
        
        MessageService.confirmMessageByCode("BAIXA_MANUAL_PEDIDO_ASK").then(function(confirmed) {
            General.callRestEngine("opl_solicitacao#/baixaManualPedido", "Row", widget.currentRow).then(function(response) {
                delete widget.currentRow.NEW_IDBAIXEXOL;
                widget.currentRow.IDBAIXEXOL = 3;
                
                itensPedidosWidget.reload();
                
                widget.getAction("editaDadosPedido").isVisible = false;
                widget.getAction("baixaManualPedido").isVisible = false;
                widget.getAction("cancelarPedido").isVisible = false;
                widget.getAction("encerrarPedido").isVisible = false;
                widget.getAction("exportarPedido").isVisible = false;
                widget.getAction("excluiPedido").isVisible = false;
                widget.getAction("emAbertoPedido").isVisible = true;
                
                ScreenService.closePopup();
                
                MessageService.showMessageByCode("BAIXA_MANUAL_SUCCESS");
            }).catch(function(error) {
                MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
            });
        });
    };
    
    this.cancelarEncerrarPedido = function(widget, op) {
        const itensPedidosWidget = templateManager.container.getWidget("itensPedidosWidget");
        var message1, message2;
        
        widget.currentRow.NEW_IDBAIXEXOL = op;
        
        if(op == 5) {
            message1 = "CANCELA_PEDIDO_ASK";
            message2 = "CANCELA_PEDIDO_SUCCESS";
        } else {
            message1 = "ENCERRA_PEDIDO_ASK";
            message2 = "ENCERRA_PEDIDO_SUCCESS";
        }
        
        MessageService.confirmMessageByCode(message1).then(function(confirmed) {
            General.callRestEngine("opl_solicitacao#/cancelaEncerraPedido", "Row", widget.currentRow).then(function(response) {
                delete widget.currentRow.NEW_IDBAIXEXOL;
                widget.currentRow.IDBAIXEXOL = op;
                
                itensPedidosWidget.reload();
                
                widget.getAction("editaDadosPedido").isVisible = false;
                widget.getAction("baixaManualPedido").isVisible = false;
                widget.getAction("cancelarPedido").isVisible = false;
                widget.getAction("encerrarPedido").isVisible = false;
                widget.getAction("exportarPedido").isVisible = false;
                widget.getAction("excluiPedido").isVisible = false;
                widget.getAction("emAbertoPedido").isVisible = true;
                
                ScreenService.closePopup();
                
                MessageService.showMessageByCode(message2);
            }).catch(function(error) {
                MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
            });
        });
    };
    
    this.emAbertoPedido = function(widget) {
        const itensPedidosWidget = templateManager.container.getWidget("itensPedidosWidget");
        
        widget.currentRow.NEW_IDBAIXEXOL = 0;
        
        MessageService.confirmMessageByCode("EMABERTO_PEDIDO_ASK").then(function(confirmed) {
            General.callRestEngine("opl_solicitacao#/emAbertoPedido", "Row", widget.currentRow).then(function(response) {
                delete widget.currentRow.NEW_IDBAIXEXOL;
                widget.currentRow.IDBAIXEXOL = null;
                
                itensPedidosWidget.reload();
                
                widget.getAction("editaDadosPedido").isVisible = true;
                widget.getAction("baixaManualPedido").isVisible = true;
                widget.getAction("cancelarPedido").isVisible = true;
                widget.getAction("encerrarPedido").isVisible = true;
                widget.getAction("excluiPedido").isVisible = true;
                widget.getAction("emAbertoPedido").isVisible = false;
                
                if(parametrosParaSupri && parametrosParaSupri.IDENVIOITMPEDOL == 'S') {
                    widget.getAction("exportarPedido").isVisible = true;
                } else {
                    widget.getAction("exportarPedido").isVisible = false;
                }
                
                ScreenService.closePopup();
                
                MessageService.showMessageByCode("EMABERTO_SUCCESS");
            }).catch(function(error) {
                MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
            });
        });
    };
    
    this.excluiPedido = function(widget) {
        const itensPedidosWidget = templateManager.container.getWidget("itensPedidosWidget");
        const stripeWidget = templateManager.container.getWidget("stripeWidget");
        const detalhesPedidoWidget = templateManager.container.getWidget("detalhesPedido");
        
        MessageService.confirmMessageByCode("EXCLUIR_PEDIDO_ASK").then(function(confirmed) {
            General.callRestEngine("opl_solicitacao#/exclusaoPedido", "Row", widget.currentRow).then(function(response) {
                widget.currentRow = {};
                widget.enabled = false;
                
                itensPedidosWidget.currentRow = {};
                itensPedidosWidget.activate();
                itensPedidosWidget.reload();
                
                stripeWidget.currentRow = {};
                
                detalhesPedidoWidget.enabled = false;
                
                MessageService.showMessageByCode("EXCLUSAO_REALIZADA");
            }).catch(function(error) {
                MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
            });
        });
    };
    
    this.cancelarNovoPedido = function(widget) {
        const widgetDadosPedido = templateManager.container.getWidget("dadosPedido");
        const itensPedidosWidget = templateManager.container.getWidget("itensPedidosWidget");
        const detalhesPedidoWidget = templateManager.container.getWidget("detalhesPedido");
        
        MessageService.confirmMessageByCode("CANCEL_NOVO_PEDIDO").then(function(confirmed) {
            itensPedidosWidget.enabled = true;
        
            detalhesPedidoWidget.enabled = true;
            
            ScreenService.closeSwipe();
            ScreenService.closeSwipe();
            
            widgetDadosPedido.activate();
        });
    };
    
    this.abrirAbaProdutos = function(widget) {
        const prodsNovoPedidoWidget = templateManager.container.getWidget("prodsNovoPedidoWidget");
        
        prodsNovoPedidoWidget.enabled = true;
        
        widget.enabled = false;
        
        prodsNovoPedidoWidget.activate();
    };
    
    this.adicionaNovoProdutoPedido = function(widget) {
        const inclusaoProdutoNovoPedidoWidget = templateManager.container.getWidget("inclusaoProdutoNovoPedidoWidget");
        const adicionaNovoPedidoWidget = templateManager.container.getWidget("adicionaNovoPedido");
        
        //var mascaraProduto = getLocalVar('CDPICTPROD');
        var fieldProduto = inclusaoProdutoNovoPedidoWidget.getField('NMPRODUTO');
        
        //mascaraProduto = mascaraProduto.split('.');
        
        //var nivelProduto = mascaraProduto.length;
        
        fieldProduto.dataSourceFilter.forEach(function(filtro) {
            if(filtro.name == "P_PRODCMP")
                filtro.value = parametrosParaSupri.IDUTLPROCMP;
            if(filtro.name == "P_CDFILSOLI")
                filtro.value = "FILIAL_LOGADA";
            if(filtro.name == "CDFILIAL")
                filtro.value = adicionaNovoPedidoWidget.currentRow.CDFILDEST || null;
        });
        
        inclusaoProdutoNovoPedidoWidget.currentRow.DTPROGENPEOL = moment().format('L');
        
        ScreenService.openPopup(inclusaoProdutoNovoPedidoWidget);
    };
    
    this.salvaInclusaoProdutoNvoPedido = function(widget) {
        const dataProc = moment(getLocalVar("DTPROCESSA"), "DD/MM/YYYY").format("MM-DD-YYYY");
        const dataEscd = moment(widget.currentRow.DTPROGENPEOL, "DD/MM/YYYY").format("MM-DD-YYYY");
        const prodsNovoPedidoWidget = widget.getParent();
        const adicionaNovoPedidoWidget = templateManager.container.getWidget("adicionaNovoPedido");
        
        widget.currentRow.CDFILDEST = adicionaNovoPedidoWidget.currentRow.CDFILDEST;
        
        widget.currentRow.FINAL = permissoesFinaisOperador;
        widget.currentRow.GERAL = permissoesGeraisOperador;
        
        if(widget.isValid()) {
            if(moment(dataEscd).isSameOrAfter(dataProc)) {
                if(prodsNovoPedidoWidget.dataSource.data.length == 0) {
                    General.callRestEngine("opl_solicitacao#/adqProcedureCarregaPerifili", "Row", widget.currentRow).then(function(response) {
                        var message = response.messages[0].message != undefined ? response.messages[0].message : null;
                        
                        if(message == "successful") {
                            prodsNovoPedidoWidget.dataSource.data.push(angular.copy(widget.currentRow));
                    
                            widget.currentRow = {};
                            
                            ScreenService.closePopup();
                            
                            MessageService.showMessageByCode("PRODUCT_INSERT_LIST_SUCCESS");
                        }
                    }).catch(function(error) {
                        MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
                    });
                    
                } else {
                    var podeInserir = true;
                    
                    prodsNovoPedidoWidget.dataSource.data.forEach(row => {
                        if(row.DTPROGENPEOL == widget.currentRow.DTPROGENPEOL && row.CDMARCA == widget.currentRow.CDMARCA && row.CDPRODESTO == widget.currentRow.CDPRODESTO) {
                            podeInserir = false;
                        }
                    });
                    
                    if(podeInserir) {
                        General.callRestEngine("opl_solicitacao#/adqProcedureCarregaPerifili", "Row", widget.currentRow).then(function(response) {
                            var message = response.messages[0].message != undefined ? response.messages[0].message : null;
                        
                            if(message == "successful") {
                                prodsNovoPedidoWidget.dataSource.data.push(angular.copy(widget.currentRow));
                        
                                widget.currentRow = {};
                                
                                ScreenService.closePopup();
                                
                                MessageService.showMessageByCode("PRODUCT_INSERT_LIST_SUCCESS");
                            }
                        }).catch(function(error) {
                            MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
                        });
                    } else {
                        MessageService.showMessageByCode("ITEM_ALREADY_EXISTS_PEDIDO");
                    }
                }
            } else {
                MessageService.showMessageByCode("DATA_MAIOR_IGUAL_PROCESSAMENTO");
            }
        }
    };
    
    this.excluiNovoProdutoPedido = function(widget) {
        const checkedRows = widget.getCheckedRows();
        const allRows = widget.dataSource.data;
        const returnRows = allRows.filter(function(rowA) {
            return !checkedRows.find(function(rowB) {
                return rowA.DTPROGENPEOL == rowB.DTPROGENPEOL && rowA.CDMARCA == rowB.CDMARCA && rowA.CDPRODESTO == rowB.CDPRODESTO;
            });
        });
        
        MessageService.confirmMessageByCode("CONFIRM_PRODUCT_DELETE_LIST").then(function(confirmed) {
            widget.dataSource.data = returnRows;
        });
    };
    
    this.finalizaNovoPedido = function(widget) {
        const adicionaNovoPedidoWidget = templateManager.container.getWidget("adicionaNovoPedido");
        const widgetDadosPedido = templateManager.container.getWidget("dadosPedido");
        const itensPedidosWidget = templateManager.container.getWidget("itensPedidosWidget");
        const widgetStripe = templateManager.container.getWidget("stripeWidget");
        const widgetDetalhesPedido = templateManager.container.getWidget("detalhesPedido");
        
        const rowFinal = {
            "DADOS": angular.copy(adicionaNovoPedidoWidget.currentRow),
            "PRODUTOS": angular.copy(widget.dataSource.data),
            "PARAMETROS": {
                "GERAL": permissoesGeraisOperador,
                "FINAL": permissoesFinaisOperador
            }
        };
        
        if(widget.dataSource.data.length > 0) {
            if(adicionaNovoPedidoWidget.isValid()) {
                MessageService.confirmMessageByCode("CONFIRMA_NOVO_PEDIDO").then(function(confirmed) {
                    General.callRestEngine("opl_solicitacao#/inclusaoPedido", "Row", rowFinal).then(function(response) {
                        widgetDadosPedido.currentRow = adicionaNovoPedidoWidget.currentRow;
                        widgetDadosPedido.getAction("editaDadosPedido").isVisible = true;
                        widgetDadosPedido.getAction("baixaManualPedido").isVisible = true;
                        widgetDadosPedido.getAction("cancelarPedido").isVisible = true;
                        widgetDadosPedido.getAction("encerrarPedido").isVisible = true;
                        widgetDadosPedido.getAction("excluiPedido").isVisible = true;
                        widgetDadosPedido.getAction("emAbertoPedido").isVisible = false;
                        
                        if(parametrosParaSupri && parametrosParaSupri.IDENVIOITMPEDOL == 'S') {
                            widgetDadosPedido.getAction("exportarPedido").isVisible = true;
                        } else {
                            widgetDadosPedido.getAction("exportarPedido").isVisible = false;
                        }
                        
                        adicionaNovoPedidoWidget.currentRow = {};
                        
                        itensPedidosWidget.currentRow = {};
                        itensPedidosWidget.reload();
                        itensPedidosWidget.enabled = true;
                        
                        widgetStripe.currentRow = {};
                        
                        widget.dataSource.data = [];
                        
                        widgetDetalhesPedido.enabled = true;
                        
                        ScreenService.closeSwipe();
                        ScreenService.closeSwipe();
                        
                        MessageService.showMessageByCode("NEW_PEDIDO_SUCCESS");
                    }).catch(function(error) {
                        MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
                    });
                }).catch(function(declined) {
                    adicionaNovoPedidoWidget.activate();
                });
            } else {
                adicionaNovoPedidoWidget.activate();
                
                MessageService.showMessageByCode("OBRIGATORY_FIELDS");
            }
        } else {
            MessageService.showMessageByCode("ONE_PRODUCT_NEC_INSERT");
        }
    };
    
    this.exportarPedido = function(widget) {
        const widgetFatPrec = templateManager.container.getWidget("exportarPedidoOLWidget");
        
        widget.currentRow.IDENVIOITMPEDOL = parametrosParaSupri.IDENVIOITMPEDOL;
        
        MessageService.confirmMessageByCode("CONFIRM_EXPORT_PEDIDO").then(function(confirmed) {
            if(parametrosParaSupri && parametrosParaSupri.IDENVIOITMPEDOL == 'S') {
                ScreenService.openPopup(widgetFatPrec);
            } else {
                General.callRestEngine("opl_solicitacao#/exportarPedidoOL", "Row", widget.currentRow).then(function(response) {
                    ScreenService.closePopup();
                    
                    MessageService.showMessageByCode("PEDIDO_EXPORTADO_SUCESSO");
                }).catch(function(error) {
                    MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
                });
            }
        });
    };
    
    this.salvaExportaPedido = function(widget) {
        const widgetPedido = widget.getParent();
        
        var currentRow = angular.copy(widgetPedido.currentRow);
        
        currentRow.CDFATPRECO = widget.currentRow.CDFATPRECO;
        
        if(widget.isValid()) {
            General.callRestEngine("opl_solicitacao#/exportarPedidoOL", "Row", currentRow).then(function(response) {
                ScreenService.closePopup();
                    
                MessageService.showMessageByCode("PEDIDO_EXPORTADO_SUCESSO");
            }).catch(function(error) {
                MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
            });
        }
    };
    
    this.importacaoSolicitacaoOL = function(widget) {
        const importacaoSolicitacaoComprasOLWidget = templateManager.container.getWidget("importacaoSolicitacaoComprasOLWidget");
        
        importacaoSolicitacaoComprasOLWidget.currentRow = {};
        
        if(parametrosParaSupri.IDUTILCONSSOLIOLEXT === 'S') {
            importacaoSolicitacaoComprasOLWidget.getField("NMFATPRECO").isVisible = true;
            importacaoSolicitacaoComprasOLWidget.getField("EXTRA").isVisible = true;
            importacaoSolicitacaoComprasOLWidget.getField("NMLOTENVITOL").isVisible = true;
            importacaoSolicitacaoComprasOLWidget.getField("EXTRA").readOnly = false;
            importacaoSolicitacaoComprasOLWidget.getField("NMLOTENVITOL").readOnly = false;
        } else {
            importacaoSolicitacaoComprasOLWidget.getField("NMFATPRECO").isVisible = false;
            importacaoSolicitacaoComprasOLWidget.getField("EXTRA").isVisible = false;
            importacaoSolicitacaoComprasOLWidget.getField("NMLOTENVITOL").isVisible = false;
            importacaoSolicitacaoComprasOLWidget.getField("EXTRA").readOnly = true;
            importacaoSolicitacaoComprasOLWidget.getField("NMLOTENVITOL").readOnly = true;
        }
        
        if(parametrosParaSupri.IDENVIOITMPEDOL == 'S') {
            importacaoSolicitacaoComprasOLWidget.getField("NMFATPRECO").isVisible = true;
        } else {
            importacaoSolicitacaoComprasOLWidget.getField("NMFATPRECO").isVisible = false;
        }
        
        ScreenService.openPopup(importacaoSolicitacaoComprasOLWidget);
    };
    
    this.readOnlyImportSolFields = function(widget) {
        const fieldNaoConsid = widget.getField("NCONSIDERASUBGRUPO");
        const fieldSubgrupo = widget.getField("CDSUBGRPROD");
        const fieldProdIni = widget.getField("NMPRODINI");
        const fieldProdFin = widget.getField("NMPRODFIN");
        
        fieldNaoConsid.readOnly = widget.currentRow.TODOSPRODUTOS == 'S' ? true : false;
        
        fieldSubgrupo.readOnly = widget.currentRow.TODOSPRODUTOS == 'S' ? true : widget.currentRow.NCONSIDERASUBGRUPO == 'S' ? true : false;
        
        fieldProdIni.readOnly = widget.currentRow.TODOSPRODUTOS == 'S' ? true : false;
        
        fieldProdFin.readOnly = widget.currentRow.TODOSPRODUTOS == 'S' ? true : false;
        
        if(widget.currentRow.TODOSPRODUTOS == 'S') {
            widget.currentRow.CDSUBGRPROD = null;
            widget.currentRow.NCONSIDERASUBGRUPO = 'S';
            widget.currentRow.NMPRODINI = null;
            widget.currentRow.CDPRODINI = null;
            widget.currentRow.NMPRODFIN = null;
            widget.currentRow.CDPRODFIN = null;
            
            delete fieldProdIni.validations;
            delete fieldProdFin.validations;
        } else {
            fieldProdIni.validations = {
                "required": true
            };
            fieldProdFin.validations = {
                "required": true
            };
        }
        
        widget.activate();
    };
    
    this.confirmaImportSolOL = function(widget) {
        const itensPedidosWidget = templateManager.container.getWidget("itensPedidosWidget");
        const widgetDetalhesPedido = templateManager.container.getWidget("detalhesPedido");
        
        widget.currentRow.CDFILLANC = getLocalVar("CDFILIAL");
        widget.currentRow.CDPRODINI = widget.currentRow.CDPRODINI ? widget.currentRow.CDPRODINI : null;
        widget.currentRow.CDPRODFIN = widget.currentRow.CDPRODFIN ? (widget.currentRow.CDPRODFIN + "ZZZZZZZZZZZZZZZZZZZZ").substr(0, 20) : null;
        widget.currentRow.CDREGIAOBKP = (!widget.currentRow.CDREGIAO || widget.currentRow.CDREGIAO.length == 0) ? null : '_' + widget.currentRow.CDREGIAO.join('_') + '_';
        widget.currentRow.CDSUBGRPRODBKP = (!widget.currentRow.CDSUBGRPROD || widget.currentRow.CDSUBGRPROD.length == 0) ? null : '_' + widget.currentRow.CDSUBGRPROD.join('_') + '_';
        widget.currentRow.CDGRUPPRODBKP = (!widget.currentRow.CDGRUPPROD || widget.currentRow.CDGRUPPROD.length == 0) ? null : widget.currentRow.CDGRUPPROD[0];
        widget.currentRow.CDGRUPFILIBKP = (!widget.currentRow.CDGRUPFILI || widget.currentRow.CDGRUPFILI.length == 0) ? null : '_' + widget.currentRow.CDGRUPFILI.join('_') + '_';
        
        if(widget.isValid()) {
            MessageService.confirmMessageByCode("CONFIRM_IMPORT_SOL_OL").then(function(confirmed) {
                General.callRestEngine("opl_solicitacao#/adqValidacoes", "Row", widget.currentRow).then(function(response) {
                    const produtos = response.dataset.adqValidacoes;
                    const inconsistWidget = templateManager.container.getWidget("inconsistenciaProdutosImportWidget");
                    
                    if(!Util.isEmptyOrBlank(produtos) && produtos.length >= 1) {
                        MessageService.confirmMessageByCode("INCONS_PROCESSO_IMPORTACAO").then(function(confirmed) {
                            inconsistWidget.dataSource.data = produtos;
                            
                            ScreenService.openPopup(inconsistWidget);
                            
                            inconsistWidget.reload();
                            inconsistWidget.activate();
                        }).catch(function(declined) {
                            General.callRestEngine("opl_solicitacao#/importacaoSolicitacaoOL", "Row", widget.currentRow).then(function(response) {
                                ScreenService.closePopup();
                                
                                itensPedidosWidget.reload();
                                
                                widgetDetalhesPedido.reload();
                                
                                MessageService.showMessageByCode("IMPORT_SUCCESS");
                            }).catch(function(error) {
                                if(error.data.error == "ERROR_APUR" || error.data.error == "APUR_NOT_RESULTS") {
                                    MessageService.showMessageByCode(error.data.error);
                                } else {
                                    MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
                                }
                            });
                        });
                    } else {
                       General.callRestEngine("opl_solicitacao#/importacaoSolicitacaoOL", "Row", widget.currentRow).then(function(response) {
                            ScreenService.closePopup();
                            
                            itensPedidosWidget.reload();
                            
                            widgetDetalhesPedido.reload();
                            
                            MessageService.showMessageByCode("IMPORT_SUCCESS");
                        }).catch(function(error) {
                            if(error.data.error == "ERROR_APUR" || error.data.error == "APUR_NOT_RESULTS") {
                                MessageService.showMessageByCode(error.data.error);
                            } else {
                                MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
                            }
                        });
                    }
                }).catch(function(error) {
                    MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
                });
            });
        } else {
            MessageService.showMessageByCode("OBRIGATORY_FIELDS");
        }
    };
    
    this.finalizaImportSolIncons = function(widgetIncons) {
        const itensPedidosWidget = templateManager.container.getWidget("itensPedidosWidget");
        const widgetDetalhesPedido = templateManager.container.getWidget("detalhesPedido");
        const widget = widgetIncons.getParent();
        
        General.callRestEngine("opl_solicitacao#/importacaoSolicitacaoOL", "Row", widget.currentRow).then(function(response) {
            ScreenService.closePopup();
            ScreenService.closePopup();
                                
            itensPedidosWidget.reload();
                                
            widgetDetalhesPedido.reload();
                                
            MessageService.showMessageByCode("IMPORT_SUCCESS");
        }).catch(function(error) {
            if(error.data.error == "ERROR_APUR" || error.data.error == "APUR_NOT_RESULTS") {
                MessageService.showMessageByCode(error.data.error);
            } else {
                MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
            }
        });
    };
    
    this.emissaoPedidosOL = function(widget) {
        const emissaoPedidosOLWidget = templateManager.container.getWidget("emissaoPedidosOLWidget");
        const widgetItensPedido = templateManager.container.getWidget("itensPedidosWidget");
        
        console.log(widgetItensPedido);
        
        emissaoPedidosOLWidget.currentRow = {};
        emissaoPedidosOLWidget.currentRow.TCDLOTENVITOL = 'N';
        emissaoPedidosOLWidget.currentRow.IDBAIXAAFSAI = [ '0', '1', '2', '3' ];
        emissaoPedidosOLWidget.currentRow.IDBAIXAAFENT = [ '0', '1', '2', '3', '4', '5' ];
        emissaoPedidosOLWidget.currentRow.PEDOLEXTR = [ 'S', 'N' ];
        emissaoPedidosOLWidget.currentRow.CDFILIOPELOG = widgetItensPedido.appliedFilter.FILTER_ROW.NMFILIALOL;
        emissaoPedidosOLWidget.currentRow.CDFILDEST = widgetItensPedido.appliedFilter.FILTER_ROW.NMFILIAL;
        emissaoPedidosOLWidget.currentRow.NCONSIDERASUBGRUPO = widgetItensPedido.appliedFilter.FILTER_ROW.NCONSIDERASUBGRUPO;
        if(emissaoPedidosOLWidget.currentRow.NCONSIDERASUBGRUPO == 'N') {
            emissaoPedidosOLWidget.currentRow.CDGRUPPROD = widgetItensPedido.appliedFilter.FILTER_ROW.CDGRUPPROD;
            emissaoPedidosOLWidget.currentRow.CDSUBGRPROD = widgetItensPedido.appliedFilter.FILTER_ROW.CDSUBGRPROD;
            emissaoPedidosOLWidget.currentRow.NMSUBGRPROD = widgetItensPedido.appliedFilter.FILTER_ROW.NMSUBGRPROD;
            
            emissaoPedidosOLWidget.getField("CDSUBGRPROD").readOnly = false;
        } else {
            emissaoPedidosOLWidget.getField("CDSUBGRPROD").readOnly = true;
        }
        emissaoPedidosOLWidget.currentRow.CDROTATRANS = widgetItensPedido.appliedFilter.FILTER_ROW.CDROTATRANS;
        emissaoPedidosOLWidget.currentRow.DTPROGENPEOL = widgetItensPedido.appliedFilter.FILTER_ROW.DTPROGENPEOL;
        emissaoPedidosOLWidget.currentRow.DTPROGEMBARQ = widgetItensPedido.appliedFilter.FILTER_ROW.DTPROGEMBARQ;
        emissaoPedidosOLWidget.currentRow.NMPRODINI = widgetItensPedido.appliedFilter.FILTER_ROW.NMPRODINI;
        emissaoPedidosOLWidget.currentRow.NMPRODFIN = widgetItensPedido.appliedFilter.FILTER_ROW.NMPRODFIN;
        emissaoPedidosOLWidget.currentRow.PEDOLEXTR = widgetItensPedido.appliedFilter.FILTER_ROW.PEDOLEXTR;
        emissaoPedidosOLWidget.currentRow.TCDLOTENVITOL = widgetItensPedido.appliedFilter.FILTER_ROW.TCDLOTENVITOL;
        if(emissaoPedidosOLWidget.currentRow.TCDLOTENVITOL == 'L') {
            emissaoPedidosOLWidget.currentRow.CDLOTE = widgetItensPedido.appliedFilter.FILTER_ROW.CDLOTE;
            emissaoPedidosOLWidget.currentRow.CDLOTENVITOL = widgetItensPedido.appliedFilter.FILTER_ROW.CDLOTENVITOL;
            emissaoPedidosOLWidget.currentRow.NMLOTENVITOL = widgetItensPedido.appliedFilter.FILTER_ROW.NMLOTENVITOL;
            
            emissaoPedidosOLWidget.getField("CDLOTE").readOnly = false;
            emissaoPedidosOLWidget.getField("CDLOTE").validations = {
                "required": true
            };
        } else {
            emissaoPedidosOLWidget.getField("CDLOTE").readOnly = true;
            delete emissaoPedidosOLWidget.getField("CDLOTE").validations;
        }
        
        emissaoPedidosOLWidget.getField("CDFILIOPELOG").reload();
        emissaoPedidosOLWidget.getField("CDFILDEST").reload();
        emissaoPedidosOLWidget.getField("CDSUBGRPROD").reload();
        emissaoPedidosOLWidget.getField("CDROTATRANS").reload();
        emissaoPedidosOLWidget.getField("NMPRODINI").reload();
        emissaoPedidosOLWidget.getField("NMPRODFIN").reload();
        emissaoPedidosOLWidget.getField("CDLOTE").reload();
        
        ScreenService.openPopup(emissaoPedidosOLWidget);
    };
    
    this.changeFieldRota = function(widget) {
        const fieldRota = widget.getField("CDROTATRANS");
        
        if(widget.currentRow.NCONSIDERAROTA === 'N') {
            fieldRota.readOnly = false;
            fieldRota.reload();
            fieldRota.setValue(null);
        } else {
            fieldRota.readOnly = true;
            fieldRota.reload();
            fieldRota.setValue(null);
        }
        
        widget.activate();
    };
    
    function validaProdsIncons(produtos) {
        produtos.forEach(p => {
           p.DTPROGENPEOL = p.DTPROGENPEOL.substr(0, 10);
           p.DTPROGEMBARQ = p.DTPROGEMBARQ.substr(0, 10);
           
           p.DSINCONS = "";
           
           if(!Util.isEmptyOrBlank(p.RELACPRODOL) && p.RELACPRODOL == 'S') {
               p.DSINCONS = p.DSINCONS + "Produto sem relacionamento do OL cadastrado.\n";
           }
           if(!Util.isEmptyOrBlank(p.PRODATCMP) && p.PRODATCMP == 'S') {
               p.DSINCONS = p.DSINCONS + "Produto não está ativo para compra.\n";
           }
           if(!Util.isEmptyOrBlank(p.PRODCONV) && p.PRODCONV == 'S') {
               p.DSINCONS = p.DSINCONS + "Produto sem conversão para a Unidade de Estoque.\n";
           }
           if(!Util.isEmptyOrBlank(p.PRODNPESO) && p.PRODNPESO == 'S') {
               p.DSINCONS = p.DSINCONS + "Produto sem peso unitário cadastrado.\n";
           }
           if(!Util.isEmptyOrBlank(p.ESTOQUE) && p.ESTOQUE == 'S') {
               p.DSINCONS = p.DSINCONS + "Produto sem quantidade disponível em estoque.\n";
           }
           if(!Util.isEmptyOrBlank(p.PRODNCOT) && p.PRODNCOT == 'S') {
               p.DSINCONS = p.DSINCONS + "Produto sem custo.\n";
           }
           if(!Util.isEmptyOrBlank(p.PRCLASSFISC) && p.PRCLASSFISC == 'S') {
               p.DSINCONS = p.DSINCONS + "Produto sem classificação fiscal.\n";
           }
           if(!Util.isEmptyOrBlank(p.AGRUPAMENTO) && p.AGRUPAMENTO == 'S') {
               p.DSINCONS = p.DSINCONS + "Produto sem agrupamento de produtos.\n";
           }
           if(!Util.isEmptyOrBlank(p.RESERVA) && p.RESERVA == 'S') {
               p.DSINCONS = p.DSINCONS + "Produto sem reserva cadastrada.\n";
           }
           if(!Util.isEmptyOrBlank(p.RESERVA) && p.RESERVA == 'S') {
               p.DSINCONS = p.DSINCONS + "Produto sem reserva cadastrada.\n";
           }
           if(!Util.isEmptyOrBlank(p.PARAMFISCOL) && p.PARAMFISCOL == 'S') {
               p.DSINCONS = p.DSINCONS + "Produto sem parametrização fiscal do OL.\n";
           }
           if(!Util.isEmptyOrBlank(p.CRTLFISOL) && p.CRTLFISOL == 'S') {
               p.DSINCONS = p.DSINCONS + "Produto sem controle fiscal do OL.\n";
           }
           if(!Util.isEmptyOrBlank(p.PRODAGRUP) && p.PRODAGRUP == 'S') {
               p.DSINCONS = p.DSINCONS + "Produto sem agrupamento.\n";
           }
        });
        
        return produtos;
    }
    
    this.confirmaEmissaoPedidosOL = function(widget, opcao) {
        const row = angular.copy(widget.currentRow);
        const widgetEmail = templateManager.container.getWidget("enviaEmailEmissaoWidget");
        var reportRow = {};
        
        opEmissao = opcao;
        
        widgetEmail.getField("SENDOPERATOR").label = "Enviar Cópia para " + getLocalVar("NMOPERADOR");
        
        reportRow.P_CDCLIENTE = '';
        reportRow.P_TCDCLIENTE = 'T';
        reportRow.P_CDFILIOL = Util.isEmptyOrBlank(row.CDFILIOPELOG) ? '' : '_' + row.CDFILIOPELOG.join('_') + '_';
        reportRow.P_TCDFILIOL = Util.isEmptyOrBlank(row.CDFILIOPELOG) ? 'T' : '';
        reportRow.L_ROTA = Util.isEmptyOrBlank(row.CDROTATRANS) ? 'T' : '_' + row.CDROTATRANS.join('_') + '_';
        reportRow.L_ROTA1 = Util.isEmptyOrBlank(row.CDROTATRANS) ? 'T' : '_' + row.CDROTATRANS.join('_') + '_';
        reportRow.P_ROTA = Util.isEmptyOrBlank(row.CDROTATRANS) ? 'T' : '_' + row.CDROTATRANS.join('_') + '_';
        reportRow.P_CDFILIAL = Util.isEmptyOrBlank(row.CDFILDEST) ? '' : '_' + row.CDFILDEST.join('_') + '_';
        reportRow.P_TCDFILIAL = Util.isEmptyOrBlank(row.CDFILDEST) ? 'T' : '';
        reportRow.P_DTENTRINI = (Util.isEmptyOrBlank(row.DTPROGENPEOL.start) && Util.isEmptyOrBlank(row.DTPROGENPEOL.end)) ? '' : moment(row.DTPROGENPEOL.start, "DD/MM/YYYY").format('L');
        reportRow.P_DTENTRFIN = (Util.isEmptyOrBlank(row.DTPROGENPEOL.start) && Util.isEmptyOrBlank(row.DTPROGENPEOL.end)) ? '' : moment(row.DTPROGENPEOL.end, "DD/MM/YYYY").format('L');
        reportRow.P_TDTENTR = (Util.isEmptyOrBlank(row.DTPROGENPEOL.start) && Util.isEmptyOrBlank(row.DTPROGENPEOL.end)) ? 'T' : '';
        reportRow.P_DTEMBINI = (Util.isEmptyOrBlank(row.DTPROGEMBARQ.start) && Util.isEmptyOrBlank(row.DTPROGEMBARQ.end)) ? '' : moment(row.DTPROGEMBARQ.start, "DD/MM/YYYY").format('L');
        reportRow.P_DTEMBFIN = (Util.isEmptyOrBlank(row.DTPROGEMBARQ.start) && Util.isEmptyOrBlank(row.DTPROGEMBARQ.end)) ? '' : moment(row.DTPROGEMBARQ.end, "DD/MM/YYYY").format('L');
        reportRow.P_TDTEMB = (Util.isEmptyOrBlank(row.DTPROGEMBARQ.start) && Util.isEmptyOrBlank(row.DTPROGEMBARQ.end)) ? 'T' : '';
        reportRow.P_SUBGRUPO = row.NCONSIDERASUBGRUPO === 'S' ? 'N' : Util.isEmptyOrBlank(row.CDSUBGRPROD) ? 'T' : '_' + row.CDSUBGRPROD.join('_') + '_';
        reportRow.P_CDGRUPPROD = row.NCONSIDERASUBGRUPO === 'S' ? '' : parametrosParaSupri.CDGRUPPROD;
        reportRow.P_CDPRODINI = (Util.isEmptyOrBlank(row.CDPRODINI) && Util.isEmptyOrBlank(row.CDPRODFIN)) ? '' : row.CDPRODINI;
        reportRow.P_CDPRODFIN = (Util.isEmptyOrBlank(row.CDPRODINI) && Util.isEmptyOrBlank(row.CDPRODFIN)) ? "ZZZZZZZZZZZZZZZZZZZZ" : (row.CDPRODFIN + "ZZZZZZZZZZZZZZZZZZZZ").substr(0, 20);
        reportRow.P_CDPRODFINTEXT = (Util.isEmptyOrBlank(row.CDPRODINI) && Util.isEmptyOrBlank(row.CDPRODFIN)) ? '' : row.CDPRODFIN;
        reportRow.L_PRODUTO = (Util.isEmptyOrBlank(row.CDPRODINI) && Util.isEmptyOrBlank(row.CDPRODFIN)) ? 'T' : 'X';
        reportRow.P_PRODUTO = (Util.isEmptyOrBlank(row.CDPRODINI) && Util.isEmptyOrBlank(row.CDPRODFIN)) ? 'T' : 'X';
        reportRow.L_OPERADOR = parametrosGerais.IDRESTRFILIOPER === 'S' ? getLocalVar("CDOPERADOR") : 'T';
        reportRow.L_OPERADOR1 = parametrosGerais.IDRESTRFILIOPER === 'S' ? getLocalVar("CDOPERADOR") : 'T';
        reportRow.P_OPERADOR = parametrosGerais.IDRESTRFILIOPER === 'S' ? getLocalVar("CDOPERADOR") : 'T';
        reportRow.P_NMPRODINI = Util.isEmptyOrBlank(row.NMPRODINI) ? '' : row.NMPRODINI;
        reportRow.P_NMPRODFIN = Util.isEmptyOrBlank(row.NMPRODFIN) ? '' : row.NMPRODFIN;
        reportRow.P_IDSITUACAO = 'P';
        reportRow.P_IDBAIXEXOL = '_' + row.IDBAIXAAFENT.join('_') + '_';
        reportRow.P_IDBAIXEXSAI = '_' + row.IDBAIXAAFSAI.join('_') + '_';
        reportRow.P_PEDEXOLEXTR = row.PEDOLEXTR.length == 2 ? 'T' : row.PEDOLEXTR[0] === 'S' ? 'S' : 'N';
        reportRow.P_CDLOTENVITOL = row.TCDLOTENVITOL === 'S' ? 'S' : row.TCDLOTENVITOL === 'N' ? 'T' : row.TCDLOTENVITOL === 'L' ? Util.isEmptyOrBlank(row.CDLOTENVITOL) ? 'T' : '_' + row.CDLOTENVITOL.join('_') + '_' : 'T';
        reportRow.P_NRSEQRUPTURAOL = '';
        reportRow.P_TNRSEQRUPTURAOL = 'T';
        reportRow.STRATEGY = widget.currentRow.RELATORIO.split('.')[1];
        reportRow.__report_name = widget.currentRow.RELATORIO.split('.')[0];
        reportRow.reportLabel = widget.currentRow.RELATORIO.split('.')[0];
        reportRow.QR2TYPE = widget.currentRow.QR2TYPE;
        
        widget.reportRow = reportRow;
        
        if(widget.isValid()) {
            ServiceLancamentoPedidoOL.retornaCookieEmail().then(function(messages) {
                var cookies = messages.messages[0].message;
                
                widgetEmail.currentRow.NOME_ARQUIVO = cookies.shift();
                widgetEmail.currentRow.MENSAGEM = cookies.shift();
                widgetEmail.currentRow.ASSUNTO = cookies.shift();
                widgetEmail.currentRow.SENDOPERATOR = cookies.shift();
                widgetEmail.currentRow.EMAILS = cookies.shift();
                
                const promises = [
        		    MessageService.getMessageByCode("SUCCESS_MESSAGE"),
        		    MessageService.getMessageByCode("ERROR_MESSAGE"),
        		    MessageService.getMessageByCode("EMAIL_N_REGISTERED"),
        		    MessageService.getMessageByCode("EMAIL_SEND_SUCCESS"),
        		    MessageService.getMessageByCode("EMAIL_SEND_FAILED")
                ];
                
                Promise.all(promises).then((response) => {
                   const msgArray = {
                        'SUCCESS_MESSAGE': response.shift(),
                        'ERROR_MESSAGE': response.shift(),
                        'EMAIL_N_REGISTERED': response.shift(),
                        'EMAIL_SEND_SUCCESS': response.shift(),
            		    'EMAIL_SEND_FAILED': response.shift()
                    };
                
                    widgetEmail.currentRow.MSGARRAY = msgArray;
                });
                
                if(!widgetEmail.currentRow.NOME_ARQUIVO) {
                    widgetEmail.currentRow.NOME_ARQUIVO = "";
                }
                if(!widgetEmail.currentRow.EMAILS) {
                    widgetEmail.currentRow.EMAILS = "";
                }
                if(!widgetEmail.currentRow.MENSAGEM) {
                    widgetEmail.currentRow.MENSAGEM = "Envio de E-Mail Emissão de Pedidos OL";
                }
                if(!widgetEmail.currentRow.ASSUNTO) {
                    widgetEmail.currentRow.ASSUNTO = "Envio de E-Mail Emissão de Pedidos OL";
                }
                
                General.callRestEngine("opl_solicitacao#/getParametro", "Row", {}).then(function(response) {
                    reportRow.P_GERARESERVA = response.dataset.getParametro[0].IDUTILCONSSOLIOL;
                    
                    if(!Util.isEmptyOrBlank(reportRow.P_GERARESERVA) && reportRow.P_GERARESERVA == 'S') {
                        General.callRestEngine("opl_solicitacao#/getVdItem", "Row", reportRow).then(function(response) {
                            const arrayResult = response.dataset.data;
                            var prodsIncons = arrayResult[0];
                                
                            if(prodsIncons.length > 0) {
                                prodsIncons = validaProdsIncons(prodsIncons);
                                    
                                MessageService.confirmMessageByCode("INCONS_PROCESSO_EMISSAO").then(function(confirmed) {
                                    const inconsistWidget = templateManager.container.getWidget("inconsistenciaProdutosEmissaoWidget");
                                        
                                    inconsistWidget.dataSource.data = prodsIncons;
                                    inconsistWidget.reportRow = reportRow;
                                    
                                    ScreenService.openPopup(inconsistWidget);
                                        
                                    inconsistWidget.reload();
                                    inconsistWidget.activate();
                                }).catch(function(declined) {
                                    if(widget.isValid() && reportRow.STRATEGY) {
                                        if(opcao == 1) {
                                            General.openReportPopup(widget, self.openReport, [widget, reportRow, widget.currentRow.RELATORIO.split('.')[0]]);
                                        } else {
                                            ScreenService.openPopup(widgetEmail);
                                        }
                                    }
                                });
                            } else {
                                if(widget.isValid() && reportRow.STRATEGY) {
                                    if(opcao == 1) {
                                        General.openReportPopup(widget, self.openReport, [widget, reportRow, widget.currentRow.RELATORIO.split('.')[0]]);
                                    } else {
                                        ScreenService.openPopup(widgetEmail);
                                    }
                                }
                            }
                        }).catch(function(error) {
                            MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
                        });
                    } else {
                        General.callRestEngine("opl_solicitacao#/getVdItem", "Row", reportRow).then(function(response) {
                            const arrayResult = response.dataset.data;
                            var prodsIncons = arrayResult[0];
                                
                            if(prodsIncons.length > 0) {
                                prodsIncons = validaProdsIncons(prodsIncons);
                                    
                                MessageService.confirmMessageByCode("INCONS_PROCESSO_EMISSAO").then(function(confirmed) {
                                    const inconsistWidget = templateManager.container.getWidget("inconsistenciaProdutosEmissaoWidget");
                                        
                                    inconsistWidget.dataSource.data = prodsIncons;
                                    inconsistWidget.reportRow = reportRow;
                                        
                                    ScreenService.openPopup(inconsistWidget);
                                        
                                    inconsistWidget.reload();
                                    inconsistWidget.activate();
                                }).catch(function(declined) {
                                    if(widget.isValid() && reportRow.STRATEGY) {
                                        if(opcao == 1) {
                                            General.openReportPopup(widget, self.openReport, [widget, reportRow, widget.currentRow.RELATORIO.split('.')[0]]);
                                        } else {
                                            ScreenService.openPopup(widgetEmail);
                                        }
                                    }
                                });
                            } else {
                                if(widget.isValid() && reportRow.STRATEGY) {
                                    if(opcao == 1) {
                                        General.openReportPopup(widget, self.openReport, [widget, reportRow, widget.currentRow.RELATORIO.split('.')[0]]);
                                    } else {
                                        ScreenService.openPopup(widgetEmail);
                                    }
                                }
                            }
                        }).catch(function(error) {
                            MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
                        });
                    }
                }).catch(function(error) {
                    MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
                });
            }).catch(function(error) {
                MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
            });
        } else {
            MessageService.showMessageByCode("OBRIGATORY_FIELDS");
            ScreenService.closePopup();
        }
    };
    
    this.finalizaEmissaoIncons = function(widget) {
        const reportRow = widget.reportRow;
        const widgetEmissao = widget.getParent();
        const widgetEmail = templateManager.container.getWidget("enviaEmailEmissaoWidget");
        
        ScreenService.closePopup();
        
        if(widgetEmissao.isValid() && reportRow.STRATEGY) {
            if(opEmissao == 1) {
                General.openReportPopup(widgetEmissao, self.openReport, [widgetEmissao, reportRow, reportRow.reportLabel]);
            } else {
                ScreenService.openPopup(widgetEmail);
            }
        }
    };
    
    this.openReport = function(widget, row, reportName) {
        row.QR2TYPE = widget.currentRow.QR2TYPE;
        row.STRATEGY = widget.currentRow.RELATORIO.split('.')[1];
        
        if(row.QR2TYPE == "TXT") {
            if(row.P_GERARESERVA == 'S') {
                if(Util.isEmptyOrBlank(permissoesFinaisOperador)) {
                    if(Util.isEmptyOrBlank(permissoesGeraisOperador)) {
                        MessageService.confirmMessageByCode("BLOQUEAR_PEDIDOS").then(function(confirmed) {
                            General.callRestEngine("opl_solicitacao#/bloqueiaPedidoOL").then(function(response) {
                                General.openReport("opl_solicitacao#/sup07200_relatorio", reportName, row).then(success => {}).catch(error => {
                                    MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
                                });
                            }).catch(function(error) {
                                MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
                            });
                        }).catch(function(declined) {
                            General.openReport("opl_solicitacao#/sup07200_relatorio", reportName, row).then(success => {}).catch(error => {
                                MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
                            });
                        });
                    } else {
                        if(permissoesGeraisOperador.indexOf("SVOL") == -1) {
                            MessageService.confirmMessageByCode("BLOQUEAR_PEDIDOS").then(function(confirmed) {
                                General.callRestEngine("opl_solicitacao#/bloqueiaPedidoOL").then(function(response) {
                                    General.openReport("opl_solicitacao#/sup07200_relatorio", reportName, row).then(success => {}).catch(error => {
                                        MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
                                    });
                                }).catch(function(error) {
                                    MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
                                });
                            }).catch(function(declined) {
                                General.openReport("opl_solicitacao#/sup07200_relatorio", reportName, row).then(success => {}).catch(error => {
                                    MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
                                });
                            });
                        } else {
                            MessageService.showMessageByCode("OPER_BLOCK");
                        }
                    }
                } else {
                    if(permissoesGeraisOperador.indexOf("SVOL") != -1 && permissoesFinaisOperador.indexOf("SVOL") != -1) {
                        MessageService.confirmMessageByCode("BLOQUEAR_PEDIDOS").then(function(confirmed) {
                            General.callRestEngine("opl_solicitacao#/bloqueiaPedidoOL").then(function(response) {
                                General.openReport("opl_solicitacao#/sup07200_relatorio", reportName, row).then(success => {}).catch(error => {
                                    MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
                                });
                            }).catch(function(error) {
                                MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
                            });
                        }).catch(function(declined) {
                            General.openReport("opl_solicitacao#/sup07200_relatorio", reportName, row).then(success => {}).catch(error => {
                                MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
                            });
                        });
                    } else {
                        MessageService.showMessageByCode("OPER_BLOCK");
                    }
                }
            } else {
                General.openReport("opl_solicitacao#/sup07200_relatorio", reportName, row).then(success => {}).catch(error => {
                    MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
                });
            }
        } else {
            General.openReport("opl_solicitacao#/sup07200_relatorio", reportName, row).then(success => {}).catch(error => {
                MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
            });
        }
    };
    
    this.prodQtdeInlineChange = function(widget) {
        const adicionaNovoPedidoWidget = templateManager.container.getWidget("adicionaNovoPedido");
        
        adicionaNovoPedidoWidget.enabled = false;
    };
    
    this.prodQtdeInlineCancel = function(widget) {
        const adicionaNovoPedidoWidget = templateManager.container.getWidget("adicionaNovoPedido");
        
        adicionaNovoPedidoWidget.enabled = true;
        
        widget.rollbackInlineEdit();
        widget.list();
    };
    
    this.prodQtdeInlineSave  = function(widget) {
        const adicionaNovoPedidoWidget = templateManager.container.getWidget("adicionaNovoPedido");
        
        adicionaNovoPedidoWidget.enabled = true;
        
        widget.commitInlineEdit();
        widget.list();
    };
    
    this.onChangeQtdeInline = function(widget) {
        const widgetDetalhesPedido = templateManager.container.getWidget("detalhesPedido");
        const widgetDadosPedido = templateManager.container.getWidget("dadosPedido");
        
        widgetDadosPedido.setEnabled(false);
        widgetDetalhesPedido.setEnabled(false);
        widget.showCheckbox = false;
    };
    
    this.onCancelInlineEdit = function(widget) {
        const widgetDetalhesPedido = templateManager.container.getWidget("detalhesPedido");
        const widgetDadosPedido = templateManager.container.getWidget("dadosPedido");
        
        if(widget.currentRow.NRPEDEXOL) {
            widgetDadosPedido.enabled = true;
            widgetDetalhesPedido.enabled = true;
        }
        
        widget.showCheckbox = true;
        widget.rollbackInlineEdit();
        widget.list();
    };
    
    this.onSaveInlineEdit = function(widget) {
        const widgetDetalhesPedido = templateManager.container.getWidget("detalhesPedido");
        const widgetDadosPedido = templateManager.container.getWidget("dadosPedido");
        const changedRows = widget.dataSource.data.filter(row => {
            return (row.changed === true);
        });
        const rowsLiberadas = widget.dataSource.data.filter(row => {
            return (row.changed === true && (row.IDBAIXEXOL == null || row.IDBAIXEXOL == 0 || row.IDBAIXEXOL == 1) && (row.IDBAIXENPEOL == null || row.IDBAIXENPEOL == 0 || row.IDBAIXENPEOL == 1));
        });
        
        if(rowsLiberadas.length == changedRows.length) {
            MessageService.confirmMessageByCode("QTPROGENPEOL_DELETE_ZERO").then(function(confirmed) {
                rowsLiberadas.forEach(row => {
                   row.NEW_QTPROGENPEOL = row.QTPROGENPEOL_inline;
                   row.OLD_QTPROGENPEOL = row.changed_QTPROGENPEOL;
                   row.CDFILDEST = row.CDFILDEST.substr(0, 4);
                   row.DTPROGENPEOL = moment(row.DTPROGENPEOL, "DD/MM/YYYY").format("DD/MM/YYYY");
                });
                
                General.callRestEngine("opl_solicitacao#/alteraQuantidadeItemPedidoOLInline", "Row", rowsLiberadas).then(function(response) {
                    if(widget.currentRow.NRPEDEXOL) {
                        widgetDadosPedido.enabled = true;
                        widgetDetalhesPedido.enabled = true;
                    }
                    
                    widget.showCheckbox = true;
                    widget.commitInlineEdit();
                    widget.list();
                    widget.reload();
                    widget.activate();
                    
                    MessageService.showMessageByCode("QTPROGENPEOL_EDIT_SUCCESS");
                }).catch(function(error) {
                    if(widget.currentRow.NRPEDEXOL) {
                        widgetDadosPedido.enabled = true;
                        widgetDetalhesPedido.enabled = true;
                    }
                    
                    widget.showCheckbox = true;
                    widget.rollbackInlineEdit();
                    widget.list();
                    
                    MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
                });
            });
        } else {
            MessageService.showMessageByCode("ONLY_EMABERTO_PARCIAL_ITENS_PEDIDO_EDIT");
            
            if(widget.currentRow.NRPEDEXOL) {
                widgetDadosPedido.enabled = true;
                widgetDetalhesPedido.enabled = true;
            }
            
            widget.showCheckbox = true;
            widget.rollbackInlineEdit();
            widget.list();
        }
    };
    
    this.cancelaNovoItemPedido = function(widget) {
        MessageService.confirmMessageByCode("CANCEL_NOVO_ITEM_PEDIDO").then(function(confirmed) {
            ScreenService.closeSwipe();
            widget.getParent().activate();
            widget.getParent().list();
        });
    };
    
    this.realizaCalculoPorcentagens = function(widgetAltAutomaticaProd, cdProdutoOld) {
        const fieldAjusteUnidade = widgetAltAutomaticaProd.getField('AJUSTE_UNIDADE');
        const fieldAjusteQuantidade = widgetAltAutomaticaProd.getField('AJUSTE_QUANTIDADE');
        const row = {
            "CDPRODUTO_OLD": cdProdutoOld,
            "CDARVPROD": widgetAltAutomaticaProd.currentRow.CDARVPROD
        };
        
        return General.callRestEngine("opl_solicitacao#/calcularAjustesProduto", "Row", row).then(function(response) {
            const ajustes = response.dataset.data[0];
            
            if(!Util.isEmptyOrBlank(ajustes.AJUSTEUN)) {
                if(ajustes.AJUSTEUN == 0 || ajustes.AJUSTEUN == null) {
                    fieldAjusteUnidade.setValue('0');
                } else {
                    fieldAjusteUnidade.setValue(ajustes.AJUSTEUN);
                }
                fieldAjusteUnidade.reload();
            } else {
                fieldAjusteUnidade.setValue('0');
            }
            
            if(!Util.isEmptyOrBlank(ajustes.AJUSTEQTDE)) {
                if(ajustes.AJUSTEQTDE == 0 || ajustes.AJUSTEQTDE == null) {
                    fieldAjusteQuantidade.setValue('0');
                } else {
                    fieldAjusteQuantidade.setValue(ajustes.AJUSTEQTDE);
                }
                fieldAjusteQuantidade.reload();
            } else {
                fieldAjusteQuantidade.setValue('0');
            }
            
            fieldAjusteUnidade.reload();
    		fieldAjusteQuantidade.reload();
        }).catch(function(error) {
            MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
        });
    };
    
    this.verificaProduto = function(field) {
        const widget = field.widget;
        const widgetGrid = widget.getParent();
        const checkedRowsGrid = widgetGrid.getCheckedRows();
        
        if(!Util.isEmptyOrBlank(widget.currentRow.CDARVPROD)) {
            for(let i = 0; i < checkedRowsGrid.length; i++) {
                if(checkedRowsGrid[i].CDARVPROD === widget.currentRow.CDARVPROD) {
                    MessageService.showMessageByCode("NEW_PRODUCT_PRODUCT_ORIGIN");
                    field.clearValue();
                    return;
                }
            }
            this.realizaCalculoPorcentagens(widget, checkedRowsGrid[0].CDARVPROD);
        } else {
            widget.currentRow.AJUSTE_UNIDADE = '0';
            widget.currentRow.AJUSTE_QUANTIDADE = '0';
        }
    };
    
    this.enviaEmail = function(widget) {
        widget.currentRow.MSGOPL = "Email automático enviado pelo Operador Logístico";
        widget.currentRow.MSGDATESENT = "Disponilizado em: ";
        widget.currentRow.DSLINK = "Clique aqui para visualizar o Relatório";
        
        const reportRow = widget.getParent().reportRow;
        const row = {
            "DADOS_EMAIL": widget.currentRow,
            "CURRENT_ROW": reportRow
        };
        
        if(widget.currentRow.EXTENSAO == "TXT") {
            if(reportRow.P_GERARESERVA == 'S') {
                if(Util.isEmptyOrBlank(permissoesFinaisOperador)) {
                    if(Util.isEmptyOrBlank(permissoesGeraisOperador)) {
                        MessageService.confirmMessageByCode("BLOQUEAR_PEDIDOS").then(function(confirmed) {
                            General.callRestEngine("opl_solicitacao#/bloqueiaPedidoOL").then(function(response) {
                                if(widget.isValid()) {
                                    ServiceLancamentoPedidoOL.enviaEmailEmissao(row).then(function(success) {
                                        exibeLogEmail(widget, success.messages, false);
                                    }).catch(function(error) {
                                        MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
                                    });
                                }
                            }).catch(function(error) {
                                MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
                            });
                        }).catch(function(declined) {
                            if(widget.isValid()) {
                                ServiceLancamentoPedidoOL.enviaEmailEmissao(row).then(function(success) {
                                    exibeLogEmail(widget, success.messages, false);
                                }).catch(function(error) {
                                    MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
                                });
                            }
                        });
                    } else {
                        if(permissoesGeraisOperador.indexOf("SVOL") == -1) {
                            MessageService.confirmMessageByCode("BLOQUEAR_PEDIDOS").then(function(confirmed) {
                                General.callRestEngine("opl_solicitacao#/bloqueiaPedidoOL").then(function(response) {
                                    if(widget.isValid()) {
                                        ServiceLancamentoPedidoOL.enviaEmailEmissao(row).then(function(success) {
                                            exibeLogEmail(widget, success.messages, false);
                                        }).catch(function(error) {
                                            MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
                                        });
                                    }
                                }).catch(function(error) {
                                    MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
                                });
                            }).catch(function(declined) {
                                if(widget.isValid()) {
                                    ServiceLancamentoPedidoOL.enviaEmailEmissao(row).then(function(success) {
                                        exibeLogEmail(widget, success.messages, false);
                                    }).catch(function(error) {
                                        MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
                                    });
                                }
                            });
                        } else {
                            MessageService.showMessageByCode("OPER_BLOCK");
                        }
                    }
                } else {
                    if(permissoesGeraisOperador.indexOf("SVOL") != -1 && permissoesFinaisOperador.indexOf("SVOL") != -1) {
                        MessageService.confirmMessageByCode("BLOQUEAR_PEDIDOS").then(function(confirmed) {
                            General.callRestEngine("opl_solicitacao#/bloqueiaPedidoOL").then(function(response) {
                                if(widget.isValid()) {
                                    ServiceLancamentoPedidoOL.enviaEmailEmissao(row).then(function(success) {
                                        exibeLogEmail(widget, success.messages, false);
                                    }).catch(function(error) {
                                        MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
                                    });
                                }
                            }).catch(function(error) {
                                MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
                            });
                        }).catch(function(declined) {
                            if(widget.isValid()) {
                                ServiceLancamentoPedidoOL.enviaEmailEmissao(row).then(function(success) {
                                    exibeLogEmail(widget, success.messages, false);
                                }).catch(function(error) {
                                    MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
                                });
                            }
                        });
                    } else {
                        MessageService.showMessageByCode("OPER_BLOCK");
                    }
                }
            } else {
                if(widget.isValid()) {
                    ServiceLancamentoPedidoOL.enviaEmailEmissao(row).then(function(success) {
                        exibeLogEmail(widget, success.messages, false);
                    }).catch(function(error) {
                        MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
                    });
                }
            }
        } else {
            if(widget.isValid()) {
                ServiceLancamentoPedidoOL.enviaEmailEmissao(row).then(function(success) {
                    exibeLogEmail(widget, success.messages, false);
                }).catch(function(error) {
                    MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
                });
            }
        }
    };
    
    function exibeLogEmail(widget, success, isGroup) {
        const widgetOrigem = templateManager.container.getActiveWidget();
        const arrayMesssages = widget.currentRow.MSGARRAY;
        let arrayError = [];
        let arraySuccess = [];
        let arrayLogs = [];
        let addHeadSuccess = true;
        let addHeadError = true;
        
        success.forEach(function(row) {
            const logSuccess = row.message.SUCCESS;
            const logError = row.message.ERROR;
        
			if(!Util.isEmptyOrBlank(logSuccess)) {
			    if(addHeadSuccess) {
				    addHeadSuccess = false;
				    arraySuccess = arraySuccess.concat(setArrayLog(logSuccess, arrayMesssages));
				    adicionaCabecalhoAoLog(arraySuccess, arrayMesssages.SUCCESS_MESSAGE);
			    } else {
			        arraySuccess = arraySuccess.concat(setArrayLog(logSuccess, arrayMesssages));
			    }
			}
			
			if(!Util.isEmptyOrBlank(logError)) {
			    if(addHeadError) {
				    addHeadError = false;
				    arrayError = arrayError.concat(setArrayLog(logError, arrayMesssages));
				    adicionaCabecalhoAoLog(arrayError, arrayMesssages.ERROR_MESSAGE);
			    } else {
			        arrayError = arrayError.concat(setArrayLog(logError, arrayMesssages));
			    }
			}
        });

        arrayLogs = arrayError.concat(arraySuccess);
        ScreenService.closePopup();
        General.showErrorMessages(widgetOrigem, arrayLogs, ScreenService.i18n('Log'));
    }
    
    function adicionaCabecalhoAoLog(logArray, titulo) {
        logArray.unshift('----------------------------');
        logArray.unshift(titulo);
        logArray.unshift('----------------------------');
    }
    
    function setArrayLog(messages, arrayMesssages) {
        let result = [];
        
        messages.forEach(row => {
    		result.push(arrayMesssages[row.MESSAGE]);
		});
		
		return result;
    }
    
    this.changeFilterProduct = function(field) {
        field.dataSourceFilter.forEach(function(row) {
            if(row.name == "P_CDFILIOPELOG") {
                row.value = CDFILIOPELOGPROD;
            }
        });
        
        field.reload();
    };
    
    function verificaPermissaoItem(widget, item) {
        if(Util.isEmptyOrBlank(permissoesFinaisOperador)) {
            if(Util.isEmptyOrBlank(permissoesGeraisOperador)) {
                return true;
            } else {
                if(permissoesGeraisOperador.indexOf("BLOL") != -1) {
                    if(item.IDITMPEDOLBLOQ == 'S') {
                        return false;
                    } else {
                        return true;
                    }
                } else {
                    return true;
                }
            }
        } else {
            if(Util.isEmptyOrBlank(permissoesGeraisOperador)) {
                return true;
            } else {
                if(permissoesGeraisOperador.indexOf("BLOL") != -1 && permissoesFinaisOperador.indexOf("BLOL") != -1) {
                    return true;
                } else {
                    if(item.IDITMPEDOLBLOQ == 'S') {
                        return false;
                    } else {
                        return true;
                    }
                }
            }
        }
    }
    
    this.onFieldInlineEdit = function(widget, args) {
        if(!verificaPermissaoItem(widget, args.row)) {
            MessageService.showMessageByCode("OPER_BLOCK");
            widget.rollbackInlineEdit();
            widget.list();
            widget.reload();
            widget.showCheckbox = true;
        }
    };
    
    this.clearProduto = function(widget) {
        widget.getField("NMPRODUTO").clearValue();
        widget.getField("NMPRODUTO").reload();
    };
    
    this.validaSegMercadoProdFili = function(field) {
        ScreenService.showLoader();
        
        var row = {};
        
        
        if(field.widget.name == "adicionaItemPedido") {
            row.CDFILDEST = field.widget.currentRow.CDFILDEST;
        } else {
            field.dataSourceFilter.forEach(f => {
                if(f.name == "CDFILIAL")
                    row.CDFILDEST = f.value;
            });
        }
        
        
        row.CDARVPROD = field.widget.currentRow.CDARVPROD;
        
        if(!Util.isEmptyOrBlank(row.CDARVPROD)) {
            General.callRestEngine("opl_solicitacao#/validaSegMercadoProdFili", "Row", row).then(function(response) {
                ScreenService.hideLoader();
            }).catch(function(error) {
                ScreenService.hideLoader();
                
                if(error.data.error == "PRODUTO_NOT_SEGMERCADO" || error.data.error == "PRODUTO_NOT_PRODFILI_ATIVO") {
                    MessageService.showMessageByCode(error.data.error);
                } else {
                    MessageService.showMessageByCode("ERR_GENERICO", { "PARAM": error.data.error });
                }
                
                field.clearValue();
            });
        } else {
            ScreenService.hideLoader();
        }
    };
}

Configuration(function(ContextRegister) {
    ContextRegister.register("Sup07200_lancamento_de_pedidos_Controller", Sup07200_lancamento_de_pedidos_Controller);
});

// FILE: ./assets/modules/consolidacao/assets/modules/solicitacao/assets/js/controllers/sup07800DataDeEmbarqueOperadorLogisticoController.js
function sup07800DataDeEmbarqueOperadorLogisticoController(ScreenService, templateManager, ZhFilterPreferences, ZHPromise, General, restEngine, MessageService) {
    
    //Armazena a OL selecionada através do campo Operador Logistico 
	var var_CDFILIOPELOG;
	var var_OL;
	var var_NMFILIAL;
	var var_new_CDFILIOPELOG;
	
    //Abre o filtro
	this.openFilter = function(widget) {
    	ScreenService.showLoader();
        var rowsToSet = {};
		ZhFilterPreferences.openFilterWidget(widget, rowsToSet).then(opened => {
			ScreenService.hideLoader();
		}).catch(error => {
			ScreenService.hideLoader();
		});
    };
    
	//Abre a tela para adicionar um novo OPL
	this.addOPL = function(widget){
	    widget.newRow();
	    widget.getField("OL").readOnly = true;
	    widget.currentRow.OL = var_OL;
	    widget.currentRow.NMFILIAL = var_NMFILIAL;
	    widget.currentRow.CDFILIOPELOG = var_new_CDFILIOPELOG;
	    widget.getField("CDFILIAL").reload();
	};
    
    //Salva a edição do Numero de dias
    this.saveInLineEdit = function(widget, dataSet, name){
        //Salva os registros modificados 
        restEngine.post("opl_solicitacao#/crud/"+name+"/save", {
            "requestType": "DataSet",
            "dataset": dataSet
        }).then(sucesso => {
                widget.activate();
                widget.list();
                widget.reload();
                ScreenService.successNotification("Alteração salva com sucesso.");
            }, error => {
                ScreenService.successNotification("Erro ao salvar alteração.");
            }
		);
	};
	
	//Salva um novo OPL
	this.saveCrud = function(args) {
	    //Refereencia ao widget
	    var widget = args.owner.widget;
        //Armazena o template 
        var template = templateManager.container.getWidget('gridDatadeembarqueOperadorlogísticoWidget');
        //Adiciona o CDFILIOPELOG na array "dataSet"
        args.row.CDFILIOPELOG = var_new_CDFILIOPELOG;
        //Se os campos do formulário forem preenchidos
        if(args.row.CDFILIOPELOG !== '' && args.row.CDFILIAL && args.row.NMPRODUTO !== '' && args.row.IDSOMENTEUTIL !== '' && args.row.NRDIAEMBARQUE !== '' 
        ){
            //Armazena os dados
            let arrayPromisses = [];
            let arrayFiliaisFails = [];
            let arrayFiliaisSuccess = [];
            let arrayFiliais = widget.currentRow.CDFILIAL;
    		ScreenService.showLoader();
            //Passa por cada filial
            arrayFiliais.forEach(filial => {
                //Armazena os dados a serem salvos
                let dataSet = {"data" : 
                    {
                        "CDARVPROD" : args.row.CDARVPROD,
                        "CDFILIOPELOG" : args.row.CDFILIOPELOG,
                        "CDPRODUTO" : args.row.CDPRODUTO,
                        "NRDIAEMBARQUE" : args.row.NRDIAEMBARQUE,
                        "IDSOMENTEUTIL" : args.row.IDSOMENTEUTIL,
                        "__is_new": true
                    }
                };
                //Adiciona a filial na array
                dataSet.data.CDFILIAL = filial;
                //Salva o registro
                arrayPromisses.push(
                    restEngine.post("opl_solicitacao#/crud/dataembarqueol/save", {
                        "requestType": "Row",
                        "row": dataSet.data
                    }).then( function (data) {
                        arrayFiliaisSuccess.push(filial);
                    }, function(error){
                        arrayFiliaisFails.push(filial);
                    })
                );
            });
            //Se o foreach terminou
            ZHPromise.all(arrayPromisses).then(function(){
                //Ordena as arrays em ordem crescente
                arrayFiliaisFails = arrayFiliaisFails.sort((a, b) => a - b);
                //Concatena os itens da array
                let filialFail = arrayFiliaisFails.join();
                //Mensagem para exibir os dados com sucesso ou falha na adição        
                let message = "Não foi possível adicionar Data de Embarque para a(s) Unidade(s) abaixo. <br><br>" + filialFail.toString();
                //Se foi selecionada apenas uma unidade e a mesma já existir no DB
                if (arrayFiliaisFails.length === 1 && arrayFiliaisSuccess.length === 0) {
                    //Se o registro já existe
                    ScreenService.errorNotification("O registro já existe.");
                } else if (arrayFiliaisFails.length === arrayPromisses.length) {
                    //Se todos os registros já existem
                    ScreenService.errorNotification("Já existem dados cadastrados com o mesmo produto para todas Unidades selecionadas.");
                } else {
                    //Retorna resposta ao usuário
                    ScreenService.closeSwipe().then(function () {
                        //Retorna mensagem 
                        if(arrayFiliaisFails.length >= 1){
                            ScreenService.showMessage(message);   
                        }
                        template.reload();
                        widget.activate();
                        widget.list();
                        ScreenService.successNotification("Data de Embarque adicionada com sucesso.");
                    });    
                } 
            });
            ScreenService.hideLoader();
        } else {
            //Verifica se o widget é válido
            widget.isValid();
        }
	};

    //Retorna os dados necessários para execução do filtro do campo UNIDADE
    this.getFieldValueFilter = function(fieldName, widgetName) {
        var container =  templateManager.container;
        if(container) {
            var filterWidget;
            var filterBeforeApply = templateManager.container.getActiveWidget();
            
            //test about how widget is... (field or filter)
    	    if(filterBeforeApply.label != 'Filtro'){		
    		    filterBeforeApply = filterBeforeApply.lastActiveWidget;
                filterWidget = filterBeforeApply;
                
            }
            if(filterBeforeApply.name == 'zhFilterPreferencesSelectConditions') {
            	filterWidget = filterBeforeApply;
            }
            else {
                var f = container.getWidget(widgetName);
                if(f) {
                     filterWidget = container.getWidget(widgetName).appliedFilter;
                }
            }
            // Insert values
            if(filterWidget) {
                var valueField;
                if(filterBeforeApply.name == 'zhFilterPreferencesSelectConditions')
                    valueField = filterWidget.currentRow[fieldName];
                else
                    valueField = filterWidget.FILTER_ROW[fieldName];
                return valueField || null;
            }
            else return null;
        }
        else return null;
    };
    
	//Busca o valor da OL Selecionada
    this.getOLSelecionada = function(args) {
        var_CDFILIOPELOG = args.owner.owner.widget.currentRow.CDFILIAL;
    };
    
    //Busca os dados da OL selecionada
    this.getDataOLFiltered = function(args) {
        var widget = args.owner.owner.widget;
        var_OL = widget.currentRow.OL;
        var_NMFILIAL = widget.currentRow.NMFILIAL;  
        var_new_CDFILIOPELOG = widget.currentRow.CDFILIAL;
    };
    
	//Retorna o valor da OL Selecionada para o dataSourceFilter
    this.getOLForFilterUnidade = function() {
        return var_new_CDFILIOPELOG;
    };
    
    //Seta o filtro a trazer os dados para o grid
    this.setDataSourceFilter = function (args) {
        const widget = templateManager.container.getWidget('gridDatadeembarqueOperadorlogísticoWidget');
        const row = args.e.preference.FILTER_ROW;
        widget.dataSourceFilter = [
            {
                "name": "P_CDREGIAO",
                "operator": "=",
                "value": this.concatArrayForParams(row.CDREGIAO, 'T')
                
            },
            {
                "name": "P_CDFILIAL",
                "operator": "=",
                "value": this.concatArrayForParams(row.CDFILIALUN, 'T')
                
            },
            {
                "name": "P_CDPRODINI",
                "operator": "=",
                "value": row.CDARVPRODINI
            },
            {
                "name": "P_CDPRODFIN",
                "operator": "=",
                "value": row.CDARVPRODFIN
            },
            {
                "name": "P_CDFILIOPELOG",
                "operator": "=",
                "value": row.CDFILIAL
            }
        ];
        widget.reload();
    };
    
    //Limpa os campos do filtro ao selecionar o OPERADOR LÓGISTICO
    this.clearFilterFields = function(args) {
        var widget = args.owner.owner.widget;
		ScreenService.showLoader();
		//Se a OL selecionada for diferente da anterior selecionada ou vazio... apaga o formulário
		if (var_CDFILIOPELOG !== widget.currentRow.CDFILIAL) {
    		if (widget.name === 'zhFilterPreferencesSelectConditions') {
    		    setTimeout(() => {
    		        widget.currentRow.REGIAO = "";
    		        widget.currentRow.CDREGIAO = "";
    		        widget.currentRow.NMREGIAO = "";
    		        widget.getField('REGIAO').clearValue();
    	            widget.currentRow.UNIDADE = "";
    		        widget.currentRow.CDFILIALUN = "";
    		        widget.currentRow.NMFILIALUN = "";
    		        widget.getField('UNIDADE').clearValue();
                    widget.currentRow.NMPRODUTOINI = "";
                    widget.currentRow.CDARVPRODINI = "";
                    widget.currentRow.CDPRODINI = "";
                    widget.getField('NMPRODUTOINI').clearValue();
                    widget.currentRow.NMPRODUTOFIN = "";
                    widget.currentRow.CDARVPRODFIN = "";
                    widget.currentRow.CDPRODFIN = "";
                    widget.getField('NMPRODUTOFIN').clearValue();
    		    }, 200);
    		}
		}
		//Busca os dados da OL selecionada
		this.getDataOLFiltered(args);
        ScreenService.hideLoader();
    };
    
    //Limpa o campo UNIDADE ao alterr o campo REGIÃO
    this.clearFieldUnidade = function(args) {
        var widget = args.owner.owner.widget;
        ScreenService.showLoader();
	    setTimeout(() => {
            widget.currentRow.UNIDADE = "";
	        widget.currentRow.CDFILIALUN = "";
	        widget.currentRow.NMFILIALUN = "";
	        widget.getField('UNIDADE').clearValue();
	    }, 200);
        ScreenService.hideLoader();
    };
    
    //Exclui a linhas selecionadas na listagem
	this.deleteCrudCheckedRows = function(widget) {
        var deferred = ZHPromise.defer();
        MessageService.confirmMessageByCode("CONFIRMA_EXCLUSAO_ITENS").then(function(confirmed) {
            widget.removeCheckedRows().then(function () {
                widget.reload();
                widget.unSelectAll();
                deferred.resolve();
            }, function (error) {
                ScreenService.showMessage(error.data.error);
                deferred.reject();
            });
        });
        return deferred.promise;
    };
    
    // Desabilita ou Habilita as actions de acordo com a aplicação do filtro
    this.changeActionsVisible = function(widget) {
        widget.actions.forEach(action => action.isVisible = widget.appliedFilter? true:false);
    };
    
    //Altera o label concatenando com o operador logistico selecionado no filtro
    this.setLabelOPL = function(args){
        args.label = "Data de Embarque - " + var_OL; 
    };
    
    //Concatenação de parametros
    this.concatArrayForParams = function(arr, defaultValue) {
        return !Util.isEmptyOrBlank(arr) ? arr.join('_') : defaultValue;
    };
   
}

 Configuration(function(ContextRegister) {
    ContextRegister.register("sup07800DataDeEmbarqueOperadorLogisticoController", sup07800DataDeEmbarqueOperadorLogisticoController);
});
